@@ -40,6 +40,8 @@ import matplotlib.patches as mpatches
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 
+from pygmi.misc import ContextModule
+
 
 class MyMplCanvas(FigureCanvasQTAgg):
     """
@@ -87,14 +89,14 @@ class MyMplCanvas(FigureCanvasQTAgg):
         usgs = xl.parse('USGS')
         cgs = xl.parse('CGS')
         cgslookup = xl.parse('250K Lookup')
-        colors = xl.parse('Colors')
+        colours = xl.parse('Colours')
         xl.close()
 
         usgs = usgs.set_index('code').to_dict()['description']
         cgslookup['COLOR_CODE'] = cgslookup['COLOR_CODE'].astype(str)
         cgslookup['COLOR_CODE'] = cgslookup['COLOR_CODE'].apply('{0:0>3}'.format)
         stratcol = cgslookup.set_index('LITHO_NAME').to_dict()['COLOR_CODE']
-        col = colors.set_index('code').to_dict()['color']
+        col = colours.set_index('code').to_dict()['colour']
         clith = cgs.set_index('lithology').to_dict()['lithology description']
         cgs = cgs.set_index('lithology').to_dict()['code']
         col['none'] = 'ffffff'
@@ -107,7 +109,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
             if np.isnan(cgs[i]):
                 hatch[i] = [[], []]
                 continue
-            svgfile = idir + '\\images\\' + str(int(cgs[i]))+'.svg'
+            svgfile = idir + '\\' + str(int(cgs[i]))+'.svg'
             pverts, pcodes = gethatch(svgfile)
             hatch[i] = [pverts, pcodes]
 
@@ -179,8 +181,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
             if strat[j] == 'none':
                 ax.text(19.2, j*2+1.9, strat[j].capitalize())
             else:
-                ax.text(19.2, j*2+1.9, strat[j].capitalize() + ' ' +
-                        rlookup[rank[j]])
+                ax.text(19.2, j*2+1.9,
+                        strat[j].capitalize()+' '+rlookup[rank[j]])
 
         self.figure.canvas.draw()
 
@@ -203,18 +205,14 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ax = fig.gca()
         fig.subplots_adjust(top=0.995)
         fig.subplots_adjust(bottom=0.005)
-        # fig.subplots_adjust(left=0.005)
-        # fig.subplots_adjust(right=0.25)
         fig.subplots_adjust(left=0.01)
         fig.subplots_adjust(right=0.3)
 
         idir = __file__.rpartition('\\')[0]
         logfile = idir+'\\logplot.xlsx'
 
-        # pagewidth = 8
         pageheight = 8
         dpp = 25  # depth per page
-        # wpp = dpp*pagewidth/pageheight
         fontsize = 10
         dpi = (fontsize/72)*(dpp/pageheight)
 
@@ -224,15 +222,14 @@ class MyMplCanvas(FigureCanvasQTAgg):
         usgs = xl.parse('USGS')
         cgs = xl.parse('CGS')
         cgslookup = xl.parse('250K Lookup')
-        colors = xl.parse('Colors')
+        colours = xl.parse('Colours')
         xl.close()
 
         usgs = usgs.set_index('code').to_dict()['description']
         cgslookup['COLOR_CODE'] = cgslookup['COLOR_CODE'].astype(str)
         cgslookup['COLOR_CODE'] = cgslookup['COLOR_CODE'].apply('{0:0>3}'.format)
         stratcol = cgslookup.set_index('LITHO_NAME').to_dict()['COLOR_CODE']
-        col = colors.set_index('code').to_dict()['color']
-        # clith = cgs.set_index('lithology').to_dict()['lithology description']
+        col = colours.set_index('code').to_dict()['colour']
         cgs = cgs.set_index('lithology').to_dict()['code']
         col['none'] = 'ffffff'
         col['nan'] = 'ffffff'
@@ -244,7 +241,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
             if np.isnan(cgs[i]):
                 hatch[i] = [[], []]
                 continue
-            svgfile = idir + '\\images\\' + str(int(cgs[i]))+'.svg'
+            svgfile = idir + '\\' + str(int(cgs[i]))+'.svg'
             pverts, pcodes = gethatch(svgfile)
             hatch[i] = [pverts, pcodes]
 
@@ -257,7 +254,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         lithd = np.array(df['Lithology description'].replace(np.nan, ''))
         lith = np.array(df['Lithology'])
         strat = np.array(df['Stratigraphy'].replace(np.nan, 'none'))
-        # rank = np.array(df['Rank'].replace(np.nan, 'none'))
 
         hcompanyno = hdf['Companyno'].iloc[0]
         indx = np.nonzero(companyno == hcompanyno)[0]
@@ -280,11 +276,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
                 if depthfrom[indx][i] != depthfrom[indx][i+1]:
                     yfin = lithdpos[i] - dpi*(1+lithd[i].count('\n'))*1.4
     # Start creating plots
-        #     pdf = PdfPages(odir+chkname(hrow['Companyno']+'.pdf'))
-        # fig.set_figheight(pageheight*numpages)
-        # fig.set_figwidth(pagewidth)
-
-        # ax.set_xlim((0, wpp))
         ax.set_ylim((-dpp*numpages, 0.))
         ax.set_aspect('equal')
         ax.get_xaxis().set_visible(False)
@@ -331,80 +322,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
             ax.hlines(dto, 0, 4)  # Bottom of log
 
         self.figure.canvas.draw()
-        # self.figure.tight_layout()
 
 
-class GraphWindow(QtWidgets.QDialog):
-    """
-    Graph Window.
-
-    Attributes
-    ----------
-    parent : parent
-        reference to the parent routine
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-        self.parent = parent
-
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Borehole Log')
-
-        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
-        hbl1 = QtWidgets.QHBoxLayout()
-        hbl2 = QtWidgets.QHBoxLayout()
-        self.hbl = QtWidgets.QHBoxLayout()
-        self.mmc = MyMplCanvas(self)
-        self.mmc2 = MyMplCanvas(self)
-        # mpl_toolbar = NavigationToolbar(self.mmc, self.parent)
-        # self.mmc.setFixedHeight(3000)
-        self.label_topleft = QtWidgets.QLabel()
-        self.label_topright = QtWidgets.QLabel()
-        self.label_bottomleft = QtWidgets.QLabel()
-        self.label_bottomright = QtWidgets.QLabel()
-        self.label_topright.setAlignment(QtCore.Qt.AlignRight |
-                                         QtCore.Qt.AlignVCenter)
-        self.label_bottomright.setAlignment(QtCore.Qt.AlignRight |
-                                            QtCore.Qt.AlignVCenter)
-
-        self.scroll = QtWidgets.QScrollArea(self)
-        self.scroll.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
-        self.scroll.setWidget(self.mmc)
-
-        self.combobox1 = QtWidgets.QComboBox()
-        self.label1 = QtWidgets.QLabel('Borehole ID:')
-        self.hbl.addWidget(self.label1)
-        self.hbl.addWidget(self.combobox1)
-
-        hbl1.addWidget(self.label_topleft)
-        hbl1.addWidget(self.label_topright)
-        hbl2.addWidget(self.label_bottomleft)
-        hbl2.addWidget(self.label_bottomright)
-        vbl.addLayout(hbl1)
-        vbl.addWidget(self.scroll)
-        vbl.addLayout(hbl2)
-        vbl.addWidget(self.mmc2)
-        # vbl.addWidget(mpl_toolbar)
-        vbl.addLayout(self.hbl)
-
-        self.setFocus()
-
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        # self.combobox2.currentIndexChanged.connect(self.change_band)
-
-    def change_band(self):
-        """
-        Combo box to change band.
-
-        Returns
-        -------
-        None.
-
-        """
-
-
-class PlotLog(GraphWindow):
+class PlotLog(ContextModule):
     """
     Plot Log Class.
 
@@ -416,14 +336,59 @@ class PlotLog(GraphWindow):
 
     def __init__(self, parent=None):
         super().__init__(parent)
-        # self.label2.hide()
-        # self.combobox2.hide()
-        self.indata = {}
-        self.parent = parent
+
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Borehole Log')
+
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        hbl_1 = QtWidgets.QHBoxLayout()
+        hbl_2 = QtWidgets.QHBoxLayout()
+        self.hbl = QtWidgets.QHBoxLayout()
+        self.mmc = MyMplCanvas(self)
+        self.mmc2 = MyMplCanvas(self)
+
+        self.lbl_topleft = QtWidgets.QLabel()
+        self.lbl_topright = QtWidgets.QLabel()
+        self.lbl_bottomleft = QtWidgets.QLabel()
+        self.lbl_bottomright = QtWidgets.QLabel()
+        self.lbl_topright.setAlignment(QtCore.Qt.AlignRight |
+                                       QtCore.Qt.AlignVCenter)
+        self.lbl_bottomright.setAlignment(QtCore.Qt.AlignRight |
+                                          QtCore.Qt.AlignVCenter)
+
+        self.scroll = QtWidgets.QScrollArea(self)
+        self.scroll.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
+        self.scroll.setWidget(self.mmc)
+
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.lbl_1 = QtWidgets.QLabel('Borehole ID:')
+        self.hbl.addWidget(self.lbl_1)
+        self.hbl.addWidget(self.cmb_1)
+
+        hbl_1.addWidget(self.lbl_topleft)
+        hbl_1.addWidget(self.lbl_topright)
+        hbl_2.addWidget(self.lbl_bottomleft)
+        hbl_2.addWidget(self.lbl_bottomright)
+        vbl.addLayout(hbl_1)
+        vbl.addWidget(self.scroll)
+        vbl.addLayout(hbl_2)
+        vbl.addWidget(self.mmc2)
+        vbl.addLayout(self.hbl)
+
+        self.setFocus()
+
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
 
     def change_band(self):
-        """Combo box to choose band."""
-        i = self.combobox1.currentText()
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        i = self.cmb_1.currentText()
         if 'Borehole' in self.indata:
             data = self.indata['Borehole'][i]
             hdf = data['header']
@@ -435,7 +400,8 @@ class PlotLog(GraphWindow):
             hcompanyno = hdf['Companyno'].iloc[0]
             hfilt = (hdf['Companyno'] == hcompanyno).to_numpy().nonzero()[0][0]
             hrow = hdf.iloc[hfilt].astype(str)
-            topleft = hrow['Company']+'\n'+hrow['Farmname']+' ('+hrow['Farmno']+')'
+            topleft = (hrow['Company']+'\n'+hrow['Farmname'] +
+                       ' ('+hrow['Farmno']+')')
             topright = 'Hole no: '+hrow['Companyno']+'\n Sheet 1 of 1'
             bottomleft = 'Drill date: '+hrow['Drill date'].split()[0]
             bottomleft += '\nDepth from: '+hrow['Depth from']
@@ -443,10 +409,10 @@ class PlotLog(GraphWindow):
             bottomright = 'Elevation: '+hrow['Elevation']
             bottomright += '\nLatitude: '+hrow['Declat']
             bottomright += '\nLongitude: '+hrow['Declon']
-            self.label_topleft.setText(topleft)
-            self.label_topright.setText(topright)
-            self.label_bottomleft.setText(bottomleft)
-            self.label_bottomright.setText(bottomright)
+            self.lbl_topleft.setText(topleft)
+            self.lbl_topright.setText(topright)
+            self.lbl_bottomleft.setText(bottomleft)
+            self.lbl_bottomright.setText(bottomright)
 
             self.mmc2.update_legend(data)
             self.mmc.update_log(data)
@@ -461,11 +427,12 @@ class PlotLog(GraphWindow):
 
         """
         self.show()
+        data = []
         if 'Borehole' in self.indata:
             data = self.indata['Borehole']
 
         for i in data:
-            self.combobox1.addItem(i)
+            self.cmb_1.addItem(i)
         self.change_band()
 
 
@@ -507,7 +474,6 @@ def gethatch(svgfile):
                 continue
 
             dpath.append(tag.get('d'))
-            # style.append(tag.get('style'))
             stmp = {}
             for i in tag.get('style').split(';'):
                 tmp = i.split(':')
@@ -565,10 +531,6 @@ def gethatch(svgfile):
                 verts += (pvals+trans).tolist()
                 codes += [Path.CURVE4]*len(pvals)
 
-            # if pkey.upper() == 'Z':
-            #     verts += [trans]
-            #     codes += [Path.LINETO]
-
             rtmp = pvals[-1]
 
         if style[idx]['fill'] not in pverts:
@@ -583,23 +545,6 @@ def gethatch(svgfile):
         pverts[i] /= np.max(pverts[i])
         pverts[i] *= 4
 
-#  Draw here
-#    fig, ax = plt.subplots(figsize=(6, 6))
-#    for i in pverts:
-#        pathfin = Path(pverts[i], pcodes[i])
-#        pp1 = mpatches.PathPatch(pathfin, transform=ax.transData, fill=False)
-#
-#        if i == '#ffffff':
-#            pp1.set_fill(True)
-#            pp1.set_facecolor('w')
-#        elif i != 'none':
-#            pp1.set_fill(True)
-#            pp1.set_facecolor('k')
-#        ax.add_patch(pp1)
-#    plt.axis('equal')
-#    plt.tight_layout()
-#    plt.show()
-
     return pverts, pcodes
 
 
