@@ -25,13 +25,12 @@
 """Main Crisp Clustering set of routines."""
 
 import os
-import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 
 from pygmi.raster.datatypes import Data
 import pygmi.clust.var_ratio as vr
-from pygmi.misc import ProgressBarText, BasicModule
+from pygmi.misc import BasicModule
 
 
 class CrispClust(BasicModule):
@@ -39,18 +38,18 @@ class CrispClust(BasicModule):
 
     def __init__(self, parent=None):
         super().__init__(parent)
-        self.spinbox_maxclusters = QtWidgets.QSpinBox()
-        self.combobox_alg = QtWidgets.QComboBox()
-        self.doublespinbox_maxerror = QtWidgets.QDoubleSpinBox()
-        self.spinbox_maxiterations = QtWidgets.QSpinBox()
-        self.spinbox_repeatedruns = QtWidgets.QSpinBox()
-        self.spinbox_minclusters = QtWidgets.QSpinBox()
-        self.groupbox = QtWidgets.QGroupBox()
-        self.label_7 = QtWidgets.QLabel()
-        self.doublespinbox_constraincluster = QtWidgets.QDoubleSpinBox()
-        self.radiobutton_random = QtWidgets.QRadioButton()
-        self.radiobutton_manual = QtWidgets.QRadioButton()
-        self.radiobutton_datadriven = QtWidgets.QRadioButton()
+        self.sb_maxclusters = QtWidgets.QSpinBox()
+        self.cmb_alg = QtWidgets.QComboBox()
+        self.dsb_maxerror = QtWidgets.QDoubleSpinBox()
+        self.sb_maxiterations = QtWidgets.QSpinBox()
+        self.sb_repeatedruns = QtWidgets.QSpinBox()
+        self.sb_minclusters = QtWidgets.QSpinBox()
+        self.gbox = QtWidgets.QGroupBox()
+        self.lbl_7 = QtWidgets.QLabel()
+        self.dsb_constraincluster = QtWidgets.QDoubleSpinBox()
+        self.rb_random = QtWidgets.QRadioButton()
+        self.rb_manual = QtWidgets.QRadioButton()
+        self.rb_datadriven = QtWidgets.QRadioButton()
 
         self.setupui()
 
@@ -66,8 +65,8 @@ class CrispClust(BasicModule):
         self.type = 'crisp'
         self.log = ''
 
-        self.combobox_alg.addItems(['k-means', 'advanced k-means', 'w-means'])
-        self.combobox_alg.currentIndexChanged.connect(self.combo)
+        self.cmb_alg.addItems(['k-means', 'advanced k-means', 'w-means'])
+        self.cmb_alg.currentIndexChanged.connect(self.combo)
         self.combo()
 
     def setupui(self):
@@ -79,68 +78,68 @@ class CrispClust(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
-        verticallayout = QtWidgets.QVBoxLayout(self.groupbox)
+        gl_1 = QtWidgets.QGridLayout(self)
+        vbl = QtWidgets.QVBoxLayout(self.gbox)
 
         buttonbox = QtWidgets.QDialogButtonBox()
-        label = QtWidgets.QLabel()
-        label_2 = QtWidgets.QLabel()
-        label_3 = QtWidgets.QLabel()
-        label_4 = QtWidgets.QLabel()
-        label_5 = QtWidgets.QLabel()
-        label_6 = QtWidgets.QLabel()
+        lbl_1 = QtWidgets.QLabel()
+        lbl_2 = QtWidgets.QLabel()
+        lbl_3 = QtWidgets.QLabel()
+        lbl_4 = QtWidgets.QLabel()
+        lbl_5 = QtWidgets.QLabel()
+        lbl_6 = QtWidgets.QLabel()
 
-        self.spinbox_minclusters.setMinimum(1)
-        self.spinbox_minclusters.setProperty('value', 5)
-        self.spinbox_maxclusters.setMinimum(1)
-        self.spinbox_maxclusters.setProperty('value', 5)
-        self.spinbox_maxiterations.setMinimum(1)
-        self.spinbox_maxiterations.setMaximum(1000)
-        self.spinbox_maxiterations.setProperty('value', 100)
-        self.doublespinbox_maxerror.setDecimals(5)
-        self.doublespinbox_maxerror.setProperty('value', 1e-05)
-        self.spinbox_repeatedruns.setMinimum(1)
+        self.sb_minclusters.setMinimum(1)
+        self.sb_minclusters.setProperty('value', 5)
+        self.sb_maxclusters.setMinimum(1)
+        self.sb_maxclusters.setProperty('value', 5)
+        self.sb_maxiterations.setMinimum(1)
+        self.sb_maxiterations.setMaximum(1000)
+        self.sb_maxiterations.setProperty('value', 100)
+        self.dsb_maxerror.setDecimals(5)
+        self.dsb_maxerror.setProperty('value', 1e-05)
+        self.sb_repeatedruns.setMinimum(1)
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
-        self.radiobutton_random.setChecked(True)
-        self.groupbox.hide()
+        self.rb_random.setChecked(True)
+        self.gbox.hide()
 
         self.setWindowTitle('Crisp Clustering')
-        label.setText('Cluster Algorithm:')
-        label_2.setText('Minimum Clusters:')
-        label_3.setText('Maximum Clusters')
-        label_4.setText('Maximum Iterations:')
-        label_5.setText('Terminate if relative change per iteration '
-                        'is less than:')
-        label_6.setText('Repeated Runs:')
-        self.label_7.setText('Constrain Cluster Shape '
-                             '(0: unconstrained, 1: spherical)')
-        self.groupbox.setTitle('Initial Guess')
-        self.radiobutton_random.setText('Random')
-        self.radiobutton_manual.setText('Manual')
-        self.radiobutton_datadriven.setText('Data Driven')
+        lbl_1.setText('Cluster Algorithm:')
+        lbl_2.setText('Minimum Clusters:')
+        lbl_3.setText('Maximum Clusters')
+        lbl_4.setText('Maximum Iterations:')
+        lbl_5.setText('Terminate if relative change per iteration '
+                      'is less than:')
+        lbl_6.setText('Repeated Runs:')
+        self.lbl_7.setText('Constrain Cluster Shape '
+                           '(0: unconstrained, 1: spherical)')
+        self.gbox.setTitle('Initial Guess')
+        self.rb_random.setText('Random')
+        self.rb_manual.setText('Manual')
+        self.rb_datadriven.setText('Data Driven')
 
-        gridlayout.addWidget(label, 0, 2, 1, 1)
-        gridlayout.addWidget(self.combobox_alg, 0, 4, 1, 1)
-        gridlayout.addWidget(label_2, 1, 2, 1, 1)
-        gridlayout.addWidget(self.spinbox_minclusters, 1, 4, 1, 1)
-        gridlayout.addWidget(label_3, 2, 2, 1, 1)
-        gridlayout.addWidget(self.spinbox_maxclusters, 2, 4, 1, 1)
-        gridlayout.addWidget(label_4, 3, 2, 1, 1)
-        gridlayout.addWidget(self.spinbox_maxiterations, 3, 4, 1, 1)
-        gridlayout.addWidget(label_5, 4, 2, 1, 1)
-        gridlayout.addWidget(self.doublespinbox_maxerror, 4, 4, 1, 1)
-        gridlayout.addWidget(label_6, 5, 2, 1, 1)
-        gridlayout.addWidget(self.spinbox_repeatedruns, 5, 4, 1, 1)
-        gridlayout.addWidget(self.label_7, 6, 2, 1, 1)
-        gridlayout.addWidget(self.doublespinbox_constraincluster, 6, 4, 1, 1)
-        gridlayout.addWidget(self.groupbox, 8, 2, 1, 3)
-        gridlayout.addWidget(buttonbox, 9, 4, 1, 1)
+        gl_1.addWidget(lbl_1, 0, 2, 1, 1)
+        gl_1.addWidget(self.cmb_alg, 0, 4, 1, 1)
+        gl_1.addWidget(lbl_2, 1, 2, 1, 1)
+        gl_1.addWidget(self.sb_minclusters, 1, 4, 1, 1)
+        gl_1.addWidget(lbl_3, 2, 2, 1, 1)
+        gl_1.addWidget(self.sb_maxclusters, 2, 4, 1, 1)
+        gl_1.addWidget(lbl_4, 3, 2, 1, 1)
+        gl_1.addWidget(self.sb_maxiterations, 3, 4, 1, 1)
+        gl_1.addWidget(lbl_5, 4, 2, 1, 1)
+        gl_1.addWidget(self.dsb_maxerror, 4, 4, 1, 1)
+        gl_1.addWidget(lbl_6, 5, 2, 1, 1)
+        gl_1.addWidget(self.sb_repeatedruns, 5, 4, 1, 1)
+        gl_1.addWidget(self.lbl_7, 6, 2, 1, 1)
+        gl_1.addWidget(self.dsb_constraincluster, 6, 4, 1, 1)
+        gl_1.addWidget(self.gbox, 8, 2, 1, 3)
+        gl_1.addWidget(buttonbox, 9, 4, 1, 1)
 
-        verticallayout.addWidget(self.radiobutton_random)
-        verticallayout.addWidget(self.radiobutton_manual)
-        verticallayout.addWidget(self.radiobutton_datadriven)
+        vbl.addWidget(self.rb_random)
+        vbl.addWidget(self.rb_manual)
+        vbl.addWidget(self.rb_datadriven)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -154,13 +153,13 @@ class CrispClust(BasicModule):
         None.
 
         """
-        i = str(self.combobox_alg.currentText())
+        i = str(self.cmb_alg.currentText())
         if i == 'w-means':
-            self.label_7.show()
-            self.doublespinbox_constraincluster.show()
+            self.lbl_7.show()
+            self.dsb_constraincluster.show()
         else:
-            self.label_7.hide()
-            self.doublespinbox_constraincluster.hide()
+            self.lbl_7.hide()
+            self.dsb_constraincluster.hide()
 
     def settings(self, nodialog=False):
         """
@@ -178,79 +177,63 @@ class CrispClust(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         tst = np.unique([i.data.shape for i in self.indata['Raster']])
         if tst.size > 2:
-            self.showprocesslog('Error: Your input datasets have different '
-                                'sizes. Merge the data first')
+            self.showlog('Error: Your input datasets have different '
+                         'sizes. Merge the data first')
             return False
 
         self.update_vars()
 
         if not nodialog:
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
             self.parent.process_is_active()
-        self.run()
+        self.acceptall()
 
         if not nodialog:
             self.parent.process_is_active(False)
             self.parent.pbar.to_max()
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.combobox_alg.setCurrentText(projdata['cltype'])
-        self.spinbox_minclusters.setProperty('value', projdata['min_cluster'])
-        self.spinbox_maxclusters.setProperty('value', projdata['max_cluster'])
-        self.spinbox_maxiterations.setProperty('value', projdata['max_iter'])
-        self.doublespinbox_maxerror.setProperty('value',
-                                                projdata['term_thresh'])
-        self.spinbox_repeatedruns.setProperty('value', projdata['runs'])
-        self.doublespinbox_constraincluster.setProperty('value',
-                                                        projdata['constrain'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
         self.update_vars()
-        projdata = {}
 
-        projdata['cltype'] = self.cltype
-        projdata['min_cluster'] = self.min_cluster
-        projdata['max_cluster'] = self.max_cluster
-        projdata['max_iter'] = self.max_iter
-        projdata['term_thresh'] = self.term_thresh
-        projdata['runs'] = self.runs
-        projdata['constrain'] = self.constrain
+        self.saveobj(self.sb_maxclusters)
+        self.saveobj(self.cmb_alg)
+        self.saveobj(self.dsb_maxerror)
+        self.saveobj(self.sb_maxiterations)
+        self.saveobj(self.sb_repeatedruns)
+        self.saveobj(self.sb_minclusters)
+        self.saveobj(self.dsb_constraincluster)
+        self.saveobj(self.rb_random)
+        self.saveobj(self.rb_manual)
+        self.saveobj(self.rb_datadriven)
 
-        return projdata
+        self.saveobj(self.cltype)
+        self.saveobj(self.min_cluster)
+        self.saveobj(self.max_cluster)
+        self.saveobj(self.max_iter)
+        self.saveobj(self.term_thresh)
+        self.saveobj(self.runs)
+        self.saveobj(self.constrain)
+        self.saveobj(self.denorm)
+        self.saveobj(self.init_type)
+        self.saveobj(self.type)
+        self.saveobj(self.log)
 
     def update_vars(self):
         """
@@ -261,15 +244,15 @@ class CrispClust(BasicModule):
         None.
 
         """
-        self.cltype = str(self.combobox_alg.currentText())
-        self.min_cluster = self.spinbox_minclusters.value()
-        self.max_cluster = self.spinbox_maxclusters.value()
-        self.max_iter = self.spinbox_maxiterations.value()
-        self.term_thresh = self.doublespinbox_maxerror.value()
-        self.runs = self.spinbox_repeatedruns.value()
-        self.constrain = self.doublespinbox_constraincluster.value()
+        self.cltype = str(self.cmb_alg.currentText())
+        self.min_cluster = self.sb_minclusters.value()
+        self.max_cluster = self.sb_maxclusters.value()
+        self.max_iter = self.sb_maxiterations.value()
+        self.term_thresh = self.dsb_maxerror.value()
+        self.runs = self.sb_repeatedruns.value()
+        self.constrain = self.dsb_constraincluster.value()
 
-    def run(self):
+    def acceptall(self):
         """
         Process the data.
 
@@ -278,7 +261,7 @@ class CrispClust(BasicModule):
         None.
 
         """
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         self.update_vars()
 
         cltype = self.cltype
@@ -287,15 +270,15 @@ class CrispClust(BasicModule):
         max_iter = self.max_iter
         term_thresh = self.term_thresh
         no_clust = np.array([self.min_cluster, self.max_cluster])
-        de_norm = self.denorm
+        # de_norm = self.denorm
 
-        self.showprocesslog('Crisp Clustering started')
+        self.showlog('Crisp Clustering started')
 
 # #############################################################################
 # Section to deal with different bands having different null values.
 # Start with the first entry
 #         masktmp = data[0].data.mask
-# # Add the all the masks to this. This promotes False values to True.
+#   Add the all the masks to this. This promotes False values to True.
 #         for i in data:
 #             masktmp += i.data.mask
 #         for i, _ in enumerate(data):    # Apply this to all the bands
@@ -307,7 +290,7 @@ class CrispClust(BasicModule):
         masktmp = ~masktmp
         for datai in data:
             if datai.nodata != 0.0:
-                self.showprocesslog('Setting '+datai.dataid+' nodata to 0.')
+                self.showlog('Setting '+datai.dataid+' nodata to 0.')
                 datai.data = np.ma.array(datai.data.filled(0))
             datai.data.mask = masktmp
 
@@ -315,7 +298,7 @@ class CrispClust(BasicModule):
 
         dat_in = np.array([i.data.compressed() for i in data]).T
 
-        if self.radiobutton_manual.isChecked() is True:
+        if self.rb_manual.isChecked() is True:
             ext = ('ASCII matrix (*.txt);;'
                    'ASCII matrix (*.asc);;'
                    'ASCII matrix (*.dat)')
@@ -374,10 +357,10 @@ class CrispClust(BasicModule):
         dat_out = [Data() for i in range(no_clust[0], no_clust[1]+1)]
 
         for i in range(no_clust[0], no_clust[1]+1):
-            self.showprocesslog('Number of Clusters:'+str(i))
+            self.showlog('Number of Clusters:'+str(i))
             cnt = cnt + 1
-            if self.radiobutton_datadriven.isChecked() is True:
-                self.showprocesslog('Initial guess: data driven')
+            if self.rb_datadriven.isChecked() is True:
+                self.showlog('Initial guess: data driven')
                 no_samp = dat_in.shape[0]
                 dno_samp = no_samp/i
                 idx = np.arange(0, no_samp+dno_samp, dno_samp)
@@ -396,20 +379,20 @@ class CrispClust(BasicModule):
                     dat_in, i, startmdat[i], startmfix[i], max_iter,
                     term_thresh, cltype, cov_constr)
 
-            elif self.radiobutton_manual.isChecked() is True:
+            elif self.rb_manual.isChecked() is True:
 
-                self.showprocesslog('Initial guess: manual')
+                self.showlog('Initial guess: manual')
 
                 clidx, clcent, clobj_fcn, clvrc = self.crisp_means(
                     dat_in, i, startmdat[i], startmfix[i], max_iter,
                     term_thresh, cltype, cov_constr)
 
-            elif self.radiobutton_random.isChecked() is True:
-                self.showprocesslog('Initial guess: random')
+            elif self.rb_random.isChecked() is True:
+                self.showlog('Initial guess: random')
 
                 clobj_fcn = np.array([np.inf])
                 for j in range(no_runs):
-                    self.showprocesslog('Run '+str(j+1)+' of'+str(no_runs))
+                    self.showlog(f'Run {j+1} of {no_runs}')
 
                     xmins = np.minimum(dat_in, 1)
                     xmaxs = np.maximum(dat_in, 1)
@@ -458,12 +441,12 @@ class CrispClust(BasicModule):
             i.set_transform(transform=data[0].transform)
             i.crs = data[0].crs
 
-        self.showprocesslog('Crisp Cluster complete ('+self.cltype + ' ' +
-                            self.init_type+')')
+        self.showlog('Crisp Cluster complete ('+self.cltype + ' ' +
+                     self.init_type+')')
 
         for i in dat_out:
             i.data += 1
-            i.data = i.data.astype(np.uint8)
+            i.data = np.ma.masked_equal(i.data.filled(0).astype(int), 0)
             i.nodata = 0
         self.outdata['Cluster'] = dat_out
         self.outdata['Raster'] = self.indata['Raster']
@@ -487,7 +470,7 @@ class CrispClust(BasicModule):
             cluster centre positions, either empty [] --> randomly guessed
             center positions will be used for initialisation or NO_CLUSTxP
             matrix
-        centfix : TYPE
+        centfix : numpy array
             Constrains the position of cluster centers, if CENTFIX is empty,
             cluster centers can freely vary during cluster analysis, otherwise
             CENTFIX is of equal size to CENT and gives an absolute deviation
@@ -511,7 +494,7 @@ class CrispClust(BasicModule):
         cov_constr : float
             scalar between [0 1], values > 0 trim the covariance matrix
             to avoid needle-like ellipsoids for the clusters, applies only for
-            CLTYPE='vardet', but must always be provided.
+            cltype='vardet', but must always be provided.
 
         Returns
         -------
@@ -526,7 +509,7 @@ class CrispClust(BasicModule):
         vrc : numpy array
             Variance Ratio Criterion
         """
-        self.showprocesslog(' ')
+        self.showlog(' ')
 
         no_samples = data.shape[0]
         if cent.size == 0:  # if no center values are provided
@@ -560,7 +543,8 @@ class CrispClust(BasicModule):
             dist_prev = edist
             # calc new cluster centre positions
             cent, idx = gcentroids(data, idx, no_clust, mindist)
-            # constrain the cluster center positions to keep it in  the given interval
+            # constrain the cluster center positions to keep it in  the given
+            # interval
             if centfix.size > 0:
                 # constrain the center positions within the given limits
                 cent_idx = cent > (cent_orig+centfix)
@@ -572,8 +556,8 @@ class CrispClust(BasicModule):
 
             # calc new cluster centre distances
             edist = gdist(data, cent, idx, no_clust, cltype, cov_constr)
-            # get new index values for each data point and the distance from each
-            # sample to its cluster center
+            # get new index values for each data point and the distance from
+            # each sample to its cluster center
             mindist = edist.min(0)
             idx = edist.argmin(0)
 
@@ -585,9 +569,10 @@ class CrispClust(BasicModule):
             else:
                 obj_fcn_dif = 100 * ((obj_fcn_prev-obj_fcn[i]) / obj_fcn[i])
 
-            self.showprocesslog(f'Iteration: {i} Threshold: {term_thresh})'
-                                f' Current: {obj_fcn_dif:.2e}', True)
-            # if no termination threshold provided, ignore this and do all iterations
+            self.showlog(f'Iteration: {i} Threshold: {term_thresh})'
+                         f' Current: {obj_fcn_dif:.2e}', True)
+            # if no termination threshold provided, ignore this and do all
+            # iterations
             if term_thresh > 0:
                 # if the improvement between the last two iterations was less
                 # than a defined threshold in percent
@@ -656,8 +641,8 @@ def gdist(data, center, index, no_clust, cltype, cov_constr):
     ----------
     data : numpy array
         Input data.
-    center : TYPE
-        DESCRIPTION.
+    center : numpy array
+        center of each class.
     index : numpy array
         Cluster index number for each sample.
     no_clust : int
