@@ -25,7 +25,6 @@
 """Fuzzy clustering."""
 
 import os
-import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 
@@ -39,18 +38,18 @@ class FuzzyClust(BasicModule):
 
     def __init__(self, parent=None):
         super().__init__(parent)
-        self.combobox_alg = QtWidgets.QComboBox()
-        self.doublespinbox_maxerror = QtWidgets.QDoubleSpinBox()
-        self.doublespinbox_fuzzynessexp = QtWidgets.QDoubleSpinBox()
-        self.doublespinbox_constraincluster = QtWidgets.QDoubleSpinBox()
-        self.spinbox_maxclusters = QtWidgets.QSpinBox()
-        self.spinbox_maxiterations = QtWidgets.QSpinBox()
-        self.spinbox_repeatedruns = QtWidgets.QSpinBox()
-        self.spinbox_minclusters = QtWidgets.QSpinBox()
-        self.label_7 = QtWidgets.QLabel()
-        self.radiobutton_random = QtWidgets.QRadioButton()
-        self.radiobutton_manual = QtWidgets.QRadioButton()
-        self.radiobutton_datadriven = QtWidgets.QRadioButton()
+        self.cmb_alg = QtWidgets.QComboBox()
+        self.dsb_maxerror = QtWidgets.QDoubleSpinBox()
+        self.dsb_fuzzynessexp = QtWidgets.QDoubleSpinBox()
+        self.dsb_constraincluster = QtWidgets.QDoubleSpinBox()
+        self.sb_maxclusters = QtWidgets.QSpinBox()
+        self.sb_maxiterations = QtWidgets.QSpinBox()
+        self.sb_repeatedruns = QtWidgets.QSpinBox()
+        self.sb_minclusters = QtWidgets.QSpinBox()
+        self.lbl_7 = QtWidgets.QLabel()
+        self.rb_random = QtWidgets.QRadioButton()
+        self.rb_manual = QtWidgets.QRadioButton()
+        self.rb_datadriven = QtWidgets.QRadioButton()
 
         self.setupui()
 
@@ -66,11 +65,11 @@ class FuzzyClust(BasicModule):
         self.type = 'fuzzy'
         self.fexp = 1.5
 
-        self.combobox_alg.addItems(['fuzzy c-means',
-                                    'advanced fuzzy c-means',
-                                    'Gustafson-Kessel'])
-#                                   , 'Gath-Geva'])
-        self.combobox_alg.currentIndexChanged.connect(self.combo)
+        self.cmb_alg.addItems(['fuzzy c-means',
+                               'advanced fuzzy c-means',
+                               'Gustafson-Kessel'])  # , 'Gath-Geva'])
+
+        self.cmb_alg.currentIndexChanged.connect(self.combo)
         self.combo()
 
     def setupui(self):
@@ -82,74 +81,74 @@ class FuzzyClust(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
-        groupbox = QtWidgets.QGroupBox(self)
-        verticallayout = QtWidgets.QVBoxLayout(groupbox)
+        gl_1 = QtWidgets.QGridLayout(self)
+        gbox = QtWidgets.QGroupBox(self)
+        vbl = QtWidgets.QVBoxLayout(gbox)
 
         buttonbox = QtWidgets.QDialogButtonBox(self)
-        label = QtWidgets.QLabel()
-        label_2 = QtWidgets.QLabel()
-        label_3 = QtWidgets.QLabel()
-        label_4 = QtWidgets.QLabel()
-        label_5 = QtWidgets.QLabel()
-        label_6 = QtWidgets.QLabel()
-        label_8 = QtWidgets.QLabel()
+        lbl_1 = QtWidgets.QLabel()
+        lbl_2 = QtWidgets.QLabel()
+        lbl_3 = QtWidgets.QLabel()
+        lbl_4 = QtWidgets.QLabel()
+        lbl_5 = QtWidgets.QLabel()
+        lbl_6 = QtWidgets.QLabel()
+        lbl_8 = QtWidgets.QLabel()
 
-        self.spinbox_maxclusters.setMinimum(1)
-        self.spinbox_maxclusters.setProperty('value', 5)
-        self.spinbox_maxiterations.setMinimum(1)
-        self.spinbox_maxiterations.setMaximum(1000)
-        self.spinbox_maxiterations.setProperty('value', 100)
-        self.spinbox_repeatedruns.setMinimum(1)
-        self.spinbox_minclusters.setMinimum(1)
-        self.spinbox_minclusters.setProperty('value', 5)
-        self.doublespinbox_maxerror.setDecimals(5)
-        self.doublespinbox_maxerror.setProperty('value', 1e-05)
-        self.doublespinbox_fuzzynessexp.setProperty('value', 1.5)
-        self.radiobutton_random.setChecked(True)
+        self.sb_maxclusters.setMinimum(1)
+        self.sb_maxclusters.setProperty('value', 5)
+        self.sb_maxiterations.setMinimum(1)
+        self.sb_maxiterations.setMaximum(1000)
+        self.sb_maxiterations.setProperty('value', 100)
+        self.sb_repeatedruns.setMinimum(1)
+        self.sb_minclusters.setMinimum(1)
+        self.sb_minclusters.setProperty('value', 5)
+        self.dsb_maxerror.setDecimals(5)
+        self.dsb_maxerror.setProperty('value', 1e-05)
+        self.dsb_fuzzynessexp.setProperty('value', 1.5)
+        self.rb_random.setChecked(True)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
 
         self.setWindowTitle('Fuzzy Clustering')
-        groupbox.setTitle('Initial Guess')
-        groupbox.hide()
-        label.setText('Cluster Algorithm:')
-        label_2.setText('Minimum Clusters:')
-        label_3.setText('Maximum Clusters')
-        label_4.setText('Maximum Iterations:')
-        label_5.setText('Terminate if relative change per iteration is less '
-                        'than:')
-        label_6.setText('Repeated Runs:')
-        self.label_7.setText('Constrain Cluster Shape (0: unconstrained, '
-                             '1: spherical)')
-        label_8.setText('Fuzzyness Exponent')
-        self.radiobutton_random.setText('Random')
-        self.radiobutton_manual.setText('Manual')
-        self.radiobutton_datadriven.setText('Data Driven')
+        gbox.setTitle('Initial Guess')
+        gbox.hide()
+        lbl_1.setText('Cluster Algorithm:')
+        lbl_2.setText('Minimum Clusters:')
+        lbl_3.setText('Maximum Clusters')
+        lbl_4.setText('Maximum Iterations:')
+        lbl_5.setText('Terminate if relative change per iteration is less '
+                      'than:')
+        lbl_6.setText('Repeated Runs:')
+        self.lbl_7.setText('Constrain Cluster Shape (0: unconstrained, '
+                           '1: spherical)')
+        lbl_8.setText('Fuzzyness Exponent')
+        self.rb_random.setText('Random')
+        self.rb_manual.setText('Manual')
+        self.rb_datadriven.setText('Data Driven')
 
-        gridlayout.addWidget(label, 0, 2, 1, 1)
-        gridlayout.addWidget(label_2, 1, 2, 1, 1)
-        gridlayout.addWidget(label_3, 2, 2, 1, 1)
-        gridlayout.addWidget(label_4, 3, 2, 1, 1)
-        gridlayout.addWidget(label_5, 4, 2, 1, 1)
-        gridlayout.addWidget(label_6, 5, 2, 1, 1)
-        gridlayout.addWidget(self.label_7, 6, 2, 1, 1)
-        gridlayout.addWidget(label_8, 7, 2, 1, 1)
-        gridlayout.addWidget(groupbox, 9, 2, 1, 3)
+        gl_1.addWidget(lbl_1, 0, 2, 1, 1)
+        gl_1.addWidget(lbl_2, 1, 2, 1, 1)
+        gl_1.addWidget(lbl_3, 2, 2, 1, 1)
+        gl_1.addWidget(lbl_4, 3, 2, 1, 1)
+        gl_1.addWidget(lbl_5, 4, 2, 1, 1)
+        gl_1.addWidget(lbl_6, 5, 2, 1, 1)
+        gl_1.addWidget(self.lbl_7, 6, 2, 1, 1)
+        gl_1.addWidget(lbl_8, 7, 2, 1, 1)
+        gl_1.addWidget(gbox, 9, 2, 1, 3)
 
-        gridlayout.addWidget(self.combobox_alg, 0, 4, 1, 1)
-        gridlayout.addWidget(self.spinbox_minclusters, 1, 4, 1, 1)
-        gridlayout.addWidget(self.spinbox_maxclusters, 2, 4, 1, 1)
-        gridlayout.addWidget(self.spinbox_maxiterations, 3, 4, 1, 1)
-        gridlayout.addWidget(self.doublespinbox_maxerror, 4, 4, 1, 1)
-        gridlayout.addWidget(self.spinbox_repeatedruns, 5, 4, 1, 1)
-        gridlayout.addWidget(self.doublespinbox_constraincluster, 6, 4, 1, 1)
-        gridlayout.addWidget(self.doublespinbox_fuzzynessexp, 7, 4, 1, 1)
-        gridlayout.addWidget(buttonbox, 10, 4, 1, 1)
+        gl_1.addWidget(self.cmb_alg, 0, 4, 1, 1)
+        gl_1.addWidget(self.sb_minclusters, 1, 4, 1, 1)
+        gl_1.addWidget(self.sb_maxclusters, 2, 4, 1, 1)
+        gl_1.addWidget(self.sb_maxiterations, 3, 4, 1, 1)
+        gl_1.addWidget(self.dsb_maxerror, 4, 4, 1, 1)
+        gl_1.addWidget(self.sb_repeatedruns, 5, 4, 1, 1)
+        gl_1.addWidget(self.dsb_constraincluster, 6, 4, 1, 1)
+        gl_1.addWidget(self.dsb_fuzzynessexp, 7, 4, 1, 1)
+        gl_1.addWidget(buttonbox, 10, 4, 1, 1)
 
-        verticallayout.addWidget(self.radiobutton_random)
-        verticallayout.addWidget(self.radiobutton_manual)
-        verticallayout.addWidget(self.radiobutton_datadriven)
+        vbl.addWidget(self.rb_random)
+        vbl.addWidget(self.rb_manual)
+        vbl.addWidget(self.rb_datadriven)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -163,13 +162,13 @@ class FuzzyClust(BasicModule):
         None.
 
         """
-        i = str(self.combobox_alg.currentText())
+        i = str(self.cmb_alg.currentText())
         if i in ('Gath-Geva', 'Gustafson-Kessel'):
-            self.label_7.show()
-            self.doublespinbox_constraincluster.show()
+            self.lbl_7.show()
+            self.dsb_constraincluster.show()
         else:
-            self.label_7.hide()
-            self.doublespinbox_constraincluster.hide()
+            self.lbl_7.hide()
+            self.dsb_constraincluster.hide()
 
     def settings(self, nodialog=False):
         """
@@ -187,23 +186,23 @@ class FuzzyClust(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         tst = np.unique([i.data.shape for i in self.indata['Raster']])
         if tst.size > 2:
-            self.showprocesslog('Error: Your input datasets have different '
-                                'sizes. Merge the data first')
+            self.showlog('Error: Your input datasets have different '
+                         'sizes. Merge the data first')
             return False
 
         if not nodialog:
             self.update_vars()
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
             self.parent.process_is_active()
-        self.run()
+        self.acceptall()
 
         if not nodialog:
             self.parent.process_is_active(False)
@@ -211,57 +210,40 @@ class FuzzyClust(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.combobox_alg.setCurrentText(projdata['cltype'])
-        self.spinbox_minclusters.setProperty('value', projdata['min_cluster'])
-        self.spinbox_maxclusters.setProperty('value', projdata['max_cluster'])
-        self.spinbox_maxiterations.setProperty('value', projdata['max_iter'])
-        self.doublespinbox_maxerror.setProperty('value',
-                                                projdata['term_thresh'])
-        self.spinbox_repeatedruns.setProperty('value', projdata['runs'])
-        self.doublespinbox_constraincluster.setProperty('value',
-                                                        projdata['constrain'])
-        self.doublespinbox_fuzzynessexp.setProperty('value',
-                                                    projdata['fexp'])
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
         self.update_vars()
-        projdata = {}
 
-        projdata['cltype'] = self.cltype
-        projdata['min_cluster'] = self.min_cluster
-        projdata['max_cluster'] = self.max_cluster
-        projdata['max_iter'] = self.max_iter
-        projdata['term_thresh'] = self.term_thresh
-        projdata['runs'] = self.runs
-        projdata['constrain'] = self.constrain
-        projdata['fexp'] = self.fexp
+        self.saveobj(self.cmb_alg)
+        self.saveobj(self.dsb_maxerror)
+        self.saveobj(self.dsb_fuzzynessexp)
+        self.saveobj(self.dsb_constraincluster)
+        self.saveobj(self.sb_maxclusters)
+        self.saveobj(self.sb_maxiterations)
+        self.saveobj(self.sb_repeatedruns)
+        self.saveobj(self.sb_minclusters)
+        self.saveobj(self.rb_random)
+        self.saveobj(self.rb_manual)
+        self.saveobj(self.rb_datadriven)
 
-        return projdata
+        self.saveobj(self.cltype)
+        self.saveobj(self.min_cluster)
+        self.saveobj(self.max_cluster)
+        self.saveobj(self.max_iter)
+        self.saveobj(self.term_thresh)
+        self.saveobj(self.runs)
+        self.saveobj(self.constrain)
+        self.saveobj(self.denorm)
+        self.saveobj(self.init_type)
+        self.saveobj(self.type)
+        self.saveobj(self.fexp)
 
     def update_vars(self):
         """
@@ -272,16 +254,16 @@ class FuzzyClust(BasicModule):
         None.
 
         """
-        self.cltype = str(self.combobox_alg.currentText())
-        self.min_cluster = self.spinbox_minclusters.value()
-        self.max_cluster = self.spinbox_maxclusters.value()
-        self.max_iter = self.spinbox_maxiterations.value()
-        self.term_thresh = self.doublespinbox_maxerror.value()
-        self.runs = self.spinbox_repeatedruns.value()
-        self.constrain = self.doublespinbox_constraincluster.value()
-        self.fexp = self.doublespinbox_fuzzynessexp.value()
+        self.cltype = str(self.cmb_alg.currentText())
+        self.min_cluster = self.sb_minclusters.value()
+        self.max_cluster = self.sb_maxclusters.value()
+        self.max_iter = self.sb_maxiterations.value()
+        self.term_thresh = self.dsb_maxerror.value()
+        self.runs = self.sb_repeatedruns.value()
+        self.constrain = self.dsb_constraincluster.value()
+        self.fexp = self.dsb_fuzzynessexp.value()
 
-    def run(self):
+    def acceptall(self):
         """
         Run.
 
@@ -290,7 +272,7 @@ class FuzzyClust(BasicModule):
         None.
 
         """
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         self.update_vars()
 
         cltype = self.cltype
@@ -302,12 +284,12 @@ class FuzzyClust(BasicModule):
         de_norm = self.denorm
         expo = self.fexp
 
-        self.showprocesslog('Fuzzy Clustering started')
+        self.showlog('Fuzzy Clustering started')
 
 # #############################################################################
 # Section to deal with different bands having different null values.
 #         masktmp = data[0].data.mask   # Start with the first entry
-# # Add the masks to this.This promotes False values to True if necessary
+# Add the masks to this.This promotes False values to True if necessary
 #         for i in data:
 #             masktmp += i.data.mask
 #         for i, _ in enumerate(data):    # Apply this to all the bands
@@ -319,7 +301,7 @@ class FuzzyClust(BasicModule):
         masktmp = ~masktmp
         for datai in data:
             if datai.nodata != 0.0:
-                self.showprocesslog('Setting '+datai.dataid+' nodata to 0.')
+                self.showlog('Setting '+datai.dataid+' nodata to 0.')
                 datai.data = np.ma.array(datai.data.filled(0))
             datai.data.mask = masktmp
 
@@ -327,7 +309,7 @@ class FuzzyClust(BasicModule):
 
         dat_in = np.array([i.data.compressed() for i in data]).T
 
-        if self.radiobutton_manual.isChecked() is True:
+        if self.rb_manual.isChecked() is True:
             ext = ('ASCII matrix (*.txt);;'
                    'ASCII matrix (*.asc);;'
                    'ASCII matrix (*.dat)')
@@ -386,10 +368,10 @@ class FuzzyClust(BasicModule):
         dat_out = [Data() for i in range(no_clust[0], no_clust[1] + 1)]
 
         for i in range(no_clust[0], no_clust[1] + 1):
-            self.showprocesslog('Number of Clusters:' + str(i))
+            self.showlog(f'Number of Clusters: {i}')
             cnt = cnt + 1
-            if self.radiobutton_datadriven.isChecked() is True:
-                self.showprocesslog('Initial guess: data driven')
+            if self.rb_datadriven.isChecked() is True:
+                self.showlog('Initial guess: data driven')
 
                 no_samp = dat_in.shape[0]
                 dno_samp = no_samp / i
@@ -409,20 +391,19 @@ class FuzzyClust(BasicModule):
                     dat_in, i, startmdat[i], startmfix[i], max_iter,
                     term_thresh, expo, cltype, cov_constr)
 
-            elif self.radiobutton_manual.isChecked() is True:
-                self.showprocesslog('Initial guess: manual')
+            elif self.rb_manual.isChecked() is True:
+                self.showlog('Initial guess: manual')
 
                 clu, clcent, clobj_fcn, clvrc, clnce, clxbi = self.fuzzy_means(
                     dat_in, i, startmdat[i], startmfix[i],
                     max_iter, term_thresh, expo, cltype, cov_constr)
 
-            elif self.radiobutton_random.isChecked() is True:
-                self.showprocesslog('Initial guess: random')
+            elif self.rb_random.isChecked() is True:
+                self.showlog('Initial guess: random')
 
                 clobj_fcn = np.array([np.Inf])
                 for j in range(no_runs):
-                    self.showprocesslog('Run ' + str(j+1) + ' of' +
-                                        str(no_runs))
+                    self.showlog(f'Run {j+1} of {no_runs}')
 
                     xmins = np.minimum(dat_in, 1)
                     xmaxs = np.maximum(dat_in, 1)
@@ -478,6 +459,7 @@ class FuzzyClust(BasicModule):
                 dummy = np.ones(data[0].data.shape) * np.nan
                 alpha1 = (data[0].data.mask == 0)
                 dummy[alpha1 == 1] = clu[k, :]
+                dummy = np.ma.masked_invalid(dummy)
                 dat_out[cnt].metadata['Cluster']['memdat'].append(dummy)
             dat_out[cnt].metadata['Cluster']['vrc'] = clvrc
             dat_out[cnt].metadata['Cluster']['nce'] = clnce
@@ -492,8 +474,7 @@ class FuzzyClust(BasicModule):
             i.data += 1
             i.crs = data[0].crs
 
-        self.showprocesslog('Fuzzy Cluster complete' + ' (' + self.cltype +
-                            ' ' + self.init_type + ')')
+        self.showlog(f'Fuzzy Cluster complete ({self.cltype} {self.init_type})')
 
         self.outdata['Cluster'] = dat_out
         self.outdata['Raster'] = self.indata['Raster']
@@ -516,14 +497,14 @@ class FuzzyClust(BasicModule):
             and N is the number of coordinates (attributes) for each sample.
         no_clust : int
             Number of clusters.
-        init : TYPE
+        init : numpy array
             INIT may be set to [], in this case the FCM generates random
             initial center locations to start the algorithm. Alternatively,
             INIT can be of matrix type, either containing a user-given
             membership matrix [NO_CLUST M] or a cluster center matrix
             [NO_CLUST, N].
-        centfix : TYPE
-            DESCRIPTION.
+        centfix : numpy array
+            Constrains the position of cluster centers.
         maxit : int
             MAXIT give the maximum number of iterations..
         term_thresh : float
@@ -563,7 +544,7 @@ class FuzzyClust(BasicModule):
         xbi : numpy array
             Xie beni index.
         """
-        self.showprocesslog(' ')
+        self.showlog(' ')
 
         if cltype == 'fuzzy c-means':
             cltype = 'fcm'
@@ -609,7 +590,7 @@ class FuzzyClust(BasicModule):
         # if membership matrix is provided
         elif init.shape[0] == no_clust and init.shape[1] == no_samples:
             if init[init < 0].size > 0:  # check for negative memberships
-                self.showprocesslog('No negative memberships allowed!')
+                self.showlog('No negative memberships allowed!')
                 # scale given memberships to a column sum of unity
             uuu = init / (np.ones([no_clust, 1]) * init.sum())
             # MF matrix after exponential modification
@@ -640,12 +621,11 @@ class FuzzyClust(BasicModule):
             m_f = uuu ** expo
             obj_fcn[i] = np.sum((edist ** 2) * m_f)  # objective function
             if i > 0:
-                self.showprocesslog('Iteration: ' + str(i) + ' Threshold: ' +
-                                    str(term_thresh) + ' Current: ' +
-                                    '{:.2e}'.format(100*((obj_fcn[i - 1] -
-                                                          obj_fcn[i]) /
-                                                         obj_fcn[i - 1])),
-                                    True)
+                self.showlog('Iteration: ' + str(i) + ' Threshold: ' +
+                             str(term_thresh) + ' Current: ' +
+                             '{:.2e}'.format(100*((obj_fcn[i - 1] -
+                                                   obj_fcn[i]) /
+                                                  obj_fcn[i - 1])), True)
 
                 # if objective function has increased
                 if obj_fcn[i] > obj_fcn[i - 1]:
@@ -675,7 +655,7 @@ def fuzzy_dist(cent, data, uuu, expo, cltype, cov_constr):
     Parameters
     ----------
     cent : numpy array
-        DESCRIPTION.
+        Class centers.
     data : numpy array
         Input data.
     uuu : numpy array
