@@ -28,7 +28,6 @@ import numpy as np
 from PyQt5 import QtWidgets, QtCore
 from matplotlib.figure import Figure
 from matplotlib import colormaps
-from matplotlib.artist import Artist
 from matplotlib.patches import Polygon
 from matplotlib.lines import Line2D
 from matplotlib.path import Path
@@ -37,6 +36,7 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 
 from pygmi.misc import BasicModule
 
+
 class GraphHist(FigureCanvasQTAgg):
     """Graph Hist."""
 
@@ -78,8 +78,8 @@ class GraphHist(FigureCanvasQTAgg):
 
         """
         xyhist = np.zeros((bins + 1, bins + 1))
-        xxx = self.xcoord.compressed()
-        yyy = self.ycoord.compressed()
+        xxx = self.xcoord.compressed().astype(int)
+        yyy = self.ycoord.compressed().astype(int)
 
         xyhist = np.histogram2d(xxx, yyy, bins + 1)
 
@@ -94,7 +94,7 @@ class GraphHist(FigureCanvasQTAgg):
         ----------
         bins : int
             Number of bins.
-        dattmp : list
+        dattmp : list of PyGMI Data
             Data.
         ctmp : list
             Cluster indices.
@@ -108,11 +108,11 @@ class GraphHist(FigureCanvasQTAgg):
         clust = np.ma.array(dattmp[ctmp[2] - 1].data.flatten())
         clust.mask = np.ma.getmaskarray(self.xcoord)
         clust = clust.compressed()
-        xxx = self.xcoord.compressed()
-        yyy = self.ycoord.compressed()
+        xxx = self.xcoord.compressed().astype(int)
+        yyy = self.ycoord.compressed().astype(int)
         xyhist = np.zeros((bins + 1, bins + 1))
 
-        xyhist[xxx, yyy] = (clust + 1)
+        xyhist[xxx, yyy] = clust + 1
 
         xymahist = np.ma.masked_equal(xyhist, 0)
         return xymahist
@@ -194,8 +194,9 @@ class GraphHist(FigureCanvasQTAgg):
         ystep = yptp / 50
         self.xcoord = self.xcoord/xstep
         self.ycoord = self.ycoord/ystep
-        self.xcoord = self.xcoord.astype(int)
-        self.ycoord = self.ycoord.astype(int)
+
+        self.xcoord = np.trunc(self.xcoord)
+        self.ycoord = np.trunc(self.ycoord)
 
     def setup_hist(self):
         """
@@ -399,7 +400,6 @@ class PolygonInteractor(QtCore.QObject):
                            color='y', animated=True)
         self.ax.add_line(self.line)
 
-        self.poly.add_callback(self.poly_changed)
         self._ind = None  # the active vert
 
         self.canvas.mpl_connect('button_press_event',
@@ -446,34 +446,14 @@ class PolygonInteractor(QtCore.QObject):
         self.canvas.draw()
         self.update_plots()
 
-    def poly_changed(self, poly):
-        """
-        Polygon changed.
-
-        Parameters
-        ----------
-        poly : TYPE
-            DESCRIPTION.
-
-        Returns
-        -------
-        None.
-
-        """
-        # this method is called whenever the polygon object is called
-        # only copy the artist props to the line (except visibility)
-        vis = self.line.get_visible()
-        Artist.update_from(self.line, poly)
-        self.line.set_visible(vis)  # don't use the poly visibility state
-
     def get_ind_under_point(self, event):
         """
         Get the index of vertex under point if within epsilon tolerance.
 
         Parameters
         ----------
-        event : TYPE
-            Unused.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -500,8 +480,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -569,8 +549,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -594,15 +574,14 @@ class PolygonInteractor(QtCore.QObject):
         self.polymask = Path(self.poly.xy).contains_points(self.pntxy)
         self.polyi_changed.emit()
 
-
     def motion_notify_callback(self, event):
         """
         Mouse notify callback.
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -664,11 +643,11 @@ class ScatterPlot(BasicModule):
         None.
 
         """
-        grid_main = QtWidgets.QGridLayout(self)
-        group_cp = QtWidgets.QGroupBox('Cross Plot Settings')
-        grid_left = QtWidgets.QGridLayout(group_cp)
-        group_map = QtWidgets.QGroupBox('Map Settings')
-        grid_right = QtWidgets.QGridLayout(group_map)
+        gl_main = QtWidgets.QGridLayout(self)
+        gbox_cp = QtWidgets.QGroupBox('Cross Plot Settings')
+        gl_left = QtWidgets.QGridLayout(gbox_cp)
+        gbox_map = QtWidgets.QGroupBox('Map Settings')
+        gl_right = QtWidgets.QGridLayout(gbox_map)
 
         self.setWindowTitle('Scatter Plot Tool')
 
@@ -678,22 +657,22 @@ class ScatterPlot(BasicModule):
         lbl_combo_right = QtWidgets.QLabel('Data Band:')
         lbl_combo2_right = QtWidgets.QLabel('Cluster Overlay:')
 
-        grid_left.addWidget(lbl_combo_left, 0, 0, 1, 1)
-        grid_left.addWidget(lbl_combo2_left, 1, 0, 1, 1)
-        grid_left.addWidget(lbl_combo3_left, 2, 0, 1, 1)
-        grid_left.addWidget(self.cp_dpoly, 0, 2, 1, 1)
-        grid_left.addWidget(self.cp_combo, 0, 1, 1, 1)
-        grid_left.addWidget(self.cp_combo2, 1, 1, 1, 1)
-        grid_left.addWidget(self.cp_combo3, 2, 1, 1, 1)
-        grid_right.addWidget(lbl_combo_right, 0, 0, 1, 1)
-        grid_right.addWidget(lbl_combo2_right, 1, 0, 1, 1)
-        grid_right.addWidget(self.map_dpoly, 0, 2, 1, 1)
-        grid_right.addWidget(self.map_combo, 0, 1, 1, 1)
-        grid_right.addWidget(self.map_combo2, 1, 1, 1, 1)
-        grid_main.addWidget(self.hist, 0, 0, 1, 1)
-        grid_main.addWidget(self.map, 0, 1, 1, 1)
-        grid_main.addWidget(group_cp, 1, 0, 1, 1)
-        grid_main.addWidget(group_map, 1, 1, 1, 1)
+        gl_left.addWidget(lbl_combo_left, 0, 0, 1, 1)
+        gl_left.addWidget(lbl_combo2_left, 1, 0, 1, 1)
+        gl_left.addWidget(lbl_combo3_left, 2, 0, 1, 1)
+        gl_left.addWidget(self.cp_dpoly, 0, 2, 1, 1)
+        gl_left.addWidget(self.cp_combo, 0, 1, 1, 1)
+        gl_left.addWidget(self.cp_combo2, 1, 1, 1, 1)
+        gl_left.addWidget(self.cp_combo3, 2, 1, 1, 1)
+        gl_right.addWidget(lbl_combo_right, 0, 0, 1, 1)
+        gl_right.addWidget(lbl_combo2_right, 1, 0, 1, 1)
+        gl_right.addWidget(self.map_dpoly, 0, 2, 1, 1)
+        gl_right.addWidget(self.map_combo, 0, 1, 1, 1)
+        gl_right.addWidget(self.map_combo2, 1, 1, 1, 1)
+        gl_main.addWidget(self.hist, 0, 0, 1, 1)
+        gl_main.addWidget(self.map, 0, 1, 1, 1)
+        gl_main.addWidget(gbox_cp, 1, 0, 1, 1)
+        gl_main.addWidget(gbox_map, 1, 1, 1, 1)
 
         self.cp_dpoly.clicked.connect(self.on_cp_dpoly)
         self.map_dpoly.clicked.connect(self.on_map_dpoly)
@@ -707,7 +686,7 @@ class ScatterPlot(BasicModule):
         None.
 
         """
-        self.hist.polyi.new_poly([[10, 10]])
+        self.hist.polyi.new_poly([[1, 1]])
 
         mtmp = self.map_combo.currentIndex()
         mask = self.indata['Raster'][mtmp].data.mask
@@ -726,7 +705,7 @@ class ScatterPlot(BasicModule):
         None.
 
         """
-        self.map.polyi.new_poly([[10, 10]])
+        self.map.polyi.new_poly([[1, 1]])
         dattmp = self.hist.csp.get_array()
         dattmp.mask = np.ma.getmaskarray(np.ma.masked_equal(dattmp.data, 0.))
         self.hist.csp.changed()
@@ -746,7 +725,6 @@ class ScatterPlot(BasicModule):
             self.c[0] = gstmp
             self.hist.update_graph(clearaxis=True)
             self.on_cp_dpoly()
-            # self.map.polyi.update_plots()
 
     def on_cp_combo2(self):
         """
@@ -762,7 +740,6 @@ class ScatterPlot(BasicModule):
             self.c[1] = gstmp
             self.hist.update_graph(clearaxis=True)
             self.on_cp_dpoly()
-            # self.map.polyi.update_plots()
 
     def on_cp_combo3(self):
         """
@@ -776,7 +753,6 @@ class ScatterPlot(BasicModule):
         self.c[2] = self.cp_combo3.currentIndex()
         self.hist.update_graph()
         self.on_cp_dpoly()
-        # self.map.polyi.update_plots()
 
     def on_map_combo(self):
         """
@@ -789,8 +765,6 @@ class ScatterPlot(BasicModule):
         """
         self.m[0] = self.map_combo.currentIndex()
         self.map.update_graph()
-        # self.on_map_dpoly()
-        # self.hist.polyi.update_plots()
 
     def on_map_combo2(self):
         """
@@ -803,7 +777,6 @@ class ScatterPlot(BasicModule):
         """
         self.m[1] = self.map_combo2.currentIndex()
         self.map.update_graph()
-        # self.hist.polyi.update_plots()
 
     def settings(self, nodialog=False):
         """
@@ -821,9 +794,8 @@ class ScatterPlot(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('Error: You must have a multi-band raster '
-                                'dataset in addition to your cluster analysis'
-                                ' results')
+            self.showlog('Error: You must have a multi-band raster dataset '
+                         'in addition to your cluster analysis results')
             return False
 
         self.dat_tmp = self.indata['Raster']
@@ -875,41 +847,19 @@ class ScatterPlot(BasicModule):
         self.hist.update_graph(clearaxis=True)
         self.map.update_graph()
 
-        self.exec_()
-
+        self.exec()
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
 
     def update_map(self):
         """
@@ -953,7 +903,7 @@ class ScatterPlot(BasicModule):
                          self.hist.ycoord[polymask]]).T
         dattmp.mask = np.ones_like(np.ma.getmaskarray(dattmp))
         for i in atmp:
-            dattmp.mask[i[1], i[0]] = False
+            dattmp.mask[int(i[1]), int(i[0])] = False
         self.hist.csp.changed()
         self.hist.figure.canvas.draw()
 
@@ -1014,12 +964,10 @@ def _testfn():
 
     app = QtWidgets.QApplication(sys.argv)
 
-    DM = ScatterPlot()
-    DM.indata['Raster'] = dat
-    DM.indata['Cluster'] = dat2
-    DM.settings()
-
-    aaa=1
+    tmp1 = ScatterPlot()
+    tmp1.indata['Raster'] = dat
+    tmp1.indata['Cluster'] = dat2
+    tmp1.settings()
 
 
 if __name__ == "__main__":
