@@ -54,39 +54,40 @@ class MenuWidget():
 
         self.parent = parent
         self.parent.add_to_context('Cluster')
+        self.parent.add_to_context('memCluster')
         context_menu = self.parent.context_menu
 
         # Normal menus
-        self.menuclustering = QtWidgets.QMenu('Classification')
-        parent.menubar.addAction(self.menuclustering.menuAction())
+        self.menu = QtWidgets.QMenu('Classification')
+        parent.menubar.addAction(self.menu.menuAction())
 
         self.action_clustering = QtWidgets.QAction('Cluster Analysis')
-        self.menuclustering.addAction(self.action_clustering)
+        self.menu.addAction(self.action_clustering)
         self.action_clustering.triggered.connect(self.cluster)
 
         self.action_crisp_clustering = QtWidgets.QAction("Crisp Clustering")
-        self.menuclustering.addAction(self.action_crisp_clustering)
+        self.menu.addAction(self.action_crisp_clustering)
         self.action_crisp_clustering.triggered.connect(self.crisp_cluster)
 
         self.action_fuzzy_clustering = QtWidgets.QAction("Fuzzy Clustering")
-        self.menuclustering.addAction(self.action_fuzzy_clustering)
+        self.menu.addAction(self.action_fuzzy_clustering)
         self.action_fuzzy_clustering.triggered.connect(self.fuzzy_cluster)
 
-        self.menuclustering.addSeparator()
+        self.menu.addSeparator()
 
         self.action_segmentation = QtWidgets.QAction('Image Segmentation')
-        self.menuclustering.addAction(self.action_segmentation)
+        self.menu.addAction(self.action_segmentation)
         self.action_segmentation.triggered.connect(self.segmentation)
 
         self.action_super_class = QtWidgets.QAction("Supervised "
                                                     "Classification")
-        self.menuclustering.addAction(self.action_super_class)
+        self.menu.addAction(self.action_super_class)
         self.action_super_class.triggered.connect(self.super_class)
 
-        self.menuclustering.addSeparator()
+        self.menu.addSeparator()
 
         self.action_scatter_plot = QtWidgets.QAction('Scatter Plot Tool')
-        self.menuclustering.addAction(self.action_scatter_plot)
+        self.menu.addAction(self.action_scatter_plot)
         self.action_scatter_plot.triggered.connect(self.scatter_plot)
 
 # Context menus
@@ -102,9 +103,8 @@ class MenuWidget():
         self.action_show_class_data.triggered.connect(self.show_raster_data)
 
         self.action_show_membership_data = QtWidgets.QAction("Show Membership "
-                                                             "Data (Fuzzy "
-                                                             "Only)")
-        context_menu['Cluster'].addAction(self.action_show_membership_data)
+                                                             "Data")
+        context_menu['memCluster'].addAction(self.action_show_membership_data)
         self.action_show_membership_data.triggered.connect(self.show_membership_data)
 
         self.action_show_objvrcncexbigraphs = QtWidgets.QAction("Show OBJ, "
