@@ -23,9 +23,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 """Image segmentation routines."""
-import copy
+
 import numpy as np
-from sklearn.cluster import DBSCAN
+from sklearn.cluster import KMeans
 import skimage
 import sklearn.preprocessing as skp
 from numba import jit
@@ -41,11 +41,11 @@ class ImageSeg(BasicModule):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.scale = QtWidgets.QLineEdit('1000')
-        self.wcompact = QtWidgets.QLineEdit('0.5')
-        self.wcolor = QtWidgets.QLineEdit('0.9')
-        self.eps = QtWidgets.QLineEdit('0.1')
-        self.dbscan = QtWidgets.QCheckBox('Use DBSCAN to group segments')
+        self.le_scale = QtWidgets.QLineEdit('1000')
+        self.le_wcompact = QtWidgets.QLineEdit('0.5')
+        self.le_wcolor = QtWidgets.QLineEdit('0.9')
+        self.cb_optics = QtWidgets.QCheckBox('Use K-Means to group segments')
+        self.le_numclust = QtWidgets.QLineEdit('8')
 
         self.setupui()
 
@@ -58,26 +58,26 @@ class ImageSeg(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.clust.segmentation')
 
         lbl_wcompact = QtWidgets.QLabel('Compactness weight')
         lbl_wcolor = QtWidgets.QLabel('Colour weight')
         lbl_scale = QtWidgets.QLabel('Maximum allowable cost function')
-        lbl_eps = QtWidgets.QLabel('DBSCAN eps')
+        lbl_numclust = QtWidgets.QLabel('Number of clusters')
 
         val = QtGui.QDoubleValidator(0.0, 1.0, 2)
         val.setNotation(QtGui.QDoubleValidator.StandardNotation)
         val.setLocale(QtCore.QLocale(QtCore.QLocale.C))
 
-        self.wcompact.setValidator(val)
-        self.wcolor.setValidator(val)
-        self.dbscan.setChecked(False)
+        self.le_wcompact.setValidator(val)
+        self.le_wcolor.setValidator(val)
+        self.cb_optics.setChecked(True)
 
         val = QtGui.QDoubleValidator()
         val.setBottom = 0
-        self.scale.setValidator(QtGui.QIntValidator(self))
+        self.le_scale.setValidator(QtGui.QIntValidator(self))
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
@@ -85,22 +85,22 @@ class ImageSeg(BasicModule):
 
         self.setWindowTitle(r'Image Segmentation')
 
-        gridlayout_main.addWidget(lbl_wcompact, 0, 0, 1, 1)
-        gridlayout_main.addWidget(self.wcompact, 0, 1, 1, 1)
+        gl_main.addWidget(lbl_wcompact, 0, 0, 1, 1)
+        gl_main.addWidget(self.le_wcompact, 0, 1, 1, 1)
 
-        gridlayout_main.addWidget(lbl_wcolor, 1, 0, 1, 1)
-        gridlayout_main.addWidget(self.wcolor, 1, 1, 1, 1)
+        gl_main.addWidget(lbl_wcolor, 1, 0, 1, 1)
+        gl_main.addWidget(self.le_wcolor, 1, 1, 1, 1)
 
-        gridlayout_main.addWidget(lbl_scale, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.scale, 2, 1, 1, 1)
+        gl_main.addWidget(lbl_scale, 2, 0, 1, 1)
+        gl_main.addWidget(self.le_scale, 2, 1, 1, 1)
 
-        gridlayout_main.addWidget(self.dbscan, 3, 0, 1, 2)
+        gl_main.addWidget(self.cb_optics, 3, 0, 1, 2)
 
-        gridlayout_main.addWidget(lbl_eps, 4, 0, 1, 1)
-        gridlayout_main.addWidget(self.eps, 4, 1, 1, 1)
+        gl_main.addWidget(lbl_numclust, 4, 0, 1, 1)
+        gl_main.addWidget(self.le_numclust, 4, 1, 1, 1)
 
-        gridlayout_main.addWidget(helpdocs, 5, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 5, 1, 1, 3)
+        gl_main.addWidget(helpdocs, 5, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 5, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -121,106 +121,90 @@ class ImageSeg(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         data1 = []
         for i in self.indata['Raster']:
             data1.append(i.data.data)
+            data1[-1] = 255*(data1[-1] - data1[-1].min())/data1[-1].ptp()
 
         data1 = np.array(data1)
         data1 = np.moveaxis(data1, 0, -1)
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
 
             if tmp != 1:
                 return False
 
-        scale = float(self.scale.text())
-        wcolor = float(self.wcolor.text())
-        wcompact = float(self.wcompact.text())
-        eps = float(self.eps.text())
+        try:
+            scale = float(self.le_scale.text())
+            wcolor = float(self.le_wcolor.text())
+            wcompact = float(self.le_wcompact.text())
+            numclust = int(self.le_numclust.text())
+        except ValueError:
+            self.showlog('Error in parameter values.')
+            return False
 
         doshape = True
 
         omap = self.segment1(data1, scale=scale, wcolor=wcolor,
                              wcompact=wcompact, doshape=doshape)
 
-        odat = copy.deepcopy(self.indata['Raster'][0])
+        odat = self.indata['Raster'][0].copy(True)
         odat.data = np.ma.array(omap, mask=self.indata['Raster'][0].data.mask)
         odat.dataid = 'Segments'
+        odat.data = odat.data + 1
 
         self.outdata['Raster'] = [odat]
 
-        if not self.dbscan.isChecked():
+        if not self.cb_optics.isChecked():
             return True
 
         means = []
+        uvals = []
         for i in range(odat.data.max()+1):
             tmp = data1[odat.data == i]
             if tmp.size == 0:
                 continue
             means.append(tmp.mean(0))
+            uvals.append(i)
+
+        if numclust > len(means):
+            self.showlog('Aborting K-Means, you have fewer segments than '
+                         'your required clusters. Outputting segents only.')
+            return True
 
         means = np.array(means)
         means = skp.StandardScaler().fit_transform(means)
-        dbout = DBSCAN(eps=eps).fit_predict(means)
+        dbout = KMeans(n_clusters=numclust).fit_predict(means)
 
         data2 = odat.data.copy()
 
-        newmax = dbout.max()+1
         for i, val in enumerate(dbout):
-            filt = (odat.data == i)
-            if val == -1:
-                data2[filt] = newmax
-                newmax += 1
-                continue
+            filt = (odat.data == uvals[i])
             data2[filt] = val
 
-        odat.data = data2
+        odat.data = data2+1
         self.outdata['Raster'] = [odat]
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.scale.setText(projdata['scale'])
-        self.scale.setText(projdata['wcolor'])
-        self.scale.setText(projdata['wcompact'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['scale'] = self.scale.text()
-        projdata['wcolor'] = self.wcolor.text()
-        projdata['wcompact'] = self.wcompact.text()
-
-        return projdata
+        self.saveobj(self.le_scale)
+        self.saveobj(self.le_wcolor)
+        self.saveobj(self.le_wcompact)
+        self.saveobj(self.le_eps)
+        self.saveobj(self.cb_dbscan)
 
     def segment1(self, data, scale=500, wcolor=0.5, wcompact=0.5,
                  doshape=True):
@@ -231,7 +215,7 @@ class ImageSeg(BasicModule):
         ----------
         data : numpy array
             Input data.
-        scale : TYPE, optional
+        scale : int, optional
             Scale. The default is 500.
         wcolor : float, optional
             Colour weight. The default is 0.5.
@@ -248,7 +232,7 @@ class ImageSeg(BasicModule):
         """
         rows, cols, bands = data.shape
 
-        self.showprocesslog('Initialising...')
+        self.showlog('Initialising...')
 
         olist = {}
         slist = {}
@@ -271,12 +255,12 @@ class ImageSeg(BasicModule):
                     nlist[(k, i*cols+j)] = 1
                 omap[i, j] = i*cols+j
 
-        self.showprocesslog('merging...')
+        self.showlog('merging...')
 
         omap = self._segment2(omap, olist, slist, mlist, nlist, bands,
                               doshape, wcompact, wcolor, scale)
 
-        self.showprocesslog('renumbering...')
+        self.showlog('renumbering...')
         tmp = np.unique(omap)
 
         for i, val in enumerate(tmp):
@@ -309,13 +293,13 @@ class ImageSeg(BasicModule):
             Compactness weight. The default is 0.5.
         wcolor : float, optional
             Colour weight. The default is 0.5.
-        scale : TYPE, optional
+        scale : int, optional
             Scale. The default is 500.
 
 
         Returns
         -------
-        omap : TYPE
+        omap : numpy array
             output data.
 
         """
@@ -337,12 +321,8 @@ class ImageSeg(BasicModule):
             elist = set(olist.keys())
 
             clen = len(elist)
-            if self.pbar is not None:
-                self.pbar.setMaximum(clen)
-                self.pbar.setMinimum(0)
-                self.pbar.setValue(0)
-            self.showprocesslog('Iteration number: '+str(cnt))
-            oldperc = 0
+            pbar = self.piter(range(clen))
+            self.showlog('Iteration number: '+str(cnt))
 
             olist3 = olist.copy()
 
@@ -478,16 +458,13 @@ class ImageSeg(BasicModule):
 
                 elist.discard(hind)
 
-                cnow = clen-len(elist)
-                if cnow*1000//clen-oldperc > 0:
-                    if self.pbar is not None:
-                        self.pbar.setValue(cnow)
-                    oldperc = cnow*1000//clen
+                next(pbar)
 
                 rmin, rmax = rminmax[i]
                 cmin, cmax = cminmax[i]
 
-                omap[rmin:rmax+1, cmin:cmax+1][omap[rmin:rmax+1, cmin:cmax+1] == hind] = i
+                omap[rmin:rmax+1, cmin:cmax+1][omap[rmin:rmax+1,
+                                                    cmin:cmax+1] == hind] = i
 
         return omap
 
@@ -526,24 +503,18 @@ def _testfn():
     import sys
     import matplotlib.pyplot as plt
     from pygmi.raster.datatypes import Data
-    from pygmi.misc import PTime
     from matplotlib import rcParams
 
     rcParams['figure.dpi'] = 300
 
     app = QtWidgets.QApplication(sys.argv)
 
-    data1 = skimage.data.coffee()  # 400x600 48.5 secs
+    data1 = skimage.data.coffee()
 
     plt.imshow(data1)
     plt.axis('off')
     plt.show()
 
-    wcolor = 0.5
-    wcompact = 0.5
-    doshape = True
-    scale = 1000
-
     b1 = Data()
     b1.data = np.ma.array(data1[:, :, 0])
     b2 = Data()
@@ -553,11 +524,9 @@ def _testfn():
 
     data = [b1, b2, b3]
 
-    ttt = PTime()
     IS = ImageSeg()
     IS.indata = {'Raster': data}
     IS.settings()
-    ttt.since_last_call()
 
     odata = IS.outdata['Raster'][0]
 
@@ -566,5 +535,40 @@ def _testfn():
     plt.show()
 
 
+def _testfn2():
+    """Test routine."""
+    import sys
+    import matplotlib.pyplot as plt
+    from pygmi.raster.datatypes import Data
+    from pygmi.raster.iodefs import get_raster
+
+    ifile = r"D:\Segmentation\Test_20010213_bands.tif"
+
+    app = QtWidgets.QApplication(sys.argv)
+
+    data = get_raster(ifile)
+
+    for i, _ in enumerate(data):
+        vmin, vmax = data[i].get_vmin_vmax()
+
+        plt.title(f'{i}')
+        plt.imshow(data[i].data, vmin=vmin, vmax=vmax)
+        plt.axis('off')
+        plt.show()
+
+    IS = ImageSeg()
+    IS.indata = {'Raster': data}
+    IS.settings()
+
+    odata = IS.outdata['Raster'][0]
+
+    plt.imshow(odata.data)
+    plt.axis('off')
+    plt.colorbar()
+    plt.show()
+
+    breakpoint()
+
+
 if __name__ == "__main__":
-    _testfn()
+    _testfn2()
