@@ -26,13 +26,11 @@
 
 import os
 import sys
-import copy
 import numpy as np
 from PyQt5 import QtWidgets, QtCore
 import matplotlib.pyplot as plt
 from matplotlib.figure import Figure
-from matplotlib import colormaps
-from matplotlib.artist import Artist
+# from matplotlib import colormaps
 from matplotlib.patches import Polygon as mPolygon
 from matplotlib.lines import Line2D
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
@@ -65,55 +63,21 @@ class GraphMap(FigureCanvasQTAgg):
 
     def __init__(self, parent=None):
         self.figure = Figure()
+        self.ax1 = self.figure.add_subplot(111)
 
         super().__init__(self.figure)
+
         self.setParent(parent)
 
         self.parent = parent
         self.polyi = None
         self.data = []
-        self.cdata = []
-        self.mindx = [0, 0]
-        self.csp = None
-        self.subplot = None
+        self.im1 = None
 
-    def init_graph(self):
-        """
-        Initialise the graph.
+        self.bands = [0, 1, 2]
+        self.manip = 'RGB Ternary'
 
-        Returns
-        -------
-        None.
-
-        """
-        mtmp = self.mindx
-        dat = self.data[mtmp[0]]
-
-        self.figure.clf()
-        self.subplot = self.figure.add_subplot(111)
-
-        self.csp = imshow(self.subplot, dat.data, extent=dat.extent,
-                          cmap=colormaps['jet'])
-        axes = self.figure.gca()
-
-        if dat.crs is not None:
-            crs = dat.crs.to_dict()
-        else:
-            crs = {}
-
-        if 'proj' in crs and crs['proj'] == 'longlat':
-            axes.set_xlabel('Longitude')
-            axes.set_ylabel('Latitude')
-        else:
-            axes.set_xlabel('Eastings')
-            axes.set_ylabel('Northings')
-
-        axes.xaxis.set_major_formatter(frm)
-        axes.yaxis.set_major_formatter(frm)
-
-        self.figure.canvas.draw()
-
-    def polyint(self):
+    def polyint(self, dat):
         """
         Polygon integrator.
 
@@ -122,8 +86,7 @@ class GraphMap(FigureCanvasQTAgg):
         None.
 
         """
-        mtmp = self.mindx
-        dat = self.data[mtmp[0]].data
+        dat = dat[self.bands[0]].data
 
         xtmp = np.arange(dat.shape[1])
         ytmp = np.arange(dat.shape[0])
@@ -135,31 +98,123 @@ class GraphMap(FigureCanvasQTAgg):
         xmesh = xmesh.filled(np.nan)
         ymesh = ymesh.filled(np.nan)
         pntxy = np.transpose([xmesh, ymesh])
-        self.polyi = PolygonInteractor(self.subplot, pntxy)
+        self.polyi = PolygonInteractor(self.ax1, pntxy)
 
-    def update_graph(self):
+    def compute_initial_figure(self, dat):
         """
-        Update graph.
+        Compute initial figure.
+
+        Parameters
+        ----------
+        dat : PyGMI Data
+            PyGMI dataset.
 
         Returns
         -------
         None.
 
         """
-        mtmp = self.mindx
-        dat = self.data[mtmp[0]]
+        clippercu = 1
+        clippercl = 1
 
-        if mtmp[1] > 0:
-            cdat = self.cdata[mtmp[1] - 1].data
-            self.csp.set_data(cdat)
-            self.csp.set_clim(cdat.min(), cdat.max())
-            self.csp.set_clim(cdat.min(), cdat.max())
+        if 'Ternary' in self.manip:
+            red = dat[self.bands[0]].data
+            green = dat[self.bands[1]].data
+            blue = dat[self.bands[2]].data
+
+            data = [red, green, blue]
+            data = np.ma.array(data)
+            data = np.moveaxis(data, 0, -1)
+            lclip = [0, 0, 0]
+            uclip = [0, 0, 0]
+
+            lclip[0], uclip[0] = np.percentile(red.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[1], uclip[1] = np.percentile(green.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[2], uclip[2] = np.percentile(blue.compressed(),
+                                               [clippercl, 100-clippercu])
         else:
-            self.csp.set_data(dat.data)
-            self.csp.set_clim(dat.data.min(), dat.data.max())
-            self.csp.set_clim(dat.data.min(), dat.data.max())
+            data = dat[self.bands[0]].data
+            lclip, uclip = np.percentile(data.compressed(),
+                                         [clippercl, 100-clippercu])
+
+        extent = dat[self.bands[0]].extent
+
+        self.im1 = imshow(self.ax1, data, extent=extent)
+        self.im1.rgbmode = self.manip
+
+        if 'Ternary' in self.manip:
+            self.im1.rgbclip = [[lclip[0], uclip[0]],
+                                [lclip[1], uclip[1]],
+                                [lclip[2], uclip[2]]]
+        else:
+            self.im1.set_clim(lclip, uclip)
+
+        if dat[self.bands[0]].crs.is_geographic:
+            self.ax1.set_xlabel('Longitude')
+            self.ax1.set_ylabel('Latitude')
+        else:
+            self.ax1.set_xlabel('Eastings')
+            self.ax1.set_ylabel('Northings')
+
+        self.ax1.xaxis.set_major_formatter(frm)
+        self.ax1.yaxis.set_major_formatter(frm)
+
+    def update_plot(self, dat):
+        """
+        Update plot.
+
+        Parameters
+        ----------
+        dat : Dictionary
+            PyGMI dataset/s in a dictionary.
+
+        Returns
+        -------
+        None.
+
+        """
+        clippercu = 1
+        clippercl = 1
+
+        if 'Ternary' in self.manip:
+            red = dat[self.bands[0]].data
+            green = dat[self.bands[1]].data
+            blue = dat[self.bands[2]].data
+
+            data = [red, green, blue]
+            data = np.ma.array(data)
+            data = np.moveaxis(data, 0, -1)
+            lclip = [0, 0, 0]
+            uclip = [0, 0, 0]
+
+            lclip[0], uclip[0] = np.percentile(red.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[1], uclip[1] = np.percentile(green.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[2], uclip[2] = np.percentile(blue.compressed(),
+                                               [clippercl, 100-clippercu])
+            self.im1.rgbclip = [[lclip[0], uclip[0]],
+                                [lclip[1], uclip[1]],
+                                [lclip[2], uclip[2]]]
+
+        else:
+            data = dat[self.bands[0]].data
+            lclip, uclip = np.percentile(data.compressed(),
+                                         [clippercl, 100-clippercu])
+
+            self.im1.set_clim(lclip, uclip)
+
+        extent = dat[self.bands[0]].extent
+
+        self.im1.rgbmode = self.manip
+        self.im1.set_data(data)
+        self.im1.set_extent(extent)
+
+        self.ax1.xaxis.set_major_formatter(frm)
+        self.ax1.yaxis.set_major_formatter(frm)
 
-        self.csp.changed()
         self.figure.canvas.draw()
 
 
@@ -196,7 +251,6 @@ class PolygonInteractor(QtCore.QObject):
                            color='y', animated=True)
         self.ax.add_line(self.line)
 
-        self.poly.add_callback(self.poly_changed)
         self._ind = None  # the active vert
 
         self.canvas.mpl_connect('draw_event', self.draw_callback)
@@ -213,8 +267,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE, optional
-            Unused. The default is None.
+        event : matplotlib.backend_bases.DrawEvent, optional
+            Draw event object. The default is None.
 
         Returns
         -------
@@ -251,34 +305,14 @@ class PolygonInteractor(QtCore.QObject):
         self.update_plots()
         self.canvas.draw()
 
-    def poly_changed(self, poly):
-        """
-        Polygon changed.
-
-        Parameters
-        ----------
-        poly : TYPE
-            DESCRIPTION.
-
-        Returns
-        -------
-        None.
-
-        """
-        # this method is called whenever the polygon object is called
-        # only copy the artist props to the line (except visibility)
-        vis = self.line.get_visible()
-        Artist.update_from(self.line, poly)
-        self.line.set_visible(vis)  # don't use the poly visibility state
-
     def get_ind_under_point(self, event):
         """
         Get the index of vertex under point if within epsilon tolerance.
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -305,8 +339,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -375,8 +409,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse Event.
 
         Returns
         -------
@@ -409,8 +443,8 @@ class PolygonInteractor(QtCore.QObject):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -444,27 +478,28 @@ class SuperClass(BasicModule):
         super().__init__(parent)
         self.m1 = 0
         self.c = [0, 1, 0]
-        self.m = [0, 0]
         self.df = None
+        self.data = {}
 
         self.map = GraphMap(self)
         self.dpoly = QtWidgets.QPushButton('Delete Polygon')
         self.apoly = QtWidgets.QPushButton('Add Polygon')
-        self.combo = QtWidgets.QComboBox()
-        self.combo_class = QtWidgets.QComboBox()
+        self.cmb_class = QtWidgets.QComboBox()
         self.tablewidget = QtWidgets.QTableWidget()
-        self.KNalgorithm = QtWidgets.QComboBox()
-        self.SVCkernel = QtWidgets.QComboBox()
-        self.DTcriterion = QtWidgets.QComboBox()
-        self.RFcriterion = QtWidgets.QComboBox()
-        self.label1 = QtWidgets.QLabel()
+        self.cmb_KNalgorithm = QtWidgets.QComboBox()
+        self.cmb_SVCkernel = QtWidgets.QComboBox()
+        self.cmb_DTcriterion = QtWidgets.QComboBox()
+        self.cmb_RFcriterion = QtWidgets.QComboBox()
+        self.lbl_1 = QtWidgets.QLabel()
+        self.cmb_band1 = QtWidgets.QComboBox()
+        self.cmb_band2 = QtWidgets.QComboBox()
+        self.cmb_band3 = QtWidgets.QComboBox()
+        self.cmb_manip = QtWidgets.QComboBox()
 
         self.mpl_toolbar = NavigationToolbar2QT(self.map, self.parent)
 
         self.setupui()
 
-        self.map.mindx = self.m
-
     def setupui(self):
         """
         Set up UI.
@@ -474,12 +509,29 @@ class SuperClass(BasicModule):
         None.
 
         """
-        grid_main = QtWidgets.QGridLayout(self)
-        group_map = QtWidgets.QGroupBox('Class Edit')
-        grid_right = QtWidgets.QGridLayout(group_map)
+        gl_main = QtWidgets.QGridLayout(self)
+        gbox_map = QtWidgets.QGroupBox('Class Edit')
+        gl_right = QtWidgets.QGridLayout(gbox_map)
 
-        group_class = QtWidgets.QGroupBox('Supervised Classification')
-        grid_class = QtWidgets.QGridLayout(group_class)
+        gbox_1 = QtWidgets.QGroupBox('Display Type')
+        vbl_1b = QtWidgets.QVBoxLayout()
+        gbox_1.setLayout(vbl_1b)
+
+        gbox_2 = QtWidgets.QGroupBox('Data Bands')
+        vbl_2b = QtWidgets.QVBoxLayout()
+        gbox_2.setLayout(vbl_2b)
+
+        gbox_class = QtWidgets.QGroupBox('Supervised Classification')
+        gl_class = QtWidgets.QGridLayout(gbox_class)
+
+        vbl_2b.addWidget(self.cmb_band1)
+        vbl_2b.addWidget(self.cmb_band2)
+        vbl_2b.addWidget(self.cmb_band3)
+
+        actions = ['RGB Ternary', 'CMY Ternary', 'Single Colour Map']
+        self.cmb_manip.addItems(actions)
+
+        vbl_1b.addWidget(self.cmb_manip)
 
         buttonbox = QtWidgets.QDialogButtonBox()
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
@@ -502,46 +554,45 @@ class SuperClass(BasicModule):
                    'Random Forest Classifier',
                    'Support Vector Classifier']
 
-        self.combo_class.clear()
-        self.combo_class.addItems(choices)
+        self.cmb_class.clear()
+        self.cmb_class.addItems(choices)
 
-        lbl_combo = QtWidgets.QLabel('Data Band:')
         lbl_class = QtWidgets.QLabel('Classifier:')
-        self.label1.setText('Algorithm:')
+        self.lbl_1.setText('Algorithm:')
 
-        self.KNalgorithm.addItems(['auto', 'ball_tree', 'kd_tree', 'brute'])
-        self.DTcriterion.addItems(['gini', 'entropy'])
-        self.RFcriterion.addItems(['gini', 'entropy'])
-        self.SVCkernel.addItems(['rbf', 'linear', 'poly'])
+        self.cmb_KNalgorithm.addItems(['auto', 'ball_tree', 'kd_tree',
+                                       'brute'])
+        self.cmb_DTcriterion.addItems(['gini', 'entropy'])
+        self.cmb_RFcriterion.addItems(['gini', 'entropy'])
+        self.cmb_SVCkernel.addItems(['rbf', 'linear', 'poly'])
 
-        self.SVCkernel.setHidden(True)
-        self.DTcriterion.setHidden(True)
-        self.RFcriterion.setHidden(True)
+        self.cmb_SVCkernel.setHidden(True)
+        self.cmb_DTcriterion.setHidden(True)
+        self.cmb_RFcriterion.setHidden(True)
 
-        grid_right.addWidget(lbl_combo, 0, 0, 1, 1)
-        grid_right.addWidget(self.combo, 0, 1, 1, 2)
+        gl_right.addWidget(self.tablewidget, 1, 0, 3, 2)
+        gl_right.addWidget(self.apoly, 1, 2, 1, 1)
+        gl_right.addWidget(self.dpoly, 2, 2, 1, 1)
+        gl_right.addWidget(calcmetrics, 3, 2, 1, 1)
+        gl_right.addWidget(loadshape, 4, 0, 1, 1)
+        gl_right.addWidget(saveshape, 4, 1, 1, 1)
 
-        grid_right.addWidget(self.tablewidget, 1, 0, 3, 2)
-        grid_right.addWidget(self.apoly, 1, 2, 1, 1)
-        grid_right.addWidget(self.dpoly, 2, 2, 1, 1)
-        grid_right.addWidget(calcmetrics, 3, 2, 1, 1)
-        grid_right.addWidget(loadshape, 4, 0, 1, 1)
-        grid_right.addWidget(saveshape, 4, 1, 1, 1)
+        gl_class.addWidget(lbl_class, 0, 0, 1, 1)
+        gl_class.addWidget(self.cmb_class, 0, 1, 1, 1)
+        gl_class.addWidget(self.lbl_1, 1, 0, 1, 1)
+        gl_class.addWidget(self.cmb_KNalgorithm, 1, 1, 1, 1)
+        gl_class.addWidget(self.cmb_DTcriterion, 1, 1, 1, 1)
+        gl_class.addWidget(self.cmb_RFcriterion, 1, 1, 1, 1)
+        gl_class.addWidget(self.cmb_SVCkernel, 1, 1, 1, 1)
 
-        grid_class.addWidget(lbl_class, 0, 0, 1, 1)
-        grid_class.addWidget(self.combo_class, 0, 1, 1, 1)
-        grid_class.addWidget(self.label1, 1, 0, 1, 1)
-        grid_class.addWidget(self.KNalgorithm, 1, 1, 1, 1)
-        grid_class.addWidget(self.DTcriterion, 1, 1, 1, 1)
-        grid_class.addWidget(self.RFcriterion, 1, 1, 1, 1)
-        grid_class.addWidget(self.SVCkernel, 1, 1, 1, 1)
+        gl_main.addWidget(self.map, 0, 0, 4, 1)
+        gl_main.addWidget(self.mpl_toolbar, 4, 0, 1, 1)
 
-        grid_main.addWidget(self.map, 0, 0, 2, 1)
-        grid_main.addWidget(self.mpl_toolbar, 2, 0, 1, 1)
-
-        grid_main.addWidget(group_map, 0, 1, 1, 1)
-        grid_main.addWidget(group_class, 1, 1, 1, 1)
-        grid_main.addWidget(buttonbox, 2, 1, 1, 1)
+        gl_main.addWidget(gbox_1, 0, 1, 1, 1)
+        gl_main.addWidget(gbox_2, 1, 1, 1, 1)
+        gl_main.addWidget(gbox_map, 2, 1, 1, 1)
+        gl_main.addWidget(gbox_class, 3, 1, 1, 1)
+        gl_main.addWidget(buttonbox, 4, 1, 1, 1)
 
         self.apoly.clicked.connect(self.on_apoly)
         self.dpoly.clicked.connect(self.on_dpoly)
@@ -551,7 +602,8 @@ class SuperClass(BasicModule):
 
         self.tablewidget.currentItemChanged.connect(self.onrowchange)
         self.tablewidget.cellChanged.connect(self.oncellchange)
-        self.combo_class.currentIndexChanged.connect(self.class_change)
+        self.cmb_class.currentIndexChanged.connect(self.class_change)
+        self.cmb_manip.currentIndexChanged.connect(self.on_combo)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -565,25 +617,25 @@ class SuperClass(BasicModule):
         None.
 
         """
-        ctext = self.combo_class.currentText()
+        ctext = self.cmb_class.currentText()
 
-        self.SVCkernel.setHidden(True)
-        self.DTcriterion.setHidden(True)
-        self.RFcriterion.setHidden(True)
-        self.KNalgorithm.setHidden(True)
+        self.cmb_SVCkernel.setHidden(True)
+        self.cmb_DTcriterion.setHidden(True)
+        self.cmb_RFcriterion.setHidden(True)
+        self.cmb_KNalgorithm.setHidden(True)
 
         if ctext == 'K Neighbors Classifier':
-            self.KNalgorithm.setHidden(False)
-            self.label1.setText('Algorithm:')
+            self.cmb_KNalgorithm.setHidden(False)
+            self.lbl_1.setText('Algorithm:')
         elif ctext == 'Decision Tree Classifier':
-            self.DTcriterion.setHidden(False)
-            self.label1.setText('Criterion:')
+            self.cmb_DTcriterion.setHidden(False)
+            self.lbl_1.setText('Criterion:')
         elif ctext == 'Random Forest Classifier':
-            self.RFcriterion.setHidden(False)
-            self.label1.setText('Criterion:')
+            self.cmb_RFcriterion.setHidden(False)
+            self.lbl_1.setText('Criterion:')
         elif ctext == 'Support Vector Classifier':
-            self.SVCkernel.setHidden(False)
-            self.label1.setText('Kernel:')
+            self.cmb_SVCkernel.setHidden(False)
+            self.lbl_1.setText('Kernel:')
 
     def calc_metrics(self):
         """
@@ -613,7 +665,7 @@ class SuperClass(BasicModule):
 
         qsave = QtWidgets.QMessageBox.Save
         qokay = QtWidgets.QMessageBox.Ok
-        ret = QtWidgets.QMessageBox.information(self.parent, 'Metrics',
+        ret = QtWidgets.QMessageBox.information(self, 'Metrics',
                                                 message,
                                                 buttons=qsave | qokay)
         if ret == qsave:
@@ -769,8 +821,21 @@ class SuperClass(BasicModule):
         None.
 
         """
-        self.m[0] = self.combo.currentIndex()
-        self.map.update_graph()
+        maniptxt = self.cmb_manip.currentText()
+
+        if 'Ternary' in maniptxt:
+            self.cmb_band2.show()
+            self.cmb_band3.show()
+        else:
+            self.cmb_band2.hide()
+            self.cmb_band3.hide()
+
+        self.map.bands = [self.cmb_band1.currentText(),
+                          self.cmb_band2.currentText(),
+                          self.cmb_band3.currentText()]
+
+        self.map.manip = maniptxt
+        self.map.update_plot(self.data)
 
     def load_shape(self):
         """
@@ -849,26 +914,57 @@ class SuperClass(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('Error: You must have a multi-band raster '
-                                'dataset in addition to your cluster '
-                                'analysis results')
+            self.showlog('Error: You must have a multi-band raster dataset in '
+                         'addition to your cluster analysis results')
             return False
 
         self.map.data = self.indata['Raster']
 
+        for i in self.indata['Raster']:
+            self.data[i.dataid] = i
+
         bands = [i.dataid for i in self.indata['Raster']]
 
-        self.combo.clear()
-        self.combo.addItems(bands)
-        self.combo.currentIndexChanged.connect(self.on_combo)
+        try:
+            self.cmb_band1.currentIndexChanged.disconnect()
+            self.cmb_band2.currentIndexChanged.disconnect()
+            self.cmb_band3.currentIndexChanged.disconnect()
+        except TypeError:
+            pass
 
-        self.map.init_graph()
+        self.cmb_band1.clear()
+        self.cmb_band2.clear()
+        self.cmb_band3.clear()
 
-        self.map.polyint()
+        self.cmb_band1.addItems(bands)
+        self.cmb_band2.addItems(bands)
+        self.cmb_band3.addItems(bands)
+
+        if len(bands) > 3:
+            self.cmb_band1.setCurrentIndex(3)
+            self.cmb_band2.setCurrentIndex(2)
+            self.cmb_band3.setCurrentIndex(1)
+        elif len(bands) == 3:
+            self.cmb_band1.setCurrentIndex(2)
+            self.cmb_band2.setCurrentIndex(1)
+            self.cmb_band3.setCurrentIndex(0)
+
+        self.cmb_band1.currentIndexChanged.connect(self.on_combo)
+        self.cmb_band2.currentIndexChanged.connect(self.on_combo)
+        self.cmb_band3.currentIndexChanged.connect(self.on_combo)
+
+        self.map.bands = [self.cmb_band1.currentText(),
+                          self.cmb_band2.currentText(),
+                          self.cmb_band3.currentText()]
+        self.map.manip = self.cmb_manip.currentText()
+
+        self.map.compute_initial_figure(self.data)
+
+        self.map.polyint(self.data)
         self.map.polyi.polyi_changed.connect(self.updatepoly)
-        self.map.update_graph()
+        self.map.update_plot(self.data)
 
-        tmp = self.exec_()
+        tmp = self.exec()
 
         if tmp == 0:
             return False
@@ -882,7 +978,7 @@ class SuperClass(BasicModule):
         yout1 = classifier.predict(datall)
         yout[~mask] = yout1
 
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         dat_out = [Data()]
 
         dat_out[-1].metadata['Cluster']['input_type'] = []
@@ -901,7 +997,8 @@ class SuperClass(BasicModule):
         dat_out[-1].nodata = zonal.fill_value
         dat_out[-1].metadata['Cluster']['no_clusters'] = i
         dat_out[-1].metadata['Cluster']['center'] = np.zeros([i, len(data)])
-        dat_out[-1].metadata['Cluster']['center_std'] = np.zeros([i, len(data)])
+        dat_out[-1].metadata['Cluster']['center_std'] = np.zeros([i,
+                                                                  len(data)])
 
         m = []
         s = []
@@ -919,59 +1016,30 @@ class SuperClass(BasicModule):
 
         for i in dat_out:
             i.data += 1
-            i.data = i.data.astype(np.uint8)
+            i.data = np.ma.masked_equal(i.data.filled(0).astype(int), 0)
             i.nodata = 0
-            i.data.data[i.data.mask] = 0
 
-        self.showprocesslog('Cluster complete')
+        self.showlog('Cluster complete')
 
         self.outdata['Cluster'] = dat_out
         self.outdata['Raster'] = self.indata['Raster']
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.combo_class.setCurrentText(projdata['combo_class'])
-        self.KNalgorithm.setCurrentText(projdata['KNalgorithm'])
-        self.DTcriterion.setCurrentText(projdata['DTcriterion'])
-        self.RFcriterion.setCurrentText(projdata['RFcriterion'])
-        self.SVCkernel.setCurrentText(projdata['SVCkernel'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['combo_class'] = self.combo_class.currentText()
-        projdata['KNalgorithm'] = self.KNalgorithm.currentText()
-        projdata['DTcriterion'] = self.DTcriterion.currentText()
-        projdata['RFcriterion'] = self.RFcriterion.currentText()
-        projdata['SVCkernel'] = self.SVCkernel.currentText()
-
-        return projdata
+        self.saveobj(self.cmb_class)
+        self.saveobj(self.cmb_KNalgorithm)
+        self.saveobj(self.cmb_DTcriterion)
+        self.saveobj(self.cmb_RFcriterion)
+        self.saveobj(self.cmb_SVCkernel)
 
     def init_classifier(self):
         """
@@ -993,19 +1061,19 @@ class SuperClass(BasicModule):
             Class labels.
 
         """
-        ctext = self.combo_class.currentText()
+        ctext = self.cmb_class.currentText()
 
         if ctext == 'K Neighbors Classifier':
-            alg = self.KNalgorithm.currentText()
+            alg = self.cmb_KNalgorithm.currentText()
             classifier = KNeighborsClassifier(algorithm=alg)
         elif ctext == 'Decision Tree Classifier':
-            crit = self.DTcriterion.currentText()
+            crit = self.cmb_DTcriterion.currentText()
             classifier = DecisionTreeClassifier(criterion=crit)
         elif ctext == 'Random Forest Classifier':
-            crit = self.RFcriterion.currentText()
+            crit = self.cmb_RFcriterion.currentText()
             classifier = RandomForestClassifier(criterion=crit)
         elif ctext == 'Support Vector Classifier':
-            ker = self.SVCkernel.currentText()
+            ker = self.cmb_SVCkernel.currentText()
             classifier = SVC(gamma='scale', kernel=ker)
 
         rows, cols = self.map.data[0].data.shape
@@ -1049,7 +1117,7 @@ class SuperClass(BasicModule):
         lbls = np.unique(y)
 
         if len(lbls) < 2:
-            self.showprocesslog('Error: You need at least two classes')
+            self.showlog('Error: You need at least two classes')
 
         X_train, X_test, y_train, y_test = train_test_split(x, y, stratify=y)
 
@@ -1057,35 +1125,6 @@ class SuperClass(BasicModule):
 
         return classifier, lbls, datall, X_test, y_test, tlbls
 
-    def update_map(self, polymask):
-        """
-        Update map.
-
-        Parameters
-        ----------
-        polymask : numpy array
-            Polygon mask.
-
-        Returns
-        -------
-        None.
-
-        """
-        if max(polymask) is False:
-            return
-
-        mtmp = self.combo.currentIndex()
-        mask = self.indata['Raster'][mtmp].data.mask
-
-        polymask = np.array(polymask)
-        polymask.shape = mask.shape
-        polymask = np.logical_or(polymask, mask)
-
-        dattmp = self.map.csp.get_array()
-        dattmp.mask = polymask
-        self.map.csp.changed()
-        self.map.figure.canvas.draw()
-
     def update_class_polys(self):
         """Update class poly summaries."""
         axes = self.map.figure.gca()
@@ -1157,7 +1196,6 @@ def _testfn():
     ifile = r"D:\Workdata\PyGMI Test Data\Classification\Cut_K_Th_U.ers"
 
     data = iodefs.get_raster(ifile)
-    # os.chdir(r'd:\Workdata\people\janinetest2')
 
     tmp = SuperClass(None)
     tmp.indata['Raster'] = data
