@@ -30,24 +30,28 @@ import copy
 from contextlib import redirect_stdout
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
+import matplotlib
+
+matplotlib.numpy = np
+
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 import discretize
-from SimPEG import (maps, data_misfit, regularization,
+from simpeg import (maps, data_misfit, regularization,
                     optimization, inversion, inverse_problem, directives)
-from SimPEG.electromagnetics import time_domain
-import SimPEG.data as Sdata
+from simpeg.electromagnetics import time_domain
+import simpeg.data as Sdata
 
 from pygmi import menu_default
-from pygmi.misc import QLabelVStack, BasicModule
+from pygmi.misc import QVStack2Layout, BasicModule
 
 
 class MyMplCanvas2(FigureCanvasQTAgg):
     """MPL Canvas class."""
 
     def __init__(self, parent=None):
-        fig = Figure()
+        fig = Figure(layout='constrained')
         super().__init__(fig)
 
     def update_line(self, sigma, z, times_off, zobs, zpred):
@@ -56,18 +60,16 @@ class MyMplCanvas2(FigureCanvasQTAgg):
 
         Parameters
         ----------
-        x : numpy array
-            X coordinates (period).
-        pdata : numpy array
-            Phase data.
-        rdata : numpy array
-            Apparent resistivity data.
-        depths : numpy array, optional
-            Model depths. The default is None.
-        res : numpy array, optional
-            Resistivities. The default is None.
-        title : str or None, optional
-            DESCRIPTION. The default is None.
+        sigma : numpy array
+            Conductivity values.
+        z : numpy array
+            Depth values.
+        times_off : numpy array
+            Time.
+        zobs : numpy array
+            Observed dBz/dt.
+        zpred : numpy array
+            Predicted dBz/dt.
 
         Returns
         -------
@@ -95,13 +97,21 @@ class MyMplCanvas2(FigureCanvasQTAgg):
         ax2.grid(True)
         ax2.legend(loc=3)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def disp_wave(self, times, wave, title):
         """
         Display waveform.
 
+        Parameters
+        ----------
+        times : numpy array
+            Times.
+        wave : numpy array
+            Waveform amplitude.
+        title : str
+            Title.
+
         Returns
         -------
         None.
@@ -117,7 +127,6 @@ class MyMplCanvas2(FigureCanvasQTAgg):
 
         ax1.plot(times, wave)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
@@ -135,52 +144,57 @@ class TDEM1D(BasicModule):
 
         vbl = QtWidgets.QVBoxLayout()
         hbl = QtWidgets.QHBoxLayout(self)
-        gbl = QLabelVStack()
+        vsl = QVStack2Layout()
 
         self.mmc1 = MyMplCanvas2(self)
         self.mmc = MyMplCanvas2(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combostype = QtWidgets.QComboBox()
-        self.combostype.addItems(['CircularLoop',
-                                  'MagDipole'])
+        self.cmb_stype = QtWidgets.QComboBox()
+        self.cmb_stype.addItems(['CircularLoop',
+                                 'MagDipole'])
 
-        self.combowtype = QtWidgets.QComboBox()
-        self.combowtype.addItems(['VTEMWaveform',
-                                  'RampOffWaveform',
-                                  'TrapezoidWaveform',
-                                  'QuarterSineRampOnWaveform',
-                                  'TriangularWaveform',
-                                  'HalfSineWaveform'])
-        self.combotxori = QtWidgets.QComboBox()
-        self.combotxori.addItems(['z', 'x', 'y'])
-        self.comborxori = QtWidgets.QComboBox()
-        self.comborxori.addItems(['z', 'x', 'y'])
-        self.comboline = QtWidgets.QComboBox()
-        self.combofid = QtWidgets.QComboBox()
-        self.combobalt = QtWidgets.QComboBox()
-        self.loopturns = QtWidgets.QLineEdit('1.0')
-        self.loopcurrent = QtWidgets.QLineEdit('1.0')
-        self.mu = QtWidgets.QLineEdit('1.25663706212e-06')
-        self.txarea = QtWidgets.QLineEdit('313.98')
-        self.txofftime = QtWidgets.QLineEdit('0.0100286')
-        self.txrampoff1 = QtWidgets.QLineEdit('0.01')
-        self.txpeaktime = QtWidgets.QLineEdit('0.01')
-        self.datachan = QtWidgets.QLineEdit('Z_Ch')
-        self.sig_half = QtWidgets.QLineEdit('0.1')
-        self.sig_air = QtWidgets.QLineEdit('1e-08')
-        self.rel_err = QtWidgets.QLineEdit('12')
-        self.noise_floor = QtWidgets.QLineEdit('7.5e-12')
-        self.wfile = QtWidgets.QLineEdit('')
-        self.maxiter = QtWidgets.QLineEdit('5')
+        self.cmb_wtype = QtWidgets.QComboBox()
+        self.cmb_wtype.addItems(['VTEMWaveform',
+                                 'RampOffWaveform',
+                                 'TrapezoidWaveform',
+                                 'QuarterSineRampOnWaveform',
+                                 'TriangularWaveform',
+                                 'HalfSineWaveform'])
+        self.cmb_txori = QtWidgets.QComboBox()
+        self.cmb_txori.addItems(['z', 'x', 'y'])
+        self.cmb_rxori = QtWidgets.QComboBox()
+        self.cmb_rxori.addItems(['z', 'x', 'y'])
+        self.cmb_line = QtWidgets.QComboBox()
+        self.cmb_fid = QtWidgets.QComboBox()
+        self.cmb_balt = QtWidgets.QComboBox()
+        self.le_loopturns = QtWidgets.QLineEdit('1.0')
+        self.le_loopcurrent = QtWidgets.QLineEdit('1.0')
+        self.le_mu = QtWidgets.QLineEdit('1.25663706212e-06')
+        self.le_txarea = QtWidgets.QLineEdit('313.98')
+        self.le_txofftime = QtWidgets.QLineEdit('0.0100286')
+        self.le_txrampoff1 = QtWidgets.QLineEdit('0.01')
+        self.le_txpeaktime = QtWidgets.QLineEdit('0.01')
+        self.le_datachan = QtWidgets.QLineEdit('Z_Ch')
+        self.le_sig_half = QtWidgets.QLineEdit('0.1')
+        self.le_sig_air = QtWidgets.QLineEdit('1e-08')
+        self.le_rel_err = QtWidgets.QLineEdit('12')
+        self.le_noise_floor = QtWidgets.QLineEdit('7.5e-12')
+        self.le_wfile = QtWidgets.QLineEdit('')
+        self.le_maxiter = QtWidgets.QLineEdit('5')
         pb_wfile = QtWidgets.QPushButton('Load Window Times')
         pb_wdisp = QtWidgets.QPushButton('Refresh Waveform')
 
-        self.mesh_cs = QtWidgets.QLineEdit('1')
-        self.mesh_ncx = QtWidgets.QLineEdit('10')
-        self.mesh_ncz = QtWidgets.QLineEdit('10')
-        self.mesh_npad = QtWidgets.QLineEdit('20')
-        self.mesh_padrate = QtWidgets.QLineEdit('1.3')
+        pixmapi = QtWidgets.QStyle.SP_DialogOpenButton
+        icon = self.style().standardIcon(pixmapi)
+        pb_wfile.setIcon(icon)
+        pb_wfile.setStyleSheet('text-align:left;')
+
+        self.le_mesh_cs = QtWidgets.QLineEdit('1')
+        self.le_mesh_ncx = QtWidgets.QLineEdit('10')
+        self.le_mesh_ncz = QtWidgets.QLineEdit('10')
+        self.le_mesh_npad = QtWidgets.QLineEdit('20')
+        self.le_mesh_padrate = QtWidgets.QLineEdit('1.3')
 
         self.lbl_profnum = QtWidgets.QLabel('Solution: 0')
 
@@ -191,50 +205,50 @@ class TDEM1D(BasicModule):
         buttonbox.setCenterButtons(True)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
 
-        gbl.addWidget('Line Number:', self.comboline)
-        gbl.addWidget(r'Fid/Station Name:', self.combofid)
-        gbl.addWidget('Bird Height:', self.combobalt)
-        gbl.addWidget('Data channel prefix:', self.datachan)
-        gbl.addWidget('Waveform Type:', self.combowtype)
-        gbl.addWidget('Tx Peak time:', self.txpeaktime)
-        gbl.addWidget('Tx Ramp Off start time:', self.txrampoff1)
-        gbl.addWidget('Tx Off time:', self.txofftime)
-        gbl.addWidget('Source Type:', self.combostype)
-        gbl.addWidget('Tx Orientation:', self.combotxori)
-        gbl.addWidget('Tx Area:', self.txarea)
-        gbl.addWidget('Number of turns in loop:', self.loopturns)
-        gbl.addWidget('Current in loop:', self.loopcurrent)
-        gbl.addWidget('Permeability of the background:', self.mu)
-        gbl.addWidget('Rx Orientation:', self.comborxori)
-        gbl.addWidget('Mesh cell size:', self.mesh_cs)
-        gbl.addWidget('Mesh number cells in x direction:', self.mesh_ncx)
-        gbl.addWidget('Mesh number cells in z direction:', self.mesh_ncz)
-        gbl.addWidget('Mesh number of cells to pad:', self.mesh_npad)
-        gbl.addWidget('Pad cell multiplier:', self.mesh_padrate)
-        gbl.addWidget('Conductivity Air:', self.sig_air)
-        gbl.addWidget('Conductivity Halfspace:', self.sig_half)
-        gbl.addWidget('Data Relative Error (%):', self.rel_err)
-        gbl.addWidget('Data Noise Floor:', self.noise_floor)
-        gbl.addWidget('Optimization - maximum iterations:', self.maxiter)
+        vsl.addWidget('Line Number:', self.cmb_line)
+        vsl.addWidget(r'Fid/Station Name:', self.cmb_fid)
+        vsl.addWidget('Bird Height:', self.cmb_balt)
+        vsl.addWidget('Data channel prefix:', self.le_datachan)
+        vsl.addWidget('Waveform Type:', self.cmb_wtype)
+        vsl.addWidget('Tx Peak time:', self.le_txpeaktime)
+        vsl.addWidget('Tx Ramp Off start time:', self.le_txrampoff1)
+        vsl.addWidget('Tx Off time:', self.le_txofftime)
+        vsl.addWidget('Source Type:', self.cmb_stype)
+        vsl.addWidget('Tx Orientation:', self.cmb_txori)
+        vsl.addWidget('Tx Area:', self.le_txarea)
+        vsl.addWidget('Number of turns in loop:', self.le_loopturns)
+        vsl.addWidget('Current in loop:', self.le_loopcurrent)
+        vsl.addWidget('Permeability of the background:', self.le_mu)
+        vsl.addWidget('Rx Orientation:', self.cmb_rxori)
+        vsl.addWidget('Mesh cell size:', self.le_mesh_cs)
+        vsl.addWidget('Mesh number cells in x direction:', self.le_mesh_ncx)
+        vsl.addWidget('Mesh number cells in z direction:', self.le_mesh_ncz)
+        vsl.addWidget('Mesh number of cells to pad:', self.le_mesh_npad)
+        vsl.addWidget('Pad cell multiplier:', self.le_mesh_padrate)
+        vsl.addWidget('Conductivity Air:', self.le_sig_air)
+        vsl.addWidget('Conductivity Halfspace:', self.le_sig_half)
+        vsl.addWidget('Data Relative Error (%):', self.le_rel_err)
+        vsl.addWidget('Data Noise Floor:', self.le_noise_floor)
+        vsl.addWidget('Optimization - maximum iterations:', self.le_maxiter)
 
-        gbl.addWidget(pb_wfile, self.wfile)
-        gbl.addWidget(helpdocs, pb_apply)
+        vsl.addWidget(pb_wfile, self.le_wfile)
+        vsl.addWidget(helpdocs, pb_apply)
 
         vbl.addWidget(self.mmc1)
         vbl.addWidget(pb_wdisp)
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
 
-        hbl.addLayout(gbl.layout)
+        hbl.addLayout(vsl)
         hbl.addLayout(vbl)
 
         pb_apply.clicked.connect(self.apply)
         pb_wfile.pressed.connect(self.get_wfile)
         pb_wdisp.pressed.connect(self.disp_wave)
 
-        self.comboline.currentIndexChanged.connect(self.change_line)
-        self.combowtype.currentIndexChanged.connect(self.disp_wave)
-        self.combostype.currentIndexChanged.connect(self.change_source)
+        self.cmb_line.currentIndexChanged.connect(self.change_line)
+        self.cmb_wtype.currentIndexChanged.connect(self.disp_wave)
+        self.cmb_stype.currentIndexChanged.connect(self.change_source)
 
         self.disp_wave()
 
@@ -255,31 +269,31 @@ class TDEM1D(BasicModule):
 
         self.disp_wave()
 
-        dprefix = (self.datachan.text()).lower()
-        line = self.comboline.currentText()
-        fid = float(self.combofid.currentText())
-        balt = self.combobalt.currentText()
-        txarea = float(self.txarea.text())
-        offtime = float(self.txofftime.text())
-        peaktime = float(self.txpeaktime.text())
-        loopturns = float(self.loopturns.text())
-        loopcurrent = float(self.loopcurrent.text())
-        mu = float(self.mu.text())
-        npad = int(self.mesh_npad.text())
-        padrate = float(self.mesh_padrate.text())
-        cs = float(self.mesh_cs.text())
-        ncx = float(self.mesh_ncx.text())
-        ncz = float(self.mesh_ncz.text())
-        npad = float(self.mesh_npad.text())
-        sig_half = float(self.sig_half.text())
-        sig_air = float(self.sig_air.text())
-        rel_err = float(self.rel_err.text())/100.
-        floor = float(self.noise_floor.text())
-        maxiter = int(self.maxiter.text())
+        dprefix = (self.le_datachan.text()).lower()
+        line = self.cmb_line.currentText()
+        fid = float(self.cmb_fid.currentText())
+        balt = self.cmb_balt.currentText()
+        txarea = float(self.le_txarea.text())
+        offtime = float(self.le_txofftime.text())
+        peaktime = float(self.le_txpeaktime.text())
+        loopturns = float(self.le_loopturns.text())
+        loopcurrent = float(self.le_loopcurrent.text())
+        mu = float(self.le_mu.text())
+        npad = int(self.le_mesh_npad.text())
+        padrate = float(self.le_mesh_padrate.text())
+        cs = float(self.le_mesh_cs.text())
+        ncx = float(self.le_mesh_ncx.text())
+        ncz = float(self.le_mesh_ncz.text())
+        npad = float(self.le_mesh_npad.text())
+        sig_half = float(self.le_sig_half.text())
+        sig_air = float(self.le_sig_air.text())
+        rel_err = float(self.le_rel_err.text())/100.
+        floor = float(self.le_noise_floor.text())
+        maxiter = int(self.le_maxiter.text())
 
-        txori = self.combotxori.currentText()
-        rxori = self.comborxori.currentText()
-        stype = self.combostype.currentText()
+        txori = self.cmb_txori.currentText()
+        rxori = self.cmb_rxori.currentText()
+        stype = self.cmb_stype.currentText()
 
         times = self.times
         times = times + peaktime
@@ -352,7 +366,7 @@ class TDEM1D(BasicModule):
 
         if stype == 'CircularLoop':
             srclist = [time_domain.Src.CircularLoop(rxlist,
-                                                    N=loopturns,
+                                                    n_turns=loopturns,
                                                     mu=mu,
                                                     current=loopcurrent,
                                                     location=srcloc,
@@ -437,7 +451,7 @@ class TDEM1D(BasicModule):
         z = np.r_[mesh.cell_centers_z[active][0], z,
                   mesh.cell_centers_z[active][-1]]
 
-        times_off = ((times - offtime)*1e6)
+        times_off = (times - offtime)*1e6
         zobs = dobs_sky/txarea
         zpred = -dpred_sky/txarea
 
@@ -452,16 +466,16 @@ class TDEM1D(BasicModule):
         None.
 
         """
-        stype = self.combostype.currentText()
+        stype = self.cmb_stype.currentText()
 
         if stype == 'CircularLoop':
-            self.loopcurrent.setEnabled(True)
-            self.loopturns.setEnabled(True)
-            self.txarea.setEnabled(True)
+            self.le_loopcurrent.setEnabled(True)
+            self.le_loopturns.setEnabled(True)
+            self.le_txarea.setEnabled(True)
         elif stype == 'MagDipole':
-            self.loopcurrent.setDisabled(True)
-            self.loopturns.setDisabled(True)
-            self.txarea.setDisabled(True)
+            self.le_loopcurrent.setDisabled(True)
+            self.le_loopturns.setDisabled(True)
+            self.le_txarea.setDisabled(True)
 
     def disp_wave(self):
         """
@@ -472,9 +486,9 @@ class TDEM1D(BasicModule):
         None.
 
         """
-        offtime = float(self.txofftime.text())
+        offtime = float(self.le_txofftime.text())
         times = np.linspace(0, offtime, 1000)
-        wtype = self.combowtype.currentText()
+        wtype = self.cmb_wtype.currentText()
 
         wform = self.update_wave()
 
@@ -508,14 +522,15 @@ class TDEM1D(BasicModule):
             Waveform.
 
         """
-        offtime = float(self.txofftime.text())
-        peaktime = float(self.txpeaktime.text())
-        rampoff1 = float(self.txrampoff1.text())
+        starttime = 0.
+        offtime = float(self.le_txofftime.text())
+        peaktime = float(self.le_txpeaktime.text())
+        rampoff1 = float(self.le_txrampoff1.text())
 
-        rampon = np.array([0, peaktime])
+        rampon = np.array([starttime, peaktime])
         rampoff = np.array([rampoff1, offtime])
 
-        wtype = self.combowtype.currentText()
+        wtype = self.cmb_wtype.currentText()
 
         if wtype == 'VTEMWaveform':
             wform = time_domain.sources.VTEMWaveform(off_time=offtime,
@@ -524,7 +539,8 @@ class TDEM1D(BasicModule):
             wform = time_domain.sources.TrapezoidWaveform(ramp_on=rampon,
                                                           ramp_off=rampoff)
         elif wtype == 'TriangularWaveform':
-            wform = time_domain.sources.TriangularWaveform(peak_time=peaktime,
+            wform = time_domain.sources.TriangularWaveform(start_time=starttime,
+                                                           peak_time=peaktime,
                                                            off_time=offtime)
         elif wtype == 'QuarterSineRampOnWaveform':
             wform = time_domain.sources.QuarterSineRampOnWaveform(
@@ -552,7 +568,7 @@ class TDEM1D(BasicModule):
         None.
 
         """
-        ext = ('Text file (*.txt)')
+        ext = 'Text file (*.txt)'
 
         if filename == '':
             filename, _ = QtWidgets.QFileDialog.getOpenFileName(
@@ -563,7 +579,7 @@ class TDEM1D(BasicModule):
         os.chdir(os.path.dirname(filename))
         self.times = np.loadtxt(filename)
 
-        self.wfile.setText(filename)
+        self.le_wfile.setText(filename)
 
     def change_line(self):
         """
@@ -574,11 +590,11 @@ class TDEM1D(BasicModule):
         None.
 
         """
-        self.combofid.clear()
+        self.cmb_fid.clear()
 
-        line = self.comboline.currentText()
+        line = self.cmb_line.currentText()
         fid = self.data.fid[self.data.line.astype(str) == line].values.astype(str)
-        self.combofid.addItems(fid)
+        self.cmb_fid.addItems(fid)
 
     def settings(self, nodialog=False):
         """
@@ -595,81 +611,88 @@ class TDEM1D(BasicModule):
             True if successful, False otherwise.
 
         """
-        if 'Line' in self.indata:
-            self.data = copy.deepcopy(self.indata['Line'])
-            self.data = list(self.data.values())[0]
+        if 'Vector' in self.indata:
+            self.data = copy.deepcopy(self.indata['Vector'][0])
         else:
-            self.showprocesslog('No line data')
+            self.showlog('No line data')
             return False
 
-        self.comboline.currentIndexChanged.disconnect()
-        self.comboline.clear()
-        self.combofid.clear()
-        self.combobalt.clear()
+        self.cmb_line.currentIndexChanged.disconnect()
+        self.cmb_line.clear()
+        self.cmb_fid.clear()
+        self.cmb_balt.clear()
 
         filt = ((self.data.columns != 'geometry') &
-                (self.data.columns != 'line') &
-                (self.data.columns != 'pygmiX') &
-                (self.data.columns != 'pygmiY'))
+                (self.data.columns != 'line'))
 
         cnames = list(self.data.columns[filt])
 
-        self.combobalt.addItems(cnames)
+        self.cmb_balt.addItems(cnames)
         for i, tmp in enumerate(cnames):
             tmp = tmp.lower()
             if ('elev' in tmp or 'alt' in tmp or 'height' in tmp or
                     'radar' in tmp):
-                self.combobalt.setCurrentIndex(i)
+                self.cmb_balt.setCurrentIndex(i)
                 break
 
         lines = list(self.data.line.unique().astype(str))
-        self.comboline.addItems(lines)
+        self.cmb_line.addItems(lines)
 
-        self.comboline.setCurrentIndex(0)
-        line = self.comboline.currentText()
+        self.cmb_line.setCurrentIndex(0)
+        line = self.cmb_line.currentText()
 
         fid = self.data.fid[self.data.line.astype(str) == line].values.astype(str)
-        self.combofid.addItems(fid)
+        self.cmb_fid.addItems(fid)
 
-        self.comboline.currentIndexChanged.connect(self.change_line)
+        self.cmb_line.currentIndexChanged.connect(self.change_line)
 
-        tmp = self.exec_()
+        if self.le_wfile.text() != '':
+            self.get_wfile(self.le_wfile.text())
+
+        tmp = self.exec()
 
         if tmp != 1:
             return False
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
+        self.saveobj(self.cmb_stype)
+        self.saveobj(self.cmb_wtype)
+        self.saveobj(self.cmb_txori)
+        self.saveobj(self.cmb_rxori)
+        self.saveobj(self.cmb_line)
+        self.saveobj(self.cmb_fid)
+        self.saveobj(self.cmb_balt)
 
-        return projdata
+        self.saveobj(self.le_mesh_cs)
+        self.saveobj(self.le_mesh_ncx)
+        self.saveobj(self.le_mesh_ncz)
+        self.saveobj(self.le_mesh_npad)
+        self.saveobj(self.le_mesh_padrate)
+
+        self.saveobj(self.le_loopturns)
+        self.saveobj(self.le_loopcurrent)
+        self.saveobj(self.le_mu)
+        self.saveobj(self.le_txarea)
+        self.saveobj(self.le_txofftime)
+        self.saveobj(self.le_txrampoff1)
+        self.saveobj(self.le_txpeaktime)
+        self.saveobj(self.le_datachan)
+        self.saveobj(self.le_sig_half)
+        self.saveobj(self.le_sig_air)
+        self.saveobj(self.le_rel_err)
+        self.saveobj(self.le_noise_floor)
+        self.saveobj(self.le_wfile)
+        self.saveobj(self.le_maxiter)
 
 
 def tonumber(test, alttext=None):
@@ -703,7 +726,7 @@ def tonumber(test, alttext=None):
 
 def _testfn():
     """Test routine."""
-    from pygmi.vector.iodefs import ImportLineData
+    from pygmi.vector.iodefs import ImportXYZ
 
     app = QtWidgets.QApplication(sys.argv)
 
@@ -711,12 +734,12 @@ def _testfn():
     filename = r'D:\Workdata\PyGMI Test Data\EM\SK655CS_Bookpurnong_ZX_HM_TxInc_newDTM.txt'
     wfile = r'D:\Workdata\PyGMI Test Data\EM\wtimes.txt'
 
-    IO = ImportLineData()
+    IO = ImportXYZ()
     IO.filt = 'Tab Delimited (*.txt)'
     IO.ifile = filename
-    IO.xchan.setCurrentText('e')
-    IO.ychan.setCurrentText('n')
-    IO.nodata.setText('-99999')
+    # IO.xchan.setCurrentText('e')
+    # IO.ychan.setCurrentText('n')
+    # IO.nodata.setText('-99999')
     IO.settings(True)
 
     # Run TEM1D routine
