@@ -22,12 +22,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Import Data."""
+"""Import Gravity Data."""
 
 import os
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 import pandas as pd
+import geopandas as gpd
 
 from pygmi import menu_default
 from pygmi.misc import BasicModule
@@ -35,9 +36,9 @@ from pygmi.misc import BasicModule
 
 class ImportCG5(BasicModule):
     """
-    Import Line Data.
+    Import CG-5 data.
 
-    This class imports ASCII point data.
+    This class imports CG-5 gravimeter data with associated GPS data.
     """
 
     def __init__(self, parent):
@@ -45,16 +46,16 @@ class ImportCG5(BasicModule):
 
         self.df_cg5 = None
         self.df_gps = None
+        self.is_import = True
 
-        self.line = QtWidgets.QComboBox()
-        self.station = QtWidgets.QComboBox()
-        self.xchan = QtWidgets.QComboBox()
-        self.ychan = QtWidgets.QComboBox()
-        self.zchan = QtWidgets.QComboBox()
-        self.nodata = QtWidgets.QLineEdit('-99999')
-        self.cg5file = QtWidgets.QLineEdit('')
-        self.gpsfile = QtWidgets.QLineEdit('')
-        self.basethres = QtWidgets.QLineEdit('10000')
+        self.cmb_line = QtWidgets.QComboBox()
+        self.cmb_station = QtWidgets.QComboBox()
+        self.cmb_xchan = QtWidgets.QComboBox()
+        self.cmb_ychan = QtWidgets.QComboBox()
+        self.cmb_zchan = QtWidgets.QComboBox()
+        self.le_cg5file = QtWidgets.QLineEdit('')
+        self.le_gpsfile = QtWidgets.QLineEdit('')
+        self.le_basethres = QtWidgets.QLineEdit('10000')
 
         self.setupui()
 
@@ -67,23 +68,30 @@ class ImportCG5(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.grav.iodefs.importpointdata')
-        label_line = QtWidgets.QLabel('Line:')
-        label_station = QtWidgets.QLabel('Station:')
-        label_xchan = QtWidgets.QLabel('Longitude:')
-        label_ychan = QtWidgets.QLabel('Latitude:')
-        label_zchan = QtWidgets.QLabel('Ellipsoid (GPS) Elevation:')
-        label_bthres = QtWidgets.QLabel('Minimum Base Station Number:')
+        lbl_line = QtWidgets.QLabel('Line:')
+        lbl_station = QtWidgets.QLabel('Station:')
+        lbl_xchan = QtWidgets.QLabel('Longitude:')
+        lbl_ychan = QtWidgets.QLabel('Latitude:')
+        lbl_zchan = QtWidgets.QLabel('Ellipsoid (GPS) Elevation:')
+        lbl_bthres = QtWidgets.QLabel('Minimum Base Station Number:')
         pb_cg5 = QtWidgets.QPushButton('Load CG-5 File')
         pb_gps = QtWidgets.QPushButton('Load GPS File')
 
-        self.line.setEnabled(False)
-        self.station.setEnabled(False)
-        self.xchan.setEnabled(False)
-        self.ychan.setEnabled(False)
-        self.zchan.setEnabled(False)
+        pixmapi = QtWidgets.QStyle.SP_DialogOpenButton
+        icon = self.style().standardIcon(pixmapi)
+        pb_gps.setIcon(icon)
+        pb_cg5.setIcon(icon)
+        pb_gps.setStyleSheet('text-align:left;')
+        pb_cg5.setStyleSheet('text-align:left;')
+
+        self.cmb_line.setEnabled(False)
+        self.cmb_station.setEnabled(False)
+        self.cmb_xchan.setEnabled(False)
+        self.cmb_ychan.setEnabled(False)
+        self.cmb_zchan.setEnabled(False)
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
@@ -91,32 +99,32 @@ class ImportCG5(BasicModule):
 
         self.setWindowTitle(r'Import CG-5 Data')
 
-        gridlayout_main.addWidget(self.cg5file, 0, 0, 1, 1)
-        gridlayout_main.addWidget(pb_cg5, 0, 1, 1, 1)
+        gl_main.addWidget(self.le_cg5file, 0, 1, 1, 1)
+        gl_main.addWidget(pb_cg5, 0, 0, 1, 1)
 
-        gridlayout_main.addWidget(self.gpsfile, 1, 0, 1, 1)
-        gridlayout_main.addWidget(pb_gps, 1, 1, 1, 1)
+        gl_main.addWidget(self.le_gpsfile, 1, 1, 1, 1)
+        gl_main.addWidget(pb_gps, 1, 0, 1, 1)
 
-        gridlayout_main.addWidget(label_line, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.line, 2, 1, 1, 1)
+        gl_main.addWidget(lbl_line, 2, 0, 1, 1)
+        gl_main.addWidget(self.cmb_line, 2, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_station, 3, 0, 1, 1)
-        gridlayout_main.addWidget(self.station, 3, 1, 1, 1)
+        gl_main.addWidget(lbl_station, 3, 0, 1, 1)
+        gl_main.addWidget(self.cmb_station, 3, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_xchan, 4, 0, 1, 1)
-        gridlayout_main.addWidget(self.xchan, 4, 1, 1, 1)
+        gl_main.addWidget(lbl_xchan, 4, 0, 1, 1)
+        gl_main.addWidget(self.cmb_xchan, 4, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_ychan, 5, 0, 1, 1)
-        gridlayout_main.addWidget(self.ychan, 5, 1, 1, 1)
+        gl_main.addWidget(lbl_ychan, 5, 0, 1, 1)
+        gl_main.addWidget(self.cmb_ychan, 5, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_zchan, 6, 0, 1, 1)
-        gridlayout_main.addWidget(self.zchan, 6, 1, 1, 1)
+        gl_main.addWidget(lbl_zchan, 6, 0, 1, 1)
+        gl_main.addWidget(self.cmb_zchan, 6, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_bthres, 7, 0, 1, 1)
-        gridlayout_main.addWidget(self.basethres, 7, 1, 1, 1)
+        gl_main.addWidget(lbl_bthres, 7, 0, 1, 1)
+        gl_main.addWidget(self.le_basethres, 7, 1, 1, 1)
 
-        gridlayout_main.addWidget(helpdocs, 8, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 8, 1, 1, 3)
+        gl_main.addWidget(helpdocs, 8, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 8, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -139,36 +147,36 @@ class ImportCG5(BasicModule):
 
         """
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
 
             if tmp != 1 or self.df_cg5 is None or self.df_gps is None:
                 return False
 
-        if self.line.currentText() == self.station.currentText():
-            self.showprocesslog('Your line column cannot be the same as your '
-                                'station column')
+        if self.cmb_line.currentText() == self.cmb_station.currentText():
+            self.showlog('Your line column cannot be the same as your '
+                         'station column')
             return False
 
-        tmp = [self.line.currentText(),
-               self.station.currentText(),
-               self.xchan.currentText(),
-               self.ychan.currentText(),
-               self.zchan.currentText()]
+        tmp = [self.cmb_line.currentText(),
+               self.cmb_station.currentText(),
+               self.cmb_xchan.currentText(),
+               self.cmb_ychan.currentText(),
+               self.cmb_zchan.currentText()]
 
         if len(set(tmp)) != len(tmp):
-            self.showprocesslog('Unable to import, two of your GPS file '
-                                'columns are the same. Make sure you have a '
-                                'line column in your GPS file, and that you '
-                                'did not specify the same column twice.')
+            self.showlog('Unable to import, two of your GPS file '
+                         'columns are the same. Make sure you have a '
+                         'line column in your GPS file, and that you '
+                         'did not specify the same column twice.')
             return False
 
         # Rename columns
         cren = {}
-        cren[self.line.currentText()] = 'line'
-        cren[self.station.currentText()] = 'station'
-        cren[self.xchan.currentText()] = 'longitude'
-        cren[self.ychan.currentText()] = 'latitude'
-        cren[self.zchan.currentText()] = 'elevation'
+        cren[self.cmb_line.currentText()] = 'line'
+        cren[self.cmb_station.currentText()] = 'station'
+        cren[self.cmb_xchan.currentText()] = 'longitude'
+        cren[self.cmb_ychan.currentText()] = 'latitude'
+        cren[self.cmb_zchan.currentText()] = 'elevation'
 
         self.df_gps.rename(columns=cren, inplace=True)
 
@@ -180,8 +188,8 @@ class ImportCG5(BasicModule):
             try:
                 self.df_gps.latitude = pd.to_numeric(self.df_gps.latitude)
             except ValueError:
-                self.showprocesslog('You have characters in your latitude'
-                                    ' string which could not be converted.')
+                self.showlog('You have characters in your latitude'
+                             ' string which could not be converted.')
                 return False
 
         if self.df_gps.longitude.dtype == 'O':
@@ -192,8 +200,8 @@ class ImportCG5(BasicModule):
             try:
                 self.df_gps.longitude = pd.to_numeric(self.df_gps.longitude)
             except ValueError:
-                self.showprocesslog('You have characters in your longitude'
-                                    ' string which could not be converted.')
+                self.showlog('You have characters in your longitude'
+                             ' string which could not be converted.')
                 return False
 
         # Get rid of text in line columns
@@ -215,88 +223,55 @@ class ImportCG5(BasicModule):
                            right_on=['line', 'station'], how='left')
 
         # eliminate ordinary stations (not base stations) without coordinates
-        filt = dfmerge['STATION'] < float(self.basethres.text())
+        filt = dfmerge['STATION'] < float(self.le_basethres.text())
 
         filt = filt & dfmerge['longitude'].isna()
 
         dfmerge = dfmerge[~filt]
 
-        dfmerge['pygmiX'] = dfmerge['longitude']
-        dfmerge['pygmiY'] = dfmerge['latitude']
+        x = dfmerge['longitude']
+        y = dfmerge['latitude']
+        dfmerge = gpd.GeoDataFrame(dfmerge, geometry=gpd.points_from_xy(x, y))
 
         dfmerge['line'] = dfmerge['line'].astype(str)
-        self.outdata['Line'] = {'Gravity': dfmerge}
+        dfmerge.attrs['Gravity'] = True
+        dfmerge.attrs['source'] = str(self.le_cg5file.text())
+        self.outdata['Vector'] = [dfmerge]
 
+        # Check for duplicates
         dtest = dfmerge.duplicated(['LINE', 'STATION'])
         dlist = dfmerge[['LINE', 'STATION']].loc[dtest]
         dlist = dlist[~dlist.duplicated()]
-        dlist = dlist[dlist.STATION < float(self.basethres.text())]
+        dlist = dlist[dlist.STATION < float(self.le_basethres.text())]
 
         if dlist.size > 0:
-            self.showprocesslog('Warning, the following are duplicated:')
-            self.showprocesslog(dlist.to_string(index=False))
+            self.showlog('Warning, the following are duplicated:')
+            self.showlog(dlist.to_string(index=False))
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.get_cg5(projdata['cg5file'])
-        self.get_gps(projdata['gpsfile'])
-
-        self.line.setCurrentText(projdata['line'])
-        self.station.setCurrentText(projdata['station'])
-        self.xchan.setCurrentText(projdata['xchan'])
-        self.ychan.setCurrentText(projdata['ychan'])
-        self.zchan.setCurrentText(projdata['zchan'])
-
-        self.nodata.setText(projdata['nodata'])
-        self.basethres.setText(projdata['basethres'])
-
-        chk = self.settings(True)
-
-        return chk
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
+        self.saveobj(self.cmb_line)
+        self.saveobj(self.cmb_station)
+        self.saveobj(self.cmb_xchan)
+        self.saveobj(self.cmb_ychan)
+        self.saveobj(self.cmb_zchan)
 
-        projdata['line'] = self.line.currentText()
-        projdata['station'] = self.station.currentText()
-        projdata['xchan'] = self.xchan.currentText()
-        projdata['ychan'] = self.ychan.currentText()
-        projdata['zchan'] = self.zchan.currentText()
-
-        projdata['nodata'] = self.nodata.text()
-        projdata['cg5file'] = self.cg5file.text()
-        projdata['gpsfile'] = self.gpsfile.text()
-        projdata['basethres'] = self.basethres.text()
-
-        return projdata
+        self.saveobj(self.le_cg5file)
+        self.saveobj(self.le_gpsfile)
+        self.saveobj(self.le_basethres)
 
     def get_cg5(self, filename=''):
         """
-        Get CG-5 filename.
+        Get CG-5 filename and load data.
 
         Parameters
         ----------
@@ -308,7 +283,7 @@ class ImportCG5(BasicModule):
         None.
 
         """
-        ext = ('CG-5 ASCII (*.txt *.xyz)')
+        ext = 'CG-5 ASCII (*.txt *.xyz)'
 
         if filename == '':
             filename, _ = QtWidgets.QFileDialog.getOpenFileName(
@@ -341,11 +316,11 @@ class ImportCG5(BasicModule):
         tmp2 = np.genfromtxt(data, dtype=dtype)
 
         self.df_cg5 = pd.DataFrame(tmp2)
-        self.cg5file.setText(filename)
+        self.le_cg5file.setText(filename)
 
     def get_gps(self, filename=''):
         """
-        Get GPS filename.
+        Get GPS filename and load data.
 
         Parameters
         ----------
@@ -357,7 +332,7 @@ class ImportCG5(BasicModule):
         None.
 
         """
-        ext = ('GPS comma delimited (*.csv)')
+        ext = 'GPS comma delimited (*.csv)'
 
         if filename == '':
             filename, _ = QtWidgets.QFileDialog.getOpenFileName(
@@ -372,7 +347,7 @@ class ImportCG5(BasicModule):
 
         self.df_gps = df2
 
-        self.gpsfile.setText(filename)
+        self.le_gpsfile.setText(filename)
 
         ltmp = list(df2.columns)
 
@@ -394,20 +369,20 @@ class ImportCG5(BasicModule):
             elif 'line' in tmp.lower():
                 lind = i
 
-        self.line.addItems(ltmp)
-        self.station.addItems(ltmp)
-        self.xchan.addItems(ltmp)
-        self.ychan.addItems(ltmp)
-        self.zchan.addItems(ltmp)
+        self.cmb_line.addItems(ltmp)
+        self.cmb_station.addItems(ltmp)
+        self.cmb_xchan.addItems(ltmp)
+        self.cmb_ychan.addItems(ltmp)
+        self.cmb_zchan.addItems(ltmp)
 
-        self.line.setCurrentIndex(lind)
-        self.station.setCurrentIndex(sind)
-        self.xchan.setCurrentIndex(xind)
-        self.ychan.setCurrentIndex(yind)
-        self.zchan.setCurrentIndex(zind)
+        self.cmb_line.setCurrentIndex(lind)
+        self.cmb_station.setCurrentIndex(sind)
+        self.cmb_xchan.setCurrentIndex(xind)
+        self.cmb_ychan.setCurrentIndex(yind)
+        self.cmb_zchan.setCurrentIndex(zind)
 
-        self.line.setEnabled(True)
-        self.station.setEnabled(True)
-        self.xchan.setEnabled(True)
-        self.ychan.setEnabled(True)
-        self.zchan.setEnabled(True)
+        self.cmb_line.setEnabled(True)
+        self.cmb_station.setEnabled(True)
+        self.cmb_xchan.setEnabled(True)
+        self.cmb_ychan.setEnabled(True)
+        self.cmb_zchan.setEnabled(True)
