@@ -24,10 +24,9 @@
 # -----------------------------------------------------------------------------
 """A set of Magnetic Data routines."""
 
-import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
-from scipy.signal import tukey
+from scipy.signal.windows import tukey
 import scipy.interpolate as si
 from scipy import signal
 from pygmi import menu_default
@@ -56,11 +55,13 @@ class Tilt1(BasicModule):
 
         self.sb_azi = QtWidgets.QSpinBox()
         self.sb_s = QtWidgets.QSpinBox()
+        self.sb_k = QtWidgets.QSpinBox()
 
         self.setupui()
 
         self.sb_s.setValue(self.smooth)
         self.sb_azi.setValue(self.azi)
+        self.sb_k.setValue(2)
 
     def setupui(self):
         """
@@ -71,11 +72,12 @@ class Tilt1(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.cooper.tilt')
-        label = QtWidgets.QLabel('Azimuth (degrees from east)')
-        label_2 = QtWidgets.QLabel('Smoothing Matrix Size (Odd, 0 for None)')
+        lbl_1 = QtWidgets.QLabel('Azimuth (degrees from east)')
+        lbl_2 = QtWidgets.QLabel('Smoothing Matrix Size (Odd, 0 for None)')
+        lbl_3 = QtWidgets.QLabel('EHGA k factor (2 or greater)')
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
@@ -86,15 +88,19 @@ class Tilt1(BasicModule):
         self.sb_s.setMinimum(0)
         self.sb_s.setMaximum(100000)
         self.sb_s.setSingleStep(1)
+        self.sb_k.setMinimum(1)
+        self.sb_k.setMaximum(1000)
 
         self.setWindowTitle('Tilt Angle')
 
-        gridlayout.addWidget(label_2, 0, 0, 1, 1)
-        gridlayout.addWidget(self.sb_s, 0, 1, 1, 1)
-        gridlayout.addWidget(label, 1, 0, 1, 1)
-        gridlayout.addWidget(self.sb_azi, 1, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 2, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 2, 1, 1, 1)
+        gl_1.addWidget(lbl_2, 0, 0, 1, 1)
+        gl_1.addWidget(self.sb_s, 0, 1, 1, 1)
+        gl_1.addWidget(lbl_1, 1, 0, 1, 1)
+        gl_1.addWidget(self.sb_azi, 1, 1, 1, 1)
+        gl_1.addWidget(lbl_3, 2, 0, 1, 1)
+        gl_1.addWidget(self.sb_k, 2, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 3, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 3, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -115,83 +121,69 @@ class Tilt1(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         if not nodialog:
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
         self.smooth = self.sb_s.value()
         self.azi = self.sb_azi.value()
+        kval = self.sb_k.value()
 
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         data2 = []
 
         for i in self.piter(range(len(data))):
-            t1, th, t2, ta, tdx = tilt1(data[i].data, self.azi, self.smooth)
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2[-5].data = t1
-            data2[-4].data = th
-            data2[-3].data = t2
-            data2[-2].data = ta
-            data2[-1].data = tdx
-            data2[-5].dataid += ' Standard Tilt Angle'
-            data2[-4].dataid += ' Hyperbolic Tilt Angle'
-            data2[-3].dataid += ' 2nd Order Tilt Angle'
-            data2[-2].dataid += ' Tilt Based Directional Derivative'
-            data2[-1].dataid += ' Total Derivative'
+            t1, th, t2, ta, tdx, tahg, ehga = tilt1(data[i].data, self.azi,
+                                                    self.smooth, kval)
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2.append(data[i].copy())
+            data2[-7].data = t1
+            data2[-6].data = th
+            data2[-5].data = t2
+            data2[-4].data = ta
+            data2[-3].data = tdx
+            data2[-2].data = tahg
+            data2[-1].data = ehga
+            data2[-7].dataid += ' Standard Tilt Angle'
+            data2[-6].dataid += ' Hyperbolic Tilt Angle'
+            data2[-5].dataid += ' 2nd Order Tilt Angle'
+            data2[-4].dataid += ' Tilt Based Directional Derivative'
+            data2[-3].dataid += ' Total Derivative'
+            data2[-2].dataid += ' Tilt Angle of the Horizontal Gradient'
+            data2[-1].dataid += ' Enhanced Horizontal Gradient Amplitude'
 
         for i in data2:
+            if i.nodata is None:
+                continue
             i.data.data[i.data.mask] = i.nodata
 
         self.outdata['Raster'] = data2
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.sb_s.setValue(projdata['smooth'])
-        self.sb_azi.setValue(projdata['azi'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['smooth'] = self.sb_s.value()
-        projdata['azi'] = self.sb_azi.value()
-
-        return projdata
+        self.saveobj(self.sb_s)
+        self.saveobj(self.sb_azi)
+        self.saveobj(self.sb_k)
 
 
-def tilt1(data, azi, s):
+def tilt1(data, azi, s, k=2):
     """
     Tilt angle calculations.
 
@@ -206,6 +198,8 @@ def tilt1(data, azi, s):
         directional filter azimuth in degrees from East
     s : int
         size of smoothing matrix to use - must be odd input 0 for no smoothing
+    k : int
+        Factor for EHGA filter. Must be > 0. Optional.
 
     Returns
     -------
@@ -219,6 +213,10 @@ def tilt1(data, azi, s):
         Tilt Based Directional Derivative
     tdx : numpy masked array
         Total Derivative
+    tahg : numpy masked array
+        Tilt Angle of the Horizontal Gradient
+    ehga : numpy masked array
+        Enhanced Horizontal Gradient Amplitude
     """
     dmin = data.min()
     dmax = data.max()
@@ -230,7 +228,8 @@ def tilt1(data, azi, s):
     if s > 0:
         se = np.ones((s, s))/(s*s)
         data2 = signal.convolve2d(data, se, 'valid')  # smooth
-        mask = signal.convolve2d(data.mask, se, 'valid')
+        mask = np.ma.getmaskarray(data.data)
+        mask = signal.convolve2d(mask, se, 'valid')
         data = np.ma.array(data2, mask=mask)
 
     nr, nc = data.shape
@@ -267,7 +266,24 @@ def tilt1(data, azi, s):
     # Standard tilt angle, hyperbolic tilt angle, 2nd order tilt angle,
     # Tilt Based Directional Derivative, Total Derivative
 
-    return t1, th, t2, ta, tdx
+    data = dxtot
+    nr, nc = data.shape
+    dy, dx = np.gradient(data)
+    dxtot = np.ma.sqrt(dx*dx+dy*dy)
+    nmax = np.max([nr, nc])
+    npts = int(2**nextpow2(nmax))
+    dz = vertical(data, npts, 1)
+    tahg = np.ma.arctan(dz/dxtot)
+
+    dxyztot = np.ma.sqrt(dx*dx + dy*dy + dz*dz)
+
+    ehga = np.ma.arcsin(k*(dz/dxyztot-1)+1)
+
+    ehga = k*(dz/dxyztot-1)+1
+    ehga[ehga < -1.0] = -1.0
+    ehga = np.ma.arcsin(ehga)
+
+    return t1, th, t2, ta, tdx, tahg, ehga
 
 
 def nextpow2(n):
@@ -357,7 +373,7 @@ class RTP(BasicModule):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.dataid = QtWidgets.QComboBox()
+        self.cmb_dataid = QtWidgets.QComboBox()
         self.dsb_inc = QtWidgets.QDoubleSpinBox()
         self.dsb_dec = QtWidgets.QDoubleSpinBox()
 
@@ -372,12 +388,12 @@ class RTP(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.dataprep.rtp')
-        label_band = QtWidgets.QLabel('Band to Reduce to the Pole:')
-        label_inc = QtWidgets.QLabel('Inclination of Magnetic Field:')
-        label_dec = QtWidgets.QLabel('Declination of Magnetic Field:')
+        lbl_band = QtWidgets.QLabel('Band to Reduce to the Pole:')
+        lbl_inc = QtWidgets.QLabel('Inclination of Magnetic Field:')
+        lbl_dec = QtWidgets.QLabel('Declination of Magnetic Field:')
 
         self.dsb_inc.setMaximum(90.0)
         self.dsb_inc.setMinimum(-90.0)
@@ -392,15 +408,15 @@ class RTP(BasicModule):
 
         self.setWindowTitle('Reduction to the Pole')
 
-        gridlayout_main.addWidget(label_band, 0, 0, 1, 1)
-        gridlayout_main.addWidget(self.dataid, 0, 1, 1, 1)
+        gl_main.addWidget(lbl_band, 0, 0, 1, 1)
+        gl_main.addWidget(self.cmb_dataid, 0, 1, 1, 1)
 
-        gridlayout_main.addWidget(label_inc, 1, 0, 1, 1)
-        gridlayout_main.addWidget(self.dsb_inc, 1, 1, 1, 1)
-        gridlayout_main.addWidget(label_dec, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.dsb_dec, 2, 1, 1, 1)
-        gridlayout_main.addWidget(helpdocs, 3, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 3, 1, 1, 3)
+        gl_main.addWidget(lbl_inc, 1, 0, 1, 1)
+        gl_main.addWidget(self.dsb_inc, 1, 1, 1, 1)
+        gl_main.addWidget(lbl_dec, 2, 0, 1, 1)
+        gl_main.addWidget(self.dsb_dec, 2, 1, 1, 1)
+        gl_main.addWidget(helpdocs, 3, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 3, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -422,17 +438,17 @@ class RTP(BasicModule):
         """
         tmp = []
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         for i in self.indata['Raster']:
             tmp.append(i.dataid)
 
-        self.dataid.clear()
-        self.dataid.addItems(tmp)
+        self.cmb_dataid.clear()
+        self.cmb_dataid.addItems(tmp)
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
 
             if tmp != 1:
                 return False
@@ -441,44 +457,18 @@ class RTP(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.dataid.setCurrentText(projdata['band'])
-        self.dsb_inc.setValue(projdata['inc'])
-        self.dsb_dec.setValue(projdata['dec'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['band'] = self.dataid.currentText()
-        projdata['inc'] = self.dsb_inc.value()
-        projdata['dec'] = self.dsb_dec.value()
-
-        return projdata
+        self.saveobj(self.cmb_dataid)
+        self.saveobj(self.dsb_inc)
+        self.saveobj(self.dsb_dec)
 
     def acceptall(self):
         """
@@ -496,7 +486,7 @@ class RTP(BasicModule):
 
         newdat = []
         for data in self.piter(self.indata['Raster']):
-            if data.dataid != self.dataid.currentText():
+            if data.dataid != self.cmb_dataid.currentText():
                 continue
             dat = rtp(data, I_deg, D_deg)
             newdat.append(dat)
@@ -656,6 +646,9 @@ def _testfn_rtp():
     finc = -57
     fdec = 50
 
+    finc = 17.3
+    fdec = -4.
+
     lmod = quick_model(numx=300, numy=300, numz=30, finc=finc, fdec=fdec)
     lmod.lith_index[100:200, 100:200, 0:10] = 1
     lmod.mht = 100
@@ -680,20 +673,19 @@ def _testfn():
     from IPython import get_ipython
     get_ipython().run_line_magic('matplotlib', 'inline')
 
-    ifile = 'd:/Workdata/bugs/detlef/TMI_norm_wdw.tif'
-    ifile = r'C:/Workdata/raster/ER Mapper/magmicrolevel.PD.ers'
+    ifile = r"D:\Workdata\PyGMI Test Data\Magnetics\RTP\rtptest.tif"
 
     dat = get_raster(ifile)[0]
 
-    t1, th, t2, ta, tdx = tilt1(dat.data, 75, 0)
+    t1, th, t2, ta, tdx, tahg, ehga = tilt1(dat.data, 75, 3)
 
     plt.figure(dpi=150)
-    plt.imshow(t2)
+    plt.imshow(tahg)
     plt.colorbar()
     plt.show()
 
     plt.figure(dpi=150)
-    plt.imshow(t1)
+    plt.imshow(ehga)
     plt.colorbar()
     plt.show()
 
