@@ -55,7 +55,6 @@ from math import sin
 from math import cos
 from math import sqrt
 from math import atan2
-import copy
 
 from numba import jit
 from PyQt5 import QtWidgets, QtCore
@@ -138,8 +137,8 @@ class IGRF(BasicModule):
 
         self.dsb_alt = QtWidgets.QDoubleSpinBox()
         self.dateedit = QtWidgets.QDateEdit()
-        self.combobox_dtm = QtWidgets.QComboBox()
-        self.combobox_mag = QtWidgets.QComboBox()
+        self.cmb_dtm = QtWidgets.QComboBox()
+        self.cmb_mag = QtWidgets.QComboBox()
         self.proj = dp.GroupProj('Input Projection')
 
         self.setupui()
@@ -153,14 +152,14 @@ class IGRF(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.igrf')
 
-        label_0 = QtWidgets.QLabel('Sensor clearance above ground')
-        label_1 = QtWidgets.QLabel('Date')
-        label_2 = QtWidgets.QLabel('Digital Elevation Model')
-        label_3 = QtWidgets.QLabel('Magnetic Data')
+        lbl_0 = QtWidgets.QLabel('Sensor clearance above ground')
+        lbl_1 = QtWidgets.QLabel('Date')
+        lbl_2 = QtWidgets.QLabel('Digital Elevation Model')
+        lbl_3 = QtWidgets.QLabel('Magnetic Data')
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
@@ -169,17 +168,17 @@ class IGRF(BasicModule):
 
         self.setWindowTitle('IGRF')
 
-        gridlayout.addWidget(self.proj, 0, 0, 1, 2)
-        gridlayout.addWidget(label_0, 2, 0, 1, 1)
-        gridlayout.addWidget(self.dsb_alt, 2, 1, 1, 1)
-        gridlayout.addWidget(label_1, 3, 0, 1, 1)
-        gridlayout.addWidget(self.dateedit, 3, 1, 1, 1)
-        gridlayout.addWidget(label_2, 4, 0, 1, 1)
-        gridlayout.addWidget(self.combobox_dtm, 4, 1, 1, 1)
-        gridlayout.addWidget(label_3, 5, 0, 1, 1)
-        gridlayout.addWidget(self.combobox_mag, 5, 1, 1, 1)
-        gridlayout.addWidget(buttonbox, 6, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_1.addWidget(self.proj, 0, 0, 1, 2)
+        gl_1.addWidget(lbl_0, 2, 0, 1, 1)
+        gl_1.addWidget(self.dsb_alt, 2, 1, 1, 1)
+        gl_1.addWidget(lbl_1, 3, 0, 1, 1)
+        gl_1.addWidget(self.dateedit, 3, 1, 1, 1)
+        gl_1.addWidget(lbl_2, 4, 0, 1, 1)
+        gl_1.addWidget(self.cmb_dtm, 4, 1, 1, 1)
+        gl_1.addWidget(lbl_3, 5, 0, 1, 1)
+        gl_1.addWidget(self.cmb_mag, 5, 1, 1, 1)
+        gl_1.addWidget(buttonbox, 6, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 6, 0, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -200,52 +199,52 @@ class IGRF(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         for i in self.indata['Raster']:
             if i.crs is None:
-                self.showprocesslog(f'{i.dataid} has no projection. '
-                                    'Please assign one.')
+                self.showlog(f'{i.dataid} has no projection. '
+                             'Please assign one.')
                 return False
 
         if self.wkt is None:
-            self.wkt = self.indata['Raster'][0].crs.wkt
+            self.wkt = self.indata['Raster'][0].crs.to_wkt()
 
         self.proj.set_current(self.wkt)
 
         data = self.indata['Raster']
 
-        self.combobox_dtm.clear()
-        self.combobox_mag.clear()
+        self.cmb_dtm.clear()
+        self.cmb_mag.clear()
         for i in data:
-            self.combobox_dtm.addItem(i.dataid)
-            self.combobox_mag.addItem(i.dataid)
+            self.cmb_dtm.addItem(i.dataid)
+            self.cmb_mag.addItem(i.dataid)
 
         if len(data) > 1:
-            self.combobox_dtm.setCurrentIndex(1)
+            self.cmb_dtm.setCurrentIndex(1)
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
 
             if tmp == 0:
                 return False
 
-        i = self.combobox_mag.currentIndex()
+        i = self.cmb_mag.currentIndex()
 
         for i in data:
-            if i.dataid == self.combobox_mag.currentText():
+            if i.dataid == self.cmb_mag.currentText():
                 dxy = min(i.xdim, i.ydim)
 
         data = dp.lstack(data, dxy=dxy, piter=self.piter,
-                         pprint=self.showprocesslog)
+                         showlog=self.showlog)
 
         for i in data:
-            if i.dataid == self.combobox_mag.currentText():
+            if i.dataid == self.cmb_mag.currentText():
                 maggrid = i
-            if i.dataid == self.combobox_dtm.currentText():
+            if i.dataid == self.cmb_dtm.currentText():
                 data = i
-                wkt = i.crs.wkt
+                wkt = i.crs.to_wkt()
 
         sdate = self.dateedit.date()
         sdate = sdate.year()+sdate.dayOfYear()/sdate.daysInYear()
@@ -254,66 +253,44 @@ class IGRF(BasicModule):
         odata, fmean, imean, dmean = calc_igrf(data, sdate, alt=alt, wkt=wkt,
                                                igrfonly=False,
                                                piter=self.piter,
-                                               pprint=self.showprocesslog)
+                                               showlog=self.showlog)
+        if odata is None:
+            return False
+
         bname = 'Magnetic Data: IGRF Corrected '
         bname = bname + f'F:{fmean:.2f} I:{imean:.2f} D:{dmean:.2f}'
 
         self.outdata['Raster'] = odata
 
-        self.outdata['Raster'].append(copy.deepcopy(maggrid))
+        self.outdata['Raster'].append(maggrid.copy())
         self.outdata['Raster'][-1].data -= odata[0].data
         self.outdata['Raster'][-1].dataid = bname
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.wkt = projdata['wkt']
-        self.dsb_alt.setValue(projdata['alt'])
-        date = self.dateedit.date().fromString(projdata['date'])
-        self.dateedit.setDate(date)
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['wkt'] = self.proj.wkt
-        projdata['alt'] = self.dsb_alt.value()
-        projdata['date'] = self.dateedit.date().toString()
-
-        return projdata
+        self.saveobj(self.wkt)
+        self.saveobj(self.dsb_alt)
+        self.saveobj(self.dateedit)
+        self.saveobj(self.cmb_dtm)
+        self.saveobj(self.cmb_mag)
 
 
 def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
-              pprint=print):
+              showlog=print):
     """
     Calculate IGRF.
 
     Parameters
     ----------
-    data : PyGMI data
+    data : PyGMI Data
         Input magnetic data.
     sdate : Date
         Survey date.
@@ -323,15 +300,15 @@ def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
         WKT projection. The default is None.
     igrfonly : bool, optional
         Output IGRF only. The default is True.
-    piter : iter, optional
+    piter : function, optional
         Progress bar iterator. The default is iter.
-    pprint : print, optional
-        Print routine. The default is print.
+    showlog : function, optional
+        Display information. The default is print.
 
     Returns
     -------
-    outdata : PyGMI data
-        Output data.
+    outdata : list of PyGMI Data.
+        Output PyGMI Data.
     fmean : float
         Total intensity mean.
     imean : float
@@ -340,7 +317,7 @@ def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
         Declination mean.
     """
     MAXDEG = 13
-    MAXCOEFF = (MAXDEG*(MAXDEG+2)+1)
+    MAXCOEFF = MAXDEG*(MAXDEG+2)+1
 
     gh = np.zeros([4, MAXCOEFF])
 
@@ -397,9 +374,9 @@ def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
     igdgc = 1
 
     if maxyr < sdate < maxyr+1:
-        pprint('Warning: The date ' + str(sdate) + ' is out of range,')
-        pprint('but still within one year of model expiration date.')
-        pprint('An updated model file is available before 1.1.' + str(maxyr))
+        showlog('Warning: The date ' + str(sdate) + ' is out of range,')
+        showlog('but still within one year of model expiration date.')
+        showlog('An updated model file is available before 1.1.' + str(maxyr))
 
     if max2[modelI] == 0:
         gh = getshc(modbuff, 1, irec_pos[modelI], max1[modelI], 0, gh)
@@ -417,21 +394,15 @@ def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
                             max2[modelI], 3, gh)
 
     if wkt is not None:
-        xdat, ydat = reprojxy(xdat, ydat, wkt, 4326)
+        xdat, ydat = reprojxy(xdat, ydat, wkt, 4326, showlog)
+        if xdat is None:
+            return None, None, None, None
 
     for i in piter(range(xdat.size)):
         if igrf_F.mask[i]:
             continue
 
-        # if wkt is not None:
-        #     longitude, latitude = reprojxy(xdat[i], ydat[i], wkt, 4326)
-        # else:
-        #     longitude, latitude = xdat[i], ydat[i]
-
         longitude, latitude = xdat[i], ydat[i]
-        # if xdat1[i]-longitude != 0 or ydat1[i]-latitude != 0:
-        #     print('broken')
-
         alt = altgrid[i]
 
         # Do the first calculations
@@ -458,23 +429,23 @@ def calc_igrf(data, sdate, alt=100, wkt=None, igrfonly=True, piter=iter,
     imean = igrf_I.mean()
     dmean = igrf_D.mean()
 
-    pprint('Mean Values in Calculation')
-    pprint('=============================')
-    pprint(f'Total Intensity: {fmean:.2f}')
-    pprint(f'Inclination: {imean:.2f}')
-    pprint(f'Declination: {dmean:.2f}')
+    showlog('Mean Values in Calculation')
+    showlog('=============================')
+    showlog(f'Total Intensity: {fmean:.2f}')
+    showlog(f'Inclination: {imean:.2f}')
+    showlog(f'Declination: {dmean:.2f}')
 
     outdata = []
-    outdata.append(copy.deepcopy(data))
+    outdata.append(data.copy())
     outdata[-1].data = igrf_F
     outdata[-1].dataid = 'IGRF'
 
     if not igrfonly:
-        outdata.append(copy.deepcopy(data))
+        outdata.append(data.copy())
         outdata[-1].data = igrf_I
         outdata[-1].dataid = 'Inclination'
 
-        outdata.append(copy.deepcopy(data))
+        outdata.append(data.copy())
         outdata[-1].data = igrf_D
         outdata[-1].dataid = 'Declination'
 
@@ -786,7 +757,7 @@ def shval3(igdgc, flat, flon, elev, nmax, igh, gh):
         fm = m
         if k >= 5:
             if m == n:
-                argument = (1.0 - 0.5/fm)
+                argument = 1.0 - 0.5/fm
                 aa = sqrt(argument)
                 j = k - n - 1
                 p[k] = (1.0 + 1.0/fm) * aa * clat * p[j]
@@ -817,7 +788,7 @@ def shval3(igdgc, flat, flon, elev, nmax, igh, gh):
             x = x + cc * q[k]
             z = z - cc * p[k]
             if clat > 0:
-                y = (y + (aa*sl[m] - bb*cl[m])*fm*p[k]/((fn + 1.0)*clat))
+                y = y + (aa*sl[m] - bb*cl[m])*fm*p[k]/((fn + 1.0)*clat)
             else:
                 y = y + (aa*sl[m] - bb*cl[m])*q[k]*slat
             l = l + 2
@@ -898,7 +869,7 @@ def _testfn():
     import sys
     from pygmi.raster.iodefs import get_raster
 
-    ifile = r'C:/Workdata/testdata.hdr'
+    ifile = r"D:\Workdata\PyGMI Test Data\Raster\testdata.hdr"
 
     dat = get_raster(ifile)
 
