@@ -37,7 +37,6 @@ from math import pi
 import numpy as np
 
 from PyQt5 import QtWidgets
-from matplotlib.colors import ListedColormap
 from matplotlib import colormaps
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
@@ -47,7 +46,7 @@ from numba import jit
 from pygmi.raster.datatypes import Data
 from pygmi.raster.cooper import vertical
 from pygmi.raster.dataprep import lstack
-from pygmi.mag.dataprep import rtp
+from pygmi.mag.dataprep import rtp, nextpow2
 from pygmi.vector.dataprep import quickgrid
 from pygmi.misc import frm, ProgressBar, BasicModule
 from pygmi import menu_default
@@ -83,12 +82,13 @@ class TiltDepth(BasicModule):
         self.mmc = FigureCanvasQTAgg(self.figure)
         self.axes = self.figure.add_subplot(111)
 
-        self.cbox_band1 = QtWidgets.QComboBox()
-        self.cbox_cbar = QtWidgets.QComboBox(self)
+        self.cmb_band1 = QtWidgets.QComboBox()
+        self.cmb_cbar = QtWidgets.QComboBox(self)
         self.dsb_inc = QtWidgets.QDoubleSpinBox()
         self.dsb_dec = QtWidgets.QDoubleSpinBox()
         self.btn_apply = QtWidgets.QPushButton('Calculate Tilt Depth')
         self.btn_save = QtWidgets.QPushButton('Save Depths to Text File')
+        self.cb_rtp = QtWidgets.QCheckBox('Perform RTP on data')
         self.pbar = ProgressBar()
 
         self.setupui()
@@ -103,10 +103,10 @@ class TiltDepth(BasicModule):
 
         """
         helpdocs = menu_default.HelpButton('pygmi.raster.tiltdepth')
-        label2 = QtWidgets.QLabel('Band to perform Tilt Depth:')
-        labelc = QtWidgets.QLabel('Colour Bar:')
-        label_inc = QtWidgets.QLabel('Inclination of Magnetic Field:')
-        label_dec = QtWidgets.QLabel('Declination of Magnetic Field:')
+        lbl_2 = QtWidgets.QLabel('Band to perform Tilt Depth:')
+        lbl_c = QtWidgets.QLabel('Colour Bar:')
+        lbl_inc = QtWidgets.QLabel('Inclination of Magnetic Field:')
+        lbl_dec = QtWidgets.QLabel('Declination of Magnetic Field:')
 
         self.dsb_inc.setMaximum(90.0)
         self.dsb_inc.setMinimum(-90.0)
@@ -114,6 +114,7 @@ class TiltDepth(BasicModule):
         self.dsb_dec.setMaximum(360.0)
         self.dsb_dec.setMinimum(-360.0)
         self.dsb_dec.setValue(-17.)
+        self.cb_rtp.setChecked(True)
 
         vbl_raster = QtWidgets.QVBoxLayout()
         hbl_all = QtWidgets.QHBoxLayout(self)
@@ -123,18 +124,20 @@ class TiltDepth(BasicModule):
         spacer = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum,
                                        QtWidgets.QSizePolicy.Expanding)
         tmp = sorted(colormaps.keys())
-        self.cbox_cbar.addItem('jet')
-        self.cbox_cbar.addItems(tmp)
+        self.cmb_cbar.addItem('viridis')
+        self.cmb_cbar.addItems(tmp)
 
         self.setWindowTitle('Tilt Depth Interpretation')
 
-        vbl_raster.addWidget(label2)
-        vbl_raster.addWidget(self.cbox_band1)
-        vbl_raster.addWidget(labelc)
-        vbl_raster.addWidget(self.cbox_cbar)
-        vbl_raster.addWidget(label_inc)
+        vbl_raster.addWidget(lbl_2)
+        vbl_raster.addWidget(self.cmb_band1)
+        vbl_raster.addWidget(lbl_c)
+        vbl_raster.addWidget(self.cmb_cbar)
+
+        vbl_raster.addWidget(self.cb_rtp)
+        vbl_raster.addWidget(lbl_inc)
         vbl_raster.addWidget(self.dsb_inc)
-        vbl_raster.addWidget(label_dec)
+        vbl_raster.addWidget(lbl_dec)
         vbl_raster.addWidget(self.dsb_dec)
         vbl_raster.addWidget(self.btn_apply)
         vbl_raster.addWidget(self.pbar)
@@ -147,9 +150,26 @@ class TiltDepth(BasicModule):
         hbl_all.addLayout(vbl_raster)
         hbl_all.addLayout(vbl_right)
 
-        self.cbox_cbar.currentIndexChanged.connect(self.change_cbar)
-        self.btn_apply.clicked.connect(self.change_band1)
+        self.cmb_cbar.currentIndexChanged.connect(self.change_cbar)
+        self.btn_apply.clicked.connect(self.calculate)
         self.btn_save.clicked.connect(self.save_depths)
+        self.cb_rtp.clicked.connect(self.rtp_choice)
+
+    def rtp_choice(self):
+        """
+        Check if RTP must be done.
+
+        Returns
+        -------
+        None.
+
+        """
+        if self.cb_rtp.isChecked():
+            self.dsb_inc.setEnabled(True)
+            self.dsb_dec.setEnabled(True)
+        else:
+            self.dsb_inc.setEnabled(False)
+            self.dsb_dec.setEnabled(False)
 
     def save_depths(self):
         """
@@ -174,7 +194,7 @@ class TiltDepth(BasicModule):
 
         os.chdir(os.path.dirname(filename))
         np.savetxt(filename, self.depths, delimiter=',',
-                   header='x, y, id, depth')
+                   header='x, y, id, depth', comments='')
 
         QtWidgets.QMessageBox.information(self.parent, 'Information',
                                           'Save completed!')
@@ -190,39 +210,31 @@ class TiltDepth(BasicModule):
         None.
 
         """
-        zout = self.indata['Raster'][0]
-        txt = str(self.cbox_cbar.currentText())
+        if 'Raster' not in self.outdata:
+            return
+
+        zout = self.outdata['Raster'][0]
+        txt = str(self.cmb_cbar.currentText())
 
         self.figure.clear()
         self.axes = self.figure.add_subplot(111)
 
-        self.axes.contour(self.X, self.Y, self.Z, [0])
-        self.axes.contour(self.X, self.Y, self.Z, [45], linestyles='dashed')
-        self.axes.contour(self.X, self.Y, self.Z, [-45], linestyles='dashed')
-
         cmap = colormaps[txt]
-        cmap2 = np.array([cmap(i) for i in range(cmap.N)])
-        low = int(cmap.N*(45/180))
-        high = int(cmap.N*(135/180))
-        cmap2[low:high] = cmap2[int(cmap.N/2)]
 
-        cmap3 = ListedColormap(cmap2)
-        ims = self.axes.imshow(self.Z, extent=zout.extent, cmap=cmap3)
+        vmin = zout.data.mean() - 2.5*zout.data.std()
+        vmax = zout.data.mean() + 2.5*zout.data.std()
 
-        if self.x0 is not None:
-            i = 0
-            self.axes.plot(self.x1[i], self.y1[i], 'oy')
-            self.axes.plot(self.x0[i], self.y0[i], 'sy')
-            self.axes.plot(self.x2[i], self.y2[i], 'oy')
+        ims = self.axes.imshow(zout.data, extent=zout.extent, cmap=cmap,
+                               interpolation='nearest', vmin=vmin, vmax=vmax)
 
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
 
-        self.figure.colorbar(ims, format=frm)
+        self.figure.colorbar(ims, format=frm, label='Depth')
 
         self.figure.canvas.draw()
 
-    def change_band1(self):
+    def calculate(self):
         """
         Routine which occurs when apply button is pressed.
 
@@ -231,20 +243,21 @@ class TiltDepth(BasicModule):
         None.
 
         """
-        txt = str(self.cbox_band1.currentText())
+        txt = str(self.cmb_band1.currentText())
 
         self.btn_apply.setText('Calculating...')
-        QtWidgets.QApplication.processEvents()
         self.btn_apply.setEnabled(False)
 
         for i in self.indata['Raster']:
             if i.dataid == txt:
-                self.tiltdepth(i)
-                self.change_cbar()
+                dat = i
+                break
+
+        self.tiltdepth(dat)
+        self.change_cbar()
 
         self.btn_apply.setEnabled(True)
         self.btn_apply.setText('Calculate Tilt Depth')
-        QtWidgets.QApplication.processEvents()
 
     def settings(self, nodialog=False):
         """
@@ -262,7 +275,7 @@ class TiltDepth(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         self.indata['Raster'] = lstack(self.indata['Raster'])
@@ -272,45 +285,32 @@ class TiltDepth(BasicModule):
         for i in data:
             blist.append(i.dataid)
 
-        self.cbox_band1.clear()
-        self.cbox_band1.addItems(blist)
+        self.cmb_band1.clear()
+        self.cmb_band1.addItems(blist)
 
-        if nodialog is False:
-            self.show()
-        QtWidgets.QApplication.processEvents()
+        if not nodialog:
+            tmp = self.exec()
+        else:
+            tmp = 1
+
+        if tmp != 1:
+            return False
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.cmb_band1)
+        self.saveobj(self.cmb_cbar)
+        self.saveobj(self.dsb_inc)
+        self.saveobj(self.dsb_dec)
 
     def tiltdepth(self, data):
         """
@@ -335,15 +335,22 @@ class TiltDepth(BasicModule):
         inc = self.dsb_inc.value()
         dec = self.dsb_dec.value()
 
-        zout = rtp(data, inc, dec)
+        if self.cb_rtp.isChecked():
+            zout = rtp(data, inc, dec)
+        else:
+            zout = data
 
         # Tilt
         self.pbar.setValue(1)
 
         nr, nc = zout.data.shape
         dy, dx = np.gradient(zout.data)
-        dxtot = np.sqrt(dx**2+dy**2)
-        dz = vertical(zout.data)
+        dxtot = np.ma.sqrt(dx**2+dy**2)
+
+        nmax = np.max([nr, nc])
+        npts = int(2**nextpow2(nmax))
+        dz = vertical(zout.data, npts, 1)
+
         t1 = np.arctan(dz/dxtot)
 
         self.pbar.setValue(2)
@@ -421,7 +428,7 @@ class TiltDepth(BasicModule):
         self.depths = np.transpose([gx0, gy0, cntid0.astype(int), dist])
 
         tmp = quickgrid(gx0, gy0, dist, data.xdim,
-                        showprocesslog=self.showprocesslog)
+                        showlog=self.showlog)
 
         mask = np.ma.getmaskarray(tmp)
         gdat = tmp.data
@@ -431,12 +438,12 @@ class TiltDepth(BasicModule):
         dat.data.mask = mask[::-1]
         dat.nodata = dat.data.fill_value
         dat.set_transform(data.xdim, gx0.min(), data.ydim, gy0.max())
-        dat.dataid = data.dataid
+        dat.dataid = data.dataid+' depths'
 
         self.outdata['Raster'] = [dat]
 
 
-@jit(nopython=True, nogil=True)
+@jit(nopython=True)
 def distpc(dx, dy, dx0, dy0, dcnt):
     """
     Find closest distances.
@@ -500,18 +507,23 @@ def vgrad(cnt):
     cntid = []
 
     n = 0
-    for cntvert in cnt.allsegs[0]:
-        n += 1
+    for path in cnt.get_paths():
 
-        dx = np.diff(cntvert[:, 0])
-        dy = np.diff(cntvert[:, 1])
+        cntv = path.vertices
+        cntc = path.codes
+        cnt2 = np.split(cntv, np.where(cntc == 1)[0][1:])
+        for cntvert in cnt2:
+            n += 1
 
-        cntid.extend([n]*dx.size)
+            dx = np.diff(cntvert[:, 0])
+            dy = np.diff(cntvert[:, 1])
 
-        gx.extend((cntvert[:, 0][:-1] + dx/2).tolist())
-        gy.extend((cntvert[:, 1][:-1] + dy/2).tolist())
-        dx2.extend(dx)
-        dy2.extend(dy)
+            cntid.extend([n]*dx.size)
+
+            gx.extend((cntvert[:, 0][:-1] + dx/2).tolist())
+            gy.extend((cntvert[:, 1][:-1] + dy/2).tolist())
+            dx2.extend(dx)
+            dy2.extend(dy)
 
     cgrad = np.arctan2(dy2, dx2)
     cgrad = np.rad2deg(cgrad)
@@ -519,3 +531,29 @@ def vgrad(cnt):
     cgrad[cgrad < -90] += 180.
 
     return np.array(gx), np.array(gy), cgrad, np.array(cntid)
+
+
+def _testfn():
+    """RTP testing routine."""
+    import sys
+    from pygmi.raster.iodefs import get_raster
+
+    ifile = r"D:\Workdata\PyGMI Test Data\Magnetics\IGRF\MAGMICROLEVEL.ers"
+
+    dat = get_raster(ifile)
+
+    app = QtWidgets.QApplication(sys.argv)
+
+    tmp1 = TiltDepth()
+    tmp1.indata['Raster'] = dat
+    tmp1.cb_rtp.setChecked(False)
+    tmp1.dsb_inc.setValue(-63.)
+    tmp1.dsb_dec.setValue(-16.)
+
+    tmp1.settings()
+
+    dat = tmp1.outdata
+
+
+if __name__ == "__main__":
+    _testfn()
