@@ -38,20 +38,24 @@ pygmi packages.
 import json
 import sys
 import os
+import gc
+import textwrap
 import pkgutil
 import math
 import importlib
 from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
+import psutil
 from matplotlib import rcParams
 from matplotlib import interactive
 
 import pygmi
 from pygmi import menu_default
-from pygmi import misc
+from pygmi.misc import ProgressBar, textwrap2
 
 rcParams['axes.formatter.limits'] = [-12, 12]
 rcParams['axes.formatter.useoffset'] = False
+rcParams['font.size'] = 8
 interactive(False)
 
 QtCore.QLocale.setDefault(QtCore.QLocale.c())
@@ -188,8 +192,7 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
     context_menu = context_menu
     my_class : object
         Class that the diagram item is linked to.
-    is_import : bool
-        Flags whether my_class is used to import data
+
     text_item : None
     my_class_name : str
         Class name being referenced
@@ -204,10 +207,9 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         self.diagram_type = diagram_type
         self.context_menu = context_menu
         self.my_class = my_class
-        self.is_import = False
         self.text_item = None
         self.my_class_name = ''
-        self.showprocesslog = parent.showprocesslog
+        self.showlog = parent.showlog
 
         if hasattr(self.my_class, 'arrows'):
             self.my_class.arrows = self.arrows
@@ -299,7 +301,6 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         """
         self.scene().clearSelection()
         self.setSelected(True)
-        exclude = ['GenFPS', 'SceneList']
 
         tmp = self.context_menu['Basic'].actions()
         if ('Raster' in self.my_class.indata and
@@ -308,10 +309,30 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
 
         tmplist = list(self.my_class.outdata.keys())
         for i in tmplist:
-            if i not in exclude:
-                tmp += self.context_menu[i].actions()
+            if i not in self.context_menu:
+                continue
+            tmp += self.context_menu[i].actions()
+            if (i == 'Cluster' and i in self.my_class.outdata and 'memdat' in
+                    self.my_class.outdata['Cluster'][0].metadata['Cluster']):
+                tmp += self.context_menu['memCluster'].actions()
+            if i == 'Vector':
+                gtype = self.my_class.outdata['Vector'][0].geom_type.iloc[0]
+                if gtype == 'LineString':
+                    tmp += self.context_menu['lineVector'].actions()
+                if gtype == 'Point':
+                    tmp += self.context_menu['pntVector'].actions()
+        tmp1 = []
+        tmp2 = []
+        for val in tmp:
+            if 'Export' in val.text():
+                tmp2.append(val)
+            else:
+                tmp1.append(val)
+
         local_menu = QtWidgets.QMenu()
-        local_menu.addActions(tmp)
+        local_menu.addActions(tmp1)
+        local_menu.addSeparator()
+        local_menu.addActions(tmp2)
         local_menu.exec_(event.screenPos())
 
     def mouseDoubleClickEvent(self, event):
@@ -324,7 +345,12 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         """
         self.setBrush(QtGui.QColor(255, 0, 0, 127))
 
-        temp = self.settings()
+        try:
+            temp = self.settings()
+        except MemoryError:
+            self.parent.showlog('Memory Error! Process aborted.')
+            temp = False
+            self.my_class.parent.process_is_active(False)
         self.parent.scene.selected_item_info()
 
         if temp is True:
@@ -369,20 +395,31 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
             method.
 
         """
-        if self.my_class.indata == {} and self.is_import is False:
+        if self.my_class.indata == {} and self.my_class.is_import is False:
             QtWidgets.QMessageBox.warning(self.parent, 'Warning',
                                           ' You need to connect data first!',
                                           QtWidgets.QMessageBox.Ok)
             return False
 
+        if self.text_item is not None:
+            self.text_item.setPlainText(self.my_class_name)
+
         self.my_class.parent.process_is_active()
-        self.showprocesslog(self.my_class_name+' busy...')
+        self.showlog(self.my_class_name+' busy...')
         iflag = self.my_class.settings(nodialog)
         self.my_class.parent.process_is_active(False)
         if iflag:
-            self.showprocesslog(self.my_class_name+' finished!')
+            self.showlog(self.my_class_name+' finished!')
         else:
-            self.showprocesslog(self.my_class_name+' cancelled.')
+            self.showlog(self.my_class_name+' cancelled.')
+
+        if self.my_class.is_import is True and self.text_item is not None:
+            ifile = os.path.basename(self.my_class.ifile)
+            ifile = textwrap2(ifile, width=10, max_lines=2)
+
+            if ifile != '':
+                self.text_item.setPlainText(f'{self.my_class_name}:\n{ifile}')
+
         return iflag
 
 
@@ -428,6 +465,8 @@ class DiagramScene(QtWidgets.QGraphicsScene):
     def selected_item_info(self):
         """Display info about selected item."""
         tmp = self.selectedItems()
+        self.parent.showdatainfo('')
+
         if not tmp:
             return
 
@@ -442,7 +481,7 @@ class DiagramScene(QtWidgets.QGraphicsScene):
             for i in idata:
                 text += '\nInput ' + i + ' dataset: '
                 if i in 'Raster':
-                    if hasattr(idata[i][0], 'filename'):
+                    if idata[i] and hasattr(idata[i][0], 'filename'):
                         file = idata[i][0].filename
                     else:
                         file = i
@@ -460,7 +499,7 @@ class DiagramScene(QtWidgets.QGraphicsScene):
                 if i == 'RasterFileList':
                     text += i + '\n'
                     for j in odata[i]:
-                        text += os.path.basename(j) + '\n'
+                        text += os.path.basename(j.filename) + '\n'
                 if i in ('Raster', 'Cluster'):
                     if hasattr(odata[i][0], 'filename'):
                         file = odata[i][0].filename
@@ -563,11 +602,11 @@ class MainWidget(QtWidgets.QMainWindow):
         self.toolbar = QtWidgets.QToolBar()
 
         self.centralwidget = QtWidgets.QWidget()
-        self.grid_layout = QtWidgets.QGridLayout(self.centralwidget)
+        self.gl_1 = QtWidgets.QGridLayout(self.centralwidget)
         self.graphics_view = QtWidgets.QGraphicsView()
         self.textbrowser_datainfo = QtWidgets.QTextBrowser()
         self.textbrowser_processlog = QtWidgets.QTextBrowser()
-        self.pbar = misc.ProgressBar()
+        self.pbar = ProgressBar()
 
         self.action_run = QtWidgets.QAction(self)
         self.action_help = QtWidgets.QAction(self)
@@ -616,7 +655,10 @@ class MainWidget(QtWidgets.QMainWindow):
             if i == 'pygmi.__pycache__.menu':
                 continue
             start.update()
-            menuimports.append(importlib.import_module(i))
+            try:
+                menuimports.append(importlib.import_module(i))
+            except ModuleNotFoundError as err:
+                self.showlog(f'{i} cannot be loaded, {err}')
         start.close()
 
         self.menus = []
@@ -664,15 +706,20 @@ class MainWidget(QtWidgets.QMainWindow):
         self.textbrowser_datainfo.setSizePolicy(sizepolicy)
         self.textbrowser_processlog.setSizePolicy(sizepolicy)
 
-        self.grid_layout.addWidget(self.graphics_view, 0, 0, 4, 2)
-        self.grid_layout.addWidget(self.textbrowser_datainfo, 1, 2, 1, 1)
-        self.grid_layout.addWidget(self.textbrowser_processlog, 3, 2, 1, 1)
-        self.grid_layout.addWidget(self.pbar, 5, 0, 1, 3)
+        fstyle = QtWidgets.QFrame.Shape.Box | QtWidgets.QFrame.Shadow.Plain
+        self.textbrowser_datainfo.setFrameStyle(fstyle)
+        self.textbrowser_processlog.setFrameStyle(fstyle)
+        self.graphics_view.setFrameStyle(fstyle)
 
-        label = QtWidgets.QLabel('Dataset Information:')
-        label_2 = QtWidgets.QLabel('Process Log:')
-        self.grid_layout.addWidget(label, 0, 2, 1, 1)
-        self.grid_layout.addWidget(label_2, 2, 2, 1, 1)
+        self.gl_1.addWidget(self.graphics_view, 0, 0, 4, 2)
+        self.gl_1.addWidget(self.textbrowser_datainfo, 1, 2, 1, 1)
+        self.gl_1.addWidget(self.textbrowser_processlog, 3, 2, 1, 1)
+        self.gl_1.addWidget(self.pbar, 5, 0, 1, 3)
+
+        lbl_1 = QtWidgets.QLabel('Dataset Information:')
+        lbl_2 = QtWidgets.QLabel('Process Log:')
+        self.gl_1.addWidget(lbl_1, 0, 2, 1, 1)
+        self.gl_1.addWidget(lbl_2, 2, 2, 1, 1)
 
         self.setCentralWidget(self.centralwidget)
         self.setMenuBar(self.menubar)
@@ -744,12 +791,16 @@ class MainWidget(QtWidgets.QMainWindow):
             if isinstance(item, DiagramItem):
                 item.remove_arrows()
             self.scene.removeItem(item)
+            # del item
+        # breakpoint()
 
         for item in self.scene.items():
             if isinstance(item, DiagramItem):
                 item.update_indata()
-                if item.my_class.indata == {} and item.is_import is False:
+                if (item.my_class.indata == {} and
+                        item.my_class.is_import is False):
                     item.setBrush(self.scene.my_item_color)
+        gc.collect()
 
     def keyPressEvent(self, event):
         """
@@ -757,8 +808,8 @@ class MainWidget(QtWidgets.QMainWindow):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : QKeyEvent
+            Key press event object.
 
         Returns
         -------
@@ -776,8 +827,8 @@ class MainWidget(QtWidgets.QMainWindow):
 
         Returns
         -------
-        idata : list
-            Input list of PyGMI dataset
+        idata : list of PyGMI Data
+            Input list of PyGMI Data
         """
         idata = []
         for item in self.scene.selectedItems():
@@ -791,8 +842,8 @@ class MainWidget(QtWidgets.QMainWindow):
 
         Returns
         -------
-        odata : list
-            Output list of PyGMI dataset
+        odata : list of PyGMI Data
+            Output list of PyGMI Data
         """
         odata = []
         for item in self.scene.selectedItems():
@@ -827,30 +878,35 @@ class MainWidget(QtWidgets.QMainWindow):
         item : DiagramItem
             Return a DiagramItem object
         """
+        if 'nodialog' in kwargs:
+            nodialog = kwargs['nodialog']
+            del kwargs['nodialog']
+        else:
+            nodialog = False
+
         class_name_active = class_name(self, **kwargs)
 
         item = DiagramItem(item_type, self.scene.my_item_menu,
                            class_name_active, self)
         item_color = self.scene.my_item_color
 
-        item_name = item_name.replace(' ', '\n')
+        item_name = textwrap.wrap(item_name, width=13, break_long_words=False)
+        item_name = [f'{i: <13}' for i in item_name]
+        item_name = '\n'.join(item_name)
+        item_name = item_name.strip()
 
-        item.my_class_name = item_name.replace('\n', ' ')
-
-        if item_type == 'Io':
-            item.is_import = True
+        item.my_class_name = item_name
 
         if item_type == 'Io' and projimport is False:
-            iflag = item.settings()
+            iflag = item.settings(nodialog)
             if iflag is False:
                 return None
             if item.my_class.ifile != '':
                 ifile = os.path.basename(item.my_class.ifile)
-                if len(ifile) > len(item_name):
-                    ifile = ifile[:len(item_name)]+'\n'+ifile[len(item_name):]
-                if len(ifile) > 2*len(item_name):
-                    ifile = ifile[:2*len(item_name)]+'...\n'
-                item_name += ':\n'+ifile
+                ifile = textwrap2(ifile, width=13, max_lines=2)
+                if '\n' not in ifile:
+                    ifile = ifile + '\n'
+                item_name = f'{item_name}:\n{ifile}'
             item_color = QtGui.QColor(0, 255, 0, 127)
 
         # Do text first, since this determines size of polygon
@@ -892,6 +948,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         text_item.setParentItem(item)
         rect_item.setParentItem(item)
+        item.text_item = text_item
 
         # Enable moving
         self.scene.my_mode = 'MoveItem'
@@ -950,7 +1007,7 @@ class MainWidget(QtWidgets.QMainWindow):
         isactive : bool, optional
             boolean variable indicating if a process is active.
         """
-        if isactive:
+        if isactive is True:
             self.textbrowser_processlog.setStyleSheet(
                 'QTextBrowser { background-color: rgba(255, 0, 0, 127); }')
             self.pbar.setValue(0)
@@ -968,7 +1025,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         """
         self.process_is_active()
-        self.showprocesslog('Project load busy...')
+        self.showlog('Project load busy...')
 
         ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
             self, 'Open Project', '.', 'PyGMI project (*.json);;')
@@ -1051,7 +1108,8 @@ class MainWidget(QtWidgets.QMainWindow):
                                 'y': item.y()}
 
                 if hasattr(item.my_class, 'saveproj'):
-                    ilist[cname]['itemdata'] = item.my_class.saveproj()
+                    item.my_class.saveproj()
+                    ilist[cname]['itemdata'] = item.my_class.projdata
 
             if isinstance(item, Arrow):
                 sname = str(item.my_start_item.my_class)
@@ -1079,7 +1137,7 @@ class MainWidget(QtWidgets.QMainWindow):
                 alist[str(item)] = item
 
         if not alist:
-            self.showprocesslog('No connections. Aborting run.')
+            self.showlog('No connections. Aborting run.')
             return
 
         # Collect only items receiving data
@@ -1093,7 +1151,7 @@ class MainWidget(QtWidgets.QMainWindow):
                         getsdata = True
                 if getsdata is True:
                     ilist.append(item)
-                elif not item.is_import:
+                elif not item.my_class.is_import:
                     slist.append(item)
 
         # Get rid of arrows from an item sending data without an import.
@@ -1104,7 +1162,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         # Delete data in modules.
         for i in ilist:
-            if not i.is_import:
+            if not i.my_class.is_import:
                 i.my_class.indata = {}
                 i.my_class.outdata = {}
 
@@ -1169,7 +1227,7 @@ class MainWidget(QtWidgets.QMainWindow):
         tmp.setValue(tmp.maximumHeight())
         self.repaint()
 
-    def showprocesslog(self, txt, replacelast=False):
+    def showlog(self, txt, replacelast=False):
         """
         Show text on the process log.
 
@@ -1225,24 +1283,24 @@ class Startup(QtWidgets.QDialog):
         super().__init__(parent)
         self.setWindowFlags(QtCore.Qt.ToolTip)
 
-        self.gridlayout_main = QtWidgets.QVBoxLayout(self)
-        self.label_info = QtWidgets.QLabel(self)
-        self.label_pic = QtWidgets.QLabel(self)
-        self.label_pic.setPixmap(QtGui.QPixmap(pygmi.__path__[0] +
-                                               r'/images/logo256.ico'))
-        self.label_info.setScaledContents(True)
+        self.vbl_main = QtWidgets.QVBoxLayout(self)
+        self.lbl_info = QtWidgets.QLabel(self)
+        self.lbl_pic = QtWidgets.QLabel(self)
+        self.lbl_pic.setPixmap(QtGui.QPixmap(pygmi.__path__[0] +
+                                             r'/images/logo256.ico'))
+        self.lbl_info.setScaledContents(True)
         self.pbar = QtWidgets.QProgressBar(self)
 
         labeltext = "<font color='red'>Py</font><font color='blue'>GMI</font>"
 
         fnt = QtGui.QFont('Arial', 72, QtGui.QFont.Bold)
-        self.label_info.setFont(fnt)
-        self.label_info.setText(labeltext)
-        self.gridlayout_main.addWidget(self.label_info)
-        self.gridlayout_main.addWidget(self.label_pic)
+        self.lbl_info.setFont(fnt)
+        self.lbl_info.setText(labeltext)
+        self.vbl_main.addWidget(self.lbl_info)
+        self.vbl_main.addWidget(self.lbl_pic)
 
         self.pbar.setMaximum(pbarmax - 1)
-        self.gridlayout_main.addWidget(self.pbar)
+        self.vbl_main.addWidget(self.pbar)
 
         self.open()
 
@@ -1255,21 +1313,8 @@ class Startup(QtWidgets.QDialog):
 def main(nocgs=False):
     """Entry point for the PyGMI software."""
     # Set environment variables.
-    if 'GDAL_DATA' not in os.environ:
-        import osgeo
-        gdalpath = os.path.join(osgeo.__path__[0], r'data\gdal')
-        if os.path.exists(gdalpath):
-            os.environ['GDAL_DATA'] = gdalpath
-        else:
-            print('GDAL_PATH not set.')
-
-    if 'PROJ_DATA' not in os.environ:
-        import pyproj
-        projpath = os.path.join(pyproj.__path__[0], r'proj_dir\share\proj')
-        if os.path.exists(projpath):
-            os.environ['PROJ_DATA'] = projpath
-        else:
-            print('PROJ_DATA not set.')
+    # The line below is to fix a problem in windows with loky library.
+    os.environ['LOKY_MAX_CPU_COUNT'] = str(psutil.cpu_count(logical=False))
 
     # Start program.
     app = QtWidgets.QApplication(sys.argv)
@@ -1291,9 +1336,9 @@ def main(nocgs=False):
     wid.activateWindow()
 
     if hasattr(__builtins__, '__IPYTHON__'):
-        app.exec_()
+        app.exec()
     else:
-        sys.exit(app.exec_())
+        sys.exit(app.exec())
 
 
 if __name__ == "__main__":
