@@ -53,19 +53,19 @@ class FileMenu():
 
 # File Menu
 
-        self.menufile = QtWidgets.QMenu('File')
-        parent.menubar.addAction(self.menufile.menuAction())
+        self.menu = QtWidgets.QMenu('File')
+        parent.menubar.addAction(self.menu.menuAction())
 
         self.action_save = QtWidgets.QAction('Save Project')
-        self.menufile.addAction(self.action_save)
+        self.menu.addAction(self.action_save)
         self.action_save.triggered.connect(parent.save)
 
         self.action_load = QtWidgets.QAction('Load Project')
-        self.menufile.addAction(self.action_load)
+        self.menu.addAction(self.action_load)
         self.action_load.triggered.connect(parent.load)
 
         self.action_exit = QtWidgets.QAction('Exit')
-        self.menufile.addAction(self.action_exit)
+        self.menu.addAction(self.action_exit)
         self.action_exit.triggered.connect(parent.close)
 
 
@@ -84,14 +84,14 @@ class HelpMenu():
         self.parent = parent
         self.webpage = r'http://patrick-cole.github.io/pygmi/'
 
-        self.menuhelp = QtWidgets.QMenu('Help')
-        parent.menubar.addAction(self.menuhelp.menuAction())
+        self.menu = QtWidgets.QMenu('Help')
+        parent.menubar.addAction(self.menu.menuAction())
 
         self.action_help = QtWidgets.QAction('Help')
         self.action_about = QtWidgets.QAction('About')
 
-        self.menuhelp.addAction(self.action_help)
-        self.menuhelp.addAction(self.action_about)
+        self.menu.addAction(self.action_help)
+        self.menu.addAction(self.action_about)
 
         self.action_about.triggered.connect(self.about)
         self.action_help.triggered.connect(self.webhelp)
@@ -139,7 +139,7 @@ class HelpButton(QtWidgets.QPushButton):
     """
     Help Button.
 
-    Convenience class to add an image to a pushbutton
+    Convenience class to add a Help image to a pushbutton
     """
 
     def __init__(self, htmlfile=None, parent=None):
@@ -147,11 +147,11 @@ class HelpButton(QtWidgets.QPushButton):
 
         self.htmlfile = htmlfile
 
-        self.ipth = os.path.dirname(__file__)+r'/images/'
         self.setMinimumHeight(48)
         self.setMinimumWidth(48)
 
-        self.setIcon(QtGui.QIcon(self.ipth+'help.png'))
+        ipth = os.path.dirname(__file__)+r'/images/'
+        self.setIcon(QtGui.QIcon(ipth+'help.png'))
         self.setIconSize(self.minimumSize())
         self.clicked.connect(self.help_docs)
         self.setFlat(True)
@@ -195,8 +195,8 @@ class HelpDocs(QtWidgets.QDialog):
         # create GUI
         self.setWindowTitle('Help!')
 
-        self.vbox = QtWidgets.QVBoxLayout()
-        self.setLayout(self.vbox)
+        self.vbl = QtWidgets.QVBoxLayout()
+        self.setLayout(self.vbl)
 
         self.text = QtWidgets.QTextBrowser()
         self.text.setOpenExternalLinks(True)
@@ -214,17 +214,17 @@ class HelpDocs(QtWidgets.QDialog):
         ptmp.setColor(2, 9, ptmp.color(10))
         self.text.setPalette(ptmp)
 
-        self.vbox.addWidget(self.text)
+        self.vbl.addWidget(self.text)
 
         self.buttonbox = QtWidgets.QDialogButtonBox()
         self.buttonbox.setOrientation(QtCore.Qt.Horizontal)
         self.buttonbox.setCenterButtons(True)
         self.buttonbox.setStandardButtons(QtWidgets.QDialogButtonBox.Ok)
 
-        self.vbox.addWidget(self.buttonbox)
+        self.vbl.addWidget(self.buttonbox)
 
         self.buttonbox.accepted.connect(self.accept)
 
-        self.exec_()
+        self.exec()
 
         os.chdir(opth)
