@@ -22,18 +22,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""
-Misc is a collection of routines which can be used in PyGMI in general.
-"""
+"""Misc is a collection of routines which can be used in PyGMI in general."""
 
+import os
 import sys
 import types
 import time
+import textwrap
 import psutil
 import numpy as np
-from matplotlib import ticker
-from PyQt5 import QtWidgets, QtCore
-
+from matplotlib import ticker, cm, colors
+from PyQt5 import QtWidgets, QtCore, QtGui
 
 PBAR_STYLE = """
 QProgressBar{
@@ -110,34 +109,47 @@ class BasicModule(QtWidgets.QDialog):
         dictionary of output datasets
     ifile : str
         input file, used in IO routines and to pass filename back to main.py
-    piter : iter
+    piter : function
         reference to a progress bar iterator.
-    pbar : progressbar
+    pbar : function
         reference to a progress bar.
-    showprocesslog: stdout or alternative
+    showlog: stdout or alternative
         reference to a way to view messages, normally stdout or a Qt text box.
+    is_import: bool
+        used to indicate whether a routine contains an import within.
+    projdata : dictionary
+        Project data.
     """
 
     def __init__(self, parent=None):
         super().__init__(parent)
+
         if parent is None:
             self.stdout_redirect = sys.stdout
-            self.showprocesslog = print
+            self.showlog = print
             self.pbar = ProgressBarText()
-            self.process_is_active = print
+            self.process_is_active = lambda *args, **kwargs: None
         else:
-            self.stdout_redirect = EmittingStream(parent.showprocesslog)
-            self.showprocesslog = parent.showprocesslog
+            self.stdout_redirect = EmittingStream(parent.showlog)
+            self.showlog = parent.showlog
             self.pbar = parent.pbar
-            self.process_is_active = parent.process_is_active
+            if hasattr(parent, 'process_is_active'):
+                self.process_is_active = parent.process_is_active
+            else:
+                self.process_is_active = lambda *args, **kwargs: None
 
         self.piter = self.pbar.iter
 
         self.indata = {}
         self.outdata = {}
+        self.projdata = {}
         self.parent = parent
+        self.is_import = False
         self.ifile = ''
 
+        ipth = os.path.dirname(__file__)+r'/images/'
+        self.setWindowIcon(QtGui.QIcon(ipth+'logo256.ico'))
+
     def settings(self, nodialog=False):
         """
         Entry point into item.
@@ -184,7 +196,65 @@ class BasicModule(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-        return False
+        self.projdata = projdata
+
+        for otxt in projdata:
+            if otxt not in vars(self):
+                self.showlog('Cannot load project, you may be using an '
+                             'old project format.')
+                return False
+
+        for otxt in projdata:
+            obj = vars(self)[otxt]
+
+            if obj is None:
+                vars(self)[otxt] = projdata[otxt]
+
+            if isinstance(obj, (float, int, bool, list, np.ndarray, tuple,
+                                str)):
+                vars(self)[otxt] = projdata[otxt]
+
+            if isinstance(obj, QtWidgets.QComboBox):
+                obj.blockSignals(True)
+                obj.setCurrentText(projdata[otxt])
+                obj.blockSignals(False)
+
+            if isinstance(obj, (QtWidgets.QLineEdit, QtWidgets.QTextEdit)):
+                obj.blockSignals(True)
+                obj.setText(projdata[otxt])
+                obj.blockSignals(False)
+
+            if isinstance(obj, (QtWidgets.QSpinBox, QtWidgets.QDoubleSpinBox,
+                                QtWidgets.QSlider)):
+                obj.blockSignals(True)
+                obj.setValue(projdata[otxt])
+                obj.blockSignals(False)
+
+            if isinstance(obj, (QtWidgets.QRadioButton, QtWidgets.QCheckBox)):
+                obj.blockSignals(True)
+                obj.setChecked(projdata[otxt])
+                obj.blockSignals(False)
+
+            if isinstance(obj, QtWidgets.QDateEdit):
+                obj.blockSignals(True)
+                date = obj.date().fromString(projdata[otxt])
+                obj.setDate(date)
+                obj.blockSignals(False)
+
+            if isinstance(obj, QtWidgets.QListWidget):
+                obj.blockSignals(True)
+                obj.selectAll()
+                for i in obj.selectedItems():
+                    if i.text()[2:] not in self.projdata[otxt]:
+                        i.setSelected(False)
+                obj.blockSignals(False)
+
+        if self.is_import is True:
+            chk = self.settings(True)
+        else:
+            chk = False
+
+        return chk
 
     def saveproj(self):
         """
@@ -192,13 +262,62 @@ class BasicModule(QtWidgets.QDialog):
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
 
-        return projdata
+    def saveobj(self, obj):
+        """
+        Save an object to a dictionary.
+
+        This is a convenience function for saving project information.
+
+        Parameters
+        ----------
+        obj : variable
+            A variable to be saved.
+
+        Returns
+        -------
+        None.
+
+        """
+        otxt = None
+        for name in vars(self):
+            if id(vars(self)[name]) == id(obj):
+                otxt = name
+        if otxt is None:
+            return
+
+        if isinstance(obj, (float, int, bool, list, np.ndarray, tuple, str)):
+            self.projdata[otxt] = obj
+
+        if isinstance(obj, QtWidgets.QComboBox):
+            self.projdata[otxt] = obj.currentText()
+
+        if isinstance(obj, QtWidgets.QLineEdit):
+            self.projdata[otxt] = obj.text()
+
+        if isinstance(obj, QtWidgets.QTextEdit):
+            self.projdata[otxt] = obj.toPlainText()
+
+        if isinstance(obj, (QtWidgets.QSpinBox, QtWidgets.QDoubleSpinBox,
+                            QtWidgets.QSlider)):
+            self.projdata[otxt] = obj.value()
+
+        if isinstance(obj, (QtWidgets.QRadioButton, QtWidgets.QCheckBox)):
+            self.projdata[otxt] = obj.isChecked()
+
+        if isinstance(obj, QtWidgets.QDateEdit):
+            self.projdata[otxt] = obj.date().toString()
+
+        if isinstance(obj, QtWidgets.QListWidget):
+            tmp = []
+            for i in obj.selectedItems():
+                tmp.append(i.text()[2:])
+            self.projdata[otxt] = tmp
+
+        return
 
 
 class ContextModule(QtWidgets.QDialog):
@@ -213,11 +332,11 @@ class ContextModule(QtWidgets.QDialog):
         dictionary of input datasets
     outdata : dictionary
         dictionary of output datasets
-    piter : iter
+    piter : function
         reference to a progress bar iterator.
-    pbar : progressbar
+    pbar : function
         reference to a progress bar.
-    showprocesslog: stdout or alternative
+    showlog: stdout or alternative
         reference to a way to view messages, normally stdout or a Qt text box.
     """
 
@@ -225,14 +344,17 @@ class ContextModule(QtWidgets.QDialog):
         super().__init__(parent)
         if parent is None:
             self.stdout_redirect = sys.stdout
-            self.showprocesslog = print
+            self.showlog = print
             self.pbar = ProgressBarText()
-            self.process_is_active = print
+            self.process_is_active = lambda *args, **kwargs: None
         else:
-            self.stdout_redirect = EmittingStream(parent.showprocesslog)
-            self.showprocesslog = parent.showprocesslog
+            self.stdout_redirect = EmittingStream(parent.showlog)
+            self.showlog = parent.showlog
             self.pbar = parent.pbar
-            self.process_is_active = parent.process_is_active
+            if hasattr(parent, 'process_is_active'):
+                self.process_is_active = parent.process_is_active
+            else:
+                self.process_is_active = lambda *args, **kwargs: None
 
         self.piter = self.pbar.iter
 
@@ -240,6 +362,9 @@ class ContextModule(QtWidgets.QDialog):
         self.outdata = {}
         self.parent = parent
 
+        ipth = os.path.dirname(__file__)+r'/images/'
+        self.setWindowIcon(QtGui.QIcon(ipth+'logo256.ico'))
+
     def run(self):
         """
         Run context menu item.
@@ -251,17 +376,22 @@ class ContextModule(QtWidgets.QDialog):
         """
 
 
-class QLabelVStack:
-    """QLabelVStack."""
+class QVStack2Layout(QtWidgets.QGridLayout):
+    """
+    QVStack2Layout.
+
+    This works like VBoxLayout, except each row takes two widgets.
+
+    """
 
     def __init__(self, parent=None):
-        self.layout = QtWidgets.QGridLayout(parent)
-        self.layout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
+        super().__init__(parent)
+        self.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
         self.indx = 0
 
     def addWidget(self, widget1, widget2):
         """
-        Add two widgets on a row, widget1 can also be text.
+        Add two widgets on a row, widget can also be text.
 
         Parameters
         ----------
@@ -278,10 +408,17 @@ class QLabelVStack:
         if isinstance(widget1, str):
             widget1 = QtWidgets.QLabel(widget1)
 
-        self.layout.addWidget(widget1, self.indx, 0)
-        self.layout.addWidget(widget2, self.indx, 1)
+        if isinstance(widget2, str):
+            widget2 = QtWidgets.QLabel(widget2)
+
+        self.addWidgetOld(widget1, self.indx, 0)
+        self.addWidgetOld(widget2, self.indx, 1)
         self.indx += 1
 
+    def addWidgetOld(self, *args, **kwargs):
+        """Original Add Widget."""
+        super().addWidget(*args, **kwargs)
+
 
 class PTime():
     """
@@ -427,19 +564,18 @@ class ProgressBarText():
             self.total = 1
 
         self.otime = time.perf_counter()
-        time1 = self.otime
-        time2 = self.otime
 
         i = 0
-        oldval = 0
+        oldperc = 0
         gottototal = False
         for obj in iterable:
             yield obj
             i += 1
 
             time2 = time.perf_counter()
-            if time2-time1 > 1 and int(i*100/self.total) > oldval:
-                oldval = int(i*100/self.total)
+            curperc = int(i*100/self.total)
+            if curperc > oldperc or oldperc == 0:
+                oldperc = curperc
 
                 tleft = (self.total-i)*(time2-self.otime)/i
                 if tleft > 60:
@@ -449,7 +585,6 @@ class ProgressBarText():
                 timestr += f' {time2-self.otime:.1f} sec total      '
 
                 self.printprogressbar(i, suffix=timestr)
-                time1 = time2
                 if i == self.total:
                     gottototal = True
 
@@ -489,6 +624,51 @@ class ProgressBarText():
         self.printprogressbar(self.total)
 
 
+def discrete_colorbar(axes, csp, cdat, lbls=None):
+    """
+    Plot colour bar using discrete colours for a small range of values.
+
+    Parameters
+    ----------
+    axes : Matplotlib axes
+        Current axes.
+    csp : Plot routine
+        Handle to Matplotlib plotting routine.
+    cdat : numpy array
+        Array of values.
+    lbls : y tick labels (optional)
+
+    Returns
+    -------
+    None.
+
+    """
+    vals = np.unique(cdat)
+    if np.ma.isMaskedArray(vals):
+        vals = vals.compressed()
+    vals = vals[~np.isnan(vals)]
+
+    if len(vals) < 2:
+        print('Too few discrete values')
+        return
+    # bnds = (vals - 0.5).tolist() + [vals.max() + .5]
+
+    if hasattr(csp.norm, 'boundaries'):
+        bnds = csp.norm.boundaries
+        ticks = np.diff(bnds)/2+vals
+        cbar = axes.figure.colorbar(csp, ticks=ticks)
+    else:
+        bnds = vals.tolist() + [vals.max()+1]
+        ticks = np.diff(bnds)/2+vals
+        cbar = axes.figure.colorbar(csp, boundaries=bnds, values=vals,
+                                    ticks=ticks)
+
+    if lbls is not None:
+        cbar.ax.set_yticklabels(lbls)
+    else:
+        cbar.ax.set_yticklabels(vals)
+
+
 def getinfo(txt=None, reset=False):
     """
     Get time and memory info.
@@ -526,6 +706,41 @@ def getinfo(txt=None, reset=False):
     print(heading+memtxt+f' Time(s): {tdiff:.3f}')
 
 
+def textwrap2(text, width, placeholder='...', max_lines=None):
+    """
+    Provide slightly different placeholder functionality to textwrap.
+
+    Placeholders will be a part of last line, instead of replacing it.
+
+    Parameters
+    ----------
+    text : str
+        Text to wrap.
+    width : int
+        Maximum line length.
+    placeholder : sre, optional
+        Placeholder when lines exceed max_lines. The default is '...'.
+    max_lines : int, optional
+        Maximum number of lines. The default is None.
+
+    Returns
+    -------
+    text2 : str
+        Output wrapped text.
+
+    """
+    text2 = textwrap.wrap(text, width=width)
+
+    if max_lines is not None and text2:
+        text2 = text2[:max_lines]
+        if len(text2[-1]) == width:
+            text2[-1] = text2[-1][:-len(placeholder)] + placeholder
+
+    text2 = '\n'.join(text2)
+
+    return text2
+
+
 def tick_formatter(x, pos):
     """
     Format thousands separator in ticks for plots.
@@ -539,8 +754,8 @@ def tick_formatter(x, pos):
 
     Returns
     -------
-    newx : TYPE
-        DESCRIPTION.
+    newx : str
+        Formatted coordinate.
 
     """
     if np.ma.is_masked(x):
@@ -552,3 +767,44 @@ def tick_formatter(x, pos):
 
 
 frm = ticker.FuncFormatter(tick_formatter)
+
+
+def _testfn():
+    """Test function."""
+    # app = QtWidgets.QApplication(sys.argv)
+
+    # tmp = BasicModule()
+    # tmp.ifile = QtWidgets.QLineEdit('test')
+    # tmp.saveobj(tmp.ifile)
+
+    # print(tmp.projdata)
+
+    import matplotlib.pyplot as plt
+
+    data = [[0, 45, 50],
+            [0, 45, 50],
+            [0, 44, 50]]
+
+    lbls = ['a', 'b', 'c', 'd']
+
+    vals = np.unique(data)
+    if np.ma.isMaskedArray(vals):
+        vals = vals.compressed()
+    vals = vals[~np.isnan(vals)]
+
+    bnds = vals.tolist() + [vals.max()+1]
+
+    cmap = cm.viridis
+    norm = colors.BoundaryNorm(bnds, cmap.N)
+
+    fig = plt.figure(dpi=200)
+    ax = fig.gca()
+    cax = ax.imshow(data, norm=norm)
+
+    discrete_colorbar(ax, cax, data, lbls)
+    plt.show()
+
+    breakpoint()
+
+if __name__ == "__main__":
+    _testfn()
