@@ -31,6 +31,7 @@ from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 
 from pygmi.misc import ContextModule
 
+
 class GraphWindow(ContextModule):
     """Graph Window - Main QT Dialog class for graphs."""
 
@@ -45,15 +46,15 @@ class GraphWindow(ContextModule):
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combobox1 = QtWidgets.QComboBox()
-        self.combobox2 = QtWidgets.QComboBox()
-        self.label1 = QtWidgets.QLabel('Bands:')
-        self.label2 = QtWidgets.QLabel('Bands:')
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.cmb_2 = QtWidgets.QComboBox()
+        self.lbl_1 = QtWidgets.QLabel('Bands:')
+        self.lbl_2 = QtWidgets.QLabel('Bands:')
 
-        hbl.addWidget(self.label1)
-        hbl.addWidget(self.combobox1)
-        hbl.addWidget(self.label2)
-        hbl.addWidget(self.combobox2)
+        hbl.addWidget(self.lbl_1)
+        hbl.addWidget(self.cmb_1)
+        hbl.addWidget(self.lbl_2)
+        hbl.addWidget(self.cmb_2)
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
@@ -61,8 +62,8 @@ class GraphWindow(ContextModule):
 
         self.setFocus()
 
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cmb_2.currentIndexChanged.connect(self.change_band)
 
     def change_band(self):
         """Combo box to choose band."""
@@ -76,7 +77,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
     """
 
     def __init__(self, parent=None):
-        fig = Figure()
+        fig = Figure(layout='constrained')
         self.axes = fig.add_subplot(111)
         self.line = None
         self.ind = None
@@ -275,7 +276,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.canvas.draw()
         self.background = self.figure.canvas.copy_from_bbox(ax1.bbox)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
@@ -295,8 +295,8 @@ class PlotPoints(GraphWindow):
 
         """
         data = self.indata['MT - EDI']
-        i = self.combobox1.currentText()
-        i2 = self.combobox2.currentText()
+        i = self.cmb_1.currentText()
+        i2 = self.cmb_2.currentText()
         self.mmc.update_line(data, i, i2)
 
     def run(self):
@@ -311,14 +311,14 @@ class PlotPoints(GraphWindow):
         self.show()
         data = self.indata['MT - EDI']
         for i in data:
-            self.combobox1.addItem(i)
+            self.cmb_1.addItem(i)
         for i in ['xy, yx', 'xx, yy']:
-            self.combobox2.addItem(i)
+            self.cmb_2.addItem(i)
 
-        self.label1.setText('Station Name:')
-        self.label2.setText('Graph Type:')
-        self.combobox1.setCurrentIndex(0)
-        self.combobox2.setCurrentIndex(0)
+        self.lbl_1.setText('Station Name:')
+        self.lbl_2.setText('Graph Type:')
+        self.cmb_1.setCurrentIndex(0)
+        self.cmb_2.setCurrentIndex(0)
 
 
 def _testfn():
