@@ -36,7 +36,6 @@ Blakely, R.J., 1996. Potential Theory in Gravity and Magnetic Applications,
 1st edn. Cambridge University Press, Cambridge, UK, 441 pp. 200-201
 """
 
-import copy
 import tempfile
 from PyQt5 import QtWidgets, QtCore
 
@@ -884,8 +883,7 @@ def gridmatch(lmod, ctxt, rtxt):
 
     rows2, cols2 = data2.data.shape
 
-    dat = data_reproject(data, data.crs, data2.crs, data2.transform,
-                         rows2, cols2)
+    dat = data_reproject(data, data2.crs, data2.transform, rows2, cols2)
 
     return dat.data
 
@@ -928,7 +926,7 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
         showtext('Error: Create a model first')
         return None
 
-    ttt = PTime()
+    ptime = PTime()
     # Init some variables for convenience
     lmod.update_lithlist()
 
@@ -1083,16 +1081,14 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
 
     if 'Magnetic Dataset' in lmod.griddata:
         ztmp = gridmatch(lmod, 'Magnetic Dataset', 'Calculated Magnetics')
-        lmod.griddata['Magnetic Residual'] = copy.deepcopy(
-            lmod.griddata['Magnetic Dataset'])
+        lmod.griddata['Magnetic Residual'] = lmod.griddata['Magnetic Dataset'].copy()
         lmod.griddata['Magnetic Residual'].data = (
             lmod.griddata['Magnetic Dataset'].data - ztmp)
         lmod.griddata['Magnetic Residual'].dataid = 'Magnetic Residual'
 
     if 'Gravity Dataset' in lmod.griddata:
         ztmp = gridmatch(lmod, 'Gravity Dataset', 'Calculated Gravity')
-        lmod.griddata['Gravity Residual'] = copy.deepcopy(
-            lmod.griddata['Gravity Dataset'])
+        lmod.griddata['Gravity Residual'] = lmod.griddata['Gravity Dataset'].copy()
         lmod.griddata['Gravity Residual'].data = (
             lmod.griddata['Gravity Dataset'].data - ztmp - lmod.gregional)
         lmod.griddata['Gravity Residual'].dataid = 'Gravity Residual'
@@ -1104,7 +1100,7 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
     if pbars is not None:
         pbars.maxall()
 
-    tdiff = ttt.since_last_call(show=False)
+    tdiff = ptime.since_last_call(show=False)
     mins = int(tdiff/60)
     secs = tdiff-mins*60
 
@@ -1129,7 +1125,7 @@ def sum_fields(k, mgval, numx, numy, modind, aaa0, aaa1, mlayers, hcorflat,
     k : int
         k index.
     mgval : numpy array
-        DESCRIPTION.
+        Magnetic or gravity data being summed.
     numx : int
         Number of x elements.
     numy : int
@@ -1185,7 +1181,7 @@ def quick_model(numx=50, numy=40, numz=5, dxy=100., d_z=100.,
         Number of x elements. The default is 50.
     numy : int, optional
         Number of y elements. The default is 40.
-    numz : TYPE, optional
+    numz : int, optional
         number of z elements (layers). The default is 5.
     dxy : float, optional
         Cell size in x and y direction. The default is 100..
@@ -1203,7 +1199,7 @@ def quick_model(numx=50, numy=40, numz=5, dxy=100., d_z=100.,
         Gravity sensor height. The default is 0..
     finc : float, optional
         Magnetic field inclination (degrees). The default is -67.
-    fdec : TYPE, optional
+    fdec : float, optional
         Magnetic field declination (degrees). The default is -17.
     inputliths : list or None, optional
         List of input lithologies. The default is None.
@@ -1316,7 +1312,7 @@ def _mbox(mval, xobs, yobs, numx, numy, z0, x1, y1, z1, x2, y2, fm1, fm2, fm3,
     Parameters
     ----------
     mval : numpy array
-        DESCRIPTION.
+        Existing magnetic values.
     xobs : numpy array
         Observation X coordinates.
     yobs : numpy array
@@ -1426,15 +1422,15 @@ def _gbox(gval, xobs, yobs, numx, numy, z_0, x_1, y_1, z_1, x_2, y_2, z_2,
     Parameters
     ----------
     gval : numpy array
-        DESCRIPTION.
+        Existing gravity values.
     xobs : numpy array
         Observation X coordinates.
     yobs : numpy array
         Observation Y coordinates.
-    numx : TYPE
-        DESCRIPTION.
-    numy : TYPE
-        DESCRIPTION.
+    numx : int
+        Number of X.
+    numy : int
+        Number of Y.
     z_0 : float
         Observation height.
     x_1 : float
