@@ -22,18 +22,19 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Import Data."""
+"""Import Potential field model data."""
 
+import datetime
 import sys
 import os
-import re
 import zipfile
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
-from osgeo import osr, ogr
 import matplotlib.pyplot as plt
 import pandas as pd
-from rasterio.crs import CRS
+import geopandas as gpd
+from pyproj.crs import CRS
+from shapely.geometry import Polygon
 
 from pygmi.pfmod.datatypes import LithModel
 from pygmi.pfmod import grvmag3d
@@ -41,6 +42,7 @@ from pygmi.pfmod import mvis3d
 from pygmi import menu_default
 import pygmi.raster.dataprep as dp
 from pygmi.misc import BasicModule, ContextModule
+from pygmi.vector.dataprep import reprojxy
 # This is necessary for loading npz files, since I moved the location of
 # datatypes.
 from pygmi.pfmod import datatypes
@@ -56,6 +58,7 @@ class ImportMod3D(BasicModule):
 
         self.lmod = LithModel()
         self.filt = ''
+        self.is_import = True
 
     def settings(self, nodialog=False):
         """
@@ -111,44 +114,17 @@ class ImportMod3D(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.ifile = projdata['ifile']
-        self.filt = projdata['filt']
-
-        chk = self.settings(True)
-
-        return chk
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['ifile'] = self.ifile
-        projdata['filt'] = self.filt
-
-        return projdata
+        self.saveobj(self.ifile)
+        self.saveobj(self.filt)
 
     def import_leapfrog_csv(self, filename):
         """
@@ -177,7 +153,7 @@ class ImportMod3D(BasicModule):
         header = header[7:]
 
         mtmp = MessageCombo(header)
-        mtmp.exec_()
+        mtmp.exec()
         datindx = mtmp.master.currentIndex()
 
         x = []
@@ -278,7 +254,7 @@ class ImportMod3D(BasicModule):
             else:
                 df1 = pd.read_csv(filename, sep=' ', names=names)
         except:
-            self.showprocesslog('Unable to import file')
+            self.showlog('Unable to import file')
             return
 
         x = df1.x.to_numpy(float)
@@ -412,6 +388,8 @@ class ImportMod3D(BasicModule):
 
         # This gets rid of a legacy variable names and updates to new ones
         for i in lmod.griddata:
+            if not hasattr(lmod.griddata[i], 'datetime'):
+                lmod.griddata[i].datetime = datetime.datetime(1900, 1, 1)
             if not hasattr(lmod.griddata[i], 'units'):
                 lmod.griddata[i].units = ''
             if not hasattr(lmod.griddata[i], 'isrgb'):
@@ -458,6 +436,7 @@ class ImportMod3D(BasicModule):
 
         for i in lmod.griddata:
             if lmod.griddata[i].crs is not None:
+                lmod.griddata[i].crs = CRS.from_user_input(lmod.griddata[i].crs)
                 crsfin = lmod.griddata[i].crs
 
         for i in lmod.griddata:
@@ -519,7 +498,7 @@ class ExportMod3D(ContextModule):
 
         """
         if 'Model3D' not in self.indata:
-            self.showprocesslog('Error: You need to have a model first!')
+            self.showlog('Error: You need to have a model first!')
             return
 
         for self.lmod in self.indata['Model3D']:
@@ -533,9 +512,10 @@ class ExportMod3D(ContextModule):
             os.chdir(os.path.dirname(self.ofile))
             ext = self.ofile[-3:]
 
-            self.showprocesslog('Saving '+self.ofile+'...')
+            self.parent.process_is_active()
+
+            self.showlog('Saving '+self.ofile+'...')
 
-        # Pop up save dialog box
             if ext == 'npz':
                 self.savemodel()
             if ext == 'kmz':
@@ -544,6 +524,7 @@ class ExportMod3D(ContextModule):
                 self.mod3dtoshp()
             if ext == 'csv':
                 self.mod3dtocsv()
+            self.parent.process_is_active(False)
 
     def savemodel(self):
         """
@@ -561,9 +542,9 @@ class ExportMod3D(ContextModule):
         # Save data
         try:
             np.savez_compressed(self.ofile, **outdict)
-            self.showprocesslog('Model save complete!')
+            self.showlog('Model save complete!')
         except:
-            self.showprocesslog('ERROR! Model save failed!')
+            self.showlog('ERROR! Model save failed!')
 
     def lmod2dict(self, outdict, pre=''):
         """
@@ -644,7 +625,7 @@ class ExportMod3D(ContextModule):
         None.
 
         """
-        self.showprocesslog('csv export starting...')
+        self.showlog('csv export starting...')
 
         self.lmod.update_lith_list_reverse()
         lithname = self.lmod.lith_list_reverse.copy()
@@ -681,10 +662,10 @@ class ExportMod3D(ContextModule):
         stmp['lithname'] = ltmp
 
         head = 'X, Y, Z, Density, Susceptibility, Lithology Code, Lithology'
-        np.savetxt(self.ifile, stmp, fmt="%f, %f, %f, %f, %f, %i, %s",
+        np.savetxt(self.ofile, stmp, fmt="%f, %f, %f, %f, %f, %i, %s",
                    header=head)
 
-        self.showprocesslog('csv export complete!')
+        self.showlog('csv export complete!')
 
     def mod3dtokmz(self):
         """
@@ -708,11 +689,11 @@ class ExportMod3D(ContextModule):
         zrng = np.array(self.lmod.zrange, dtype=float)
 
         if 'Raster' in self.indata:
-            wkt = self.indata['Raster'][0].crs.wkt
+            wkt = self.indata['Raster'][0].crs.to_wkt()
         else:
             wkt = ''
         prjkmz = Exportkmz(wkt)
-        tmp = prjkmz.exec_()
+        tmp = prjkmz.exec()
 
         if tmp == 0:
             return
@@ -726,28 +707,19 @@ class ExportMod3D(ContextModule):
         smooth = prjkmz.checkbox_smooth.isChecked()
 
         orig_wkt = prjkmz.proj.wkt
-        orig = osr.SpatialReference()
-        orig.ImportFromWkt(orig_wkt)
-        orig.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
 
-        targ = osr.SpatialReference()
-        targ.SetWellKnownGeogCS('WGS84')
-        targ.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
+        res = reprojxy(xrng, yrng, orig_wkt, 4326)
 
-        prj = osr.CoordinateTransformation(orig, targ)
-
-        res = prj.TransformPoint(xrng[0], yrng[0])
-        lonwest, latsouth = res[0], res[1]
-        res = prj.TransformPoint(xrng[1], yrng[1])
-        loneast, latnorth = res[0], res[1]
+        lonwest, loneast = res[0]
+        latsouth, latnorth = res[1]
 
         # Get Save Name
-        filename = self.ifile
+        filename = self.ofile
 
-        self.showprocesslog('kmz export starting...')
+        self.showlog('kmz export starting...')
 
         # Move to 3d model tab to update the model stuff
-        self.showprocesslog('updating 3d model...')
+        self.showlog('updating 3d model...')
 
         mvis_3d.spacing = [self.lmod.dxy, self.lmod.dxy, self.lmod.d_z]
         mvis_3d.origin = [xrng[0], yrng[0], zrng[0]]
@@ -760,7 +732,7 @@ class ExportMod3D(ContextModule):
         mvis_3d.lut = tmp
         mvis_3d.update_model(smooth)
 
-        self.showprocesslog('creating kmz file')
+        self.showlog('creating kmz file')
         heading = str(0.)
         tilt = str(45.)  # angle from vertical
         lat = str(np.mean([latsouth, latnorth]))  # coord of object
@@ -824,8 +796,8 @@ class ExportMod3D(ContextModule):
             curmod = self.lmod.lith_list_reverse[lith]
 
             if len(points) > 60000:
-                self.showprocesslog(curmod + ' has too many points (' +
-                                    str(len(points))+'). Not exported')
+                self.showlog(curmod + ' has too many points (' +
+                             str(len(points))+'). Not exported')
                 points = points[:60000]
                 norm = norm[:60000]
                 faces = faces[faces.max(1) < 60000]
@@ -997,10 +969,8 @@ class ExportMod3D(ContextModule):
             for i in self.lmod.griddata:
                 x_1, x_2, y_1, y_2 = self.lmod.griddata[i].extent
 
-                res = prj.TransformPoint(x_1, y_1)
-                lonwest, latsouth = res[0], res[1]
-                res = prj.TransformPoint(x_2, y_2)
-                loneast, latnorth = res[0], res[1]
+                lonwest, latsouth = reprojxy(x_1, y_1, orig_wkt, 4326)
+                loneast, latnorth = reprojxy(x_2, y_2, orig_wkt, 4326)
 
                 dockml += (
                     '    <GroundOverlay>\r\n'
@@ -1039,9 +1009,9 @@ class ExportMod3D(ContextModule):
 
             zfile.writestr('doc.kml', dockml)
 
-        self.showprocesslog('kmz export complete!')
+        self.showlog('kmz export complete!')
 
-    def mod3dtoshp(self):
+    def mod3dtoshp(self, nodialog=False):
         """
         Save the 3D model and grids in a shapefile file.
 
@@ -1061,24 +1031,21 @@ class ExportMod3D(ContextModule):
         zrng = np.array(self.lmod.zrange, dtype=float)
 
         if 'Raster' in self.indata:
-            wkt = self.indata['Raster'][0].crs.wkt
+            wkt = self.indata['Raster'][0].crs.to_wkt()
         else:
             wkt = ''
         prjkmz = Exportkmz(wkt)
-        tmp = prjkmz.exec_()
+        prjkmz.checkbox_smooth.hide()
 
-        if tmp == 0:
-            return
+        if nodialog is False:
+            tmp = prjkmz.exec()
+            if tmp == 0:
+                return
 
-        smooth = prjkmz.checkbox_smooth.isChecked()
-
-        self.showprocesslog('shapefile export starting...')
+        self.showlog('Shapefile export starting...')
 
         # Move to 3d model tab to update the model stuff
-        if smooth is True:
-            self.showprocesslog('updating and smoothing 3d model...')
-        else:
-            self.showprocesslog('updating 3d model...')
+        self.showlog('Updating 3d model...')
 
         mvis_3d.spacing = [self.lmod.dxy, self.lmod.dxy, self.lmod.d_z]
         mvis_3d.origin = [xrng[0], yrng[0], zrng[0]]
@@ -1089,11 +1056,9 @@ class ExportMod3D(ContextModule):
         for i in itmp:
             tmp[i, :3] = self.lmod.mlut[i]
         mvis_3d.lut = tmp
-        mvis_3d.update_model(smooth)
+        mvis_3d.update_model(False)
 
-        self.showprocesslog('creating shapefile file')
-
-        driver = ogr.GetDriverByName('ESRI Shapefile')
+        self.showlog('creating polygons')
 
         # update colours
         self.lmod.update_lith_list_reverse()
@@ -1103,62 +1068,95 @@ class ExportMod3D(ContextModule):
         lkey = list(mvis_3d.faces.keys())
         lkey.pop(lkey.index(0))
 
-        for lith in lkey:
+        gdf = {}
+        for lith in self.piter(lkey):
             lithtext = mvis_3d.lmod1.lith_list_reverse[lith]
             lithsusc = self.lmod.lith_list[lithtext].susc
             lithdens = self.lmod.lith_list[lithtext].density
-            self.showprocesslog(' '+lithtext)
+
+            self.showlog(' '+lithtext)
+            QtWidgets.QApplication.processEvents()
 
             faces = np.array(mvis_3d.gfaces[lith])
 
             if faces.size == 0:
                 continue
 
-            ifile = self.ifile[:-4]+'_'+re.sub(r'[^A-Za-z]+', '_',
-                                               lithtext)+'.shp'
-            datasource = driver.CreateDataSource(ifile)
-            layer = datasource.CreateLayer('Model',
-                                           geom_type=ogr.wkbMultiPolygon25D)
-
-            layer.CreateField(ogr.FieldDefn('Lithology', ogr.OFTString))
-            layer.CreateField(ogr.FieldDefn('Susc', ogr.OFTReal))
-            layer.CreateField(ogr.FieldDefn('Density', ogr.OFTReal))
-
-            points = mvis_3d.gpoints[lith]
-
+            xfaces = []
+            yfaces = []
+            zfaces = []
+            badfaces = 0
             for f in faces:
-                multipolygon = ogr.Geometry(ogr.wkbMultiPolygon25D)
-                tmp = points[f]
+                tmp = mvis_3d.gpoints[lith][f]
+                if np.unique(tmp[:, 0]).size == 1:
+                    xfaces.append(tmp)
+                elif np.unique(tmp[:, 1]).size == 1:
+                    yfaces.append(tmp)
+                elif np.unique(tmp[:, 2]).size == 1:
+                    zfaces.append(tmp)
+                else:
+                    badfaces += 1
 
-                ring1 = ogr.Geometry(ogr.wkbLinearRing)
-                ring1.AddPoint(tmp[0, 0], tmp[0, 1], tmp[0, 2])
-                ring1.AddPoint(tmp[1, 0], tmp[1, 1], tmp[1, 2])
-                ring1.AddPoint(tmp[2, 0], tmp[2, 1], tmp[2, 2])
-                ring1.AddPoint(tmp[0, 0], tmp[0, 1], tmp[0, 2])
+            gdfxyz = {}
+            for ifaces, faces in enumerate([xfaces, yfaces, zfaces]):
+                layer = {'Lithology': [],
+                         'Susc': [],
+                         'Density': [],
+                         'const': [],
+                         'geometry': []}
 
-                # Create polygon #1
-                poly1 = ogr.Geometry(ogr.wkbPolygon25D)
-                poly1.AddGeometry(ring1)
-                multipolygon.AddGeometry(poly1)
+                for tmp1 in faces:
+                    layer['Lithology'].append(lithtext)
+                    layer['Susc'].append(lithsusc)
+                    layer['Density'].append(lithdens)
+                    layer['const'].append(tmp1[0, ifaces])
 
-                ring1 = None
-                poly1 = None
+                    tmp = np.roll(tmp1, -(ifaces+1), axis=1)
 
-                feature = ogr.Feature(layer.GetLayerDefn())
-                feature.SetGeometry(multipolygon)
-                feature.SetField('Lithology', lithtext)
-                feature.SetField('Susc', lithsusc)
-                feature.SetField('Density', lithdens)
-                layer.CreateFeature(feature)
+                    pverts = []
+                    pverts.append([tmp[0, 0], tmp[0, 1], tmp[0, 2]])
+                    pverts.append([tmp[1, 0], tmp[1, 1], tmp[1, 2]])
+                    pverts.append([tmp[2, 0], tmp[2, 1], tmp[2, 2]])
+                    pverts.append([tmp[0, 0], tmp[0, 1], tmp[0, 2]])
+                    pverts = Polygon(pverts)
+                    layer['geometry'].append(pverts)
 
-                multipolygon = None
+                ofaces = gpd.GeoDataFrame(layer)
+                ofaces = ofaces.dissolve(by='const', as_index=False,
+                                         sort=False)
 
-            # flush memory
-            layer = None
-            feature = None
-            datasource = None
+                ofaces = ofaces.explode(ignore_index=True)
+                ofaces = ofaces.set_crs(prjkmz.proj.wkt)
 
-        self.showprocesslog('shapefile export complete!')
+                filt = ofaces.geometry.is_empty
+                ofaces = ofaces[~filt]
+
+                if ifaces == 2:
+                    gdfxyz[ifaces] = ofaces
+                    continue
+
+                coords = ofaces.geometry.apply(lambda geom:
+                                               np.array(geom.exterior.coords))
+
+                geom = []
+                for i in coords:
+                    tmp = np.roll(i, ifaces+1, axis=1)
+                    pverts = Polygon(tmp)
+                    geom.append(pverts)
+                ofaces['geometry'] = geom
+                ofaces.pop('const')
+
+                gdfxyz[ifaces] = ofaces
+
+            gdf[lithtext] = pd.concat(gdfxyz, ignore_index=True)
+
+        self.showlog('Combining all lithologies...')
+        gdf = pd.concat(gdf, ignore_index=True)
+
+        self.showlog('Exporting to shapefile...')
+        gdf.to_file(self.ofile)
+
+        self.showlog('Shapefile export complete!')
 
 
 class Exportkmz(QtWidgets.QDialog):
@@ -1167,7 +1165,7 @@ class Exportkmz(QtWidgets.QDialog):
     def __init__(self, wkt, parent=None):
         super().__init__(parent)
 
-        self.checkbox_smooth = QtWidgets.QCheckBox()
+        self.cb_smooth = QtWidgets.QCheckBox()
         self.proj = dp.GroupProj('Confirm Model Projection')
         self.proj.set_current(wkt)
 
@@ -1182,20 +1180,20 @@ class Exportkmz(QtWidgets.QDialog):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.pfmod.iodefs.exportkmz')
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
 
-        gridlayout.addWidget(self.proj, 0, 0, 1, 2)
-        gridlayout.addWidget(self.checkbox_smooth, 1, 0, 1, 2)
-        gridlayout.addWidget(helpdocs, 2, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 2, 1, 1, 1)
+        gl_1.addWidget(self.proj, 0, 0, 1, 2)
+        gl_1.addWidget(self.cb_smooth, 1, 0, 1, 2)
+        gl_1.addWidget(helpdocs, 2, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 2, 1, 1, 1)
 
         self.setWindowTitle('Google Earth kmz Export')
-        self.checkbox_smooth.setText('Smooth Model')
+        self.cb_smooth.setText('Smooth Model')
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -1218,8 +1216,8 @@ class MessageCombo(QtWidgets.QDialog):
         self.outdata = {}
         self.parent = parent
 
-        self.master = QtWidgets.QComboBox()
-        self.master.addItems(combotext)
+        self.cmb_master = QtWidgets.QComboBox()
+        self.cmb_master.addItems(combotext)
 
         self.setupui()
 
@@ -1232,20 +1230,20 @@ class MessageCombo(QtWidgets.QDialog):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
-        label_master = QtWidgets.QLabel()
+        lbl_master = QtWidgets.QLabel()
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
         buttonbox.setStandardButtons(buttonbox.Ok)
 
         self.setWindowTitle('Model Choice')
-        label_master.setText('Choose Model:')
+        lbl_master.setText('Choose Model:')
 
-        gridlayout_main.addWidget(label_master, 0, 0, 1, 1)
-        gridlayout_main.addWidget(self.master, 0, 1, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 3, 1, 1, 3)
+        gl_main.addWidget(lbl_master, 0, 0, 1, 1)
+        gl_main.addWidget(self.cmb_master, 0, 1, 1, 1)
+        gl_main.addWidget(buttonbox, 3, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
 
@@ -1259,7 +1257,7 @@ class MessageCombo(QtWidgets.QDialog):
             Returns current text.
 
         """
-        return self.master.currentText()
+        return self.cmb_master.currentText()
 
 
 def _testfn():
@@ -1267,9 +1265,9 @@ def _testfn():
     from IPython import get_ipython
     get_ipython().run_line_magic('matplotlib', 'inline')
 
-    print('Starting')
-
     ifile = r"d:\Workdata\modelling\small_upper.npz"
+    ifile = r"D:\Workdata\modelling\Magmodel_Upper22km_AveAll_diapir_withDeepDens_newdens.npz"
+    ofile = r"d:\Workdata\modelling\hope2.shp"
 
     app = QtWidgets.QApplication(sys.argv)
 
@@ -1277,14 +1275,12 @@ def _testfn():
     DM.ifile = ifile
     DM.settings(nodialog=True)
 
-    odata = DM.outdata['Raster']
-
-    for dat in odata:
-        plt.figure(dpi=150)
-        plt.title(dat.dataid)
-        plt.imshow(dat.data, extent=dat.extent)
-        plt.colorbar()
-        plt.show()
+    EM = ExportMod3D()
+    EM.indata = DM.outdata
+    EM.ofile = ofile
+    EM.lmod = EM.indata['Model3D'][0]
+    EM.mod3dtoshp(nodialog=False)
+    # EM.exec()
 
 
 if __name__ == "__main__":
