@@ -29,15 +29,10 @@ import os
 import sys
 import numpy as np
 
-# The next two lines are fixes for types in PyOpenGL. They are not used, so
-# just avoid a crash when these types are not on certain platforms.
-np.float128 = np.float64
-np.complex256 = np.complex128
-
 from PyQt5 import QtCore, QtWidgets, QtOpenGL, QtGui
 from OpenGL import GL
 from OpenGL import GLU
-from OpenGL import GLUT
+# from OpenGL import GLUT
 from OpenGL.arrays import vbo
 from scipy.ndimage import zoom, convolve
 from numba import jit
@@ -89,14 +84,12 @@ class Mod3dDisplay(ContextModule):
 
         # Back to normal stuff
         self.lw_3dmod_defs = QtWidgets.QListWidget()
-        self.label = QtWidgets.QLabel()
-        self.label2 = QtWidgets.QLabel()
         self.pb_save = QtWidgets.QPushButton('Save to Image File (JPG or PNG)')
         self.pb_resetlight = QtWidgets.QPushButton('Reset Light')
         self.pb_refresh = QtWidgets.QPushButton('Refresh Model')
-        self.checkbox_smooth = QtWidgets.QCheckBox('Smooth Model')
-        self.checkbox_ortho = QtWidgets.QCheckBox('Orthographic Projection')
-        self.checkbox_axis = QtWidgets.QCheckBox('Display Axis')
+        self.cb_smooth = QtWidgets.QCheckBox('Smooth Model')
+        self.cb_ortho = QtWidgets.QCheckBox('Orthographic Projection')
+        self.cb_axis = QtWidgets.QCheckBox('Display Axis')
         self.pbar = QtWidgets.QProgressBar()
         self.glwidget = GLWidget()
         self.vslider_3dmodel = QtWidgets.QSlider()
@@ -113,14 +106,14 @@ class Mod3dDisplay(ContextModule):
         None.
 
         """
-        horizontallayout = QtWidgets.QHBoxLayout(self)
-        vbox_cmodel = QtWidgets.QVBoxLayout()
-        verticallayout = QtWidgets.QVBoxLayout()
+        hbl = QtWidgets.QHBoxLayout(self)
+        vbl_cmodel = QtWidgets.QVBoxLayout()
+        vbl = QtWidgets.QVBoxLayout()
 
         self.vslider_3dmodel.setMinimum(1)
         self.vslider_3dmodel.setMaximum(1000)
         self.vslider_3dmodel.setOrientation(QtCore.Qt.Vertical)
-        vbox_cmodel.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
+        vbl_cmodel.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
         sizepolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed,
                                            QtWidgets.QSizePolicy.Fixed)
 
@@ -131,37 +124,37 @@ class Mod3dDisplay(ContextModule):
         self.lw_3dmod_defs.setSelectionMode(
             QtWidgets.QAbstractItemView.MultiSelection)
         self.lw_3dmod_defs.setFixedWidth(220)
-        self.checkbox_smooth.setSizePolicy(sizepolicy)
+        self.cb_smooth.setSizePolicy(sizepolicy)
         self.pb_save.setSizePolicy(sizepolicy_pb)
         self.pb_refresh.setSizePolicy(sizepolicy_pb)
         self.pbar.setOrientation(QtCore.Qt.Vertical)
 
-        self.checkbox_ortho.setChecked(True)
-        self.checkbox_axis.setChecked(True)
+        self.cb_ortho.setChecked(True)
+        self.cb_axis.setChecked(True)
 
-        verticallayout.addWidget(self.lw_3dmod_defs)
-        verticallayout.addWidget(QtWidgets.QLabel('Light Position:'))
-        verticallayout.addWidget(self.msc)
-        verticallayout.addWidget(self.pb_resetlight)
-        verticallayout.addWidget(self.checkbox_smooth)
-        verticallayout.addWidget(self.checkbox_ortho)
-        verticallayout.addWidget(self.checkbox_axis)
-        verticallayout.addWidget(self.pb_save)
-        verticallayout.addWidget(self.pb_refresh)
-        vbox_cmodel.addWidget(self.glwidget)
-        horizontallayout.addWidget(self.vslider_3dmodel)
-        horizontallayout.addLayout(vbox_cmodel)
-        horizontallayout.addLayout(verticallayout)
-        horizontallayout.addWidget(self.pbar)
+        vbl.addWidget(self.lw_3dmod_defs)
+        vbl.addWidget(QtWidgets.QLabel('Light Position:'))
+        vbl.addWidget(self.msc)
+        vbl.addWidget(self.pb_resetlight)
+        vbl.addWidget(self.cb_smooth)
+        vbl.addWidget(self.cb_ortho)
+        vbl.addWidget(self.cb_axis)
+        vbl.addWidget(self.pb_save)
+        vbl.addWidget(self.pb_refresh)
+        vbl_cmodel.addWidget(self.glwidget)
+        hbl.addWidget(self.vslider_3dmodel)
+        hbl.addLayout(vbl_cmodel)
+        hbl.addLayout(vbl)
+        hbl.addWidget(self.pbar)
 
         self.lw_3dmod_defs.clicked.connect(self.change_defs)
         self.vslider_3dmodel.sliderReleased.connect(self.mod3d_vs)
         self.pb_save.clicked.connect(self.save)
         self.pb_refresh.clicked.connect(self.run)
         self.pb_resetlight.clicked.connect(self.resetlight)
-        self.checkbox_smooth.stateChanged.connect(self.update_plot)
-        self.checkbox_ortho.stateChanged.connect(self.update_model2)
-        self.checkbox_axis.stateChanged.connect(self.update_model2)
+        self.cb_smooth.stateChanged.connect(self.update_plot)
+        self.cb_ortho.stateChanged.connect(self.update_model2)
+        self.cb_axis.stateChanged.connect(self.update_model2)
         self.msc.figure.canvas.mpl_connect('button_press_event', self.sunclick)
 
     def save(self):
@@ -292,8 +285,8 @@ class Mod3dDisplay(ContextModule):
         """
         xdata, ydata = self.msc.sun.get_data()
 
-        phi = -xdata
-        theta = np.pi/2.-ydata
+        phi = -xdata[0]
+        theta = np.pi/2.-ydata[0]
 
         x = np.cos(phi)
         y = -np.sin(phi)
@@ -313,8 +306,8 @@ class Mod3dDisplay(ContextModule):
              event returned by matplotlib when a button is pressed
         """
         if event.inaxes == self.msc.axes:
-            self.msc.sun.set_xdata(event.xdata)
-            self.msc.sun.set_ydata(event.ydata)
+            self.msc.sun.set_xdata([event.xdata])
+            self.msc.sun.set_ydata([event.ydata])
             self.msc.figure.canvas.draw()
 
             phi = -event.xdata
@@ -383,8 +376,8 @@ class Mod3dDisplay(ContextModule):
 
         """
         if 'Model3D' not in self.indata:
-            self.showprocesslog('No 3D model. You may need to execute that '
-                                'module first')
+            self.showlog('No 3D model. You may need to execute that '
+                         'module first')
             return False
 
         self.lmod1 = self.indata['Model3D'][0]
@@ -396,8 +389,8 @@ class Mod3dDisplay(ContextModule):
         if liths[0] == 0:
             liths = liths[1:]
         if liths.size == 0:
-            self.showprocesslog('No 3D model. You need to draw in at least '
-                                'part of a lithology first.')
+            self.showlog('No 3D model. You need to draw in at least '
+                         'part of a lithology first.')
             return False
 
         self.show()
@@ -479,7 +472,7 @@ class Mod3dDisplay(ContextModule):
         QtWidgets.QApplication.processEvents()
 
         if issmooth is None:
-            issmooth = self.checkbox_smooth.isChecked()
+            issmooth = self.cb_smooth.isChecked()
 
         self.faces = {}
         self.norms = {}
@@ -621,7 +614,7 @@ class Mod3dDisplay(ContextModule):
                 c[1:-1, 1:-1, 1:-1] = cc
 
                 faces, vtx = MarchingCubes(xx, yy, zz, c, .1,
-                                           self.showprocesslog)
+                                           self.showlog)
 
                 if vtx.size == 0:
                     self.lmod1.update_lith_list_reverse()
@@ -649,8 +642,8 @@ class Mod3dDisplay(ContextModule):
         None.
 
         """
-        self.glwidget.is_ortho = self.checkbox_ortho.isChecked()
-        self.glwidget.has_axis = self.checkbox_axis.isChecked()
+        self.glwidget.is_ortho = self.cb_ortho.isChecked()
+        self.glwidget.has_axis = self.cb_axis.isChecked()
 
         liths = np.unique(self.gdata)
         liths = np.array(liths).astype(int)  # needed for use in faces array
@@ -716,7 +709,7 @@ class Mod3dDisplay(ContextModule):
         vadd = cmin+cptpd2
         vmult = cptp
 
-        self.glwidget.hastriangles = self.checkbox_smooth.isChecked()
+        self.glwidget.hastriangles = self.cb_smooth.isChecked()
         self.glwidget.cubeVtxArray = vtx
         self.glwidget.cubeClrArray = clr
         self.glwidget.cubeNrmArray = nrm
@@ -878,7 +871,7 @@ class GLWidget(QtOpenGL.QGLWidget):
         None.
 
         """
-        GLUT.glutInit()
+        # GLUT.glutInit()
         ctmp = QtGui.QColor.fromCmykF(0., 0., 0., 0.0)
         self.qglClearColor(ctmp)
         self.initGeometry()
@@ -1081,25 +1074,25 @@ class GLWidget(QtOpenGL.QGLWidget):
 
         GL.glColor3f(0, 0, 0)
 
-        self.print_string(xmax+6, ymax, zmin, 'X')
-        self.print_string(xmin, ymin-10, zmin, 'Y')
-        self.print_string(xmin, ymax, zmax+6, 'Z')
+        # self.print_string(xmax+6, ymax, zmin, 'X')
+        # self.print_string(xmin, ymin-10, zmin, 'Y')
+        # self.print_string(xmin, ymax, zmax+6, 'Z')
 
-        dz1 = (self.zmax-self.zmin)/5
+        # dz1 = (self.zmax-self.zmin)/5
 
-        for i in np.arange(xmin, xmax-dx, dx):
-            text = str(round((i+dx)*self.vmult+self.vadd[0], 1))
-            self.print_string(i+dx, ymax+4, zmin, text)
+        # for i in np.arange(xmin, xmax-dx, dx):
+        #     text = str(round((i+dx)*self.vmult+self.vadd[0], 1))
+        #     self.print_string(i+dx, ymax+4, zmin, text)
 
-        for i in np.arange(ymin, ymax-dy, dy):
-            text = str(round((i+dy)*self.vmult+self.vadd[1], 1))
-            self.print_string(xmax, i+dy, zmin, text)
+        # for i in np.arange(ymin, ymax-dy, dy):
+        #     text = str(round((i+dy)*self.vmult+self.vadd[1], 1))
+        #     self.print_string(xmax, i+dy, zmin, text)
 
-        tmp = self.zmin
-        for i in np.arange(zmin, zmax-dz, dz):
-            tmp += dz1
-            text = str(round(tmp, 1))
-            self.print_string(xmin, ymax+4, i+dz, text)
+        # tmp = self.zmin
+        # for i in np.arange(zmin, zmax-dz, dz):
+        #     tmp += dz1
+        #     text = str(round(tmp, 1))
+        #     self.print_string(xmin, ymax+4, i+dz, text)
 
         GL.glEnable(GL.GL_LIGHTING)
 
@@ -1124,9 +1117,9 @@ class GLWidget(QtOpenGL.QGLWidget):
 
         """
         GL.glRasterPos3f(x, y, z)
-        for _, ch in enumerate(text):
-            GLUT.glutBitmapCharacter(GLUT.GLUT_BITMAP_HELVETICA_10,
-                                     ctypes.c_int(ord(ch)))
+        # for _, ch in enumerate(text):
+        #     GLUT.glutBitmapCharacter(GLUT.GLUT_BITMAP_HELVETICA_10,
+        #                              ctypes.c_int(ord(ch)))
 
     def resizeGL(self, width, height):
         """
@@ -1198,8 +1191,8 @@ class GLWidget(QtOpenGL.QGLWidget):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : QMouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -1214,8 +1207,8 @@ class GLWidget(QtOpenGL.QGLWidget):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : QMouseEvent
+            Mouse event.
 
         Returns
         -------
@@ -1241,8 +1234,8 @@ class GLWidget(QtOpenGL.QGLWidget):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : QWheelEvent
+            Mouse wheel event.
 
         Returns
         -------
@@ -1381,7 +1374,7 @@ def normalize_v3(arr):
     return arr
 
 
-def MarchingCubes(x, y, z, c, iso, showprocesslog=print):
+def MarchingCubes(x, y, z, c, iso, showlog=print):
     """
     Marching cubes.
 
@@ -1417,8 +1410,8 @@ def MarchingCubes(x, y, z, c, iso, showprocesslog=print):
         Data.
     iso : float
         Isosurface level.
-    showprocesslog : function, optional
-        Routine to show text messages. The default is print.
+    showlog : function, optional
+        Display information. The default is print.
 
     Returns
     -------
@@ -1467,8 +1460,8 @@ def MarchingCubes(x, y, z, c, iso, showprocesslog=print):
     iden = np.nonzero(cedge.flatten(order='F'))[0]
 
     if iden.size == 0:          # all voxels are above or below iso
-        showprocesslog('Warning: No such lithology, or all voxels are above '
-                       'or below iso')
+        showlog('Warning: No such lithology, or all voxels are above '
+                'or below iso')
         F = np.array([])
         V = np.array([])
         return F, V
@@ -1613,7 +1606,7 @@ def InterpolateVertices(isolevel, p1x, p1y, p1z, p2x, p2y, p2z, valp1, valp2):
     return p
 
 
-@jit
+@jit(nopython=True)
 def fancyindex(out, var1, ii, jj, kk):
     """
     Fancy index.
@@ -2121,7 +2114,7 @@ def _testfn():
     # This activates the opengl stuff
 
     wid.show()
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
 
 
 def _testfn2():
@@ -2140,7 +2133,7 @@ def _testfn2():
     M3D.indata = IM.outdata
     M3D.data_init()
     M3D.run()
-    M3D.exec_()
+    M3D.exec()
 
 
 if __name__ == "__main__":
