@@ -30,9 +30,10 @@ import numpy as np
 from PyQt5 import QtWidgets, QtCore
 import scipy.interpolate as si
 from discretize import TensorMesh
-from SimPEG.potential_fields import magnetics
-from SimPEG.utils import surface2ind_topo,  model_builder
-from SimPEG import (maps, data, inverse_problem, data_misfit,
+from discretize.utils import active_from_xyz
+from simpeg.potential_fields import magnetics
+from simpeg.utils import model_builder
+from simpeg import (maps, data, inverse_problem, data_misfit,
                     regularization, optimization, directives,
                     inversion)
 import sklearn.cluster as skc
@@ -51,17 +52,16 @@ class MagInvert(BasicModule):
         super().__init__(parent)
         self.lmod1 = LithModel()
         self.lmod2 = LithModel()
-        # self.pbar = ProgressBar()
         self.inraster = {}
         self.tmp = []
 
-        self.combo_model = QtWidgets.QComboBox()
-        self.combo_other = QtWidgets.QComboBox()
-        self.combo_dtm = QtWidgets.QComboBox()
-        self.combo_mag = QtWidgets.QComboBox()
-        self.combo_grv = QtWidgets.QComboBox()
-        self.combo_reggrv = QtWidgets.QComboBox()
-        self.combo_dataset = QtWidgets.QComboBox()
+        self.cmb_model = QtWidgets.QComboBox()
+        self.cmb_other = QtWidgets.QComboBox()
+        self.cmb_dtm = QtWidgets.QComboBox()
+        self.cmb_mag = QtWidgets.QComboBox()
+        self.cmb_grv = QtWidgets.QComboBox()
+        self.cmb_reggrv = QtWidgets.QComboBox()
+        self.cmb_dataset = QtWidgets.QComboBox()
         self.dsb_utlx = QtWidgets.QDoubleSpinBox()
         self.dsb_utly = QtWidgets.QDoubleSpinBox()
         self.dsb_utlz = QtWidgets.QDoubleSpinBox()
@@ -95,8 +95,8 @@ class MagInvert(BasicModule):
         self.setWindowTitle('Inverse Modelling Parameters')
         helpdocs = menu_default.HelpButton('pygmi.pfmod.minv')
 
-        verticallayout = QtWidgets.QVBoxLayout(self)
-        hlayout = QtWidgets.QHBoxLayout()
+        vbl = QtWidgets.QVBoxLayout(self)
+        hbl = QtWidgets.QHBoxLayout()
 
         sizepolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding,
                                            QtWidgets.QSizePolicy.Preferred)
@@ -107,15 +107,15 @@ class MagInvert(BasicModule):
         buttonbox.button(buttonbox.Ok).setText('Run Inversion')
 
         # Current Models Groupbox
-        h_model = QtWidgets.QHBoxLayout()
+        hbl_model = QtWidgets.QHBoxLayout()
 
-        lbl1_model = QtWidgets.QLabel('Current Model:')
+        lbl_model = QtWidgets.QLabel('Current Model:')
 
-        self.combo_model.addItems(['None'])
-        self.combo_model.setSizePolicy(sizepolicy)
+        self.cmb_model.addItems(['None'])
+        self.cmb_model.setSizePolicy(sizepolicy)
 
-        h_model.addWidget(lbl1_model)
-        h_model.addWidget(self.combo_model)
+        hbl_model.addWidget(lbl_model)
+        hbl_model.addWidget(self.cmb_model)
 
         # General Properties
         self.dsb_mht.setMaximum(999999999.0)
@@ -132,32 +132,32 @@ class MagInvert(BasicModule):
         self.sb_classes.setMinimum(2)
         self.sb_classes.setMaximum(1000)
 
-        gb_gen_prop = QtWidgets.QGroupBox('General Properties')
-        gl_gen_prop = QtWidgets.QGridLayout(gb_gen_prop)
+        gbox_gen_prop = QtWidgets.QGroupBox('General Properties')
+        gl_gen_prop = QtWidgets.QGridLayout(gbox_gen_prop)
 
-        label_3 = QtWidgets.QLabel('Height of observation - Magnetic')
-        label_4 = QtWidgets.QLabel('Magnetic Field Intensity (nT)')
-        label_5 = QtWidgets.QLabel('Magnetic Inclination')
-        label_6 = QtWidgets.QLabel('Magnetic Declination')
+        lbl_3 = QtWidgets.QLabel('Height of observation - Magnetic')
+        lbl_4 = QtWidgets.QLabel('Magnetic Field Intensity (nT)')
+        lbl_5 = QtWidgets.QLabel('Magnetic Inclination')
+        lbl_6 = QtWidgets.QLabel('Magnetic Declination')
 
-        gl_gen_prop.addWidget(label_3, 3, 0, 1, 1)
+        gl_gen_prop.addWidget(lbl_3, 3, 0, 1, 1)
         gl_gen_prop.addWidget(self.dsb_mht, 3, 1, 1, 1)
-        gl_gen_prop.addWidget(label_4, 4, 0, 1, 1)
+        gl_gen_prop.addWidget(lbl_4, 4, 0, 1, 1)
         gl_gen_prop.addWidget(self.dsb_hint, 4, 1, 1, 1)
-        gl_gen_prop.addWidget(label_5, 5, 0, 1, 1)
+        gl_gen_prop.addWidget(lbl_5, 5, 0, 1, 1)
         gl_gen_prop.addWidget(self.dsb_hinc, 5, 1, 1, 1)
-        gl_gen_prop.addWidget(label_6, 6, 0, 1, 1)
+        gl_gen_prop.addWidget(lbl_6, 6, 0, 1, 1)
         gl_gen_prop.addWidget(self.dsb_hdec, 6, 1, 1, 1)
 
         # Data Information Groupbox
-        gb_data_info = QtWidgets.QGroupBox('Dataset Information')
-        gl_data_info = QtWidgets.QGridLayout(gb_data_info)
+        gbox_data_info = QtWidgets.QGroupBox('Dataset Information')
+        gl_data_info = QtWidgets.QGridLayout(gbox_data_info)
 
-        self.combo_mag.addItems(['None'])
-        self.combo_grv.addItems(['None'])
-        self.combo_reggrv.addItems(['None'])
-        self.combo_dtm.addItems(['None'])
-        self.combo_other.addItems(['None'])
+        self.cmb_mag.addItems(['None'])
+        self.cmb_grv.addItems(['None'])
+        self.cmb_reggrv.addItems(['None'])
+        self.cmb_dtm.addItems(['None'])
+        self.cmb_other.addItems(['None'])
 
         gl_data_info.setColumnStretch(0, 1)
         gl_data_info.setColumnStretch(1, 1)
@@ -166,25 +166,25 @@ class MagInvert(BasicModule):
         gl_data_info.addWidget(QtWidgets.QLabel('DTM Dataset:'), 0, 0, 1, 1)
         gl_data_info.addWidget(QtWidgets.QLabel('Magnetic Dataset:'),
                                1, 0, 1, 1)
-        gl_data_info.addWidget(self.combo_dtm, 0, 1, 1, 1)
-        gl_data_info.addWidget(self.combo_mag, 1, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_dtm, 0, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_mag, 1, 1, 1, 1)
 
         # Data Extents Groupbox
-        gb_extent = QtWidgets.QGroupBox('Model Extent Properties')
-        gl_extent = QtWidgets.QGridLayout(gb_extent)
+        gbox_extent = QtWidgets.QGroupBox('Model Extent Properties')
+        gl_extent = QtWidgets.QGridLayout(gbox_extent)
 
-        self.combo_dataset.addItems(['None'])
+        self.cmb_dataset.addItems(['None'])
 
-        lbl0 = QtWidgets.QLabel('Get Study Area from following Dataset:')
-        lbl3 = QtWidgets.QLabel('Upper Top Left X Coordinate:')
-        lbl4 = QtWidgets.QLabel('Upper Top Left Y Coordinate:')
-        lbl1 = QtWidgets.QLabel('Upper Top Left Z Coordinate (from DTM):')
-        lbl8 = QtWidgets.QLabel('Total X Extent:')
-        lbl9 = QtWidgets.QLabel('Total Y Extent:')
-        lbl10 = QtWidgets.QLabel('Total Z Extent (Depth):')
-        lbl5 = QtWidgets.QLabel('X and Y Cell Size:')
-        lbl6 = QtWidgets.QLabel('Z Cell Size:')
-        lbl99 = QtWidgets.QLabel('Number of output classes:')
+        lbl_0 = QtWidgets.QLabel('Get Study Area from following Dataset:')
+        lbl_3 = QtWidgets.QLabel('Upper Top Left X Coordinate:')
+        lbl_4 = QtWidgets.QLabel('Upper Top Left Y Coordinate:')
+        lbl_1 = QtWidgets.QLabel('Upper Top Left Z Coordinate (from DTM):')
+        lbl_8 = QtWidgets.QLabel('Total X Extent:')
+        lbl_9 = QtWidgets.QLabel('Total Y Extent:')
+        lbl_10 = QtWidgets.QLabel('Total Z Extent (Depth):')
+        lbl_5 = QtWidgets.QLabel('X and Y Cell Size:')
+        lbl_6 = QtWidgets.QLabel('Z Cell Size:')
+        lbl_99 = QtWidgets.QLabel('Number of output classes:')
 
         self.dsb_utlx.setMinimum(-999999999.0)
         self.dsb_utlx.setMaximum(999999999.0)
@@ -222,17 +222,17 @@ class MagInvert(BasicModule):
         self.sb_layers.setMaximum(1000000)
         self.sb_layers.setPrefix('Layers (Z): ')
 
-        gl_extent.addWidget(lbl0, 0, 0, 1, 1)
-        gl_extent.addWidget(lbl3, 1, 0, 1, 1)
-        gl_extent.addWidget(lbl4, 2, 0, 1, 1)
-        gl_extent.addWidget(lbl1, 3, 0, 1, 1)
-        gl_extent.addWidget(lbl8, 4, 0, 1, 1)
-        gl_extent.addWidget(lbl9, 5, 0, 1, 1)
-        gl_extent.addWidget(lbl10, 6, 0, 1, 1)
-        gl_extent.addWidget(lbl5, 7, 0, 1, 1)
-        gl_extent.addWidget(lbl6, 8, 0, 1, 1)
-        gl_extent.addWidget(lbl99, 9, 0, 1, 1)
-        gl_extent.addWidget(self.combo_dataset, 0, 1, 1, 1)
+        gl_extent.addWidget(lbl_0, 0, 0, 1, 1)
+        gl_extent.addWidget(lbl_3, 1, 0, 1, 1)
+        gl_extent.addWidget(lbl_4, 2, 0, 1, 1)
+        gl_extent.addWidget(lbl_1, 3, 0, 1, 1)
+        gl_extent.addWidget(lbl_8, 4, 0, 1, 1)
+        gl_extent.addWidget(lbl_9, 5, 0, 1, 1)
+        gl_extent.addWidget(lbl_10, 6, 0, 1, 1)
+        gl_extent.addWidget(lbl_5, 7, 0, 1, 1)
+        gl_extent.addWidget(lbl_6, 8, 0, 1, 1)
+        gl_extent.addWidget(lbl_99, 9, 0, 1, 1)
+        gl_extent.addWidget(self.cmb_dataset, 0, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utlx, 1, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utly, 2, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utlz, 3, 1, 1, 1)
@@ -246,15 +246,14 @@ class MagInvert(BasicModule):
         gl_extent.addWidget(self.sb_layers, 3, 2, 1, 1)
         gl_extent.addWidget(self.sb_classes, 9, 1, 1, 1)
 
-        hlayout.addWidget(helpdocs)
-        # hlayout.addWidget(self.pbar)
-        hlayout.addWidget(buttonbox)
+        hbl.addWidget(helpdocs)
+        hbl.addWidget(buttonbox)
 
         # Assign to main layout
-        verticallayout.addWidget(gb_data_info)
-        verticallayout.addWidget(gb_gen_prop)
-        verticallayout.addWidget(gb_extent)
-        verticallayout.addLayout(hlayout)
+        vbl.addWidget(gbox_data_info)
+        vbl.addWidget(gbox_gen_prop)
+        vbl.addWidget(gbox_extent)
+        vbl.addLayout(hbl)
 
         # Link functions
         self.dsb_xycell.valueChanged.connect(self.xycell)
@@ -265,9 +264,9 @@ class MagInvert(BasicModule):
         self.dsb_xextent.valueChanged.connect(self.upd_layers)
         self.dsb_yextent.valueChanged.connect(self.upd_layers)
         self.dsb_zextent.valueChanged.connect(self.upd_layers)
-        self.combo_dataset.currentIndexChanged.connect(self.get_area)
-        self.combo_dtm.currentIndexChanged.connect(self.choose_dtm)
-        self.combo_model.currentIndexChanged.connect(self.choose_model)
+        self.cmb_dataset.currentIndexChanged.connect(self.get_area)
+        self.cmb_dtm.currentIndexChanged.connect(self.choose_dtm)
+        self.cmb_model.currentIndexChanged.connect(self.choose_model)
 
         buttonbox.accepted.connect(self.apply_changes)
         buttonbox.rejected.connect(self.reject)
@@ -281,11 +280,11 @@ class MagInvert(BasicModule):
         None.
 
         """
-        self.showprocesslog('Working...')
+        self.showlog('Working...')
 
-        self.choose_combo(self.combo_dtm, 'DTM Dataset')
-        self.choose_combo(self.combo_mag, 'Magnetic Dataset')
-        self.choose_combo(self.combo_dataset, 'Study Area Dataset')
+        self.choose_combo(self.cmb_dtm, 'DTM Dataset')
+        self.choose_combo(self.cmb_mag, 'Magnetic Dataset')
+        self.choose_combo(self.cmb_dataset, 'Study Area Dataset')
 
         cols = self.sb_cols.value()
         rows = self.sb_rows.value()
@@ -305,7 +304,7 @@ class MagInvert(BasicModule):
         # the same dataset
         tmp = list(set(self.lmod1.griddata.values()))
         self.outdata['Raster'] = tmp
-        self.showprocesslog('Changes applied.')
+        self.showlog('Changes applied.')
 
         self.accept()
 
@@ -340,7 +339,7 @@ class MagInvert(BasicModule):
         None.
 
         """
-        ctxt = str(self.combo_dtm.currentText())
+        ctxt = str(self.cmb_dtm.currentText())
         if ctxt not in ('None', ''):
             curgrid = self.inraster[ctxt]
 
@@ -360,7 +359,7 @@ class MagInvert(BasicModule):
         None.
 
         """
-        ctxt = str(self.combo_model.currentText())
+        ctxt = str(self.cmb_model.currentText())
         if ctxt == 'None' or 'Model3D' not in self.indata:
             return
         for i in self.indata['Model3D']:
@@ -414,7 +413,7 @@ class MagInvert(BasicModule):
         None.
 
         """
-        ctxt = str(self.combo_dataset.currentText())
+        ctxt = str(self.cmb_dataset.currentText())
         if ctxt not in ('None', ''):
             curgrid = self.inraster[ctxt]
 
@@ -494,16 +493,16 @@ class MagInvert(BasicModule):
             for i in self.indata['Model3D']:
                 modnames.append(i.name)
 
-        self.combo_model.currentIndexChanged.disconnect()
+        self.cmb_model.currentIndexChanged.disconnect()
 
-        self.combo_model.clear()
-        self.combo_model.addItems(modnames)
-        self.combo_model.setCurrentIndex(0)
+        self.cmb_model.clear()
+        self.cmb_model.addItems(modnames)
+        self.cmb_model.setCurrentIndex(0)
 
         if len(modnames) >= 2:
-            self.combo_model.setCurrentIndex(1)
+            self.cmb_model.setCurrentIndex(1)
 
-        self.combo_model.currentIndexChanged.connect(self.choose_model)
+        self.cmb_model.currentIndexChanged.connect(self.choose_model)
 
     def update_combos(self):
         """
@@ -514,7 +513,7 @@ class MagInvert(BasicModule):
         None.
 
         """
-        self.combo_dataset.currentIndexChanged.disconnect()
+        self.cmb_dataset.currentIndexChanged.disconnect()
 
         gkeys = list(self.inraster.keys())
         if 'Calculated Gravity' in gkeys:
@@ -524,51 +523,51 @@ class MagInvert(BasicModule):
         gkeys = ['None'] + gkeys
 
         if len(gkeys) > 1:
-            self.combo_other.clear()
-            self.combo_other.addItems(gkeys)
-            self.combo_other.setCurrentIndex(0)
-            self.combo_dtm.clear()
-            self.combo_dtm.addItems(gkeys)
-            self.combo_dtm.setCurrentIndex(0)
-            self.combo_mag.clear()
-            self.combo_mag.addItems(gkeys)
-            self.combo_mag.setCurrentIndex(0)
-            self.combo_grv.clear()
-            self.combo_grv.addItems(gkeys)
-            self.combo_grv.setCurrentIndex(0)
-            self.combo_reggrv.clear()
-            self.combo_reggrv.addItems(gkeys)
-            self.combo_reggrv.setCurrentIndex(0)
-            self.combo_dataset.clear()
-            self.combo_dataset.addItems(gkeys)
-            self.combo_dataset.setCurrentIndex(0)
+            self.cmb_other.clear()
+            self.cmb_other.addItems(gkeys)
+            self.cmb_other.setCurrentIndex(0)
+            self.cmb_dtm.clear()
+            self.cmb_dtm.addItems(gkeys)
+            self.cmb_dtm.setCurrentIndex(0)
+            self.cmb_mag.clear()
+            self.cmb_mag.addItems(gkeys)
+            self.cmb_mag.setCurrentIndex(0)
+            self.cmb_grv.clear()
+            self.cmb_grv.addItems(gkeys)
+            self.cmb_grv.setCurrentIndex(0)
+            self.cmb_reggrv.clear()
+            self.cmb_reggrv.addItems(gkeys)
+            self.cmb_reggrv.setCurrentIndex(0)
+            self.cmb_dataset.clear()
+            self.cmb_dataset.addItems(gkeys)
+            self.cmb_dataset.setCurrentIndex(0)
 
             lkeys = list(self.lmod1.griddata.keys())
             if 'DTM Dataset' in lkeys:
                 tmp = self.lmod1.griddata['DTM Dataset'].dataid
-                self.combo_dtm.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_dtm.setCurrentIndex(gkeys.index(tmp))
 
             if 'Magnetic Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Magnetic Dataset'].dataid
-                self.combo_mag.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_mag.setCurrentIndex(gkeys.index(tmp))
 
             if 'Gravity Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Gravity Dataset'].dataid
-                self.combo_grv.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_grv.setCurrentIndex(gkeys.index(tmp))
 
             if 'Gravity Regional' in lkeys:
                 tmp = self.lmod1.griddata['Gravity Regional'].dataid
-                self.combo_reggrv.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_reggrv.setCurrentIndex(gkeys.index(tmp))
 
             if 'Study Area Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Study Area Dataset'].dataid
-                self.combo_dataset.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_dataset.setCurrentIndex(gkeys.index(tmp))
 
             if 'Other' in lkeys:
                 tmp = self.lmod1.griddata['Other'].dataid
-                self.combo_other.setCurrentIndex(gkeys.index(tmp))
+                self.cmb_other.setCurrentIndex(gkeys.index(tmp))
 
-        self.combo_dataset.currentIndexChanged.connect(self.get_area)
+        self.cmb_dataset.currentIndexChanged.connect(self.get_area)
 
     def update_vals(self):
         """
@@ -677,7 +676,7 @@ class MagInvert(BasicModule):
         if nodialog is False:
             self.update_combos()
 
-        tmp = self.exec_()
+        tmp = self.exec()
 
         if tmp != 1:
             return tmp
@@ -689,6 +688,40 @@ class MagInvert(BasicModule):
 
         return tmp
 
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.saveobj(self.cmb_model)
+        self.saveobj(self.cmb_other)
+        self.saveobj(self.cmb_dtm)
+        self.saveobj(self.cmb_mag)
+        self.saveobj(self.cmb_grv)
+        self.saveobj(self.cmb_reggrv)
+        self.saveobj(self.cmb_dataset)
+
+        self.saveobj(self.dsb_utlx)
+        self.saveobj(self.dsb_utly)
+        self.saveobj(self.dsb_utlz)
+        self.saveobj(self.dsb_xextent)
+        self.saveobj(self.dsb_yextent)
+        self.saveobj(self.dsb_zextent)
+        self.saveobj(self.dsb_xycell)
+        self.saveobj(self.dsb_zcell)
+        self.saveobj(self.sb_cols)
+        self.saveobj(self.sb_rows)
+        self.saveobj(self.sb_layers)
+        self.saveobj(self.sb_classes)
+        self.saveobj(self.dsb_mht)
+        self.saveobj(self.dsb_hdec)
+        self.saveobj(self.dsb_hint)
+        self.saveobj(self.dsb_hinc)
+
     def acceptall(self):
         """
         Accept All.
@@ -703,8 +736,10 @@ class MagInvert(BasicModule):
         dat = [self.lmod1.griddata['Magnetic Dataset'],
                self.lmod1.griddata['DTM Dataset']]
 
-        dat = lstack(dat, masterid=0, commonmask=True, piter=self.piter,
-                     pprint=self.showprocesslog)
+        masterid = self.lmod1.griddata['Magnetic Dataset'].dataid
+
+        dat = lstack(dat, masterid=masterid, commonmask=True,
+                     piter=self.piter, showlog=self.showlog)
 
         mag = dat[0]
         dtm = dat[1]
@@ -721,13 +756,6 @@ class MagInvert(BasicModule):
         xxx = np.linspace(xmin, xmax, cols, False) + xdim/2
         yyy = np.linspace(ymin, ymax, rows, False) + ydim/2
 
-        # xxx = np.arange(xmin, xmax, xdim) + xdim/2
-        # yyy = np.arange(ymin, ymax, ydim) + ydim/2
-
-        # Get rid of the extra values due to round off error
-        # xxx = xxx[xxx < xmax]
-        # yyy = yyy[yyy < ymax]
-
         xy = np.meshgrid(xxx, yyy[::-1])
         z = dtm.data + self.dsb_mht.value()
 
@@ -753,9 +781,6 @@ class MagInvert(BasicModule):
         declination = self.dsb_hdec.value()
         strength = self.dsb_hint.value()
 
-        # inducing_field = (strength, inclination, declination)
-        # source_field = magnetics.sources.SourceField(
-        #     receiver_list=receiver_list, parameters=inducing_field)
         source_field = magnetics.UniformBackgroundField(
             receiver_list=receiver_list, amplitude=strength,
             inclination=inclination, declination=declination)
@@ -770,28 +795,20 @@ class MagInvert(BasicModule):
         hy = [(dhxy, 5, -1.3), (dhxy, self.lmod1.numy), (dhxy, 5, 1.3)]
         hz = [(dh, 5, -1.3), (dh, self.lmod1.numz)]
 
-        x0 = xmin-(np.sum([dhxy*1.3**(i+1) for i in range(5)])+5)
-        y0 = ymin-(np.sum([dhxy*1.3**(i+1) for i in range(5)])+5)
+        x0 = xmin-(np.sum([dhxy*1.3**(i+1) for i in range(5)]))
+        y0 = ymin-(np.sum([dhxy*1.3**(i+1) for i in range(5)]))
         z0 = -(dh*self.lmod1.numz)-(np.sum([dh*1.3**(i+1) for i in range(5)]))
 
         mesh = TensorMesh([hx, hy, hz], [x0, y0, z0])
 
-        # hx = [(dhxy, self.lmod1.numx)]
-        # hy = [(dhxy, self.lmod1.numy)]
-        # hz = [(dh, self.lmod1.numz)]
-
-        # x0 = xmin-5
-        # y0 = ymin-5
-        # z0 = -dh*self.lmod1.numz
-
-        # mesh = TensorMesh([hx, hy, hz], [x0, y0, z0])
-        # mesh = TensorMesh([hx, hy, hz], "CCN")
-
         # Starting/Reference Model and Mapping on Tensor Mesh
         background_susceptibility = 1e-4
-        ind_active = surface2ind_topo(mesh, topo_xyz)
+
+        ind_active = active_from_xyz(mesh, topo_xyz)
         nC = int(ind_active.sum())
         model_map = maps.IdentityMap(nP=nC)
+
+        # Define Starting model
         starting_model = background_susceptibility * np.ones(nC)
 
         # Define the Physics
@@ -803,7 +820,8 @@ class MagInvert(BasicModule):
         dmis = data_misfit.L2DataMisfit(data=data_object,
                                         simulation=simulation)
         reg = regularization.Sparse(mesh, active_cells=ind_active,
-                                    mapping=model_map, reference_model=starting_model,
+                                    mapping=model_map,
+                                    reference_model=starting_model,
                                     gradient_type="total")
         reg.norms = [0, 0, 0, 0]
 
@@ -822,7 +840,7 @@ class MagInvert(BasicModule):
 
         target_misfit = directives.TargetMisfit(chifact=1)
         sensitivity_weights = directives.UpdateSensitivityWeights(
-            everyIter=False)
+            every_iteration=False)
         directives_list = [sensitivity_weights, starting_beta, save_iteration,
                            update_IRLS, update_jacobi]
 
@@ -833,19 +851,16 @@ class MagInvert(BasicModule):
             with redirect_stdout(self.stdout_redirect):
                 recovered_model = inv.run(starting_model)
         except Exception as e:
-            self.showprocesslog('Error: '+str(e))
+            self.showlog('Error: '+str(e))
             return False
 
         # Recreate True Model
-        # -------------------
-
         background_susceptibility = 0.0001
         sphere_susceptibility = 0.01
 
         true_model = background_susceptibility * np.ones(nC)
-        ind_sphere = model_builder.getIndicesSphere(
-            np.r_[0.0, 0.0, -45.0], 15.0, mesh.cell_centers
-        )
+        ind_sphere = model_builder.get_indices_sphere(
+            np.r_[0.0, 0.0, -45.0], 15.0, mesh.cell_centers)
         ind_sphere = ind_sphere[ind_active]
         true_model[ind_sphere] = sphere_susceptibility
 
@@ -862,14 +877,11 @@ class MagInvert(BasicModule):
         r3 = r2[:-5, 5:-5, 5:-5]
         r3 = np.ma.masked_invalid(r3)
         r3 = np.ma.array(r3)
-        # X = skp.StandardScaler().fit_transform(r3.flatten())
 
         X = r3.compressed().reshape(-1, 1)
 
-        # cfit = skc.KMeans(n_clusters=i, tol=self.tol,
-        #                   max_iter=self.max_iter).fit(X)
         numclasses = self.sb_classes.value()
-        cfit = skc.KMeans(n_clusters=numclasses).fit(X)
+        cfit = skc.KMeans(n_clusters=numclasses, n_init='auto').fit(X)
 
         zout = cfit.labels_
         r3[~r3.mask] = zout
@@ -884,7 +896,6 @@ class MagInvert(BasicModule):
         for i2 in range(cnt):
             susc[i2] = X[cfit.labels_ == i2].mean()
             inputliths[i2] = str(susc[i2])
-            # print(i2, susc[i2])
 
         bsusc = np.min(susc)
         bindx = np.nonzero(susc == bsusc)[0][0]
@@ -936,8 +947,8 @@ def _testfn():
     from IPython import get_ipython
     get_ipython().run_line_magic('matplotlib', 'inline')
 
-    mfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\mag.tif"
-    dfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\dem.tif"
+    mfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\magnetics\mag.tif"
+    dfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\magnetics\dem.tif"
 
     mdat = get_raster(mfile)
     ddat = get_raster(dfile)
@@ -961,16 +972,16 @@ def _testfn():
     utlx = -80
     utly = 90
     utlz = 0
-    dxy = 5.
+    dxy = 10.
     d_z = 5.
-    mht = 1.
+    mht = 10.
 
     DM.lmod1.update(cols, rows, layers, utlx, utly, utlz, dxy, d_z, mht)
 
     DM.update_combos()
-    DM.combo_dtm.setCurrentText('dem')
-    DM.combo_mag.setCurrentText('mag')
-    DM.combo_dataset.setCurrentText('mag')
+    DM.cmb_dtm.setCurrentText('dem')
+    DM.cmb_mag.setCurrentText('mag')
+    DM.cmb_dataset.setCurrentText('mag')
 
     DM.choose_dtm()
 
@@ -978,6 +989,7 @@ def _testfn():
     DM.dsb_hdec.setValue(0)
     DM.dsb_hint.setValue(50000)
     DM.dsb_hinc.setValue(90)
+    DM.dsb_zcell.setValue(5)
 
     DM.settings(True)
 
@@ -1033,21 +1045,6 @@ def _testfn():
     cbar.set_label("SI", rotation=270, labelpad=15, size=12)
     plt.show()
 
-    # r2 = plotting_map * recovered_model
-    # r2.shape = (mesh.shape_cells[2], mesh.shape_cells[1], mesh.shape_cells[0])
-
-    # r2 = r2[::-1]
-    # r2 = r2[:-5]
-
-    # plt.imshow(r2[:, r2.shape[1]//2])
-    # plt.show()
-
-    # 3D Display
-    # tmp = Mod3dDisplay()
-    # tmp.indata = DM.outdata
-    # tmp.run()
-    # tmp.exec_()
-
     get_ipython().run_line_magic('matplotlib', 'Qt5')
 
     tmp = MainWidget()
@@ -1066,21 +1063,9 @@ def _testfn2():
 
     app = QtWidgets.QApplication(sys.argv)
 
-    # mfile = r"d:\Workdata\MagInv\pcmag.tif"
-
-    # mdat = get_raster(mfile)
-    # ddat = copy.deepcopy(mdat)
-    # ddat[0].data = ddat[0].data * 0.
-
     mfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\pcmagdem.tif"
     dfile = r"D:\Workdata\PyGMI Test Data\Potential Field Modelling\MagInv\pcdem.tif"
 
-    # mfile = r"c:\Workdata\PyGMI Test Data\Test_Mar2022\Data\Testing\mag_igrfremoved.tif"
-    # dfile = r"c:\Workdata\PyGMI Test Data\Test_Mar2022\Data\ER Mapper\dtmmicrolevel.PD.ers"
-
-    # mfile = r"c:\Workdata\PyGMI Test Data\Test_Mar2022\Data\VIS_ModelArea_TMA_utm35s.tif"
-    # dfile = r"c:\Workdata\PyGMI Test Data\Test_Mar2022\Data\VIS_ModelArea_SRTM90m_utm35s.tif"
-
     mdat = get_raster(mfile)
     ddat = get_raster(dfile)
 
@@ -1125,10 +1110,6 @@ def _testfn2():
     DM.choose_dtm()
 
     DM.dsb_mht.setValue(mht)
-    # DM.dsb_hdec.setValue(0)
-    # DM.dsb_hint.setValue(50000)
-    # DM.dsb_hinc.setValue(90)
-
     DM.settings(True)
 
     maps1, mesh, ind_active, recovered_model, true_model = DM.tmp
