@@ -42,13 +42,13 @@ class MextDisplay(QtWidgets.QDialog):
         self.showtext = parent.showtext
         self.pbar = pmisc.ProgressBar()
 
-        self.combo_model = QtWidgets.QComboBox()
-        self.combo_other = QtWidgets.QComboBox()
-        self.combo_dtm = QtWidgets.QComboBox()
-        self.combo_mag = QtWidgets.QComboBox()
-        self.combo_grv = QtWidgets.QComboBox()
-        self.combo_reggrv = QtWidgets.QComboBox()
-        self.combo_dataset = QtWidgets.QComboBox()
+        self.cmb_model = QtWidgets.QComboBox()
+        self.cmb_other = QtWidgets.QComboBox()
+        self.cmb_dtm = QtWidgets.QComboBox()
+        self.cmb_mag = QtWidgets.QComboBox()
+        self.cmb_grv = QtWidgets.QComboBox()
+        self.cmb_reggrv = QtWidgets.QComboBox()
+        self.cmb_dataset = QtWidgets.QComboBox()
         self.dsb_utlx = QtWidgets.QDoubleSpinBox()
         self.dsb_utly = QtWidgets.QDoubleSpinBox()
         self.dsb_utlz = QtWidgets.QDoubleSpinBox()
@@ -76,8 +76,8 @@ class MextDisplay(QtWidgets.QDialog):
         self.setWindowTitle('Model Extent Parameters')
         helpdocs = menu_default.HelpButton('pygmi.pfmod.mext')
 
-        verticallayout = QtWidgets.QVBoxLayout(self)
-        hlayout = QtWidgets.QHBoxLayout()
+        vbl = QtWidgets.QVBoxLayout(self)
+        hbl = QtWidgets.QHBoxLayout()
 
         sizepolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding,
                                            QtWidgets.QSizePolicy.Preferred)
@@ -90,62 +90,62 @@ class MextDisplay(QtWidgets.QDialog):
                                                '(reset calculations)')
 
         # Current Models Groupbox
-        h_model = QtWidgets.QHBoxLayout()
+        hbl_model = QtWidgets.QHBoxLayout()
 
-        lbl1_model = QtWidgets.QLabel('Current Model:')
+        lbl_model = QtWidgets.QLabel('Current Model:')
 
-        self.combo_model.addItems(['None'])
-        self.combo_model.setSizePolicy(sizepolicy)
+        self.cmb_model.addItems(['None'])
+        self.cmb_model.setSizePolicy(sizepolicy)
 
-        h_model.addWidget(lbl1_model)
-        h_model.addWidget(self.combo_model)
+        hbl_model.addWidget(lbl_model)
+        hbl_model.addWidget(self.cmb_model)
 
         # Data Information Groupbox
-        gb_data_info = QtWidgets.QGroupBox('Dataset Information')
-        gl_data_info = QtWidgets.QGridLayout(gb_data_info)
+        gbox_data_info = QtWidgets.QGroupBox('Dataset Information')
+        gl_data_info = QtWidgets.QGridLayout(gbox_data_info)
 
-        self.combo_mag.addItems(['None'])
-        self.combo_grv.addItems(['None'])
-        self.combo_reggrv.addItems(['None'])
-        self.combo_dtm.addItems(['None'])
-        self.combo_other.addItems(['None'])
+        self.cmb_mag.addItems(['None'])
+        self.cmb_grv.addItems(['None'])
+        self.cmb_reggrv.addItems(['None'])
+        self.cmb_dtm.addItems(['None'])
+        self.cmb_other.addItems(['None'])
 
         gl_data_info.setColumnStretch(0, 1)
         gl_data_info.setColumnStretch(1, 1)
         gl_data_info.setColumnStretch(2, 1)
 
-        lbl1_data_info = QtWidgets.QLabel('DTM Dataset:')
-        lbl2_data_info = QtWidgets.QLabel('Magnetic Dataset:')
-        lbl3_data_info = QtWidgets.QLabel('Gravity Dataset:')
-        lbl4_data_info = QtWidgets.QLabel('Gravity Regional Dataset:')
-        lbl5_data_info = QtWidgets.QLabel('Other:')
+        lbl_1_data_info = QtWidgets.QLabel('DTM Dataset:')
+        lbl_2_data_info = QtWidgets.QLabel('Magnetic Dataset:')
+        lbl_3_data_info = QtWidgets.QLabel('Gravity Dataset:')
+        lbl_4_data_info = QtWidgets.QLabel('Gravity Regional Dataset:')
+        lbl_5_data_info = QtWidgets.QLabel('Other:')
 
-        gl_data_info.addWidget(lbl1_data_info, 0, 0, 1, 1)
-        gl_data_info.addWidget(lbl2_data_info, 1, 0, 1, 1)
-        gl_data_info.addWidget(lbl3_data_info, 2, 0, 1, 1)
-        gl_data_info.addWidget(lbl4_data_info, 3, 0, 1, 1)
-        gl_data_info.addWidget(lbl5_data_info, 4, 0, 1, 1)
-        gl_data_info.addWidget(self.combo_dtm, 0, 1, 1, 1)
-        gl_data_info.addWidget(self.combo_mag, 1, 1, 1, 1)
-        gl_data_info.addWidget(self.combo_grv, 2, 1, 1, 1)
-        gl_data_info.addWidget(self.combo_reggrv, 3, 1, 1, 1)
-        gl_data_info.addWidget(self.combo_other, 4, 1, 1, 1)
+        gl_data_info.addWidget(lbl_1_data_info, 0, 0, 1, 1)
+        gl_data_info.addWidget(lbl_2_data_info, 1, 0, 1, 1)
+        gl_data_info.addWidget(lbl_3_data_info, 2, 0, 1, 1)
+        gl_data_info.addWidget(lbl_4_data_info, 3, 0, 1, 1)
+        gl_data_info.addWidget(lbl_5_data_info, 4, 0, 1, 1)
+        gl_data_info.addWidget(self.cmb_dtm, 0, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_mag, 1, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_grv, 2, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_reggrv, 3, 1, 1, 1)
+        gl_data_info.addWidget(self.cmb_other, 4, 1, 1, 1)
 
         # Data Extents Groupbox
-        gb_extent = QtWidgets.QGroupBox('Model Extent Properties')
-        gl_extent = QtWidgets.QGridLayout(gb_extent)
+        gbox_extent = QtWidgets.QGroupBox('Model Extent Properties')
+        gl_extent = QtWidgets.QGridLayout(gbox_extent)
 
-        self.combo_dataset.addItems(['None'])
+        self.cmb_dataset.addItems(['None'])
 
-        lbl0 = QtWidgets.QLabel('Get Study Area from following Dataset:')
-        lbl3 = QtWidgets.QLabel('Upper Top Left X Coordinate:')
-        lbl4 = QtWidgets.QLabel('Upper Top Left Y Coordinate:')
-        lbl1 = QtWidgets.QLabel('Upper Top Left Z Coordinate (from DTM):')
-        lbl8 = QtWidgets.QLabel('Total X Extent:')
-        lbl9 = QtWidgets.QLabel('Total Y Extent:')
-        lbl10 = QtWidgets.QLabel('Total Z Extent (Depth):')
-        lbl5 = QtWidgets.QLabel('X and Y Cell Size:')
-        lbl6 = QtWidgets.QLabel('Z Cell Size:')
+        lbl_0 = QtWidgets.QLabel('Get Study Area from following Dataset:')
+        lbl_3 = QtWidgets.QLabel('Upper Top Left X Coordinate:')
+        lbl_4 = QtWidgets.QLabel('Upper Top Left Y Coordinate:')
+        lbl_1 = QtWidgets.QLabel('Upper Top Left Z Coordinate (from DTM):')
+        lbl_8 = QtWidgets.QLabel('Total X Extent:')
+        lbl_9 = QtWidgets.QLabel('Total Y Extent:')
+        lbl_10 = QtWidgets.QLabel('Total Z Extent (Depth):')
+        lbl_5 = QtWidgets.QLabel('X and Y Cell Size:')
+        lbl_6 = QtWidgets.QLabel('Z Cell Size:')
 
         self.dsb_utlx.setMinimum(-999999999.0)
         self.dsb_utlx.setMaximum(999999999.0)
@@ -183,16 +183,16 @@ class MextDisplay(QtWidgets.QDialog):
         self.sb_layers.setMaximum(1000000)
         self.sb_layers.setPrefix('Layers (Z): ')
 
-        gl_extent.addWidget(lbl0, 0, 0, 1, 1)
-        gl_extent.addWidget(lbl3, 1, 0, 1, 1)
-        gl_extent.addWidget(lbl4, 2, 0, 1, 1)
-        gl_extent.addWidget(lbl1, 3, 0, 1, 1)
-        gl_extent.addWidget(lbl8, 4, 0, 1, 1)
-        gl_extent.addWidget(lbl9, 5, 0, 1, 1)
-        gl_extent.addWidget(lbl10, 6, 0, 1, 1)
-        gl_extent.addWidget(lbl5, 7, 0, 1, 1)
-        gl_extent.addWidget(lbl6, 8, 0, 1, 1)
-        gl_extent.addWidget(self.combo_dataset, 0, 1, 1, 1)
+        gl_extent.addWidget(lbl_0, 0, 0, 1, 1)
+        gl_extent.addWidget(lbl_3, 1, 0, 1, 1)
+        gl_extent.addWidget(lbl_4, 2, 0, 1, 1)
+        gl_extent.addWidget(lbl_1, 3, 0, 1, 1)
+        gl_extent.addWidget(lbl_8, 4, 0, 1, 1)
+        gl_extent.addWidget(lbl_9, 5, 0, 1, 1)
+        gl_extent.addWidget(lbl_10, 6, 0, 1, 1)
+        gl_extent.addWidget(lbl_5, 7, 0, 1, 1)
+        gl_extent.addWidget(lbl_6, 8, 0, 1, 1)
+        gl_extent.addWidget(self.cmb_dataset, 0, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utlx, 1, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utly, 2, 1, 1, 1)
         gl_extent.addWidget(self.dsb_utlz, 3, 1, 1, 1)
@@ -205,16 +205,16 @@ class MextDisplay(QtWidgets.QDialog):
         gl_extent.addWidget(self.sb_rows, 2, 2, 1, 1)
         gl_extent.addWidget(self.sb_layers, 3, 2, 1, 1)
 
-        hlayout.addWidget(helpdocs)
-        hlayout.addWidget(self.pbar)
-        hlayout.addWidget(buttonbox)
+        hbl.addWidget(helpdocs)
+        hbl.addWidget(self.pbar)
+        hbl.addWidget(buttonbox)
 
         # Assign to main layout
 
-        verticallayout.addLayout(h_model)
-        verticallayout.addWidget(gb_data_info)
-        verticallayout.addWidget(gb_extent)
-        verticallayout.addLayout(hlayout)
+        vbl.addLayout(hbl_model)
+        vbl.addWidget(gbox_data_info)
+        vbl.addWidget(gbox_extent)
+        vbl.addLayout(hbl)
 
         # Link functions
         self.dsb_xycell.valueChanged.connect(self.xycell)
@@ -225,9 +225,9 @@ class MextDisplay(QtWidgets.QDialog):
         self.dsb_xextent.valueChanged.connect(self.upd_layers)
         self.dsb_yextent.valueChanged.connect(self.upd_layers)
         self.dsb_zextent.valueChanged.connect(self.upd_layers)
-        self.combo_dataset.currentIndexChanged.connect(self.get_area)
-        self.combo_dtm.currentIndexChanged.connect(self.choose_dtm)
-        self.combo_model.currentIndexChanged.connect(self.choose_model)
+        self.cmb_dataset.currentIndexChanged.connect(self.get_area)
+        self.cmb_dtm.currentIndexChanged.connect(self.choose_dtm)
+        self.cmb_model.currentIndexChanged.connect(self.choose_model)
 
         buttonbox.accepted.connect(self.apply_changes)
         buttonbox.rejected.connect(self.reject)
@@ -243,12 +243,12 @@ class MextDisplay(QtWidgets.QDialog):
         """
         self.showtext('Working...')
 
-        self.choose_combo(self.combo_dtm, 'DTM Dataset')
-        self.choose_combo(self.combo_mag, 'Magnetic Dataset')
-        self.choose_combo(self.combo_grv, 'Gravity Dataset')
-        self.choose_combo(self.combo_reggrv, 'Gravity Regional')
-        self.choose_combo(self.combo_dataset, 'Study Area Dataset')
-        self.choose_combo(self.combo_other, 'Other')
+        self.choose_combo(self.cmb_dtm, 'DTM Dataset')
+        self.choose_combo(self.cmb_mag, 'Magnetic Dataset')
+        self.choose_combo(self.cmb_grv, 'Gravity Dataset')
+        self.choose_combo(self.cmb_reggrv, 'Gravity Regional')
+        self.choose_combo(self.cmb_dataset, 'Study Area Dataset')
+        self.choose_combo(self.cmb_other, 'Other')
 
         cols = self.sb_cols.value()
         rows = self.sb_rows.value()
@@ -303,7 +303,7 @@ class MextDisplay(QtWidgets.QDialog):
         None.
 
         """
-        ctxt = str(self.combo_dtm.currentText())
+        ctxt = str(self.cmb_dtm.currentText())
         if ctxt not in ('None', ''):
             curgrid = self.parent.inraster[ctxt]
 
@@ -323,7 +323,7 @@ class MextDisplay(QtWidgets.QDialog):
         None.
 
         """
-        ctxt = str(self.combo_model.currentText())
+        ctxt = str(self.cmb_model.currentText())
         if ctxt == 'None' or 'Model3D' not in self.parent.indata:
             return
         for i in self.parent.indata['Model3D']:
@@ -378,8 +378,8 @@ class MextDisplay(QtWidgets.QDialog):
         None.
 
         """
-        ctxt = str(self.combo_dataset.currentText())
-        if ctxt not in ('None', u''):
+        ctxt = str(self.cmb_dataset.currentText())
+        if ctxt not in ('None', ''):
             curgrid = self.parent.inraster[ctxt]
 
             crows, ccols = curgrid.data.shape
@@ -456,16 +456,16 @@ class MextDisplay(QtWidgets.QDialog):
             for i in self.parent.indata['Model3D']:
                 modnames.append(i.name)
 
-        self.combo_model.currentIndexChanged.disconnect()
+        self.cmb_model.currentIndexChanged.disconnect()
 
-        self.combo_model.clear()
-        self.combo_model.addItems(modnames)
-        self.combo_model.setCurrentIndex(0)
+        self.cmb_model.clear()
+        self.cmb_model.addItems(modnames)
+        self.cmb_model.setCurrentIndex(0)
 
         if len(modnames) >= 2:
-            self.combo_model.setCurrentIndex(1)
+            self.cmb_model.setCurrentIndex(1)
 
-        self.combo_model.currentIndexChanged.connect(self.choose_model)
+        self.cmb_model.currentIndexChanged.connect(self.choose_model)
 
     def update_combos(self):
         """
@@ -476,7 +476,7 @@ class MextDisplay(QtWidgets.QDialog):
         None.
 
         """
-        self.combo_dataset.currentIndexChanged.disconnect()
+        self.cmb_dataset.currentIndexChanged.disconnect()
 
         gkeys = list(self.parent.inraster.keys())
         if 'Calculated Gravity' in gkeys:
@@ -486,69 +486,69 @@ class MextDisplay(QtWidgets.QDialog):
         gkeys = ['None'] + gkeys
 
         if len(gkeys) > 1:
-            self.combo_other.clear()
-            self.combo_other.addItems(gkeys)
-            self.combo_other.setCurrentIndex(0)
-            self.combo_dtm.clear()
-            self.combo_dtm.addItems(gkeys)
-            self.combo_dtm.setCurrentIndex(0)
-            self.combo_mag.clear()
-            self.combo_mag.addItems(gkeys)
-            self.combo_mag.setCurrentIndex(0)
-            self.combo_grv.clear()
-            self.combo_grv.addItems(gkeys)
-            self.combo_grv.setCurrentIndex(0)
-            self.combo_reggrv.clear()
-            self.combo_reggrv.addItems(gkeys)
-            self.combo_reggrv.setCurrentIndex(0)
-            self.combo_dataset.clear()
-            self.combo_dataset.addItems(gkeys)
-            self.combo_dataset.setCurrentIndex(0)
+            self.cmb_other.clear()
+            self.cmb_other.addItems(gkeys)
+            self.cmb_other.setCurrentIndex(0)
+            self.cmb_dtm.clear()
+            self.cmb_dtm.addItems(gkeys)
+            self.cmb_dtm.setCurrentIndex(0)
+            self.cmb_mag.clear()
+            self.cmb_mag.addItems(gkeys)
+            self.cmb_mag.setCurrentIndex(0)
+            self.cmb_grv.clear()
+            self.cmb_grv.addItems(gkeys)
+            self.cmb_grv.setCurrentIndex(0)
+            self.cmb_reggrv.clear()
+            self.cmb_reggrv.addItems(gkeys)
+            self.cmb_reggrv.setCurrentIndex(0)
+            self.cmb_dataset.clear()
+            self.cmb_dataset.addItems(gkeys)
+            self.cmb_dataset.setCurrentIndex(0)
 
             lkeys = list(self.lmod1.griddata.keys())
             if 'DTM Dataset' in lkeys:
                 tmp = self.lmod1.griddata['DTM Dataset'].dataid
                 if tmp in gkeys:
-                    self.combo_dtm.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_dtm.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['DTM Dataset']
 
             if 'Magnetic Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Magnetic Dataset'].dataid
                 if tmp in gkeys:
-                    self.combo_mag.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_mag.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['Magnetic Dataset']
 
             if 'Gravity Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Gravity Dataset'].dataid
                 if tmp in gkeys:
-                    self.combo_grv.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_grv.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['Gravity Dataset']
 
             if 'Gravity Regional' in lkeys:
                 tmp = self.lmod1.griddata['Gravity Regional'].dataid
                 if tmp in gkeys:
-                    self.combo_reggrv.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_reggrv.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['Gravity Regional']
 
             if 'Study Area Dataset' in lkeys:
                 tmp = self.lmod1.griddata['Study Area Dataset'].dataid
                 if tmp in gkeys:
-                    self.combo_dataset.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_dataset.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['Study Area Dataset']
 
             if 'Other' in lkeys:
                 tmp = self.lmod1.griddata['Other'].dataid
                 if tmp in gkeys:
-                    self.combo_other.setCurrentIndex(gkeys.index(tmp))
+                    self.cmb_other.setCurrentIndex(gkeys.index(tmp))
                 else:
                     del self.lmod1.griddata['Other']
 
-        self.combo_dataset.currentIndexChanged.connect(self.get_area)
+        self.cmb_dataset.currentIndexChanged.connect(self.get_area)
 
     def update_vals(self):
         """
@@ -641,7 +641,7 @@ class MextDisplay(QtWidgets.QDialog):
         self.update_vals()
         self.update_combos()
 
-        self.exec_()
+        self.exec()
 
         # The next line is necessary to update any dataset changes.
         self.parent.profile.tab_activate()  # Link to tab_prof
