@@ -35,7 +35,6 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.figure import Figure
 from matplotlib import colormaps
-from osgeo import osr
 import pandas as pd
 import pygmi.raster.iodefs as ir
 
@@ -45,6 +44,7 @@ from pygmi import menu_default
 from pygmi.raster.dataprep import data_reproject
 from pygmi.raster.iodefs import get_raster
 from pygmi.misc import frm, BasicModule
+from pygmi.vector.dataprep import reprojxy
 
 
 class ProfileDisplay(QtWidgets.QWidget):
@@ -54,9 +54,9 @@ class ProfileDisplay(QtWidgets.QWidget):
         super().__init__(parent)
 
         if parent is None:
-            self.showprocesslog = print
+            self.showlog = print
         else:
-            self.showprocesslog = parent.showprocesslog
+            self.showlog = parent.showlog
 
         self.parent = parent
         self.lmod1 = parent.lmod1
@@ -84,8 +84,8 @@ class ProfileDisplay(QtWidgets.QWidget):
 
         self.hs_overview = MySlider()
         self.hs_sideview = MySlider()
-        self.combo_overview = QtWidgets.QComboBox()
-        self.combo_proftype = QtWidgets.QComboBox()
+        self.cmb_overview = QtWidgets.QComboBox()
+        self.cmb_proftype = QtWidgets.QComboBox()
 
         self.sb_layer = QtWidgets.QSpinBox()
         self.hs_layer = MySlider()
@@ -126,7 +126,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         pb_cprof_delete = QtWidgets.QPushButton('Delete Current Profile')
 
         lbl_prof_type = QtWidgets.QLabel('Profile Type:')
-        self.combo_proftype.addItems(['Standard Profile', 'Custom Profile'])
+        self.cmb_proftype.addItems(['Standard Profile', 'Custom Profile'])
 
         self.dial_prof_dir.setMaximum(359)
         self.sb_prof_dir.setMaximum(359)
@@ -169,60 +169,60 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.sb_profile_linethick.setPrefix('Line Thickness: ')
 
         # Set groupboxes and layouts
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
 
-        hl_proftype = QtWidgets.QHBoxLayout()
-        hl_proftype.addWidget(lbl_prof_type)
-        hl_proftype.addWidget(self.combo_proftype)
+        hbl_proftype = QtWidgets.QHBoxLayout()
+        hbl_proftype.addWidget(lbl_prof_type)
+        hbl_proftype.addWidget(self.cmb_proftype)
 
-        hl_profnum = QtWidgets.QHBoxLayout()
-        hl_profnum.addWidget(self.sb_profnum)
-        hl_profnum.addWidget(self.hs_profnum)
+        hbl_profnum = QtWidgets.QHBoxLayout()
+        hbl_profnum.addWidget(self.sb_profnum)
+        hbl_profnum.addWidget(self.hs_profnum)
 
-        hl_cprofnum = QtWidgets.QHBoxLayout()
-        hl_cprofnum.addWidget(self.sb_cprofnum)
-        hl_cprofnum.addWidget(self.hs_cprofnum)
+        hbl_cprofnum = QtWidgets.QHBoxLayout()
+        hbl_cprofnum.addWidget(self.sb_cprofnum)
+        hbl_cprofnum.addWidget(self.hs_cprofnum)
 
-        hl_layer = QtWidgets.QHBoxLayout()
-        hl_layer.addWidget(self.sb_layer)
-        hl_layer.addWidget(self.hs_layer)
+        hbl_layer = QtWidgets.QHBoxLayout()
+        hbl_layer.addWidget(self.sb_layer)
+        hbl_layer.addWidget(self.hs_layer)
 
-        hl_pics = QtWidgets.QHBoxLayout()
-        hl_pics.addWidget(self.combo_overview)
-        hl_pics.addWidget(self.hs_overview)
-        hl_pics.addWidget(self.hs_sideview)
+        hbl_pics = QtWidgets.QHBoxLayout()
+        hbl_pics.addWidget(self.cmb_overview)
+        hbl_pics.addWidget(self.hs_overview)
+        hbl_pics.addWidget(self.hs_sideview)
 
-        self.gb_cprof = QtWidgets.QGroupBox('Custom Profile')
-        hl_cprof = QtWidgets.QHBoxLayout(self.gb_cprof)
-        hl_cprof.addWidget(pb_cprof_add)
-        hl_cprof.addWidget(pb_cprof_delete)
-        self.gb_cprof.setHidden(True)
+        self.gbox_cprof = QtWidgets.QGroupBox('Custom Profile')
+        hbl_cprof = QtWidgets.QHBoxLayout(self.gbox_cprof)
+        hbl_cprof.addWidget(pb_cprof_add)
+        hbl_cprof.addWidget(pb_cprof_delete)
+        self.gbox_cprof.setHidden(True)
 
-        self.gb_dir = QtWidgets.QGroupBox('Profile Orientation')
-        hl_dir = QtWidgets.QHBoxLayout(self.gb_dir)
-        hl_dir.addWidget(self.dial_prof_dir)
-        hl_dir.addWidget(self.sb_prof_dir)
+        self.gbox_dir = QtWidgets.QGroupBox('Profile Orientation')
+        hbl_dir = QtWidgets.QHBoxLayout(self.gbox_dir)
+        hbl_dir.addWidget(self.dial_prof_dir)
+        hbl_dir.addWidget(self.sb_prof_dir)
 
         vl_plots = QtWidgets.QVBoxLayout()
         vl_plots.addWidget(self.mpl_toolbar)
         vl_plots.addWidget(self.mmc)
-        vl_plots.addLayout(hl_pics)
+        vl_plots.addLayout(hbl_pics)
 
         vl_tools = QtWidgets.QVBoxLayout()
-        vl_tools.addLayout(hl_proftype)
-        vl_tools.addWidget(self.gb_dir)
-        vl_tools.addWidget(self.gb_cprof)
-        vl_tools.addLayout(hl_profnum)
-        vl_tools.addLayout(hl_cprofnum)
-        vl_tools.addLayout(hl_layer)
+        vl_tools.addLayout(hbl_proftype)
+        vl_tools.addWidget(self.gbox_dir)
+        vl_tools.addWidget(self.gbox_cprof)
+        vl_tools.addLayout(hbl_profnum)
+        vl_tools.addLayout(hbl_cprofnum)
+        vl_tools.addLayout(hbl_layer)
         vl_tools.addWidget(self.lw_prof_defs)
         vl_tools.addWidget(self.sb_profile_linethick)
         vl_tools.addWidget(pb_rcopy)
         vl_tools.addWidget(pb_lbound)
         vl_tools.addWidget(pb_export_csv)
 
-        gridlayout.addLayout(vl_plots, 0, 0, 8, 1)
-        gridlayout.addLayout(vl_tools, 0, 1, 8, 1)
+        gl_1.addLayout(vl_plots, 0, 0, 8, 1)
+        gl_1.addLayout(vl_tools, 0, 1, 8, 1)
 
         # Buttons etc
         self.sb_profile_linethick.valueChanged.connect(self.setwidth)
@@ -238,10 +238,10 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.dial_prof_dir.sliderReleased.connect(self.prof_dir)
         self.sb_prof_dir.valueChanged.connect(self.sprofdir)
 
-        self.combo_proftype.currentIndexChanged.connect(self.proftype_changed)
+        self.cmb_proftype.currentIndexChanged.connect(self.proftype_changed)
 
         self.hs_overview.valueChanged.connect(self.pic_overview2)
-        self.combo_overview.currentIndexChanged.connect(self.pic_overview)
+        self.cmb_overview.currentIndexChanged.connect(self.pic_overview)
 
         pb_export_csv.clicked.connect(self.export_csv)
         pb_rcopy.clicked.connect(self.rcopy)
@@ -274,7 +274,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         gtmp = self.get_model()
 
         self.mmc.init_grid(gtmp, gtmpl)
-        self.mmc.init_grid_top(self.combo_overview.currentText(),
+        self.mmc.init_grid_top(self.cmb_overview.currentText(),
                                self.hs_overview.value())
         self.mmc.update_line_top()
 
@@ -342,10 +342,10 @@ class ProfileDisplay(QtWidgets.QWidget):
         None.
 
         """
-        text = self.combo_proftype.currentText()
+        text = self.cmb_proftype.currentText()
         if text == 'Standard Profile':
-            self.gb_dir.setHidden(False)
-            self.gb_cprof.setHidden(True)
+            self.gbox_dir.setHidden(False)
+            self.gbox_cprof.setHidden(True)
             self.sb_cprofnum.setHidden(True)
             self.hs_cprofnum.setHidden(True)
             self.sb_profnum.setHidden(False)
@@ -354,8 +354,8 @@ class ProfileDisplay(QtWidgets.QWidget):
             self.prof_dir()
             self.cproflim = None
         else:
-            self.gb_dir.setHidden(True)
-            self.gb_cprof.setHidden(False)
+            self.gbox_dir.setHidden(True)
+            self.gbox_cprof.setHidden(False)
             self.sb_cprofnum.setHidden(False)
             self.hs_cprofnum.setHidden(False)
             self.sb_profnum.setHidden(True)
@@ -475,21 +475,11 @@ class ProfileDisplay(QtWidgets.QWidget):
         if 'Borehole' not in self.parent.indata:
             return
 
-        if self.parent.indata['Raster'][0].crs.wkt == '':
+        if self.parent.indata['Raster'][0].crs is None:
             return
 
         data = self.parent.indata['Borehole']
 
-        orig = osr.SpatialReference()
-        orig.ImportFromEPSG(4326)  # WGS84 degrees
-        orig.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-
-        targ = osr.SpatialReference()
-        targ.ImportFromWkt(self.parent.indata['Raster'][0].crs.wkt)
-        targ.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-
-        prj = osr.CoordinateTransformation(orig, targ)
-
         for bnum in data:
             hdr = data[bnum]['header']
             log = data[bnum]['log']
@@ -499,8 +489,9 @@ class ProfileDisplay(QtWidgets.QWidget):
                 elev = float(hdr['Elevation'])
             except TypeError:
                 continue
-            res = prj.TransformPoint(lon, lat)
-            x, y = res[0], res[1]
+
+            x, y = reprojxy(lon, lat, 4326,
+                            self.parent.indata['Raster'][0].crs.to_wkt())
 
             if x < self.lmod1.xrange[0] or x > self.lmod1.xrange[1]:
                 continue
@@ -514,8 +505,8 @@ class ProfileDisplay(QtWidgets.QWidget):
             yind = int((y-self.lmod1.yrange[0])//self.lmod1.dxy)
             ifrom = []
             ito = []
-            for i, _ in enumerate(dfrom):
-                z1 = int((self.lmod1.zrange[1]-dfrom[i])//self.lmod1.d_z)
+            for i, dfromi in enumerate(dfrom):
+                z1 = int((self.lmod1.zrange[1]-dfromi)//self.lmod1.d_z)
                 z2 = int((self.lmod1.zrange[1]-dto[i])//self.lmod1.d_z)
                 ifrom.append(z1)
                 ito.append(z2)
@@ -621,17 +612,14 @@ class ProfileDisplay(QtWidgets.QWidget):
                          'Magnetic Residual'):
                     continue
 
-                data1 = copy.deepcopy(self.lmod1.griddata[i])
+                data1 = self.lmod1.griddata[i].copy()
                 if data1.isrgb is True:
-                    # self.showprocesslog(f'Skipping RGB image {data1.dataid}')
                     continue
                 if 'Calculated Gravity' in i:
                     data1.data = data1.data + self.lmod1.gregional
 
                 dtlx = data.extent[0]
                 d2tlx = data1.extent[0]
-                # dtly = data.extent[-1]
-                # d2tly = data1.extent[-1]
 
                 dbly = data.extent[-2]
                 d2bly = data1.extent[-2]
@@ -641,7 +629,6 @@ class ProfileDisplay(QtWidgets.QWidget):
                     ryyy2 = self.ryyy
                 else:
                     rxxx2 = (dtlx-d2tlx+self.rxxx*data.xdim)/data1.xdim + 1
-                    # ryyy2 = (d2tly-dtly+self.ryyy*data.ydim)/data1.ydim + 1
                     ryyy2 = (dbly-d2bly+self.ryyy*data.ydim)/data1.ydim + 1
 
                 tmp = data1.data.astype(float).filled(np.nan)
@@ -654,7 +641,6 @@ class ProfileDisplay(QtWidgets.QWidget):
                 dfall = pd.DataFrame(data2)
             else:
                 dtmp = pd.DataFrame(data2)
-                # dfall = dfall.append(dtmp)
                 dfall = pd.concat([dfall, dtmp])
 
         dfall = dfall.dropna(thresh=4)
@@ -687,7 +673,7 @@ class ProfileDisplay(QtWidgets.QWidget):
             return
 
         lbnd = LithBound(self.lmod1)
-        tmp = lbnd.exec_()
+        tmp = lbnd.exec()
         if tmp == 0:
             return
 
@@ -756,7 +742,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         """
         rcopy = RangedCopy(self)
 
-        tmp = rcopy.exec_()
+        tmp = rcopy.exec()
         if tmp == 0:
             return
 
@@ -915,13 +901,13 @@ class ProfileDisplay(QtWidgets.QWidget):
         y1, y2 = self.lmod1.custprofy['adhoc']
         px1, px2 = self.lmod1.custprofx['rotate']
 
-        if not(self.lmod1.xrange[0] <= x1 <= self.lmod1.xrange[1]):
+        if not (self.lmod1.xrange[0] <= x1 <= self.lmod1.xrange[1]):
             return False
-        if not(self.lmod1.xrange[0] <= x2 <= self.lmod1.xrange[1]):
+        if not (self.lmod1.xrange[0] <= x2 <= self.lmod1.xrange[1]):
             return False
-        if not(self.lmod1.yrange[0] <= y1 <= self.lmod1.yrange[1]):
+        if not (self.lmod1.yrange[0] <= y1 <= self.lmod1.yrange[1]):
             return False
-        if not(self.lmod1.yrange[0] <= y2 <= self.lmod1.yrange[1]):
+        if not (self.lmod1.yrange[0] <= y2 <= self.lmod1.yrange[1]):
             return False
 
         # convert units to cells
@@ -1024,7 +1010,7 @@ class ProfileDisplay(QtWidgets.QWidget):
 
         """
         pscale = PlotScale(self, self.lmod1)
-        tmp = pscale.exec_()
+        tmp = pscale.exec()
         if tmp == 0:
             return
 
@@ -1103,7 +1089,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         None.
 
         """
-        self.mmc.init_grid_top(self.combo_overview.currentText(),
+        self.mmc.init_grid_top(self.cmb_overview.currentText(),
                                self.hs_overview.value())
         self.mmc.figure.canvas.draw()
 
@@ -1337,7 +1323,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         gtmp = self.get_model()
 
         self.mmc.init_grid(gtmp)
-        self.mmc.init_grid_top(self.combo_overview.currentText(),
+        self.mmc.init_grid_top(self.cmb_overview.currentText(),
                                self.hs_overview.value())
         self.mmc.update_line_top()
 
@@ -1411,10 +1397,10 @@ class ProfileDisplay(QtWidgets.QWidget):
         tmprng2 = None
         tmpprof2 = None
         if 'Magnetic Dataset' in self.lmod1.griddata and self.viewmagnetics:
-            data2 = copy.deepcopy(self.lmod1.griddata['Magnetic Dataset'])
+            data2 = self.lmod1.griddata['Magnetic Dataset'].copy()
         elif ('Gravity Dataset' in self.lmod1.griddata and
               not self.viewmagnetics):
-            data2 = copy.deepcopy(self.lmod1.griddata['Gravity Dataset'])
+            data2 = self.lmod1.griddata['Gravity Dataset'].copy()
 
         if data2 is not None:
             data2.data = np.pad(data2.data, 1, 'edge')
@@ -1428,7 +1414,7 @@ class ProfileDisplay(QtWidgets.QWidget):
             rxxx2 = (dtlx-d2tlx+self.rxxx*data.xdim)/data2.xdim+1
             ryyy2 = (dbly-d2bly+self.ryyy*data.ydim)/data2.ydim+1
 
-            pdtmp = data2.data.filled(np.nan)
+            pdtmp = data2.data.astype(float).filled(np.nan)
             tmprng2 = np.linspace(px1, px2, len(rxxx2))
             tmpprof2 = ndimage.map_coordinates(pdtmp[::-1],
                                                [ryyy2-0.5, rxxx2-0.5],
@@ -1472,21 +1458,21 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.hs_profnum.valueChanged.disconnect()
         self.hs_cprofnum.valueChanged.disconnect()
         self.sb_cprofnum.valueChanged.disconnect()
-        self.combo_overview.currentIndexChanged.disconnect()
+        self.cmb_overview.currentIndexChanged.disconnect()
 
         self.lmod1 = self.parent.lmod1
         self.mmc.lmod1 = self.lmod1
 
         citems = list(self.lmod1.griddata.keys())
-        self.combo_overview.clear()
-        self.combo_overview.addItems(citems)
+        self.cmb_overview.clear()
+        self.cmb_overview.addItems(citems)
 
-        curtext = self.combo_overview.currentText()
-        cindex = self.combo_overview.findText(curtext,
-                                              QtCore.Qt.MatchFixedString)
+        curtext = self.cmb_overview.currentText()
+        cindex = self.cmb_overview.findText(curtext,
+                                            QtCore.Qt.MatchFixedString)
         if cindex == -1:
             cindex = 0
-        self.combo_overview.setCurrentIndex(cindex)
+        self.cmb_overview.setCurrentIndex(cindex)
 
         txtmsg = ('Note: The display of gravity or magnetic data is '
                   'triggered off their respective calculations. Press '
@@ -1514,14 +1500,14 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.hs_profnum.valueChanged.connect(self.hprofnum)
         self.sb_cprofnum.valueChanged.connect(self.scprofnum)
         self.hs_cprofnum.valueChanged.connect(self.hcprofnum)
-        self.combo_overview.currentIndexChanged.connect(self.pic_overview)
+        self.cmb_overview.currentIndexChanged.connect(self.pic_overview)
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
     """Matplotlib Canvas."""
 
     def __init__(self, parent=None):
-        fig = Figure()
+        fig = Figure(layout='tight')
         super().__init__(fig)
 
         self.lmod1 = parent.lmod1
@@ -1681,8 +1667,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
             width *= self.mywidth
             height *= self.mywidth
 
-            # if curaxes == self.axes:
-            #     width *= 10
             width = int(np.ceil(width))
             height = int(np.ceil(height))
 
@@ -1704,8 +1688,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
                 xxx = np.linspace(self.xold, xdata, steps)
                 yyy = np.linspace(self.yold, ydata, steps)
 
-                for i, _ in enumerate(xxx):
-                    self.set_mdata(xxx[i], yyy[i], mdata)
+                for i, xxxi in enumerate(xxx):
+                    self.set_mdata(xxxi, yyy[i], mdata)
 
             self.xold = xdata
             self.yold = ydata
@@ -1818,7 +1802,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         None.
 
         """
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def init_grid(self, dat, dat2=None, opac=0.0):
@@ -1888,7 +1871,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         None.
 
         """
-        dat2 = self.myparent.combo_overview.currentText()
+        dat2 = self.myparent.cmb_overview.currentText()
 
         extent = self.lmod1.xrange+self.lmod1.yrange
         curlayer = self.myparent.sb_layer.value()
@@ -1911,9 +1894,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
             self.lims2.set_data(dat2.data)
             self.lims2.set_extent(dat2.extent)
 
-            # vmin = dat2.data.min()
-            # vmax = dat2.data.max()
-
             vstd = dat2.data.std()
             vmean = dat2.data.mean()
             vmin = vmean - 2.5 * vstd
@@ -1940,7 +1920,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         self.lims.set_visible(True)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def slide_grid(self, dat, dat2=None, opac=None):
@@ -2218,27 +2197,27 @@ class LithBound(QtWidgets.QDialog):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
-        label_3 = QtWidgets.QLabel('Lithologies Above Layer')
-        label_4 = QtWidgets.QLabel('Lithologies Below Layer')
+        gl_1 = QtWidgets.QGridLayout(self)
+        lbl_3 = QtWidgets.QLabel('Lithologies Above Layer')
+        lbl_4 = QtWidgets.QLabel('Lithologies Below Layer')
 
-        gridlayout.addWidget(label_3, 0, 0, 1, 1)
+        gl_1.addWidget(lbl_3, 0, 0, 1, 1)
         self.lw_lithupper.setSelectionMode(
             QtWidgets.QAbstractItemView.SingleSelection)
-        gridlayout.addWidget(self.lw_lithupper, 0, 1, 1, 1)
-        gridlayout.addWidget(label_4, 1, 0, 1, 1)
+        gl_1.addWidget(self.lw_lithupper, 0, 1, 1, 1)
+        gl_1.addWidget(lbl_4, 1, 0, 1, 1)
         self.lw_lithlower.setSelectionMode(
             QtWidgets.QAbstractItemView.SingleSelection)
-        gridlayout.addWidget(self.lw_lithlower, 1, 1, 1, 1)
+        gl_1.addWidget(self.lw_lithlower, 1, 1, 1, 1)
         self.buttonbox.setOrientation(QtCore.Qt.Horizontal)
         self.buttonbox.setStandardButtons(
             QtWidgets.QDialogButtonBox.Cancel | QtWidgets.QDialogButtonBox.Ok)
 
         self.rb_depth.setChecked(True)
 
-        gridlayout.addWidget(self.rb_depth, 2, 0, 1, 2)
-        gridlayout.addWidget(self.rb_height, 3, 0, 1, 2)
-        gridlayout.addWidget(self.buttonbox, 4, 0, 1, 2)
+        gl_1.addWidget(self.rb_depth, 2, 0, 1, 2)
+        gl_1.addWidget(self.rb_height, 3, 0, 1, 2)
+        gl_1.addWidget(self.buttonbox, 4, 0, 1, 2)
 
         self.setWindowTitle('Add Lithological Boundary')
 
@@ -2384,15 +2363,15 @@ class RangedCopy(QtWidgets.QDialog):
         """
         self.setWindowTitle('Ranged Copy')
 
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.pfmod.misc.rangedcopy')
 
-        label = QtWidgets.QLabel('Range Start')
-        label_2 = QtWidgets.QLabel('Master Profile')
-        label_3 = QtWidgets.QLabel('Lithologies To Copy')
-        label_4 = QtWidgets.QLabel('Lithologies To Overwrite')
-        label_5 = QtWidgets.QLabel('Range End')
+        lbl_1 = QtWidgets.QLabel('Range Start')
+        lbl_2 = QtWidgets.QLabel('Master Profile')
+        lbl_3 = QtWidgets.QLabel('Lithologies To Copy')
+        lbl_4 = QtWidgets.QLabel('Lithologies To Overwrite')
+        lbl_5 = QtWidgets.QLabel('Range End')
 
         self.sb_master.setMaximum(999999999)
         self.sb_start.setMaximum(999999999)
@@ -2416,30 +2395,30 @@ class RangedCopy(QtWidgets.QDialog):
         self.sb_end.setValue(rmax)
         self.sb_master.setValue(rval)
 
-        gb_target = QtWidgets.QGroupBox('Target:')
-        vl_dir = QtWidgets.QHBoxLayout(gb_target)
-        vl_dir.addWidget(self.rb_sideview)
-        vl_dir.addWidget(self.rb_overview)
+        gbox_target = QtWidgets.QGroupBox('Target:')
+        hbl_dir = QtWidgets.QHBoxLayout(gbox_target)
+        hbl_dir.addWidget(self.rb_sideview)
+        hbl_dir.addWidget(self.rb_overview)
 
-        gridlayout.addWidget(gb_target, 0, 0, 1, 2)
+        gl_1.addWidget(gbox_target, 0, 0, 1, 2)
 
-        gridlayout.addWidget(label_2, 1, 0, 1, 1)
-        gridlayout.addWidget(self.sb_master, 1, 1, 1, 1)
+        gl_1.addWidget(lbl_2, 1, 0, 1, 1)
+        gl_1.addWidget(self.sb_master, 1, 1, 1, 1)
 
-        gridlayout.addWidget(label, 2, 0, 1, 1)
-        gridlayout.addWidget(self.sb_start, 2, 1, 1, 1)
+        gl_1.addWidget(lbl_1, 2, 0, 1, 1)
+        gl_1.addWidget(self.sb_start, 2, 1, 1, 1)
 
-        gridlayout.addWidget(label_5, 3, 0, 1, 1)
-        gridlayout.addWidget(self.sb_end, 3, 1, 1, 1)
+        gl_1.addWidget(lbl_5, 3, 0, 1, 1)
+        gl_1.addWidget(self.sb_end, 3, 1, 1, 1)
 
-        gridlayout.addWidget(label_3, 4, 0, 1, 1)
-        gridlayout.addWidget(self.lw_lithcopy, 4, 1, 1, 1)
+        gl_1.addWidget(lbl_3, 4, 0, 1, 1)
+        gl_1.addWidget(self.lw_lithcopy, 4, 1, 1, 1)
 
-        gridlayout.addWidget(label_4, 5, 0, 1, 1)
-        gridlayout.addWidget(self.lw_lithdel, 5, 1, 1, 1)
+        gl_1.addWidget(lbl_4, 5, 0, 1, 1)
+        gl_1.addWidget(self.lw_lithdel, 5, 1, 1, 1)
 
-        gridlayout.addWidget(helpdocs, 6, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 6, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 6, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -2594,10 +2573,10 @@ class ImportPicture(BasicModule):
         self.dsb_zmax = QtWidgets.QDoubleSpinBox()
         self.dsb_zmin = QtWidgets.QDoubleSpinBox()
 
-        self.chk_getpicture = QtWidgets.QCheckBox('Import picture for profile')
-        self.chk_getcoords = QtWidgets.QCheckBox('Get coordinates from last '
-                                                 'profile')
-        self.importfile = QtWidgets.QLineEdit('')
+        self.cb_getpicture = QtWidgets.QCheckBox('Import picture for profile')
+        self.cb_getcoords = QtWidgets.QCheckBox('Get coordinates from last '
+                                                'profile')
+        self.le_importfile = QtWidgets.QLineEdit('')
 
         self.setupui()
 
@@ -2618,9 +2597,9 @@ class ImportPicture(BasicModule):
         None.
 
         """
-        groupbox = QtWidgets.QGroupBox('Profile Coordinates')
-        gridlayout_2 = QtWidgets.QGridLayout(self)
-        gridlayout_3 = QtWidgets.QGridLayout(groupbox)
+        gbox = QtWidgets.QGroupBox('Profile Coordinates')
+        gl_2 = QtWidgets.QGridLayout(self)
+        gl_3 = QtWidgets.QGridLayout(gbox)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.pfmod.iodefs.importpicture')
 
@@ -2667,23 +2646,23 @@ class ImportPicture(BasicModule):
 
         self.setWindowTitle('New Custom Profile')
 
-        gridlayout_2.addWidget(groupbox, 0, 0, 1, 2)
-        gridlayout_2.addWidget(self.chk_getcoords, 1, 0, 1, 1)
-        gridlayout_2.addWidget(pb_import, 2, 0, 1, 1)
-        gridlayout_2.addWidget(self.importfile, 2, 1, 1, 1)
-        gridlayout_2.addWidget(helpdocs, 3, 0, 1, 1)
-        gridlayout_2.addWidget(buttonbox, 3, 1, 1, 1)
+        gl_2.addWidget(gbox, 0, 0, 1, 2)
+        gl_2.addWidget(self.cb_getcoords, 1, 0, 1, 1)
+        gl_2.addWidget(pb_import, 2, 0, 1, 1)
+        gl_2.addWidget(self.le_importfile, 2, 1, 1, 1)
+        gl_2.addWidget(helpdocs, 3, 0, 1, 1)
+        gl_2.addWidget(buttonbox, 3, 1, 1, 1)
 
-        gridlayout_3.addWidget(self.dsb_x1, 2, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_y1, 2, 1, 1, 1)
-        gridlayout_3.addWidget(self.dsb_x2, 4, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_y2, 4, 1, 1, 1)
-        gridlayout_3.addWidget(self.dsb_zmax, 5, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_zmin, 5, 1, 1, 1)
+        gl_3.addWidget(self.dsb_x1, 2, 0, 1, 1)
+        gl_3.addWidget(self.dsb_y1, 2, 1, 1, 1)
+        gl_3.addWidget(self.dsb_x2, 4, 0, 1, 1)
+        gl_3.addWidget(self.dsb_y2, 4, 1, 1, 1)
+        gl_3.addWidget(self.dsb_zmax, 5, 0, 1, 1)
+        gl_3.addWidget(self.dsb_zmin, 5, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
-        self.chk_getcoords.stateChanged.connect(self.getcoords)
+        self.cb_getcoords.stateChanged.connect(self.getcoords)
         pb_import.pressed.connect(self.get_filename)
 
     def get_filename(self):
@@ -2701,7 +2680,7 @@ class ImportPicture(BasicModule):
         if filename == '':
             return
 
-        self.importfile.setText(filename)
+        self.le_importfile.setText(filename)
 
     def getcoords(self):
         """
@@ -2714,7 +2693,7 @@ class ImportPicture(BasicModule):
         """
         zmin, zmax = self.lmod.zrange
 
-        if self.chk_getcoords.isChecked():
+        if self.cb_getcoords.isChecked():
             x1, x2 = self.lmod.custprofx['adhoc']
             y1, y2 = self.lmod.custprofy['adhoc']
         else:
@@ -2743,7 +2722,7 @@ class ImportPicture(BasicModule):
             True if successful, False otherwise.
 
         """
-        temp = self.exec_()
+        temp = self.exec()
         if temp == 0:
             return None
 
@@ -2751,7 +2730,6 @@ class ImportPicture(BasicModule):
         x2 = self.dsb_x2.value()
         y1 = self.dsb_y1.value()
         y2 = self.dsb_y2.value()
-        # zmin = self.dsb_zmin.value()
         zmax = self.dsb_zmax.value()
 
         # Check if the profile is within the model area
@@ -2815,9 +2793,9 @@ class ImportPicture(BasicModule):
         self.lmod.custprofy[curline] = [y1, y2, y1a, y2a]
         self.lmod.profpics[curline] = None
 
-        imptext = self.importfile.text()
+        imptext = self.le_importfile.text()
         if imptext != '':
-            dat = get_raster(imptext, showprocesslog=self.showprocesslog)
+            dat = get_raster(imptext, showlog=self.showlog)
 
             if dat is None:
                 QtWidgets.QMessageBox.warning(self.parent, 'Error',
@@ -2832,45 +2810,21 @@ class ImportPicture(BasicModule):
             dat.isrgb = True
 
             ra = np.sqrt((x1a-x1)**2+(y1a-y1)**2)
-            # rb = np.sqrt((x2a-x1)**2+(y2a-y1)**2)
-            # xdim = (rb-ra)/dat.shape[1]
-            # ydim = (zmax-zmin)/dat.shape[0]
 
             dat.set_transform(dat.xdim, ra, dat.ydim, zmax)
             self.lmod.profpics[curline] = dat
 
         return curline
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
 
 
 def gridmatch2(cgrv, rgrv):
@@ -2896,8 +2850,7 @@ def gridmatch2(cgrv, rgrv):
     data2 = cgrv
     rows2, cols2 = data2.data.shape
 
-    dat = data_reproject(data, data.crs, data2.crs, data2.transform,
-                         rows2, cols2)
+    dat = data_reproject(data, data2.crs, data2.transform, rows2, cols2)
 
     return dat.data
 
@@ -2919,8 +2872,8 @@ def rotate2d(pts, cntr, ang=np.pi/4):
 
     Returns
     -------
-    pts2 : TYPE
-        DESCRIPTION.
+    pts2 : numpy array
+        Rotated points.
 
     """
     trans = np.array([[np.cos(ang), np.sin(ang)], [-np.sin(ang), np.cos(ang)]])
