@@ -48,7 +48,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
     """
 
     def __init__(self, parent=None):
-        fig = Figure()
+        fig = Figure(layout='constrained')
         super().__init__(fig)
 
         self.axes = fig.add_subplot(111)
@@ -103,7 +103,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.clear()
         self.axes = self.figure.add_subplot(111)
 
-        asegs = tmp.allsegs
+        asegs = tmp.get_paths()
         lvls = tmp.levels
         xmin = self.x.min()
         xmax = self.x.max()
@@ -112,7 +112,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         lines = []
         for i, lvl in enumerate(asegs):
-            for j in lvl:
+            cnt = np.split(lvl.vertices, np.where(lvl.codes == 1)[0][1:])
+            for j in cnt:
                 x1 = j[:, 0]
                 y1 = j[:, 1]
                 z1 = [lvls[i]]*x1.size
@@ -130,7 +131,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         lines = []
         for i, lvl in enumerate(asegs):
-            for j in lvl:
+            cnt = np.split(lvl.vertices, np.where(lvl.codes == 1)[0][1:])
+            for j in cnt:
                 x1 = j[:, 0]
                 y1 = j[:, 1]
                 z1 = [lvls[i]]*x1.size
@@ -144,6 +146,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.add_collection(lc)
 
         self.axes.autoscale()
+        self.axes.set_aspect('equal')
 
         self.axes.set_xlabel('Eastings')
         self.axes.set_ylabel('Northings')
@@ -153,7 +156,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.tick_params(axis='y', labelrotation=0)
         self.axes.tick_params(axis='x', labelrotation=90)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_raster(self, data1, scale=7, rotang=10, atype='dubois',
@@ -272,7 +274,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
@@ -296,43 +297,43 @@ class PlotAnaglyph(ContextModule):
         # Define Widgets
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
-        self.combobox1 = QtWidgets.QComboBox()
-        self.combobox2 = QtWidgets.QComboBox()
-        self.cbox_cbar = QtWidgets.QComboBox()
-        self.doshade = QtWidgets.QCheckBox('Sunshade:')
-        self.doimage = QtWidgets.QRadioButton('Full Image:')
-        self.docontour = QtWidgets.QRadioButton('Contour '
-                                                '(Slider sets number):')
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.cmb_2 = QtWidgets.QComboBox()
+        self.cmb_cbar = QtWidgets.QComboBox()
+        self.cb_shade = QtWidgets.QCheckBox('Sunshade:')
+        self.rb_doimage = QtWidgets.QRadioButton('Full Image:')
+        self.rb_docontour = QtWidgets.QRadioButton('Contour '
+                                                   '(Slider sets number):')
         self.slider_scale = QtWidgets.QSlider()
         self.slider_angle = QtWidgets.QSlider()
         self.slider_cnt = QtWidgets.QSlider()
 
         # Size policies
-        self.combobox1.setSizePolicy(sizepolicy)
-        self.combobox2.setSizePolicy(sizepolicy)
-        self.cbox_cbar.setSizePolicy(sizepolicy)
+        self.cmb_1.setSizePolicy(sizepolicy)
+        self.cmb_2.setSizePolicy(sizepolicy)
+        self.cmb_cbar.setSizePolicy(sizepolicy)
 
-        self.doshade.setSizePolicy(sizepolicy)
-        self.doimage.setSizePolicy(sizepolicy)
-        self.docontour.setSizePolicy(sizepolicy)
+        self.cb_shade.setSizePolicy(sizepolicy)
+        self.rb_doimage.setSizePolicy(sizepolicy)
+        self.rb_docontour.setSizePolicy(sizepolicy)
         self.slider_scale.setSizePolicy(sizepolicy)
         self.slider_angle.setSizePolicy(sizepolicy)
         self.slider_cnt.setSizePolicy(sizepolicy)
 
         # Configure Widgets
-        self.combobox2.addItem('Dubois (Red-Green)')
-        self.combobox2.addItem('Green-Magenta')
-        self.combobox2.addItem('Amber-Blue')
-        self.combobox2.addItem('True (Red-Green)')
-        self.combobox2.addItem('Gray (Red-Green)')
-        self.combobox2.addItem('Optimized (Red-Green)')
+        self.cmb_2.addItem('Dubois (Red-Green)')
+        self.cmb_2.addItem('Green-Magenta')
+        self.cmb_2.addItem('Amber-Blue')
+        self.cmb_2.addItem('True (Red-Green)')
+        self.cmb_2.addItem('Gray (Red-Green)')
+        self.cmb_2.addItem('Optimized (Red-Green)')
 
         maps = sorted(m for m in colormaps() if not
                       m.startswith(('spectral', 'Vega', 'jet')))
 
-        self.cbox_cbar.addItem('jet')
-        self.cbox_cbar.addItems(maps)
-        self.doimage.setChecked(True)
+        self.cmb_cbar.addItem('jet')
+        self.cmb_cbar.addItems(maps)
+        self.rb_doimage.setChecked(True)
         self.slider_cnt.setMinimum(3)
         self.slider_cnt.setMaximum(30)
         self.slider_cnt.setOrientation(QtCore.Qt.Horizontal)
@@ -350,20 +351,20 @@ class PlotAnaglyph(ContextModule):
         self.slider_angle.setValue(10)
 
         # Add widgets to layout
-        vbl_left.addWidget(self.doimage)
-        vbl_left.addWidget(self.docontour)
+        vbl_left.addWidget(self.rb_doimage)
+        vbl_left.addWidget(self.rb_docontour)
         vbl_left.addWidget(self.slider_cnt)
         vbl_left.addWidget(QtWidgets.QLabel('Bands:'))
-        vbl_left.addWidget(self.combobox1)
+        vbl_left.addWidget(self.cmb_1)
         vbl_left.addWidget(QtWidgets.QLabel('Type:'))
-        vbl_left.addWidget(self.combobox2)
+        vbl_left.addWidget(self.cmb_2)
         vbl_left.addWidget(QtWidgets.QLabel('Colour Bar:'))
-        vbl_left.addWidget(self.cbox_cbar)
+        vbl_left.addWidget(self.cmb_cbar)
         vbl_left.addWidget(QtWidgets.QLabel('Scale (1-30):'))
         vbl_left.addWidget(self.slider_scale)
         vbl_left.addWidget(QtWidgets.QLabel('Image Angle (1-20):'))
         vbl_left.addWidget(self.slider_angle)
-        vbl_left.addWidget(self.doshade)
+        vbl_left.addWidget(self.cb_shade)
         vbl_right.addWidget(self.mmc)
         vbl_right.addWidget(mpl_toolbar)
         hbl.addLayout(vbl_left)
@@ -371,12 +372,12 @@ class PlotAnaglyph(ContextModule):
 
         self.setFocus()
 
-        self.doimage.released.connect(self.change_image)
-        self.docontour.released.connect(self.change_contours)
-        self.doshade.stateChanged.connect(self.change_colors)
-        self.combobox1.currentIndexChanged.connect(self.change_all)
-        self.combobox2.currentIndexChanged.connect(self.change_atype)
-        self.cbox_cbar.currentIndexChanged.connect(self.change_colors)
+        self.rb_doimage.released.connect(self.change_image)
+        self.rb_docontour.released.connect(self.change_contours)
+        self.cb_shade.stateChanged.connect(self.change_colors)
+        self.cmb_1.currentIndexChanged.connect(self.change_all)
+        self.cmb_2.currentIndexChanged.connect(self.change_atype)
+        self.cmb_cbar.currentIndexChanged.connect(self.change_colors)
         self.slider_scale.sliderReleased.connect(self.change_all)
         self.slider_angle.sliderReleased.connect(self.change_all)
         self.slider_cnt.sliderReleased.connect(self.change_contours)
@@ -390,19 +391,19 @@ class PlotAnaglyph(ContextModule):
         None.
 
         """
-        i = self.combobox1.currentIndex()
-        txt = str(self.cbox_cbar.currentText())
+        i = self.cmb_1.currentIndex()
+        txt = str(self.cmb_cbar.currentText())
         cbar = colormaps[txt]
-        shade = self.doshade.isChecked()
+        shade = self.cb_shade.isChecked()
         scale = self.slider_scale.value()
         rotang = self.slider_angle.value()
 
-        if self.docontour.isChecked():
+        if self.rb_docontour.isChecked():
             data = self.indata['Raster']
             self.mmc.update_contours(data[i], scale=scale, rotang=rotang)
         else:
             data = self.indata['Raster']
-            self.mmc.update_raster(data[i], atype=self.combobox2.currentText(),
+            self.mmc.update_raster(data[i], atype=self.cmb_2.currentText(),
                                    cmap=cbar, shade=shade, scale=scale,
                                    rotang=rotang)
 
@@ -415,11 +416,11 @@ class PlotAnaglyph(ContextModule):
         None.
 
         """
-        txt = str(self.cbox_cbar.currentText())
+        txt = str(self.cmb_cbar.currentText())
         cbar = colormaps[txt]
-        shade = self.doshade.isChecked()
+        shade = self.cb_shade.isChecked()
 
-        self.mmc.update_colors(atype=self.combobox2.currentText(),
+        self.mmc.update_colors(atype=self.cmb_2.currentText(),
                                cmap=cbar, doshade=shade)
 
     def change_atype(self):
@@ -431,7 +432,7 @@ class PlotAnaglyph(ContextModule):
         None.
 
         """
-        self.mmc.update_atype(atype=self.combobox2.currentText())
+        self.mmc.update_atype(atype=self.cmb_2.currentText())
 
     def change_contours(self):
         """
@@ -442,16 +443,16 @@ class PlotAnaglyph(ContextModule):
         None.
 
         """
-        self.docontour.setChecked(True)
+        self.rb_docontour.setChecked(True)
 
-        i = self.combobox1.currentIndex()
+        i = self.cmb_1.currentIndex()
         scale = self.slider_scale.value()
         rotang = self.slider_angle.value()
 
-        self.doshade.setDisabled(True)
-        self.combobox1.setDisabled(True)
-        self.combobox2.setDisabled(True)
-        self.cbox_cbar.setDisabled(True)
+        self.cb_shade.setDisabled(True)
+        self.cmb_1.setDisabled(True)
+        self.cmb_2.setDisabled(True)
+        self.cmb_cbar.setDisabled(True)
 
         data = self.indata['Raster']
 
@@ -469,10 +470,10 @@ class PlotAnaglyph(ContextModule):
         """
         self.slider_scale.setValue(5)
         self.slider_angle.setValue(10)
-        self.doshade.setEnabled(True)
-        self.combobox1.setEnabled(True)
-        self.combobox2.setEnabled(True)
-        self.cbox_cbar.setEnabled(True)
+        self.cb_shade.setEnabled(True)
+        self.cmb_1.setEnabled(True)
+        self.cmb_2.setEnabled(True)
+        self.cmb_cbar.setEnabled(True)
 
         self.change_all()
 
@@ -485,14 +486,19 @@ class PlotAnaglyph(ContextModule):
         None.
 
         """
-        self.show()
         if 'Raster' in self.indata:
             data = self.indata['Raster']
         else:
             return
 
+        if self.indata['Raster'][0].isrgb:
+            self.showlog('RGB images cannot be used in this module.')
+            return
+
+        self.show()
+
         for i in data:
-            self.combobox1.addItem(i.dataid)
+            self.cmb_1.addItem(i.dataid)
         self.change_all()
 
 
