@@ -30,9 +30,9 @@
 |    http://www.wits.ac.za/science/geophysics/gc.htm
 """
 
-import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
+from numba import jit
 
 from pygmi import menu_default
 from pygmi.misc import ProgressBarText, BasicModule
@@ -63,8 +63,8 @@ class Gradients(BasicModule):
         self.rb_vgrad = QtWidgets.QRadioButton('Vertical Derivative')
         self.rb_dratio = QtWidgets.QRadioButton('Derivative Ratio')
         self.rb_thg = QtWidgets.QRadioButton('Total Horizonal Gradient')
-        self.label_or = QtWidgets.QLabel('Strength Factor')
-        self.label_az = QtWidgets.QLabel('Azimuth')
+        self.lbl_or = QtWidgets.QLabel('Strength Factor')
+        self.lbl_az = QtWidgets.QLabel('Azimuth')
 
         self.setupui()
 
@@ -80,7 +80,7 @@ class Gradients(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.cooper.gradients')
 
@@ -92,20 +92,20 @@ class Gradients(BasicModule):
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
         self.rb_ddir.setChecked(True)
         self.sb_order.hide()
-        self.label_or.hide()
+        self.lbl_or.hide()
 
         self.setWindowTitle('Gradient Calculation')
 
-        gridlayout.addWidget(self.rb_ddir, 0, 0, 1, 1)
-        gridlayout.addWidget(self.rb_dratio, 1, 0, 1, 1)
-        gridlayout.addWidget(self.rb_vgrad, 2, 0, 1, 1)
-        gridlayout.addWidget(self.rb_thg, 3, 0, 1, 1)
-        gridlayout.addWidget(self.label_az, 4, 0, 1, 1)
-        gridlayout.addWidget(self.sb_azi, 4, 1, 1, 1)
-        gridlayout.addWidget(self.label_or, 5, 0, 1, 1)
-        gridlayout.addWidget(self.sb_order, 5, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 6, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 6, 1, 1, 1)
+        gl_1.addWidget(self.rb_ddir, 0, 0, 1, 1)
+        gl_1.addWidget(self.rb_dratio, 1, 0, 1, 1)
+        gl_1.addWidget(self.rb_vgrad, 2, 0, 1, 1)
+        gl_1.addWidget(self.rb_thg, 3, 0, 1, 1)
+        gl_1.addWidget(self.lbl_az, 4, 0, 1, 1)
+        gl_1.addWidget(self.sb_azi, 4, 1, 1, 1)
+        gl_1.addWidget(self.lbl_or, 5, 0, 1, 1)
+        gl_1.addWidget(self.sb_order, 5, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 6, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -130,18 +130,19 @@ class Gradients(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
+        self.radiochange()
         if not nodialog:
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
         self.azi = self.sb_azi.value()
         self.order = self.sb_order.value()
 
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
 
         for i in self.piter(range(len(data))):
             if self.rb_ddir.isChecked():
@@ -154,8 +155,8 @@ class Gradients(BasicModule):
                 data[i].data = thgrad(data[i].data, data[i].xdim, data[i].ydim)
             else:
                 if data[i].xdim != data[i].ydim:
-                    self.showprocesslog('X and Y dimension are different. '
-                                        'Please resample')
+                    self.showlog('X and Y dimension are different. '
+                                 'Please resample')
                     return False
 
                 mask = np.ma.getmaskarray(data[i].data)
@@ -173,63 +174,23 @@ class Gradients(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.azi = projdata['azim']
-        self.order = projdata['order']
-
-        self.sb_azi.setValue(projdata['azim'])
-        self.sb_order.setValue(projdata['order'])
-
-        if projdata['type'] == 'dratio':
-            self.rb_dratio.setChecked(True)
-        if projdata['type'] == 'ddir':
-            self.rb_dratio.setChecked(True)
-        if projdata['type'] == 'vgrad':
-            self.rb_dratio.setChecked(True)
-
-        self.radiochange()
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        self.azi = self.sb_azi.value()
-        self.order = self.sb_order.value()
-        projdata['azim'] = self.azi
-        projdata['order'] = self.order
-
-        if self.rb_dratio.isChecked():
-            projdata['type'] = 'dratio'
-        elif self.rb_ddir.isChecked():
-            projdata['type'] = 'ddir'
-        else:
-            projdata['type'] = 'vgrad'
-
-        return projdata
+        self.saveobj(self.azi)
+        self.saveobj(self.order)
+        self.saveobj(self.sb_order)
+        self.saveobj(self.sb_azi)
+        self.saveobj(self.rb_ddir)
+        self.saveobj(self.rb_vgrad)
+        self.saveobj(self.rb_dratio)
+        self.saveobj(self.rb_thg)
 
     def radiochange(self):
         """
@@ -241,18 +202,18 @@ class Gradients(BasicModule):
 
         """
         self.sb_order.hide()
-        self.label_or.hide()
+        self.lbl_or.hide()
         self.sb_azi.hide()
-        self.label_az.hide()
+        self.lbl_az.hide()
 
         if self.rb_dratio.isChecked():
             self.sb_order.show()
-            self.label_or.show()
+            self.lbl_or.show()
             self.sb_azi.show()
-            self.label_az.show()
+            self.lbl_az.show()
         elif self.rb_ddir.isChecked():
             self.sb_azi.show()
-            self.label_az.show()
+            self.lbl_az.show()
 
 
 def gradients(data, azi, xint, yint):
@@ -378,11 +339,11 @@ class Visibility2d(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.cooper.visibility')
-        label = QtWidgets.QLabel('Viewing Height (% std dev)')
-        label_2 = QtWidgets.QLabel('Window Size (Odd)')
+        lbl_1 = QtWidgets.QLabel('Viewing Height (% std dev)')
+        lbl_2 = QtWidgets.QLabel('Window Size (Odd)')
 
         self.sb_dh.setMinimum(1)
         self.sb_dh.setMaximum(10000)
@@ -395,12 +356,12 @@ class Visibility2d(BasicModule):
 
         self.setWindowTitle('Visibility')
 
-        gridlayout.addWidget(label_2, 0, 0, 1, 1)
-        gridlayout.addWidget(self.sb_wsize, 0, 1, 1, 1)
-        gridlayout.addWidget(label, 1, 0, 1, 1)
-        gridlayout.addWidget(self.sb_dh, 1, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 2, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 2, 1, 1, 1)
+        gl_1.addWidget(lbl_2, 0, 0, 1, 1)
+        gl_1.addWidget(self.sb_wsize, 0, 1, 1, 1)
+        gl_1.addWidget(lbl_1, 1, 0, 1, 1)
+        gl_1.addWidget(self.sb_dh, 1, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 2, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 2, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -421,25 +382,25 @@ class Visibility2d(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         if not nodialog:
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
         self.wsize = self.sb_wsize.value()
         self.dh = self.sb_dh.value()
 
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         data2 = []
 
         for i, datai in enumerate(data):
-            self.showprocesslog(datai.dataid+':')
+            self.showlog(datai.dataid+':')
 
             vtot, vstd, vsum = visibility2d(datai.data, self.wsize,
-                                            self.dh*data[i].data.std()/100.,
+                                            self.dh*datai.data.std()/100.,
                                             self.piter)
 
             buff = self.wsize//2
@@ -448,9 +409,9 @@ class Visibility2d(BasicModule):
             xdim = datai.transform[0]
             ydim = abs(datai.transform[4])
 
-            data2.append(copy.deepcopy(datai))
-            data2.append(copy.deepcopy(datai))
-            data2.append(copy.deepcopy(datai))
+            data2.append(datai.copy(True))
+            data2.append(datai.copy(True))
+            data2.append(datai.copy(True))
             data2[-3].data = vtot
             data2[-2].data = vstd
             data2[-1].data = vsum
@@ -467,46 +428,21 @@ class Visibility2d(BasicModule):
                 data2[i].data = np.ma.array(data2[i].data, mask=mask)
 
         self.outdata['Raster'] = data2
-        self.showprocesslog('Finished!')
+        self.showlog('Finished!')
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.sb_wsize.setValue(projdata['wsize'])
-        self.sb_dh.setValue(projdata['vheight'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['wsize'] = self.sb_wsize.value()
-        projdata['vheight'] = self.sb_dh.value()
-
-        return projdata
+        self.saveobj(self.sb_wsize)
+        self.saveobj(self.sb_dh)
 
 
 def visibility2d(data, wsize, dh, piter=iter):
@@ -524,7 +460,7 @@ def visibility2d(data, wsize, dh, piter=iter):
         window size, must be odd
     dh : float
         height of observer above surface
-    piter : iter
+    piter : function, optional
         Progress bar iterable. The default is iter.
 
     Returns
@@ -540,14 +476,24 @@ def visibility2d(data, wsize, dh, piter=iter):
     nr, nc = np.shape(data)
     wsize = abs(np.real(wsize))
     w2 = int(np.floor(wsize/2))
-    vn = np.zeros([nr, nc])
-    vs = np.zeros([nr, nc])
-    ve = np.zeros([nr, nc])
-    vw = np.zeros([nr, nc])
-    vd1 = np.zeros([nr, nc])
-    vd2 = np.zeros([nr, nc])
-    vd3 = np.zeros([nr, nc])
-    vd4 = np.zeros([nr, nc])
+    vn = np.zeros_like(data)
+    vs = np.zeros_like(data)
+    ve = np.zeros_like(data)
+    vw = np.zeros_like(data)
+    vd1 = np.zeros_like(data)
+    vd2 = np.zeros_like(data)
+    vd3 = np.zeros_like(data)
+    vd4 = np.zeros_like(data)
+    # vstd = np.zeros_like(data)
+
+    # vn = np.zeros([nr, nc])
+    # vs = np.zeros([nr, nc])
+    # ve = np.zeros([nr, nc])
+    # vw = np.zeros([nr, nc])
+    # vd1 = np.zeros([nr, nc])
+    # vd2 = np.zeros([nr, nc])
+    # vd3 = np.zeros([nr, nc])
+    # vd4 = np.zeros([nr, nc])
     vstd = np.zeros([nr, nc])
     mask = np.ma.getmaskarray(data)
     mean = data.mean()
@@ -608,6 +554,81 @@ def visibility2d(data, wsize, dh, piter=iter):
     return vtot, vstd, vsum
 
 
+@jit(nopython=True)
+def visibilitytot(data, wsize, dh):
+    """
+    Compute visibility as a textural measure.
+
+    Compute vertical derivatives by calculating the visibility at different
+    heights above the surface (see paper)
+
+    Parameters
+    ----------
+    data : numpy array
+        input dataset - numpy MxN array
+    wsize : int
+        window size, must be odd
+    dh : float
+        height of observer above surface
+    piter : function, optional
+        Progress bar iterable. The default is iter.
+
+    Returns
+    -------
+    vtot : numpy array
+        Total visibility.
+    vstd : numpy array
+        Visibility variation.
+    vsum : numpy array
+        Visibility vector resultant.
+
+    """
+    nr, nc = np.shape(data)
+    wsize = abs(np.real(wsize))
+    w2 = int(np.floor(wsize/2))
+    vtot = np.zeros_like(data)
+
+
+    # mask = np.ma.getmaskarray(data)
+    # mean = data.mean()
+    # data = data.data
+    # data[mask] = mean
+
+    for j in range(nc):    # Columns
+        for i in range(w2, nr-w2):
+            dtmp = data[i-w2:i+w2+1, j]
+            vtot[i, j] += __visible1(dtmp, wsize, w2+1, dh)
+            vtot[i, j] += __visible2(dtmp, w2+1, dh)
+
+    for j in range(w2, nc-w2):    # Rows
+        for i in range(nr):
+            dtmp = data[i, j-w2:j+w2+1]
+            vtot[i, j] += __visible1(dtmp, wsize, w2+1, dh)
+            vtot[i, j] += __visible2(dtmp, w2+1, dh)
+
+    for j in range(w2, nc-w2):
+        for i in range(w2, nr-w2):
+            dtmp = np.zeros(wsize)
+            for k in range(wsize):
+                dtmp[k] = data[i-w2+k, j-w2+k]
+            vtot[i, j] += __visible1(dtmp, wsize, w2+1, dh)
+            vtot[i, j] += __visible2(dtmp, w2+1, dh)
+            dtmp = np.zeros(wsize)
+            for k in range(wsize):
+                dtmp[k] = data[i+w2-k, j-w2+k]
+            vtot[i, j] += __visible1(dtmp, wsize, w2+1, dh)
+            vtot[i, j] += __visible2(dtmp, w2+1, dh)
+
+    # vtot = vn+vs+ve+vw+vd1+vd2+vd3+vd4
+    vtot = vtot[w2:nr-w2, w2:nc-w2]
+
+    # vtot = np.ma.array(vtot)
+    # vtot.mask = mask[w2:-w2, w2:-w2]
+
+    return vtot
+
+
+@jit(nopython=True, fastmath=True)
 def __visible1(dat, nr, cp, dh):
     """
     Visible 1.
@@ -644,6 +665,7 @@ def __visible1(dat, nr, cp, dh):
     return num
 
 
+@jit(nopython=True, fastmath=True)
 def __visible2(dat, cp, dh):
     """
     Visible 2.
@@ -784,10 +806,10 @@ class AGC(BasicModule):
         None.
 
         """
-        gridlayout = QtWidgets.QGridLayout(self)
+        gl_1 = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.cooper.AGC')
-        label_2 = QtWidgets.QLabel('Window Size (Odd)')
+        lbl_2 = QtWidgets.QLabel('Window Size (Odd)')
 
         self.sb_wsize.setPrefix('')
         self.sb_wsize.setMinimum(3)
@@ -800,13 +822,13 @@ class AGC(BasicModule):
 
         self.setWindowTitle('Automatic Gain Control')
 
-        gridlayout.addWidget(self.rb_mean, 0, 0, 1, 1)
-        gridlayout.addWidget(self.rb_median, 1, 0, 1, 1)
-        gridlayout.addWidget(self.rb_rms, 2, 0, 1, 1)
-        gridlayout.addWidget(label_2, 3, 0, 1, 1)
-        gridlayout.addWidget(self.sb_wsize, 3, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 4, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 4, 1, 1, 1)
+        gl_1.addWidget(self.rb_mean, 0, 0, 1, 1)
+        gl_1.addWidget(self.rb_median, 1, 0, 1, 1)
+        gl_1.addWidget(self.rb_rms, 2, 0, 1, 1)
+        gl_1.addWidget(lbl_2, 3, 0, 1, 1)
+        gl_1.addWidget(self.sb_wsize, 3, 1, 1, 1)
+        gl_1.addWidget(helpdocs, 4, 0, 1, 1)
+        gl_1.addWidget(buttonbox, 4, 1, 1, 1)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -827,11 +849,11 @@ class AGC(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('No Raster Data.')
+            self.showlog('No Raster Data.')
             return False
 
         if not nodialog:
-            temp = self.exec_()
+            temp = self.exec()
             if temp == 0:
                 return False
 
@@ -843,59 +865,37 @@ class AGC(BasicModule):
 
         self.wsize = self.sb_wsize.value()
 
-        data = copy.deepcopy(self.indata['Raster'])
+        data = [i.copy() for i in self.indata['Raster']]
         data2 = []
 
         for datai in data:
-            self.showprocesslog(datai.dataid+':')
+            self.showlog(datai.dataid+':')
 
             agcdata = agc(datai.data, self.wsize, atype, nodata=datai.nodata,
                           piter=self.piter)
-            data2.append(copy.deepcopy(datai))
+            data2.append(datai.copy())
             data2[-1].data = agcdata
             data2[-1].dataid += ' AGC'
 
         self.outdata['Raster'] = data2
-        self.showprocesslog('Finished!')
+        self.showlog('Finished!')
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        self.sb_wsize.setValue(projdata['wsize'])
-        self.sb_dh.setValue(projdata['vheight'])
-
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        projdata['wsize'] = self.sb_wsize.value()
-        projdata['vheight'] = self.sb_dh.value()
-
-        return projdata
+        self.saveobj(self.sb_wsize)
+        self.saveobj(self.sb_dh)
+        self.saveobj(self.rb_mean)
+        self.saveobj(self.rb_median)
+        self.saveobj(self.rb_rms)
 
 
 def agc(data, wsize, atype='mean', nodata=0., piter=iter):
@@ -912,7 +912,7 @@ def agc(data, wsize, atype='mean', nodata=0., piter=iter):
         AGC type - can be median or mean, default is 'mean'.
     nodata : float, optional
         no data value, default is 0.
-    piter : iter
+    piter : function, optional
         Progress bar iterable. The default is iter.
 
     Returns
