@@ -58,7 +58,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
     """
 
     def __init__(self, parent=None):
-        fig = Figure()
+        fig = Figure(layout='constrained', dpi=150)
         self.axes = fig.add_subplot(111)
         super().__init__(fig)
 
@@ -69,7 +69,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         Parameters
         ----------
         data1 : PyGMI raster Data
-            raster dataset to be used in contouring.
+            raster dataset to be used.
         dmat : numpy array
             dummy matrix of numbers to be plotted using pcolor.
 
@@ -91,10 +91,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
                 ctmp = np.abs(ctmp)
                 ctmp = ctmp.tolist()
 
-                if dmat[i, j] < 0.01:
-                    atext = f'{dmat[i, j]:.1e}'
-                else:
-                    atext = f'{dmat[i, j]:.2f}'
+                atext = f'{dmat[i, j]:.2f}'
 
                 self.axes.text(i+.5, j+.5, atext, c=ctmp, rotation=45,
                                ha='center', va='center')
@@ -110,7 +107,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         cbar = self.figure.colorbar(rdata, format=frm)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_raster(self, data1, cmap):
@@ -140,12 +136,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
             cbar = self.figure.colorbar(rdata, format=frm)
             cbar.set_label(data1.units)
 
-        if data1.crs is not None:
-            crs = data1.crs.to_dict()
-        else:
-            crs = {}
-
-        if 'proj' in crs and crs['proj'] == 'longlat':
+        if data1.crs is not None and data1.crs.is_geographic:
             self.axes.set_xlabel('Longitude')
             self.axes.set_ylabel('Latitude')
         else:
@@ -155,7 +146,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_hexbin(self, data1, data2):
@@ -202,7 +192,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.set_xlabel(data1.units)
         self.axes.set_ylabel(data2.units)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_surface(self, data, cmap):
@@ -229,6 +218,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         y = dtly-np.arange(rows)*data.ydim-data.ydim/2
         x, y = np.meshgrid(x, y)
         z = data.data.copy()
+        vmin, vmax = np.percentile(z.compressed(), [1, 99])
 
         if not np.ma.is_masked(z):
             z = np.ma.array(z)
@@ -238,7 +228,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         cmap = colormaps[cmap]
 
-        norml = mcolors.Normalize(vmin=z.min(), vmax=z.max())
+        norml = mcolors.Normalize(vmin=vmin, vmax=vmax)
 
         z.data[z.mask] = np.nan
         z = z.data
@@ -246,8 +236,10 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.clear()
         self.axes = self.figure.add_subplot(111, projection='3d')
 
+        vmin, vmax = np.percentile(z, [1, 99])
+
         surf = self.axes.plot_surface(x, y, z, cmap=cmap,
-                                      norm=norml, vmin=z.min(), vmax=z.max(),
+                                      norm=norml, vmin=vmin, vmax=vmax,
                                       shade=False, antialiased=False)
 
         self.figure.colorbar(surf, format=frm)
@@ -261,10 +253,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.set_ylabel('Y')
         self.axes.set_zlabel('Z')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_hist(self, data1, ylog):
+    def update_hist(self, data1, ylog, iscum):
         """
         Update the histogram plot.
 
@@ -274,6 +265,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
             raster dataset to be used
         ylog : bool
             Boolean for a log scale on y-axis.
+        iscum : bool
+            Boolean for a cumulative distribution.
 
         Returns
         -------
@@ -284,10 +277,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes = self.figure.add_subplot(111)
 
         dattmp = data1.data[data1.data.mask == 0].flatten()
-        self.axes.hist(dattmp, bins='sqrt')
-        self.axes.set_title(data1.dataid, fontsize=12)
-        self.axes.set_xlabel('Data Value', fontsize=8)
-        self.axes.set_ylabel('Counts', fontsize=8)
+        self.axes.hist(dattmp, bins='sqrt', cumulative=iscum,
+                       histtype='stepfilled', edgecolor='k')
+        self.axes.set_title(data1.dataid)
+        self.axes.set_xlabel('Data Value')
+        self.axes.set_ylabel('Counts')
 
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
@@ -295,7 +289,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         if ylog is True:
             self.axes.set_yscale('log')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
@@ -305,7 +298,7 @@ class PlotCCoef(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
+        self.setWindowTitle('Correlation Coefficients')
 
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         self.mmc = MyMplCanvas(self)
@@ -327,7 +320,14 @@ class PlotCCoef(ContextModule):
         None.
 
         """
-        data = self.indata['Raster']
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+        else:
+            return
+
+        if self.indata['Raster'][0].isrgb:
+            self.showlog('RGB images cannot be used in this module.')
+            return
 
         if not check_bands(data):
             QtWidgets.QMessageBox.warning(self, 'Warning',
@@ -351,31 +351,31 @@ class PlotRaster(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
+        self.setWindowTitle('Raster Plot (Simple)')
 
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         hbl = QtWidgets.QHBoxLayout()
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combobox1 = QtWidgets.QComboBox()
-        label1 = QtWidgets.QLabel('Bands:')
-        hbl.addWidget(label1)
-        hbl.addWidget(self.combobox1)
+        self.cmb_1 = QtWidgets.QComboBox()
+        lbl_1 = QtWidgets.QLabel('Bands:')
+        hbl.addWidget(lbl_1)
+        hbl.addWidget(self.cmb_1)
 
-        self.combobox2 = QtWidgets.QComboBox()
-        label2 = QtWidgets.QLabel('Colormap:')
-        hbl.addWidget(label2)
-        hbl.addWidget(self.combobox2)
-        self.combobox2.addItems(['viridis', 'jet', 'gray', 'terrain'])
+        self.cmb_2 = QtWidgets.QComboBox()
+        lbl_2 = QtWidgets.QLabel('Colormap:')
+        hbl.addWidget(lbl_2)
+        hbl.addWidget(self.cmb_2)
+        self.cmb_2.addItems(['viridis', 'jet', 'gray', 'terrain'])
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
         vbl.addLayout(hbl)
 
         self.setFocus()
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cmb_2.currentIndexChanged.connect(self.change_band)
 
     def change_band(self):
         """
@@ -386,8 +386,8 @@ class PlotRaster(ContextModule):
         None.
 
         """
-        i = self.combobox1.currentIndex()
-        cmap = self.combobox2.currentText()
+        i = self.cmb_1.currentIndex()
+        cmap = self.cmb_2.currentText()
         if 'Raster' in self.indata:
             data = self.indata['Raster']
             self.mmc.update_raster(data[i], cmap)
@@ -402,13 +402,14 @@ class PlotRaster(ContextModule):
 
         """
         self.show()
+        data = []
         if 'Raster' in self.indata:
             data = self.indata['Raster']
         elif 'Cluster' in self.indata:
             data = self.indata['Cluster']
 
         for i in data:
-            self.combobox1.addItem(i.dataid)
+            self.cmb_1.addItem(i.dataid)
 
 
 class PlotSurface(ContextModule):
@@ -417,23 +418,23 @@ class PlotSurface(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
+        self.setWindowTitle('Surface Plot')
 
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         hbl = QtWidgets.QHBoxLayout()
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combobox1 = QtWidgets.QComboBox()
-        label1 = QtWidgets.QLabel('Bands:')
-        hbl.addWidget(label1)
-        hbl.addWidget(self.combobox1)
+        self.cmb_1 = QtWidgets.QComboBox()
+        lbl_1 = QtWidgets.QLabel('Bands:')
+        hbl.addWidget(lbl_1)
+        hbl.addWidget(self.cmb_1)
 
-        self.combobox2 = QtWidgets.QComboBox()
-        label2 = QtWidgets.QLabel('Colormap:')
-        hbl.addWidget(label2)
-        hbl.addWidget(self.combobox2)
-        self.combobox2.addItems(['viridis', 'jet', 'gray', 'terrain'])
+        self.cmb_2 = QtWidgets.QComboBox()
+        lbl_2 = QtWidgets.QLabel('Colormap:')
+        hbl.addWidget(lbl_2)
+        hbl.addWidget(self.cmb_2)
+        self.cmb_2.addItems(['viridis', 'jet', 'gray', 'terrain'])
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
@@ -441,8 +442,8 @@ class PlotSurface(ContextModule):
 
         self.setFocus()
 
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cmb_2.currentIndexChanged.connect(self.change_band)
 
     def change_band(self):
         """
@@ -453,8 +454,8 @@ class PlotSurface(ContextModule):
         None.
 
         """
-        i = self.combobox1.currentIndex()
-        cmap = self.combobox2.currentText()
+        i = self.cmb_1.currentIndex()
+        cmap = self.cmb_2.currentText()
         if 'Raster' in self.indata:
             data = self.indata['Raster']
             self.mmc.update_surface(data[i], cmap)
@@ -469,12 +470,18 @@ class PlotSurface(ContextModule):
 
         """
         if 'Raster' in self.indata:
-            self.show()
             data = self.indata['Raster']
+        else:
+            return
 
-            for i in data:
-                self.combobox1.addItem(i.dataid)
-            self.change_band()
+        if self.indata['Raster'][0].isrgb:
+            self.showlog('RGB images cannot be used in this module.')
+            return
+
+        self.show()
+        for i in data:
+            self.cmb_1.addItem(i.dataid)
+        self.change_band()
 
 
 class PlotScatter(ContextModule):
@@ -487,21 +494,21 @@ class PlotScatter(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
+        self.setWindowTitle('Hexbin Plot')
 
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         hbl = QtWidgets.QHBoxLayout()
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combobox1 = QtWidgets.QComboBox()
-        self.combobox2 = QtWidgets.QComboBox()
-        label1 = QtWidgets.QLabel('X Band:')
-        label2 = QtWidgets.QLabel('Y Band:')
-        hbl.addWidget(label1)
-        hbl.addWidget(self.combobox1)
-        hbl.addWidget(label2)
-        hbl.addWidget(self.combobox2)
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.cmb_2 = QtWidgets.QComboBox()
+        lbl_1 = QtWidgets.QLabel('X Band:')
+        lbl_2 = QtWidgets.QLabel('Y Band:')
+        hbl.addWidget(lbl_1)
+        hbl.addWidget(self.cmb_1)
+        hbl.addWidget(lbl_2)
+        hbl.addWidget(self.cmb_2)
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
@@ -509,8 +516,8 @@ class PlotScatter(ContextModule):
 
         self.setFocus()
 
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cmb_2.currentIndexChanged.connect(self.change_band)
 
     def change_band(self):
         """
@@ -522,8 +529,8 @@ class PlotScatter(ContextModule):
 
         """
         data = self.indata['Raster']
-        i = self.combobox1.currentIndex()
-        j = self.combobox2.currentIndex()
+        i = self.cmb_1.currentIndex()
+        j = self.cmb_2.currentIndex()
 
         x = data[i]
         y = data[j]
@@ -546,14 +553,22 @@ class PlotScatter(ContextModule):
         None.
 
         """
-        self.show()
-        data = self.indata['Raster']
-        for i in data:
-            self.combobox1.addItem(i.dataid)
-            self.combobox2.addItem(i.dataid)
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+        else:
+            return
 
-        self.combobox1.setCurrentIndex(0)
-        self.combobox2.setCurrentIndex(1)
+        if self.indata['Raster'][0].isrgb:
+            self.showlog('RGB images cannot be used in this module.')
+            return
+
+        self.show()
+        for i in data:
+            self.cmb_1.addItem(i.dataid)
+            self.cmb_2.addItem(i.dataid)
+
+        self.cmb_1.setCurrentIndex(0)
+        self.cmb_2.setCurrentIndex(1)
 
 
 class PlotHist(ContextModule):
@@ -562,19 +577,21 @@ class PlotHist(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
+        self.setWindowTitle('Histogram')
 
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         hbl = QtWidgets.QHBoxLayout()
         self.mmc = MyMplCanvas(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        self.combobox1 = QtWidgets.QComboBox()
-        label1 = QtWidgets.QLabel('Bands:')
-        self.chk_log = QtWidgets.QCheckBox('Log Y Axis:')
-        hbl.addWidget(self.chk_log)
-        hbl.addWidget(label1)
-        hbl.addWidget(self.combobox1)
+        self.cmb_1 = QtWidgets.QComboBox()
+        lbl_1 = QtWidgets.QLabel('Bands:')
+        self.cb_log = QtWidgets.QCheckBox('Log Y Axis:')
+        self.cb_cum = QtWidgets.QCheckBox('Cumulative:')
+        hbl.addWidget(self.cb_log)
+        hbl.addWidget(self.cb_cum)
+        hbl.addWidget(lbl_1)
+        hbl.addWidget(self.cmb_1)
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
@@ -582,8 +599,9 @@ class PlotHist(ContextModule):
 
         self.setFocus()
 
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.chk_log.stateChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cb_log.stateChanged.connect(self.change_band)
+        self.cb_cum.stateChanged.connect(self.change_band)
 
     def change_band(self):
         """
@@ -595,9 +613,10 @@ class PlotHist(ContextModule):
 
         """
         data = self.indata['Raster']
-        i = self.combobox1.currentIndex()
-        ylog = self.chk_log.isChecked()
-        self.mmc.update_hist(data[i], ylog)
+        i = self.cmb_1.currentIndex()
+        ylog = self.cb_log.isChecked()
+        iscum = self.cb_cum.isChecked()
+        self.mmc.update_hist(data[i], ylog, iscum)
 
     def run(self):
         """
@@ -608,12 +627,20 @@ class PlotHist(ContextModule):
         None.
 
         """
-        self.show()
-        data = self.indata['Raster']
-        for i in data:
-            self.combobox1.addItem(i.dataid)
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+        else:
+            return
 
-        self.combobox1.setCurrentIndex(0)
+        if self.indata['Raster'][0].isrgb:
+            self.showlog('RGB images cannot be used in this module.')
+            return
+
+        self.show()
+        for i in data:
+            self.cmb_1.addItem(i.dataid)
+
+        self.cmb_1.setCurrentIndex(0)
         self.change_band()
 
 
@@ -623,7 +650,7 @@ def check_bands(data):
 
     Parameters
     ----------
-    data : PyGMI Data
+    data : list of PyGMI Data
         PyGMI raster dataset.
 
     Returns
