@@ -148,11 +148,13 @@ class MenuWidget():
         context_menu['Raster'].addAction(self.action_basic_statistics)
         self.action_basic_statistics.triggered.connect(self.basic_stats)
 
-        self.action_show_raster_data = QtWidgets.QAction('Show Raster Data (Simple)')
+        self.action_show_raster_data = QtWidgets.QAction('Show Raster Data '
+                                                         '(Simple)')
         context_menu['Raster'].addAction(self.action_show_raster_data)
         self.action_show_raster_data.triggered.connect(self.show_raster_data)
 
-        self.action_show_raster_data2 = QtWidgets.QAction('Show Raster Data (Advanced)')
+        self.action_show_raster_data2 = QtWidgets.QAction('Show Raster Data '
+                                                          '(Advanced)')
         context_menu['Raster'].addAction(self.action_show_raster_data2)
         self.action_show_raster_data2.triggered.connect(self.show_raster_data2)
 
@@ -177,7 +179,7 @@ class MenuWidget():
         context_menu['Raster'].addAction(self.action_show_2d_corr_coef)
         self.action_show_2d_corr_coef.triggered.connect(self.show_ccoef)
 
-        self.action_export_data = QtWidgets.QAction('Export Data')
+        self.action_export_data = QtWidgets.QAction('Export Raster Data')
         context_menu['Raster'].addAction(self.action_export_data)
         self.action_export_data.triggered.connect(self.export_data)
 
@@ -271,7 +273,7 @@ class MenuWidget():
 
     def merge(self):
         """Merge datasets."""
-        self.parent.item_insert('Io', 'Data Merge', dataprep.DataMerge)
+        self.parent.item_insert('Io', 'Data Mosaic', dataprep.DataMerge)
 
     def lstack(self):
         """Layer stack datasets."""
