@@ -8,18 +8,16 @@ pcole, 2021  - Bug fix to allow for correct zooming if origin is set to 'upper'
 """
 from __future__ import print_function, division
 
-from math import cos, sin, tan
 import numpy as np
-import numexpr as ne
-from scipy import ndimage
 
 from matplotlib import rcParams
-from matplotlib import colormaps
 import matplotlib.image as mi
 import matplotlib.colors as mcolors
 from matplotlib import cbook
 from matplotlib.transforms import IdentityTransform, Affine2D
 
+from pygmi.raster.misc import currentshader, histeq, norm2
+
 IDENTITY_TRANSFORM = IdentityTransform()
 
 
@@ -371,9 +369,10 @@ class ModestImage(mi.AxesImage):
             colormap[:, :, 2] = (1-colormap[:, :, 2])*(1-self.kval)
 
         if np.ma.isMaskedArray(self._A):
-            mask = np.logical_or(self._A[:, :, 0].mask,
-                                 self._A[:, :, 1].mask)
-            mask = np.logical_or(mask, self._A[:, :, 2].mask)
+            colormap = colormap.filled(0)
+            mask = np.logical_and(self._A[:, :, 0].mask,
+                                  self._A[:, :, 1].mask)
+            mask = np.logical_and(mask, self._A[:, :, 2].mask)
             colormap[:, :, 3] = np.logical_not(mask)
         return colormap
 
@@ -440,280 +439,6 @@ class ModestImage(mi.AxesImage):
         self.set_clim(vmin, vmax)
 
 
-def aspect2(data):
-    """
-    Aspect of a dataset.
-
-    Parameters
-    ----------
-    data : numpy MxN array
-        input data used for the aspect calculation
-
-    Returns
-    -------
-    adeg : numpy masked array
-        aspect in degrees
-    dzdx : numpy array
-        gradient in x direction
-    dzdy : numpy array
-        gradient in y direction
-    """
-    cdy = np.array([[1., 2., 1.], [0., 0., 0.], [-1., -2., -1.]])
-    cdx = np.array([[1., 0., -1.], [2., 0., -2.], [1., 0., -1.]])
-
-    dzdx = ndimage.convolve(data, cdx)  # Use convolve: matrix filtering
-    dzdy = ndimage.convolve(data, cdy)  # 'valid' gets reduced array
-
-    dzdx = ne.evaluate('dzdx/8.')
-    dzdy = ne.evaluate('dzdy/8.')
-
-    # Aspect Section
-    pi = np.pi
-    adeg = ne.evaluate('90-arctan2(dzdy, -dzdx)*180./pi')
-    adeg = np.ma.masked_invalid(adeg)
-    adeg[np.ma.less(adeg, 0.)] += 360.
-    adeg[np.logical_and(dzdx == 0, dzdy == 0)] = -1.
-
-    return [adeg, dzdx, dzdy]
-
-
-def currentshader(data, cell, theta, phi, alpha):
-    """
-    Blinn shader - used for sun shading.
-
-    Parameters
-    ----------
-    data : numpy array
-        Dataset to be shaded.
-    cell : float
-        between 1 and 100 - controls sunshade detail.
-    theta : float
-        sun elevation (also called g in code below)
-    phi : float
-        azimuth
-    alpha : float
-        how much incident light is reflected (0 to 1)
-
-    Returns
-    -------
-    R : numpy array
-        array containing the shaded results.
-
-    """
-    asp = aspect2(data)
-    n = 2
-    pinit = asp[1]
-    qinit = asp[2]
-    p = ne.evaluate('pinit/cell')
-    q = ne.evaluate('qinit/cell')
-    sqrt_1p2q2 = ne.evaluate('sqrt(1+p**2+q**2)')
-
-    cosg2 = cos(theta/2)
-    p0 = -cos(phi)*tan(theta)
-    q0 = -sin(phi)*tan(theta)
-    sqrttmp = ne.evaluate('(1+sqrt(1+p0**2+q0**2))')
-    p1 = ne.evaluate('p0 / sqrttmp')
-    q1 = ne.evaluate('q0 / sqrttmp')
-
-    cosi = ne.evaluate('((1+p0*p+q0*q)/(sqrt_1p2q2*sqrt(1+p0**2+q0**2)))')
-    coss = ne.evaluate('((1+p1*p+q1*q)/(sqrt_1p2q2*sqrt(1+p1**2+q1**2)))')
-    Ps = ne.evaluate('coss**n')
-    R = np.ma.masked_invalid(ne.evaluate('((1-alpha)+alpha*Ps)*cosi/cosg2'))
-
-    return R
-
-
-def histcomp(img, nbr_bins=None, perc=5., uperc=None):
-    """
-    Histogram Compaction.
-
-    This compacts a % of the outliers in data, allowing for a cleaner, linear
-    representation of the data.
-
-    Parameters
-    ----------
-    img : numpy array
-        data to compact
-    nbr_bins : int
-        number of bins to use in compaction
-    perc : float
-        percentage of histogram to clip. If uperc is not None, then this is
-        the lower percentage, default is 5.
-    uperc : float
-        upper percentage to clip. If uperc is None, then it is set to the
-        same value as perc, default is None.
-
-    Returns
-    -------
-    img2 : numpy array
-        compacted array
-    svalue : float
-        Start value
-    evalue : float
-        End value
-
-    """
-    if uperc is None:
-        uperc = perc
-
-    if nbr_bins is None:
-        nbr_bins = max(img.shape)
-        nbr_bins = max(nbr_bins, 256)
-
-    # get image histogram
-    imask = np.ma.getmaskarray(img)
-    tmp = img.compressed()
-    imhist, bins = np.histogram(tmp, nbr_bins)
-
-    cdf = imhist.cumsum()  # cumulative distribution function
-    if cdf[-1] == 0:
-        return img
-    cdf = cdf / float(cdf[-1])  # normalize
-
-    perc = perc/100.
-    uperc = uperc/100.
-
-    sindx = np.arange(nbr_bins)[cdf > perc][0]
-    if cdf[0] > (1-uperc):
-        eindx = 1
-    else:
-        eindx = np.arange(nbr_bins)[cdf < (1-uperc)][-1]+1
-    svalue = bins[sindx]
-    evalue = bins[eindx]
-
-    img2 = np.empty_like(img, dtype=np.float32)
-    np.copyto(img2, img)
-
-    filt = np.ma.less(img2, svalue)
-    img2[filt] = svalue
-
-    filt = np.ma.greater(img2, evalue)
-    img2[filt] = evalue
-
-    img2 = np.ma.array(img2, mask=imask)
-
-    return img2, svalue, evalue
-
-
-def histeq(img, nbr_bins=32768):
-    """
-    Histogram Equalization.
-
-    Equalizes the histogram to colours. This allows for seeing as much data as
-    possible in the image, at the expense of knowing the real value of the
-    data at a point. It bins the data equally - flattening the distribution.
-
-    Parameters
-    ----------
-    img : numpy array
-        input data to be equalised
-    nbr_bins : integer
-        number of bins to be used in the calculation, default is 32768
-
-    Returns
-    -------
-    im2 : numpy array
-        output data
-    """
-    # get image histogram
-    imhist, bins = np.histogram(img.compressed(), nbr_bins)
-    bins = (bins[1:]-bins[:-1])/2+bins[:-1]  # get bin center point
-
-    cdf = imhist.cumsum()  # cumulative distribution function
-    cdf = cdf - cdf[0]  # subtract min, which is first val in cdf
-    cdf = cdf.astype(np.int64)
-    cdf = nbr_bins * cdf / cdf[-1]  # norm to nbr_bins
-
-    # use linear interpolation of cdf to find new pixel values
-    im2 = np.interp(img, bins, cdf)
-    im2 = np.ma.array(im2, mask=img.mask)
-
-    return im2
-
-
-def img2rgb(img, cbar=colormaps['jet']):
-    """
-    Image to RGB.
-
-    convert image to 4 channel rgba colour image.
-
-    Parameters
-    ----------
-    img : numpy array
-        array to be converted to rgba image.
-    cbar : matplotlib colour map
-        colormap to apply to the image, default is jet.
-
-    Returns
-    -------
-    im2 : numpy array
-        output rgba image
-    """
-    im2 = img.copy()
-    im2 = norm255(im2)
-    cbartmp = cbar(range(255))
-    cbartmp = np.array([[0., 0., 0., 1.]]+cbartmp.tolist())*255
-    cbartmp = cbartmp.round()
-    cbartmp = cbartmp.astype(np.uint8)
-    im2 = cbartmp[im2]
-    im2[:, :, 3] = np.logical_not(img.mask)*254+1
-
-    return im2
-
-
-def norm2(dat, datmin=None, datmax=None):
-    """
-    Normalise array vector between 0 and 1.
-
-    Parameters
-    ----------
-    dat : numpy array
-        array to be normalised
-    datmin : float
-        data minimum, default is None
-    datmax : float
-        data maximum, default is None
-
-    Returns
-    -------
-    out : numpy array of floats
-        normalised array
-    """
-    if datmin is None:
-        datmin = float(dat.min())
-    if datmax is None:
-        datmax = float(dat.max())
-    datptp = datmax - datmin
-    out = np.ma.array(ne.evaluate('(dat-datmin)/datptp'))
-    out.mask = np.ma.getmaskarray(dat)
-    out[out < 0] = 0.
-    out[out > 1] = 1.
-
-    return out
-
-
-def norm255(dat):
-    """
-    Normalise array vector between 1 and 255.
-
-    Parameters
-    ----------
-    dat : numpy array
-        array to be normalised
-
-    Returns
-    -------
-    out : numpy array of 8 bit integers
-        normalised array
-    """
-    datmin = float(dat.min())
-    datptp = float(dat.ptp())
-    out = ne.evaluate('254*(dat-datmin)/datptp+1')
-    out = out.round()
-    out = out.astype(np.uint8)
-    return out
-
-
 def imshow(axes, X, cmap=None, norm=None, aspect=None,
            interpolation=None, alpha=None, vmin=None, vmax=None,
            origin=None, extent=None, shape=None, filternorm=1,
@@ -741,7 +466,6 @@ def imshow(axes, X, cmap=None, norm=None, aspect=None,
     im.set_data(X)
     im.set_alpha(alpha)
 
-
     axes._set_artist_props(im)
 
     axes.format_coord = lambda x, y: f'x = {x:,.5f}, y = {y:,.5f}'
@@ -845,7 +569,7 @@ def _testfn():
     from pygmi.raster.iodefs import get_raster
     from pygmi.misc import ProgressBarText
     import matplotlib.pyplot as plt
-    from IPython import get_ipython
+    # from IPython import get_ipython
     # get_ipython().magic('matplotlib qt5')
 
     ifile = r'd:\Work\Programming\mpl-modest-image-master\test.tif'
