@@ -25,6 +25,7 @@
 """Routine which displays a table graphically with various stats."""
 
 from PyQt5 import QtWidgets
+from PyQt5.QtCore import Qt
 import numpy as np
 import scipy.stats.mstats as st
 
@@ -37,7 +38,9 @@ class BasicStats(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.combobox = QtWidgets.QComboBox()
+        self.resize(640, 320)
+
+        self.cmb_1 = QtWidgets.QComboBox()
         self.tablewidget = QtWidgets.QTableWidget()
         self.pushbutton_save = QtWidgets.QPushButton('Save')
 
@@ -59,14 +62,14 @@ class BasicStats(ContextModule):
         vbl = QtWidgets.QVBoxLayout()
 
         vbl.addWidget(self.pushbutton_save)
-        vbl.addWidget(self.combobox)
+        vbl.addWidget(self.cmb_1)
 
         hbl.addWidget(self.tablewidget)
         hbl.addLayout(vbl)
 
         self.setWindowTitle('Basic Statistics')
 
-        self.combobox.currentIndexChanged.connect(self.combo)
+        self.cmb_1.currentIndexChanged.connect(self.combo)
         self.pushbutton_save.clicked.connect(self.save)
 
     def combo(self):
@@ -78,13 +81,21 @@ class BasicStats(ContextModule):
         None.
 
         """
-        i = self.combobox.currentIndex()
+        i = self.cmb_1.currentIndex()
         data = self.data[i][:, 1:]
 
         for row in range(data.shape[0]):
             for col in range(data.shape[1]):
-                self.tablewidget.setCellWidget(
-                    row, col, QtWidgets.QLabel(str(data[row, col])))
+                datnum = data[row, col]
+                if isinstance(datnum, int):
+                    txt = f' {datnum}'
+                else:
+                    txt = f' {datnum:,.5f}'
+
+                txt = QtWidgets.QLabel(txt)
+                txt.setAlignment(Qt.AlignRight)
+
+                self.tablewidget.setCellWidget(row, col, txt)
 
         self.tablewidget.resizeColumnsToContents()
 
@@ -105,14 +116,26 @@ class BasicStats(ContextModule):
         cols = self.cols[1:]
 
         if len(self.data) == 1:
-            self.combobox.hide()
+            self.cmb_1.hide()
 
-        self.combobox.addItems(self.bands)
+        self.cmb_1.addItems(self.bands)
         self.tablewidget.setRowCount(data.shape[0])
         self.tablewidget.setColumnCount(data.shape[1])
         self.tablewidget.setHorizontalHeaderLabels(cols)
         self.tablewidget.setVerticalHeaderLabels(rows)
 
+        for i, _ in enumerate(cols):
+            item = self.tablewidget.horizontalHeaderItem(i)
+            fnt = item.font()
+            fnt.setBold(True)
+            item.setFont(fnt)
+
+        for i, _ in enumerate(rows):
+            item = self.tablewidget.verticalHeaderItem(i)
+            fnt = item.font()
+            fnt.setBold(True)
+            item.setFont(fnt)
+
         self.combo()
         self.show()
 
@@ -168,17 +191,17 @@ def basicstats_calc(data):
         srow.append(dtmp.std())
         srow.append(np.median(dtmp))
         srow.append(np.median(abs(dtmp - srow[-1])))
-        srow.append(i.data.size)
+        srow.append(dtmp.size)
         srow.append(i.data.shape[1])
         srow.append(i.data.shape[0])
-        srow.append(st.skew(dtmp))
+        srow.append(st.skew(dtmp) * 1.)
         srow.append(st.kurtosis(dtmp))
-        srow = np.array(srow).tolist()
+        # srow = np.array(srow).tolist()
         stats.append([i.dataid] + srow)
 
     bands = ['Data Column']
     cols = ['Band', 'Minimum', 'Maximum', 'Mean', 'Std Dev', 'Median',
-            'Median Abs Dev', 'No Samples', 'No cols (samples in x-dir)',
+            'Median Abs Dev', 'No Unmasked Samples', 'No cols (samples in x-dir)',
             'No rows (samples in y-dir)', 'Skewness', 'Kurtosis']
     dattmp = [np.array(stats, dtype=object)]
     return bands, cols, dattmp
@@ -190,7 +213,7 @@ class ClusterStats(ContextModule):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.combobox = QtWidgets.QComboBox()
+        self.cmb_1 = QtWidgets.QComboBox()
         self.tablewidget = QtWidgets.QTableWidget()
         self.pushbutton_save = QtWidgets.QPushButton('Save')
 
@@ -212,7 +235,7 @@ class ClusterStats(ContextModule):
         vbl = QtWidgets.QVBoxLayout()
 
         vbl.addWidget(self.pushbutton_save)
-        vbl.addWidget(self.combobox)
+        vbl.addWidget(self.cmb_1)
 
         hbl.addWidget(self.tablewidget)
         hbl.addLayout(vbl)
@@ -220,7 +243,7 @@ class ClusterStats(ContextModule):
         self.setWindowTitle(
             'Cluster Statistics (Mean Value : Std Deviation)')
 
-        self.combobox.currentIndexChanged.connect(self.combo)
+        self.cmb_1.currentIndexChanged.connect(self.combo)
         self.pushbutton_save.clicked.connect(self.save)
 
     def combo(self):
@@ -232,7 +255,7 @@ class ClusterStats(ContextModule):
         None.
 
         """
-        i = self.combobox.currentIndex()
+        i = self.cmb_1.currentIndex()
         data = self.data[i]
 
         self.tablewidget.setRowCount(len(data))
@@ -263,7 +286,7 @@ class ClusterStats(ContextModule):
                       for i in data]
 
         if 'input_type' not in data[0].metadata['Cluster']:
-            self.showprocesslog('Your dataset does not qualify')
+            self.showlog('Your dataset does not qualify')
             return False
 
         self.cols = list(data[0].metadata['Cluster']['input_type'])
@@ -275,7 +298,7 @@ class ClusterStats(ContextModule):
 
             for j, _ in enumerate(val):
                 for k, _ in enumerate(val[0]):
-                    val[j][k] = f'{val[j][k]:.4f} : {std[j][k]:.4f}'
+                    val[j][k] = f'{val[j][k]:,.4f} : {std[j][k]:,.4f}'
             self.data.append(val)
 
         data = self.data[0]
@@ -283,14 +306,26 @@ class ClusterStats(ContextModule):
         cols = self.cols
 
         if len(self.data) == 1:
-            self.combobox.hide()
+            self.cmb_1.hide()
 
-        self.combobox.addItems(self.bands)
+        self.cmb_1.addItems(self.bands)
         self.tablewidget.setRowCount(len(data))
         self.tablewidget.setColumnCount(len(data[0]))
         self.tablewidget.setHorizontalHeaderLabels(cols)
         self.tablewidget.setVerticalHeaderLabels(rows)
 
+        for i, _ in enumerate(cols):
+            item = self.tablewidget.horizontalHeaderItem(i)
+            fnt = item.font()
+            fnt.setBold(True)
+            item.setFont(fnt)
+
+        for i, _ in enumerate(rows):
+            item = self.tablewidget.verticalHeaderItem(i)
+            fnt = item.font()
+            fnt.setBold(True)
+            item.setFont(fnt)
+
         self.combo()
         return True
 
@@ -340,8 +375,8 @@ def savetable(ofile, bands, cols, data):
         for i in cols[1:]:
             htmp += ',' + i
 
-        for k, _ in enumerate(bands):
-            fobj.write(bands[k]+'\n')
+        for k, bandsk in enumerate(bands):
+            fobj.write(bandsk+'\n')
             fobj.write(htmp+'\n')
             for i, _ in enumerate(data[k]):
                 rtmp = str(data[k][i][0])
