@@ -23,7 +23,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 """Hyperspectral Interpretation Routines."""
-import json
 import sys
 import re
 import os
@@ -44,6 +43,7 @@ from pygmi.raster.iodefs import get_raster
 from pygmi.raster.datatypes import numpy_to_pygmi
 from pygmi.raster.iodefs import export_raster
 from pygmi.rsense import features
+from pygmi.raster.modest_image import imshow
 
 
 class GraphMap(FigureCanvasQTAgg):
@@ -57,10 +57,11 @@ class GraphMap(FigureCanvasQTAgg):
     """
 
     def __init__(self, parent=None):
-        self.figure = Figure()
+        self.figure = Figure(layout='constrained')
 
         super().__init__(self.figure)
         self.setParent(parent)
+        self.rgb = True
 
         self.parent = parent
         self.datarr = []
@@ -88,7 +89,7 @@ class GraphMap(FigureCanvasQTAgg):
         None.
 
         """
-        dat = self.datarr[self.mindx]
+        dat = self.datarr[self.mindx].data
 
         if self.refl != 1.:
             dat = dat/self.refl
@@ -99,34 +100,37 @@ class GraphMap(FigureCanvasQTAgg):
         ax1 = self.figure.add_subplot(211)
         self.ax1 = ax1
 
-        ymin = dat.mean()-2*dat.std()
-        ymax = dat.mean()+2*dat.std()
+        self.compute_initial_figure()
 
-        if self.rotate is True:
-            self.csp = ax1.imshow(dat.T, vmin=ymin, vmax=ymax,
-                                  interpolation='none')
-            rows, cols = cols, rows
-        else:
-            self.csp = ax1.imshow(dat, vmin=ymin, vmax=ymax,
-                                  interpolation='none')
+        # ymin = dat.mean()-2*dat.std()
+        # ymax = dat.mean()+2*dat.std()
 
-        ax1.set_xlim((0, cols))
-        ax1.set_ylim((0, rows))
-        ax1.xaxis.set_visible(False)
-        ax1.yaxis.set_visible(False)
+        # if self.rotate is True:
+        #     self.csp = ax1.imshow(dat.T, vmin=ymin, vmax=ymax,
+        #                           interpolation='none')
+        #     rows, cols = cols, rows
+        # else:
+        #     self.csp = ax1.imshow(dat, vmin=ymin, vmax=ymax,
+        #                           interpolation='none')
 
-        ax1.xaxis.set_major_formatter(frm)
-        ax1.yaxis.set_major_formatter(frm)
+        # ax1.set_xlim((0, cols))
+        # ax1.set_ylim((0, rows))
+        # ax1.xaxis.set_visible(False)
+        # ax1.yaxis.set_visible(False)
 
-        ax1.plot(self.col, self.row, '+w')
+        # ax1.xaxis.set_major_formatter(frm)
+        # ax1.yaxis.set_major_formatter(frm)
+
+        # if self.rotate is True:
+        #     ax1.plot(self.row, self.col, '+w')
+        # else:
+        #     ax1.plot(self.col, self.row, '+w')
 
         ax2 = self.figure.add_subplot(212)
 
-        prof = []
-        for i in self.datarr:
-            prof.append(i[self.row, self.col])
+        prof = [i.data[self.row, self.col] for i in self.datarr]
 
-        prof = np.ma.stack(prof)/self.refl
+        prof = np.ma.stack(prof).filled(0)/self.refl
 
         ax2.format_coord = lambda x, y: f'Wavelength: {x:1.2f}, Y: {y:1.2f}'
         ax2.grid(True)
@@ -164,9 +168,63 @@ class GraphMap(FigureCanvasQTAgg):
         rect.set_alpha(0.5)
         ax2.add_patch(rect)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
+    def compute_initial_figure(self):
+        """Compute initial figure."""
+        clippercu = 1
+        clippercl = 1
+        dat = self.datarr
+
+        redidx = (np.abs(self.wvl - 630)).argmin()
+        greenidx = (np.abs(self.wvl - 532)).argmin()
+        blueidx = (np.abs(self.wvl - 465)).argmin()
+
+        if self.rgb is True:
+            red = dat[redidx].data/self.refl
+            green = dat[greenidx].data/self.refl
+            blue = dat[blueidx].data/self.refl
+
+            data = [red, green, blue]
+            data = np.ma.array(data)
+            data = np.moveaxis(data, 0, -1)
+            lclip = [0, 0, 0]
+            uclip = [0, 0, 0]
+
+            lclip[0], uclip[0] = np.percentile(red.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[1], uclip[1] = np.percentile(green.compressed(),
+                                               [clippercl, 100-clippercu])
+            lclip[2], uclip[2] = np.percentile(blue.compressed(),
+                                               [clippercl, 100-clippercu])
+        else:
+            data = dat[self.mindx].data/self.refl
+            lclip, uclip = np.percentile(data.compressed(),
+                                         [clippercl, 100-clippercu])
+
+        extent = dat[self.mindx].extent
+
+        self.im1 = imshow(self.ax1, data, extent=extent)
+
+        if self.rgb is True:
+            self.im1.rgbmode = 'RGB Ternary'
+            self.im1.rgbclip = [[lclip[0], uclip[0]],
+                                [lclip[1], uclip[1]],
+                                [lclip[2], uclip[2]]]
+        else:
+            self.im1.rgbmode = 'None'
+            self.im1.set_clim(lclip, uclip)
+
+        if dat[self.mindx].crs.is_geographic:
+            self.ax1.set_xlabel('Longitude')
+            self.ax1.set_ylabel('Latitude')
+        else:
+            self.ax1.set_xlabel('Eastings')
+            self.ax1.set_ylabel('Northings')
+
+        self.ax1.xaxis.set_major_formatter(frm)
+        self.ax1.yaxis.set_major_formatter(frm)
+
 
 class AnalSpec(BasicModule):
     """Analyse spectra."""
@@ -174,10 +232,6 @@ class AnalSpec(BasicModule):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.depthmarkers = {'Start': [0., 0., 0.]}
-        self.nummarkers = 1
-        self.depthfunc = None
-        self.dx = 1.
         self.spectra = None
         self.feature = {}
         self.feature[900] = [776, 1050, 850, 910]
@@ -189,15 +243,13 @@ class AnalSpec(BasicModule):
         self.feature[2330] = [2120, 2370]
 
         self.map = GraphMap(self)
-        self.combo = QtWidgets.QComboBox()
-        self.combo_feature = QtWidgets.QComboBox()
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.cmb_feature = QtWidgets.QComboBox()
         self.mpl_toolbar = NavigationToolbar2QT(self.map, self.parent)
-        self.dsb_mdepth = QtWidgets.QDoubleSpinBox()
-        self.pb_save = QtWidgets.QPushButton('Save')
         self.lbl_info = QtWidgets.QLabel('')
-        self.group_info = QtWidgets.QGroupBox('Information:')
-        self.chk_hull = QtWidgets.QCheckBox('Remove Hull')
-        self.chk_rot = QtWidgets.QCheckBox('Rotate View')
+        self.gbox_info = QtWidgets.QGroupBox('Information:')
+        self.cb_hull = QtWidgets.QCheckBox('Remove Hull')
+        self.cb_rgb = QtWidgets.QCheckBox('True Colour Ternary')
         self.lw_speclib = QtWidgets.QListWidget()
 
         self.setupui()
@@ -216,14 +268,15 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        grid_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
 
         buttonbox = QtWidgets.QDialogButtonBox()
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
 
-        infolayout = QtWidgets.QVBoxLayout(self.group_info)
+        vbl_info = QtWidgets.QVBoxLayout(self.gbox_info)
         pb_speclib = QtWidgets.QPushButton('Load ENVI Spectral Library')
+        self.cb_rgb.setChecked(True)
 
         self.lbl_info.setWordWrap(True)
         self.lw_speclib.addItem('None')
@@ -231,27 +284,27 @@ class AnalSpec(BasicModule):
         lbl_combo = QtWidgets.QLabel('Display Band:')
         lbl_feature = QtWidgets.QLabel('Feature:')
 
-        infolayout.addWidget(self.lbl_info)
+        vbl_info.addWidget(self.lbl_info)
 
-        grid_main.addWidget(lbl_combo, 0, 1)
-        grid_main.addWidget(self.combo, 0, 2)
-        grid_main.addWidget(lbl_feature, 1, 1)
-        grid_main.addWidget(self.combo_feature, 1, 2)
-        grid_main.addWidget(self.chk_rot, 2, 1)
-        grid_main.addWidget(self.chk_hull, 2, 2)
-        grid_main.addWidget(pb_speclib, 3, 1, 1, 2)
-        grid_main.addWidget(self.lw_speclib, 4, 1, 1, 2)
+        gl_main.addWidget(lbl_combo, 0, 1)
+        gl_main.addWidget(self.cmb_1, 0, 2)
+        gl_main.addWidget(lbl_feature, 1, 1)
+        gl_main.addWidget(self.cmb_feature, 1, 2)
+        gl_main.addWidget(self.cb_rgb, 2, 1)
+        gl_main.addWidget(self.cb_hull, 2, 2)
+        gl_main.addWidget(pb_speclib, 3, 1, 1, 2)
+        gl_main.addWidget(self.lw_speclib, 4, 1, 1, 2)
 
-        grid_main.addWidget(self.group_info, 5, 1, 8, 2)
+        gl_main.addWidget(self.gbox_info, 5, 1, 8, 2)
 
-        grid_main.addWidget(self.map, 0, 0, 10, 1)
-        grid_main.addWidget(self.mpl_toolbar, 11, 0)
+        gl_main.addWidget(self.map, 0, 0, 10, 1)
+        gl_main.addWidget(self.mpl_toolbar, 11, 0)
 
-        grid_main.addWidget(buttonbox, 12, 0, 1, 1, QtCore.Qt.AlignLeft)
+        gl_main.addWidget(buttonbox, 12, 0, 1, 1, QtCore.Qt.AlignLeft)
 
-        self.combo_feature.currentIndexChanged.connect(self.feature_change)
-        self.chk_hull.clicked.connect(self.hull)
-        self.chk_rot.clicked.connect(self.rotate_view)
+        self.cmb_feature.currentIndexChanged.connect(self.feature_change)
+        self.cb_hull.clicked.connect(self.hull)
+        self.cb_rgb.clicked.connect(self.rotate_view)
         pb_speclib.clicked.connect(self.load_splib)
         self.lw_speclib.currentRowChanged.connect(self.disp_splib)
 
@@ -264,8 +317,8 @@ class AnalSpec(BasicModule):
 
         Parameters
         ----------
-        event : TYPE
-            DESCRIPTION.
+        event : matplotlib.backend_bases.MouseEvent
+            Mouse Event.
 
         Returns
         -------
@@ -290,8 +343,13 @@ class AnalSpec(BasicModule):
         self.map.row = int(event.ydata)
         self.map.col = int(event.xdata)
 
-        if self.chk_rot.isChecked():
-            self.map.row, self.map.col = self.map.col, self.map.row
+        dat = self.map.datarr[self.map.mindx]
+
+        self.map.row = int((dat.extent[-1]-self.map.row)//dat.ydim)
+        self.map.col = int((self.map.col-dat.extent[0])//dat.xdim)
+
+        # if self.cb_rgb.isChecked():
+        #     self.map.row, self.map.col = self.map.col, self.map.row
 
         self.map.init_graph()
 
@@ -301,8 +359,8 @@ class AnalSpec(BasicModule):
 
         Parameters
         ----------
-        row : TYPE
-            Unused.
+        row : int
+            row of table, unused.
 
         Returns
         -------
@@ -322,7 +380,7 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        txt = self.combo_feature.currentText()
+        txt = self.cmb_feature.currentText()
 
         self.map.feature = [int(txt)] + self.feature[int(txt)]
 
@@ -337,7 +395,7 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        self.map.remhull = self.chk_hull.isChecked()
+        self.map.remhull = self.cb_hull.isChecked()
         self.map.init_graph()
 
     def load_splib(self):
@@ -349,7 +407,7 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        ext = ('ENVI Spectral Library (*.sli)')
+        ext = 'ENVI Spectral Library (*.sli)'
 
         filename, _ = QtWidgets.QFileDialog.getOpenFileName(
             self.parent, 'Open File', '.', ext)
@@ -375,7 +433,7 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        self.map.mindx = self.combo.currentIndex()
+        self.map.mindx = self.cmb_1.currentIndex()
         self.map.init_graph()
 
     def rotate_view(self):
@@ -387,31 +445,9 @@ class AnalSpec(BasicModule):
         None.
 
         """
-        self.map.rotate = self.chk_rot.isChecked()
+        self.map.rgb = self.cb_rgb.isChecked()
         self.map.init_graph()
 
-    def save(self):
-        """
-        Save depth marks to a json file, with same name as the raster image.
-
-        Returns
-        -------
-        None.
-
-        """
-        sdata = {}
-
-        ofile = self.indata['Raster'][0].filename[:-4]+'.json'
-
-        sdata['numcores'] = self.sb_numcore.value()
-        sdata['traylen'] = self.dsb_traylen.value()
-        sdata['depthmarkers'] = self.depthmarkers
-
-        with open(ofile, 'w', encoding='utf-8') as todisk:
-            json.dump(sdata, todisk, indent=4)
-
-        self.lbl_info.setText('Save complete.')
-
     def settings(self, nodialog=False):
         """
         Entry point into item.
@@ -428,14 +464,14 @@ class AnalSpec(BasicModule):
 
         """
         if 'Raster' not in self.indata:
-            self.showprocesslog('Error: You must have a multi-band raster '
-                                'dataset in addition to your cluster '
-                                'analysis results')
+            self.showlog('Error: You must have a multi-band raster '
+                         'dataset in addition to your cluster '
+                         'analysis results')
             return False
 
         if 'wavelength' not in self.indata['Raster'][0].metadata['Raster']:
-            self.showprocesslog('Error: Your data should have wavelengths in'
-                                ' the metadata')
+            self.showlog('Error: Your data should have wavelengths in'
+                         ' the metadata')
             return False
 
         dat = self.indata['Raster']
@@ -449,8 +485,8 @@ class AnalSpec(BasicModule):
                 needsmerge = True
 
         if needsmerge is True:
-            self.showprocesslog('Error: Your data bands have different sizes. '
-                                'Use Layer Stack to fix this first')
+            self.showlog('Error: Your data bands have different sizes. '
+                         'Use Layer Stack to fix this first')
             return False
 
         wavelengths = []
@@ -466,34 +502,37 @@ class AnalSpec(BasicModule):
             self.map.refl = float(
                 dat[0].metadata['Raster']['reflectance_scale_factor'])
 
-        dat2 = []
+        # dat2 = []
         wvl = []
         for j in dat:
-            dat2.append(j.data)
+            # dat2.append(j.data)
             wvl.append(float(j.metadata['Raster']['wavelength']))
 
-        self.map.datarr = dat2
+        dat2 = np.ma.array(dat2)
+
+        # self.map.datarr = dat2
+        self.map.datarr = dat
         self.map.nodata = dat[0].nodata
         self.map.wvl = np.array(wvl)
         if self.map.wvl.max() < 20:
             self.map.wvl = self.map.wvl*1000.
-            self.showprocesslog('Wavelengths appear to be in nanometers. '
-                                'Converting to micrometers.')
+            self.showlog('Wavelengths appear to be in nanometers. '
+                         'Converting to micrometers.')
 
         bands = [i.dataid for i in self.indata['Raster']]
 
-        self.combo.clear()
-        self.combo.addItems(bands)
-        self.combo.currentIndexChanged.connect(self.on_combo)
+        self.cmb_1.clear()
+        self.cmb_1.addItems(bands)
+        self.cmb_1.currentIndexChanged.connect(self.on_combo)
 
         ftxt = [str(i) for i in self.feature]
-        self.combo_feature.disconnect()
-        self.combo_feature.clear()
-        self.combo_feature.addItems(ftxt)
+        self.cmb_feature.disconnect()
+        self.cmb_feature.clear()
+        self.cmb_feature.addItems(ftxt)
         self.feature_change()
-        self.combo_feature.currentIndexChanged.connect(self.feature_change)
+        self.cmb_feature.currentIndexChanged.connect(self.feature_change)
 
-        tmp = self.exec_()
+        tmp = self.exec()
 
         if tmp == 0:
             return False
@@ -502,36 +541,15 @@ class AnalSpec(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
 
 
 class ProcFeatures(BasicModule):
@@ -544,11 +562,12 @@ class ProcFeatures(BasicModule):
         self.ratio = {}
         self.feature = None
 
-        self.cb_ratios = QtWidgets.QComboBox()
-        self.rfiltcheck = QtWidgets.QCheckBox('If the final product is a '
-                                              'ratio, filter out values less '
-                                              'than 1.')
-        self.filtercheck = QtWidgets.QCheckBox('Filter Albedo and Vegetation')
+        self.cmb_ratios = QtWidgets.QComboBox()
+        self.cb_rfiltcheck = QtWidgets.QCheckBox('If the final product is a '
+                                                 'ratio, filter out values '
+                                                 'less than 1.')
+        self.cb_filtercheck = QtWidgets.QCheckBox('Filter Albedo and '
+                                                  'Vegetation')
         self.tablewidget = QtWidgets.QTableWidget()
 
         self.setupui()
@@ -564,7 +583,7 @@ class ProcFeatures(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.rsense.pfeat')
         lbl_ratios = QtWidgets.QLabel('Product:')
@@ -575,8 +594,8 @@ class ProcFeatures(BasicModule):
         self.tablewidget.setHorizontalHeaderLabels(['Feature', 'Filter',
                                                     'Threshold'])
         self.tablewidget.resizeColumnsToContents()
-        self.filtercheck.setChecked(True)
-        self.rfiltcheck.setChecked(True)
+        self.cb_filtercheck.setChecked(True)
+        self.cb_rfiltcheck.setChecked(True)
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
@@ -584,18 +603,18 @@ class ProcFeatures(BasicModule):
 
         self.setWindowTitle('Process Hyperspectral Features')
 
-        gridlayout_main.addWidget(lbl_ratios, 1, 0, 1, 1)
-        gridlayout_main.addWidget(self.cb_ratios, 1, 1, 1, 1)
-        gridlayout_main.addWidget(lbl_details, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.tablewidget, 2, 1, 1, 1)
-        gridlayout_main.addWidget(self.filtercheck, 3, 0, 1, 2)
-        gridlayout_main.addWidget(self.rfiltcheck, 4, 0, 1, 2)
+        gl_main.addWidget(lbl_ratios, 1, 0, 1, 1)
+        gl_main.addWidget(self.cmb_ratios, 1, 1, 1, 1)
+        gl_main.addWidget(lbl_details, 2, 0, 1, 1)
+        gl_main.addWidget(self.tablewidget, 2, 1, 1, 1)
+        gl_main.addWidget(self.cb_filtercheck, 3, 0, 1, 2)
+        gl_main.addWidget(self.cb_rfiltcheck, 4, 0, 1, 2)
 
-        gridlayout_main.addWidget(helpdocs, 6, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 6, 1, 1, 3)
+        gl_main.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 6, 1, 1, 3)
 
-        self.cb_ratios.currentIndexChanged.connect(self.product_change)
-        self.filtercheck.stateChanged.connect(self.product_change)
+        self.cmb_ratios.currentIndexChanged.connect(self.product_change)
+        self.cb_filtercheck.stateChanged.connect(self.product_change)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
 
@@ -608,12 +627,12 @@ class ProcFeatures(BasicModule):
         None.
 
         """
-        txt = self.cb_ratios.currentText()
+        txt = self.cmb_ratios.currentText()
         self.tablewidget.clear()
 
         product = self.product[txt]
 
-        if self.filtercheck.isChecked():
+        if self.cb_filtercheck.isChecked():
             product = product + self.product['filter']
 
         numrows = len(product)
@@ -648,14 +667,14 @@ class ProcFeatures(BasicModule):
         self.tablewidget.setItem(0, 3, item)
 
         for i in range(1, numrows):
-            cb = QtWidgets.QComboBox()
-            cb.addItems(['<', '>'])
-            self.tablewidget.setCellWidget(i, 1, cb)
+            cmb_1 = QtWidgets.QComboBox()
+            cmb_1.addItems(['<', '>'])
+            self.tablewidget.setCellWidget(i, 1, cmb_1)
 
             txt2 = str(product[i])
             txt2 = txt2.split()
 
-            cb.setCurrentText(txt2[1])
+            cmb_1.setCurrentText(txt2[1])
             item = QtWidgets.QTableWidgetItem(txt2[0])
             item.setFlags(item.flags() & ~QtCore.Qt.ItemIsEditable)
             self.tablewidget.setItem(i, 0, item)
@@ -689,26 +708,34 @@ class ProcFeatures(BasicModule):
         """
         tmp = []
         if 'Raster' not in self.indata and 'RasterFileList' not in self.indata:
-            self.showprocesslog('No Satellite Data')
+            self.showlog('No Satellite Data')
             return False
 
         self.feature = features.feature
         self.ratio = features.ratio
 
-        self.cb_ratios.disconnect()
+        self.cmb_ratios.disconnect()
         self.product = features.product.copy()
+
+        self.product = {key: value for (key, value) in self.product.items()
+                        if 'crystallinity' not in key}
+        self.cryst = {key: value for (key, value) in features.product.items()
+                      if 'crystallinity' in key}
+
+        self.product = dict(sorted(self.product.items()))
+
         del self.product['filter']
-        self.cb_ratios.clear()
-        self.cb_ratios.addItems(self.product)
+        self.cmb_ratios.clear()
+        self.cmb_ratios.addItems(self.product)
 
         # The filter line is added after the other products so that it does
         # not make it into the list widget
         self.product['filter'] = features.product['filter']
-        self.cb_ratios.currentIndexChanged.connect(self.product_change)
+        self.cmb_ratios.currentIndexChanged.connect(self.product_change)
         self.product_change()
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
         else:
             tmp = 1
 
@@ -719,36 +746,18 @@ class ProcFeatures(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.cmb_ratios)
+        self.saveobj(self.cb_rfiltcheck)
+        self.saveobj(self.cb_filtercheck)
 
     def acceptall(self):
         """
@@ -763,10 +772,18 @@ class ProcFeatures(BasicModule):
         """
         datfin = []
 
-        mineral = self.cb_ratios.currentText()
-        rfilt = self.rfiltcheck.isChecked()
+        mineral = self.cmb_ratios.currentText()
+        rfilt = self.cb_rfiltcheck.isChecked()
 
-        product = self.product
+        # product = self.product
+        # cryst = {key: val for (key, val) in self.cryst.items()
+        #          if key.split()[0] in mineral}
+
+        cryst = []
+        for i in self.cryst:
+            if i.split()[0] in mineral:
+                cryst = self.cryst[i]
+                break
 
         try:
             product = [int(self.tablewidget.item(0, 0).text())]
@@ -784,26 +801,27 @@ class ProcFeatures(BasicModule):
 
             os.makedirs(odir, exist_ok=True)
             for ifile in flist:
-                self.showprocesslog('Processing '+os.path.basename(ifile))
+                self.showlog('Processing '+os.path.basename(ifile))
 
                 dat = get_raster(ifile)
                 datfin = calcfeatures(dat, mineral, self.feature, self.ratio,
-                                      product, rfilt, piter=self.piter)
+                                      product, cryst, rfilt, piter=self.piter)
 
                 ofile = (os.path.basename(ifile).split('.')[0] + '_' +
                          mineral.replace(' ', '_') + '.tif')
                 ofile = os.path.join(odir, ofile)
                 if datfin[0].data.mask.min() == True:
-                    self.showprocesslog(' Could not find any ' + mineral +
-                                        '. No data to export.')
+                    self.showlog(' Could not find any ' + mineral +
+                                 '. No data to export.')
                 else:
-                    self.showprocesslog('Exporting '+os.path.basename(ofile))
-                    export_raster(ofile, datfin, 'GTiff', piter=self.piter)
+                    self.showlog('Exporting '+os.path.basename(ofile))
+                    export_raster(ofile, datfin, 'GTiff', piter=self.piter,
+                                  showlog=self.showlog)
 
         elif 'Raster' in self.indata:
             dat = self.indata['Raster']
             datfin = calcfeatures(dat, mineral, self.feature, self.ratio,
-                                  product, rfilt, piter=self.piter)
+                                  product, cryst, rfilt, piter=self.piter)
 
         if datfin[0].data.mask.min() == True:
             QtWidgets.QMessageBox.warning(self.parent, 'Warning',
@@ -816,14 +834,14 @@ class ProcFeatures(BasicModule):
         return True
 
 
-def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
+def calcfeatures(dat, mineral, feature, ratio, product, cryst=None, rfilt=True,
                  piter=iter):
     """
     Calculate feature dataset.
 
     Parameters
     ----------
-    dat : PyGMI Data
+    dat : list of PyGMI Data
         Input PyGMI data.
     mineral : str
         Mineral description.
@@ -834,24 +852,40 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
     product : dictionary
         Final hyperspectral products. Each dictionary value, is a list of
         features or ratios with thresholds to be combined.
+    cryst : dictionary, optional
+        Crystallinity of the product, if available
     rfilt : bool
         Flag to decide whether to filter final ratio products less than 1.0
-    piter : iter, optional
+    piter : function, optional
         Progress bar iterable. The default is iter.
 
     Returns
     -------
-    datfin : list
+    datfin : list of PyGMI Data.
         Output datasets.
 
     """
-    allfeatures = [i.split()[0] for i in product if i[0] == 'f']
-    allratios = [i.split()[0] for i in product if i[0] != 'f']
+    # allfeatures = [i.split()[0] for i in product if i[0] == 'f']
+    # allratios = [i.split()[0] for i in product if i[0] != 'f']
+    if cryst is None:
+        cryst = []
+
+    allfeatures = []
+    for f in feature:
+        for p in product+cryst:
+            if f in p and f not in allfeatures:
+                allfeatures.append(f)
+
+    allratios = []
+    for r in ratio:
+        for p in product+cryst:
+            if r in p and r not in allratios:
+                allratios.append(r)
 
     # Get list of wavelengths and data
     dat2 = []
     xval = []
-    for j in dat:
+    for j in piter(dat):
         dat2.append(j.data)
         refl = float(re.findall(r'[\d\.\d]+', j.dataid)[-1])
         if refl < 100.:
@@ -860,7 +894,7 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
         xval.append(refl)
 
     xval = np.array(xval)
-    dat2 = np.ma.array(dat2)
+    dat2 = np.ma.array(dat2)  # This line is very slow.
 
     # This gets nearest wavelength and assigns to R number.
     # It does not interpolate.
@@ -881,6 +915,7 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
     # Start processing
     depths = {}
     wvl = {}
+    dmax = {}
     for fname in allfeatures:
         if len(feature[fname]) == 4:
             fmin, fmax, lmin, lmax = feature[fname]
@@ -899,6 +934,7 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
         _, rows, cols = dat2.shape
         dtmp = np.zeros((rows, cols))
         ptmp = np.zeros((rows, cols))
+        mtmp = np.zeros((rows, cols))
 
         tmp = np.nonzero((xdat > lmin) & (xdat < lmax))[0]
         i1a = tmp[0]
@@ -907,36 +943,37 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
         fdat = np.moveaxis(fdat, 0, -1)
 
         for i in piter(range(rows)):
-            ptmp[i], dtmp[i] = fproc(fdat[i].data, ptmp[i], dtmp[i], i1a, i2a,
-                                     xdat)
+            ptmp[i], dtmp[i], mtmp[i] = fproc(fdat[i].data, ptmp[i], dtmp[i],
+                                              i1a, i2a, xdat, mtmp[i])
         depths[fname] = dtmp
         wvl[fname] = ptmp
         datcalc[fname] = dtmp
+        dmax[fname] = mtmp
 
     datout = None
     datout2 = None
-    tmpw = None
 
     for i in product:
-        if '>' in i or '<' in i or '=' in i or i[0] == 'r':
-            tmp = ne.evaluate(i, datcalc)
+        if i.count('f') > 1:
+            dattmp = {}
+            for j in datcalc:
+                if j in i:
+                    dattmp[j] = datcalc[j]*dmax[j]
+            tmp = ne.evaluate(i, dattmp)
         else:
-            tmp = depths[i]
-            tmpw = wvl[i]
+            tmp = ne.evaluate(i, datcalc)
 
         if datout is None:
             datout = np.nan_to_num(tmp)
-            datout2 = np.nan_to_num(tmpw)
         else:
             if tmp.max() > 1:
                 print('Problem with filter. Max value greater that 1')
                 return datfin
             datout = datout * np.nan_to_num(tmp)
-            if datout2 is not None:
-                datout2 = datout2 * np.nan_to_num(tmp)
 
     if product[0][0] == 'f':
         label = f'{mineral} depth'
+        datout2 = np.nan_to_num(wvl[product[[0][0]]])
     else:
         label = f'{mineral} ratio'
         if rfilt is True:
@@ -947,8 +984,35 @@ def calcfeatures(dat, mineral, feature, ratio, product, rfilt=True,
 
     if datout2 is not None:
         datout2 = np.ma.masked_equal(datout2, 0)
+        datout2.mask = np.logical_or(datout.mask, datout2.mask)
         datfin.append(numpy_to_pygmi(datout2, dat[0], f'{mineral} wvl'))
 
+    # Add crystallinity if present.
+    datout3 = None
+    for i in cryst:
+        if i.count('f') > 1:
+            dattmp = {}
+            for j in datcalc:
+                if j in i:
+                    dattmp[j] = datcalc[j]*dmax[j]
+            tmp = ne.evaluate(i, dattmp)
+        else:
+            tmp = ne.evaluate(i, datcalc)
+
+        if datout3 is None:
+            datout3 = np.nan_to_num(tmp)
+        else:
+            if tmp.max() > 1:
+                print('Problem with filter. Max value greater that 1')
+                return datfin
+            datout3 = datout3 * np.nan_to_num(tmp)
+
+    if datout3 is not None:
+        datout3 = np.ma.masked_equal(datout3, 0)
+        datout3.mask = np.logical_or(datout.mask, datout3.mask)
+        datfin.append(numpy_to_pygmi(datout3, dat[0],
+                                     f'{mineral} crystallinity'))
+
     return datfin
 
 
@@ -981,7 +1045,7 @@ def indexcalc(formula, dat):
 
 
 @jit(nopython=True)
-def fproc(fdat, ptmp, dtmp, i1a, i2a, xdat):
+def fproc(fdat, ptmp, dtmp, i1a, i2a, xdat, mtmp):
     """
     Feature process.
 
@@ -1019,6 +1083,7 @@ def fproc(fdat, ptmp, dtmp, i1a, i2a, xdat):
 
         yhull = phull(yval)
         crem = yval/yhull
+        mtmp[j] = -(yval - yhull).min()
 
         imin = crem[i1a:i2a].argmin()
 
@@ -1032,7 +1097,7 @@ def fproc(fdat, ptmp, dtmp, i1a, i2a, xdat):
         ptmp[j] = x
         dtmp[j] = 1. - y
 
-    return ptmp, dtmp
+    return ptmp, dtmp, mtmp
 
 
 @jit(nopython=True)
@@ -1199,7 +1264,7 @@ def readsli(ifile):
         if len(tmp) > 1:
             hdr3[tmp[0].strip()] = tmp[1].strip()
 
-    for i in hdr3.keys():
+    for i in hdr3:
         if i in ['samples', 'lines', 'bands', 'header offset', 'data type']:
             hdr3[i] = int(hdr3[i])
             continue
@@ -1233,6 +1298,7 @@ def readsli(ifile):
     dt2np[15] = np.uint64
 
     data = np.fromfile(ifile, dtype=dt2np[dtype])
+    data[data == -1.23e+34] = np.nan
     data = data / hdr3['reflectance scale factor']
 
     data.shape = (hdr3['lines'], hdr3['samples'])
@@ -1258,203 +1324,40 @@ def _testfn():
 
     app = QtWidgets.QApplication(sys.argv)
 
-    # ifile = r"d:\Workdata\Hyperspectral\080_0824-0920_ref_rect_clip.hdr"
-    # ifile = r"d:\Workdata\Remote Sensing\hyperion\EO1H1760802013198110KF_1T.ZIP"
-    ifile = r"D:\Workdata\PyGMI Test Data\Remote Sensing\Import\hyperspectral\071_0818-0932_ref_rect_BSQ.hdr"
+    # ifile = r"D:\Workdata\PyGMI Test Data\Remote Sensing\Import\hyperspectral\071_0818-0932_ref_rect_BSQ.hdr"
+    # ifile = r"D:\cut_048-055_ref_rect_DEFLATE.tif"
+    ifile = r"D:\Cu-hyperspec-testarea.tif"
 
-    xoff = 0
-    yoff = 2000
-    xsize = None
-    ysize = 1000
-    nodata = 15000
-    nodata = 0
-
-    iraster = (xoff, yoff, xsize, ysize)
-    iraster = None
-
-    # data = get_raster(ifile, nval=nodata, iraster=iraster, piter=pbar.iter)
     data = get_data(ifile)
 
-    # data = get_raster(ifile, piter=pbar.iter)
-
     tmp = ProcFeatures(None)
     tmp.indata['Raster'] = data
-    # tmp.cb_ratios.setCurrentText('ferric iron')
     tmp.settings()
 
-    dat = tmp.outdata['Raster'][0]
+    datall = tmp.outdata['Raster']
 
-    plt.figure(dpi=150)
-    plt.imshow(dat.data)
-    plt.colorbar()
-    plt.show()
-
-    print(dat.data.mean())
-
-    plt.figure(dpi=150)
-    plt.hist(dat.data.flatten(), bins=200)
-    plt.show()
-
-    tmp = np.histogram(dat.data[dat.data > 0])
+    for dat in datall:
+        plt.figure(dpi=150)
+        plt.title(dat.dataid)
+        plt.imshow(dat.data, extent=dat.extent)
+        plt.colorbar()
+        plt.tight_layout()
+        plt.show()
 
 
 def _testfn2():
     """Test routine."""
     from pygmi.rsense.iodefs import get_data
-    from pygmi.raster.dataprep import lstack
 
-    ifile = r"D:\Workdata\PyGMI Test Data\Remote Sensing\Import\hyperspectral\071_0818-0932_ref_rect_BSQ.hdr"
-    # ifile = r"c:\Workdata\Remote Sensing\hyperion\EO1H1760802013198110KF_1T.ZIP"
+    ifile = r"D:\Cu-hyperspec-testarea.tif"
 
     data = get_data(ifile)
 
-    data = lstack(data)
-
     app = QtWidgets.QApplication(sys.argv)
     tmp = AnalSpec()
     tmp.indata['Raster'] = data
     tmp.settings()
 
 
-def _testfn3():
-    """Test."""
-    ifile1 = r'd:\Workdata\Lithosphere\merge\cut-087-0824_iMNF15.hdr'
-    ifile2 = r'd:\Workdata\Lithosphere\merge\cut-088-0824_iMNF15.hdr'
-    ifile3 = r'd:\Workdata\Lithosphere\merge\cut-089-0824_iMNF15.hdr'
-
-    feat = 18
-
-    yoff = 2425
-    ysize = 400
-    nodata = 0
-    iraster = (0, yoff, None, ysize)
-
-    data1 = get_raster(ifile1, nval=nodata, iraster=iraster)
-    data2 = get_raster(ifile2, nval=nodata, iraster=iraster)
-    data3 = get_raster(ifile3, nval=nodata, iraster=iraster)
-
-    plt.figure(dpi=150)
-    plt.imshow(data1[0].data, extent=data1[0].extent)
-    plt.plot(277545, 6774900, '+k')
-    plt.show()
-
-    plt.figure(dpi=150)
-    plt.imshow(data2[0].data, extent=data2[0].extent)
-    plt.plot(277545, 6774900, '+k')
-    plt.plot(279900, 6774900, '+k')
-    plt.show()
-
-    plt.figure(dpi=150)
-    plt.imshow(data3[0].data, extent=data3[0].extent)
-    plt.plot(279900, 6774900, '+k')
-    plt.show()
-
-    yoff = 2625
-    ysize = 1
-    nodata = 0
-    iraster = (0, yoff, None, ysize)
-
-    data1 = get_raster(ifile1, nval=nodata, iraster=iraster)
-    data2 = get_raster(ifile2, nval=nodata, iraster=iraster)
-    data3 = get_raster(ifile3, nval=nodata, iraster=iraster)
-
-    for i in range(2):
-        if i == 0:
-            xxx = 277545
-            yyy = 6774900
-        else:
-            xxx = 279900
-            yyy = 6774900
-            data1 = data3
-
-        i1 = int((xxx-data1[0].extent[0])/data1[0].xdim)
-        i2 = int((xxx-data2[0].extent[0])/data2[0].xdim)
-
-        # Get list of wavelengths and data
-        dat1 = []
-        xval1 = []
-        for j in data1:
-            dat1.append(j.data)
-            refl = round(float(re.findall(r'[\d\.\d]+', j.dataid)[-1])*1000, 2)
-            xval1.append(refl)
-
-        xval1 = np.array(xval1)
-        dat1 = np.array(dat1)
-
-        dat2 = []
-        xval2 = []
-        for j in data2:
-            dat2.append(j.data)
-            refl = round(float(re.findall(r'[\d\.\d]+', j.dataid)[-1])*1000, 2)
-            xval2.append(refl)
-
-        xval2 = np.array(xval2)
-        dat2 = np.array(dat2)
-
-        dat1 = dat1[55: 98]
-        dat2 = dat2[55: 98]
-        xval1 = xval1[55: 98]
-        xval2 = xval2[55: 98]
-
-        fdat = []
-        xdat = []
-        fdat.append(dat1[:, 0, i1])
-        fdat.append(dat2[:, 0, i2])
-        xdat = xval1
-
-        fdat = np.array(fdat)
-
-        ptmp = np.array([0, 0])
-        dtmp = np.array([0, 0])
-
-        ptmp, dtmp = fproc(fdat, ptmp, dtmp, 11, 19, xdat)
-
-        spec1 = dat1[:, 0, i1]
-        spec2 = dat2[:, 0, i2]
-
-        plt.figure(dpi=150)
-        plt.title(str(i)+': '+str(i1))
-        plt.plot(xval1, spec1)
-        plt.plot(xval2, spec2, '-.')
-        ymin, ymax = plt.gca().get_ylim()
-        plt.vlines(ptmp[0], ymin, ymax, 'k')
-        plt.vlines(ptmp[1], ymin, ymax, 'k')
-
-        spec1 = spec1/phull(spec1)
-        spec2 = spec2/phull(spec2)
-
-        plt.figure(dpi=150)
-        plt.title(str(i)+': '+str(i1))
-        plt.plot(xval1, spec1)
-        plt.plot(xval2, spec2, 'r-.')
-
-        plt.plot(xval1[11:19], spec1[11:19], '.')
-        plt.plot(xval2[11:19], spec2[11:19], '.')
-
-        ymin, ymax = plt.gca().get_ylim()
-        plt.vlines(ptmp[0], ymin, ymax, label=str(ptmp[0]))
-        plt.vlines(ptmp[1], ymin, ymax, colors='r', linestyles='-.',
-                   label=str(ptmp[1]))
-        plt.legend()
-        plt.show()
-
-        plt.figure(dpi=150)
-
-        dat1 = np.ma.masked_equal(dat1, 0)
-        dat2 = np.ma.masked_equal(dat2, 0)
-
-        x1 = np.linspace(data1[0].extent[0], data1[0].extent[1],
-                         dat1[feat, 0].size)
-        x2 = np.linspace(data2[0].extent[0], data2[0].extent[1],
-                         dat2[feat, 0].size)
-        plt.plot(x1, dat1[feat, 0])
-        plt.plot(x2, dat2[feat, 0], '-.')
-
-        ymin, ymax = plt.gca().get_ylim()
-
-        plt.vlines(xxx, ymin, ymax, 'k')
-        plt.show()
-
-
 if __name__ == "__main__":
     _testfn()
