@@ -25,19 +25,19 @@
 """Transforms such as PCA and MNF."""
 
 import os
-import copy
-
 import numpy as np
 from PyQt5 import QtWidgets, QtCore
 from sklearn.decomposition import IncrementalPCA
 import numexpr as ne
 import matplotlib.pyplot as plt
 
-from pygmi.raster.iodefs import export_raster
-from pygmi.rsense.iodefs import get_data
-from pygmi.raster.dataprep import lstack
 from pygmi.misc import BasicModule
 from pygmi import menu_default
+from pygmi.raster.iodefs import export_raster
+from pygmi.raster.dataprep import lstack
+from pygmi.rsense.iodefs import get_data
+from pygmi.rsense.iodefs import get_from_rastermeta
+from pygmi.rsense.iodefs import set_export_filename
 
 
 class MNF(BasicModule):
@@ -71,7 +71,7 @@ class MNF(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.rsense.mnf')
         lbl_comps = QtWidgets.QLabel('Number of components:')
@@ -87,15 +87,15 @@ class MNF(BasicModule):
 
         self.setWindowTitle('Minimum Noise Fraction')
 
-        gridlayout_main.addWidget(self.cb_fwdonly, 1, 0, 1, 2)
-        gridlayout_main.addWidget(lbl_comps, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.sb_comps, 2, 1, 1, 1)
-        gridlayout_main.addWidget(self.rb_noise_hv, 3, 0, 1, 2)
-        gridlayout_main.addWidget(self.rb_noise_diag, 4, 0, 1, 2)
-        gridlayout_main.addWidget(self.rb_noise_quad, 5, 0, 1, 2)
+        gl_main.addWidget(self.cb_fwdonly, 1, 0, 1, 2)
+        gl_main.addWidget(lbl_comps, 2, 0, 1, 1)
+        gl_main.addWidget(self.sb_comps, 2, 1, 1, 1)
+        gl_main.addWidget(self.rb_noise_hv, 3, 0, 1, 2)
+        gl_main.addWidget(self.rb_noise_diag, 4, 0, 1, 2)
+        gl_main.addWidget(self.rb_noise_quad, 5, 0, 1, 2)
 
-        gridlayout_main.addWidget(helpdocs, 6, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 6, 1, 1, 3)
+        gl_main.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 6, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -118,9 +118,13 @@ class MNF(BasicModule):
         self.ev = None
         tmp = []
         if 'Raster' not in self.indata and 'RasterFileList' not in self.indata:
-            self.showprocesslog('No Satellite Data')
+            self.showlog('No Satellite Data')
             return False
 
+        if 'RasterFileList' in self.indata:
+            if len(self.indata['RasterFileList'][0].bands) > 5:
+                self.sb_comps.setValue(5)
+
         if 'Raster' in self.indata:
             indata = self.indata['Raster']
             self.sb_comps.setMaximum(len(indata))
@@ -128,7 +132,7 @@ class MNF(BasicModule):
                 self.sb_comps.setValue(5)
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
         else:
             tmp = 1
 
@@ -169,36 +173,20 @@ class MNF(BasicModule):
         uienabled = not self.cb_fwdonly.isChecked()
         self.sb_comps.setEnabled(uienabled)
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.sb_comps)
+        self.saveobj(self.cb_fwdonly)
+        self.saveobj(self.rb_noise_diag)
+        self.saveobj(self.rb_noise_hv)
+        self.saveobj(self.rb_noise_quad)
 
     def acceptall(self):
         """
@@ -211,6 +199,11 @@ class MNF(BasicModule):
         None.
 
         """
+        if 'RasterFileList' in self.indata:
+            flist = self.indata['RasterFileList']
+        else:
+            flist = None
+
         ncmps = self.sb_comps.value()
         odata = []
 
@@ -222,31 +215,32 @@ class MNF(BasicModule):
             noise = 'quad'
 
         if 'RasterFileList' in self.indata:
-            flist = self.indata['RasterFileList']
-            odir = os.path.join(os.path.dirname(flist[0]), 'MNF')
+            filename = flist[0].filename
+            odir = os.path.join(os.path.dirname(filename), 'MNF')
 
             os.makedirs(odir, exist_ok=True)
             for ifile in flist:
-                self.showprocesslog('Processing '+os.path.basename(ifile))
+                filename = ifile.filename
 
-                dat = get_data(ifile, piter=self.piter,
-                               showprocesslog=self.showprocesslog,
-                               extscene='Bands Only')
+                self.showlog('Processing '+os.path.basename(filename))
+
+                dat = get_from_rastermeta(ifile, piter=self.piter,
+                                          showlog=self.showlog)
                 odata, self.ev = mnf_calc(dat, ncmps, piter=self.piter,
-                                          pprint=self.showprocesslog,
+                                          showlog=self.showlog,
                                           noisetxt=noise,
                                           fwdonly=self.cb_fwdonly.isChecked())
 
-                ofile = os.path.basename(ifile).split('.')[0] + '_mnf.tif'
-                ofile = os.path.join(odir, ofile)
+                ofile = set_export_filename(dat, odir, 'mnf')
 
-                self.showprocesslog('Exporting '+os.path.basename(ofile))
-                export_raster(ofile, odata, 'GTiff', piter=self.piter)
+                self.showlog('Exporting '+os.path.basename(ofile))
+                export_raster(ofile, odata, 'GTiff', piter=self.piter,
+                              showlog=self.showlog)
 
         elif 'Raster' in self.indata:
             dat = self.indata['Raster']
             odata, self.ev = mnf_calc(dat, ncmps, piter=self.piter,
-                                      pprint=self.showprocesslog,
+                                      showlog=self.showlog,
                                       noisetxt=noise,
                                       fwdonly=self.cb_fwdonly.isChecked())
 
@@ -279,7 +273,7 @@ class PCA(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.rsense.pca')
         lbl_comps = QtWidgets.QLabel('Number of components:')
@@ -296,13 +290,13 @@ class PCA(BasicModule):
 
         self.setWindowTitle('Principal Component Analysis')
 
-        gridlayout_main.addWidget(self.cb_fwdonly, 1, 0, 1, 2)
-        gridlayout_main.addWidget(lbl_comps, 2, 0, 1, 1)
-        gridlayout_main.addWidget(self.sb_comps, 2, 1, 1, 1)
-        gridlayout_main.addWidget(self.cb_fitlist, 3, 0, 1, 2)
+        gl_main.addWidget(self.cb_fwdonly, 1, 0, 1, 2)
+        gl_main.addWidget(lbl_comps, 2, 0, 1, 1)
+        gl_main.addWidget(self.sb_comps, 2, 1, 1, 1)
+        gl_main.addWidget(self.cb_fitlist, 3, 0, 1, 2)
 
-        gridlayout_main.addWidget(helpdocs, 6, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 6, 1, 1, 3)
+        gl_main.addWidget(helpdocs, 6, 0, 1, 1)
+        gl_main.addWidget(buttonbox, 6, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -325,11 +319,13 @@ class PCA(BasicModule):
         self.ev = None
         tmp = []
         if 'Raster' not in self.indata and 'RasterFileList' not in self.indata:
-            self.showprocesslog('No Satellite Data')
+            self.showlog('No Satellite Data')
             return False
 
         if 'RasterFileList' in self.indata:
             self.cb_fitlist.setVisible(True)
+            if len(self.indata['RasterFileList'][0].bands) > 5:
+                self.sb_comps.setValue(5)
 
         if 'Raster' in self.indata:
             indata = self.indata['Raster']
@@ -338,7 +334,7 @@ class PCA(BasicModule):
                 self.sb_comps.setValue(5)
 
         if not nodialog:
-            tmp = self.exec_()
+            tmp = self.exec()
         else:
             tmp = 1
 
@@ -379,36 +375,18 @@ class PCA(BasicModule):
         uienabled = not self.cb_fwdonly.isChecked()
         self.sb_comps.setEnabled(uienabled)
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.sb_comps)
+        self.saveobj(self.cb_fwdonly)
+        self.saveobj(self.cb_fitlist)
 
     def acceptall(self):
         """
@@ -425,46 +403,58 @@ class PCA(BasicModule):
         fitlist = self.cb_fitlist.isChecked()
         fwdonly = self.cb_fwdonly.isChecked()
 
+        if 'RasterFileList' in self.indata:
+            flist = self.indata['RasterFileList']
+
+            sensors = [i.sensor for i in flist]
+            sensors = list(set(sensors))
+
+            if fitlist is True and len(sensors) > 1:
+                self.showlog('Error: You have more than one sensor type in '
+                             'your raster file list directory. Fit list is not'
+                             ' possible.')
+                return False
+
         odata = []
 
         if 'RasterFileList' in self.indata and fitlist is False:
-            flist = self.indata['RasterFileList']
-            odir = os.path.join(os.path.dirname(flist[0]), 'PCA')
+            filename = flist[0].filename
+            odir = os.path.join(os.path.dirname(filename), 'PCA')
 
             os.makedirs(odir, exist_ok=True)
             for ifile in flist:
-                self.showprocesslog('Processing '+os.path.basename(ifile))
+                filename = ifile.filename
 
-                dat = get_data(ifile, piter=self.piter,
-                               showprocesslog=self.showprocesslog,
-                               extscene='Bands Only')
+                self.showlog('Processing '+os.path.basename(filename))
+
+                dat = get_from_rastermeta(ifile, piter=self.piter,
+                                          showlog=self.showlog)
                 odata, self.ev = pca_calc(dat, ncmps, piter=self.piter,
-                                          pprint=self.showprocesslog,
+                                          showlog=self.showlog,
                                           fwdonly=fwdonly)
 
-                ofile = os.path.basename(ifile).split('.')[0] + '_pca.tif'
-                ofile = os.path.join(odir, ofile)
+                ofile = set_export_filename(dat, odir, 'pca')
 
-                self.showprocesslog('Exporting '+os.path.basename(ofile))
-                export_raster(ofile, odata, 'GTiff', piter=self.piter)
+                self.showlog('Exporting '+os.path.basename(ofile))
+                export_raster(ofile, odata, 'GTiff', piter=self.piter,
+                              showlog=self.showlog)
 
         elif 'RasterFileList' in self.indata and fitlist is True:
-            flist = self.indata['RasterFileList']
             odata, self.ev = pca_calc_fitlist(flist, ncmps, piter=self.piter,
-                                              pprint=self.showprocesslog,
+                                              showlog=self.showlog,
                                               fwdonly=fwdonly)
 
         elif 'Raster' in self.indata:
             dat = self.indata['Raster']
             odata, self.ev = pca_calc(dat, ncmps, piter=self.piter,
-                                      pprint=self.showprocesslog,
+                                      showlog=self.showlog,
                                       fwdonly=self.cb_fwdonly.isChecked())
 
         self.outdata['Raster'] = odata
         return True
 
 
-def get_noise(x2d, mask, noise=''):
+def get_noise(x2d, mask, noisetype='', piter=iter):
     """
     Calculate noise dataset from original data.
 
@@ -474,7 +464,7 @@ def get_noise(x2d, mask, noise=''):
         Input array, of dimension (MxNxChannels).
     mask : numpy array
         mask of dimension (MxN).
-    noise : str, optional
+    noisetype : str, optional
         Noise type to calculate. Can be 'diagonal', 'hv average' or ''.
         The default is ''.
 
@@ -488,25 +478,33 @@ def get_noise(x2d, mask, noise=''):
     """
     mask = ~mask
 
-    if noise == 'diagonal':
+    pbar = piter([1, 2, 3])
+    next(pbar)
+
+    if noisetype == 'diagonal':
         t1 = x2d[:-1, :-1]
         t2 = x2d[1:, 1:]
         noise = ne.evaluate('t1-t2')
 
         mask2 = mask[:-1, :-1]*mask[1:, 1:]
         noise = noise[mask2]
-        ncov = np.cov(noise.T)
-    elif noise == 'hv average':
+
+        ncov = blockwise_cov(noise.T)
+
+    elif noisetype == 'hv average':
         t1 = x2d[:-1, :-1]
         t2 = x2d[1:, :-1]
         t3 = x2d[:-1, :-1]
         t4 = x2d[:-1, 1:]
 
         noise = ne.evaluate('(t1-t2+t3-t4)')
+
         mask2 = mask[:-1, :-1]*mask[1:, :-1]*mask[:-1, 1:]
 
         noise = noise[mask2]
-        ncov = np.cov(noise.T)/4
+
+        ncov = blockwise_cov(noise.T) / 4
+
     else:
         t1 = x2d[:-2, :-2]
         t2 = x2d[:-2, 1:-1]
@@ -520,32 +518,32 @@ def get_noise(x2d, mask, noise=''):
 
         noise = ne.evaluate('(t1-2*t2+t3-2*t4+4*t5-2*t6+t7-2*t8+t9)')
 
-        # noise = (x2d[:-2, :-2] - 2*x2d[:-2, 1:-1] + x2d[:-2, 2:]
-        #          - 2*x2d[1:-1, :-2] + 4*x2d[1:-1, 1:-1] - 2*x2d[1:-1, 2:]
-        #          + x2d[2:, :-2] - 2*x2d[2:, 1:-1] + x2d[2:, 2:])/9
-
         mask2 = (mask[:-2, :-2] * mask[:-2, 1:-1] * mask[:-2, 2:] *
                  mask[1:-1, :-2] * mask[1:-1, 1:-1] * mask[1:-1, 2:] *
                  mask[2:, :-2] * mask[2:, 1:-1] * mask[2:, 2:])
 
         noise = noise[mask2]
-        ncov = np.cov(noise.T)/81
 
+        ncov = blockwise_cov(noise.T) / 81
+
+    del noise
+    next(pbar)
     # Calculate evecs and evals
     nevals, nevecs = np.linalg.eig(ncov)
 
-    # return noise, mask2
+    next(pbar)
+
     return nevals, nevecs
 
 
-def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
+def mnf_calc(dat, ncmps=None, noisetxt='hv average', showlog=print, piter=iter,
              fwdonly=True):
     """
     MNF Calculation.
 
     Parameters
     ----------
-    dat : List
+    dat : list of PyGMI Data.
         List of PyGMI Data.
     ncmps : int or None, optional
         Number of components to use for filtering. The default is None
@@ -553,7 +551,7 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
     noisetxt : txt, optional
         Noise type. Can be 'diagonal', 'hv average' or 'quad'. The default is
         'hv average'.
-    pprint : function, optional
+    showlog : function, optional
         Function for printing text. The default is print.
     piter : function, optional
         Iteration function, used for progress bars. The default is iter.
@@ -562,15 +560,15 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
 
     Returns
     -------
-    odata : list
-        Output list of PyGMI Data.Can be forward or inverse transformed data.
+    odata : list of PyGMI Data.
+        Output list of PyGMI Data. Can be forward or inverse transformed data.
     ev : numpy array
         Explained variance, from PCA.
 
     """
     x2d = []
     maskall = []
-    dat = lstack(dat, piter=piter, pprint=pprint, commonmask=True)
+    dat = lstack(dat, piter=piter, showlog=showlog, commonmask=True)
 
     for j in dat:
         x2d.append(j.data)
@@ -580,12 +578,15 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
     x2d = np.moveaxis(x2d, 0, -1)
     x2dshape = list(x2d.shape)
 
+    for i in dat:
+        i.data = None
+
     mask = maskall[:, :, 0]
 
-    pprint('Calculating noise data...')
-    nevals, nevecs = get_noise(x2d, mask, noisetxt)
+    showlog('Calculating noise data...')
+    nevals, nevecs = get_noise(x2d, mask, noisetxt, piter)
 
-    pprint('Calculating MNF...')
+    showlog('Calculating MNF...')
     Ln = np.power(nevals, -0.5)
     Ln = np.diag(Ln)
 
@@ -594,19 +595,19 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
     x = x2d[~mask]
     del x2d
 
-    Pnorm = np.dot(x, W.T)
+    Pnorm = blockwise_dot(x, W.T)
 
     pca = IncrementalPCA(n_components=ncmps)
 
     iold = 0
-    pprint('Fitting PCA')
+    showlog('Fitting PCA')
     for i in piter(np.linspace(0, Pnorm.shape[0], 20, dtype=int)):
         if i == 0:
             continue
         pca.partial_fit(Pnorm[iold: i])
         iold = i
 
-    pprint('Calculating PCA transform...')
+    showlog('Calculating PCA transform...')
 
     x2 = np.zeros((Pnorm.shape[0], pca.n_components_))
     iold = 0
@@ -621,10 +622,10 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
     evr = pca.explained_variance_ratio_
 
     if fwdonly is False:
-        pprint('Calculating inverse MNF...')
+        showlog('Calculating inverse MNF...')
         Winv = np.linalg.inv(W)
         P = pca.inverse_transform(x2)
-        x2 = np.dot(P, Winv.T)
+        x2 = blockwise_dot(P, Winv.T)
         del P
     else:
         x2dshape[-1] = ncmps
@@ -636,13 +637,15 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
 
     del x2
 
-    odata = copy.deepcopy(dat)
     if fwdonly:
-        odata = odata[:ncmps]
+        odata = [i.copy(True) for i in dat[:ncmps]]
+    else:
+        odata = [i.copy() for i in dat]
+
     for j, band in enumerate(odata):
         band.data = datall[:, :, j]
         if fwdonly is True:
-            band.dataid = (f'MNF {j+1} Explained Variance Ratio '
+            band.dataid = (f'MNF{j+1} Explained Variance Ratio '
                            f'{evr[j]*100:.2f}%')
 
     del datall
@@ -650,18 +653,18 @@ def mnf_calc(dat, ncmps=None, noisetxt='hv average', pprint=print, piter=iter,
     return odata, ev
 
 
-def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
+def pca_calc(dat, ncmps=None,  showlog=print, piter=iter, fwdonly=True):
     """
     PCA Calculation.
 
     Parameters
     ----------
-    dat : List
+    dat : list of PyGMI Data.
         List of PyGMI Data.
     ncmps : int or None, optional
         Number of components to use for filtering. The default is None
         (meaning all).
-    pprint : function, optional
+    showlog : function, optional
         Function for printing text. The default is print.
     piter : function, optional
         Iteration function, used for progress bars. The default is iter.
@@ -670,15 +673,15 @@ def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
 
     Returns
     -------
-    odata : list
-        Output list of PyGMI Data.Can be forward or inverse transformed data.
+    odata : list of PyGMI Data.
+        Output list of PyGMI Data. Can be forward or inverse transformed data.
     ev : numpy array
         Explained variance, from PCA.
 
     """
     x2d = []
     maskall = []
-    dat = lstack(dat, piter=piter, commonmask=True)
+    dat = lstack(dat, piter=piter, commonmask=True, showlog=showlog)
 
     for j in dat:
         x2d.append(j.data)
@@ -688,6 +691,9 @@ def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
     x2d = np.moveaxis(x2d, 0, -1)
     x2dshape = list(x2d.shape)
 
+    for i in dat:
+        i.data = None
+
     mask = maskall[:, :, 0]
 
     x2d = x2d[~mask]
@@ -695,14 +701,14 @@ def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
     pca = IncrementalPCA(n_components=ncmps)
 
     iold = 0
-    pprint('Fitting PCA')
+    showlog('Fitting PCA')
     for i in piter(np.linspace(0, x2d.shape[0], 20, dtype=int)):
         if i == 0:
             continue
         pca.partial_fit(x2d[iold: i])
         iold = i
 
-    pprint('Calculating PCA transform...')
+    showlog('Calculating PCA transform...')
 
     x2 = np.zeros((x2d.shape[0], pca.n_components_))
     iold = 0
@@ -717,7 +723,7 @@ def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
     evr = pca.explained_variance_ratio_
 
     if fwdonly is False:
-        pprint('Calculating inverse PCA...')
+        showlog('Calculating inverse PCA...')
         x2 = pca.inverse_transform(x2)
     else:
         x2dshape[-1] = ncmps
@@ -730,32 +736,35 @@ def pca_calc(dat, ncmps=None,  pprint=print, piter=iter, fwdonly=True):
 
     del x2
 
-    odata = copy.deepcopy(dat)
     if fwdonly:
+        odata = [i.copy(True) for i in dat]
         odata = odata[:ncmps]
+    else:
+        odata = [i.copy() for i in dat]
+
     for j, band in enumerate(odata):
         band.data = datall[:, :, j]
         if fwdonly is True:
-            band.dataid = (f'PCA {j+1} Explained Variance Ratio '
+            band.dataid = (f'PCA{j+1} Explained Variance Ratio '
                            f'{evr[j]*100:.2f}%')
     del datall
 
     return odata, ev
 
 
-def pca_calc_fitlist(flist, ncmps=None,  pprint=print, piter=iter,
+def pca_calc_fitlist(flist, ncmps=None,  showlog=print, piter=iter,
                      fwdonly=True):
     """
     PCA Calculation with using list of files in common fit.
 
     Parameters
     ----------
-    dat : List
+    dat : list of PyGMI Data.
         List of PyGMI Data.
     ncmps : int or None, optional
         Number of components to use for filtering. The default is None
         (meaning all).
-    pprint : function, optional
+    showlog : function, optional
         Function for printing text. The default is print.
     piter : function, optional
         Iteration function, used for progress bars. The default is iter.
@@ -764,24 +773,33 @@ def pca_calc_fitlist(flist, ncmps=None,  pprint=print, piter=iter,
 
     Returns
     -------
-    odata : list
+    odata : list of PyGMI Data.
         Output list of PyGMI Data.Can be forward or inverse transformed data.
     ev : numpy array
         Explained variance, from PCA.
 
     """
-    odir = os.path.join(os.path.dirname(flist[0]), 'PCA')
+    if isinstance(flist[0], list):
+        filename = flist[0][0].filename
+    else:
+        filename = flist[0].filename
+
+    odir = os.path.join(os.path.dirname(filename), 'PCA')
     os.makedirs(odir, exist_ok=True)
 
     for ifile in flist:
-        pprint('Fitting '+os.path.basename(ifile))
+        if isinstance(ifile, list):
+            filename = ifile[0].filename
+        else:
+            filename = ifile.filename
 
-        dat = get_data(ifile, piter=piter, showprocesslog=pprint,
-                       extscene='Bands Only')
+        showlog('Fitting '+os.path.basename(filename))
+
+        dat = get_from_rastermeta(ifile, piter=piter, showlog=showlog)
 
         x2d = []
         maskall = []
-        dat = lstack(dat, piter=piter, commonmask=True)
+        dat = lstack(dat, piter=piter, commonmask=True, showlog=showlog)
 
         for j in dat:
             x2d.append(j.data)
@@ -805,14 +823,18 @@ def pca_calc_fitlist(flist, ncmps=None,  pprint=print, piter=iter,
             iold = i
 
     for ifile in flist:
-        pprint('Transforming '+os.path.basename(ifile))
+        if isinstance(ifile, list):
+            filename = ifile[0].filename
+        else:
+            filename = ifile.filename
 
-        dat = get_data(ifile, piter=piter, showprocesslog=pprint,
-                       extscene='Bands Only')
+        showlog('Transforming '+os.path.basename(filename))
+
+        dat = get_from_rastermeta(ifile, piter=piter, showlog=showlog)
 
         x2d = []
         maskall = []
-        dat = lstack(dat, piter=piter)
+        dat = lstack(dat, piter=piter, showlog=showlog)
 
         for j in dat:
             x2d.append(j.data)
@@ -839,7 +861,7 @@ def pca_calc_fitlist(flist, ncmps=None,  pprint=print, piter=iter,
         evr = pca.explained_variance_ratio_
 
         if fwdonly is False:
-            pprint('Calculating inverse PCA...')
+            showlog('Calculating inverse PCA...')
             x2 = pca.inverse_transform(x2)
         else:
             x2dshape[-1] = ncmps
@@ -852,42 +874,147 @@ def pca_calc_fitlist(flist, ncmps=None,  pprint=print, piter=iter,
 
         del x2
 
-        odata = copy.deepcopy(dat)
         if fwdonly:
+            odata = [i.copy(True) for i in dat]
             odata = odata[:ncmps]
+        else:
+            odata = [i.copy() for i in dat]
+
         for j, band in enumerate(odata):
             band.data = datall[:, :, j]
             if fwdonly is True:
-                band.dataid = (f'PCA {j+1} Explained Variance Ratio '
+                band.dataid = (f'PCA{j+1} Explained Variance Ratio '
                                f'{evr[j]*100:.2f}%')
         del datall
 
-        ofile = os.path.basename(ifile).split('.')[0] + '_pca.tif'
-        ofile = os.path.join(odir, ofile)
+        ofile = set_export_filename(dat, odir, 'pca')
 
-        pprint('Exporting '+os.path.basename(ofile))
-        export_raster(ofile, odata, 'GTiff', piter=piter, compression='ZSTD')
+        showlog('Exporting '+os.path.basename(ofile))
+        export_raster(ofile, odata, 'GTiff', piter=piter, compression='ZSTD',
+                      showlog=showlog)
 
     return odata, ev
 
 
+def _block_slices(dim_size, block_size):
+    """
+    Generate slice objects.
+
+    Generator that yields slice objects for indexing into
+    sequential blocks of an array along a particular axis.
+
+    from: https://stackoverflow.com/questions/20983882/efficient-dot-products-of-large-memory-mapped-arrays
+
+    Parameters
+    ----------
+    dim_size : int
+        Dimension size.
+    block_size : int
+        Block size.
+
+    Yields
+    ------
+    slice
+        Slice to be used in blockwise_dot.
+    """
+    count = 0
+    while True:
+        yield slice(count, count + block_size, 1)
+        count += block_size
+        if count > dim_size:
+            break
+
+
+def blockwise_cov(A):
+    """
+    Blockwise covariance.
+
+    Parameters
+    ----------
+    A : numpy array
+        Matrix.
+
+    Returns
+    -------
+    ncov : numpy array
+        Covariance matrix.
+
+    """
+    A = A - np.mean(A, axis=1, keepdims=True)
+    ncov = blockwise_dot(A, A.T) / (A.shape[1] - 1)
+
+    return ncov
+
+
+def blockwise_dot(A, B, max_elements=int(2**27)):
+    """
+    Compute the dot product of two matrices in a block-wise fashion.
+
+    Only blocks of `A` with a maximum size of `max_elements` will be
+    processed simultaneously.
+
+    from : https://stackoverflow.com/questions/20983882/efficient-dot-products-of-large-memory-mapped-arrays
+
+    Parameters
+    ----------
+    A : numpy array
+        MxN matrix.
+    B : Numpy array
+        NxO matrix.
+    max_elements : int, optional
+        Maximum number of elements in a block. The default is int(2**27).
+
+    Returns
+    -------
+    out : numpy array
+        Output dot product.
+
+    """
+    m,  n = A.shape
+    n1, o = B.shape
+
+    if n1 != n:
+        raise ValueError('matrices are not aligned')
+
+    if A.flags.f_contiguous:
+        # prioritize processing as many columns of A as possible
+        max_cols = max(1, max_elements // m)
+        max_rows = max_elements // max_cols
+
+    else:
+        # prioritize processing as many rows of A as possible
+        max_rows = max(1, max_elements // n)
+        max_cols = max_elements // max_rows
+
+    out = np.empty((m, o), dtype=np.result_type(A, B))
+
+    for mm in _block_slices(m, max_rows):
+        out[mm, :] = 0
+        for nn in _block_slices(n, max_cols):
+            A_block = A[mm, nn].copy()  # copy to force a read
+            out[mm, :] += np.dot(A_block, B[nn, :])
+            del A_block
+
+    return out
+
+
 def _testfn():
     """Test routine."""
     ifile = r"D:\Workdata\PyGMI Test Data\Remote Sensing\Import\hyperion\EO1H1760802013198110KF_1T.ZIP"
+    ifile = r"D:\Sentinel2\S2B_MSIL2A_20220428T073609_N0400_R092_T36JTN_20220428T105528.zip"
 
-    ncmps = 10
+    ncmps = 5
 
-    dat = get_data(ifile, extscene='Hyperion')
+    dat = get_data(ifile)
 
     pmnf, _ = mnf_calc(dat, ncmps=ncmps, fwdonly=False)
 
-    for i, _ in enumerate(dat): #[0, 5, 10, 13, 14, 15, 20, 25]:
+    for i, _ in enumerate(dat):  # [0, 5, 10, 13, 14, 15, 20, 25]:
         vmax = dat[i].data.max()
         vmin = dat[i].data.min()
 
         plt.figure(dpi=150)
         plt.title('█████████████████Old dat2 band'+str(i))
-        # plt.title(dat[i].dataid)
         plt.imshow(dat[i].data, vmin=vmin, vmax=vmax)
         plt.colorbar()
         plt.show()
@@ -900,31 +1027,33 @@ def _testfn():
 
 
 def _testfn2():
+    import os
     import sys
     from matplotlib import rcParams
+    from pygmi.rsense.iodefs import ImportData
 
     rcParams['figure.dpi'] = 150
 
-    # ifile = r'C:/Workdata/Remote Sensing/Sentinel-2/S2A_MSIL2A_20210305T075811_N0214_R035_T35JML_20210305T103519.zip'
-    # extscene = 'Sentinel-2 Bands Only'
-    ifile = r'C:/Workdata/Remote Sensing/ASTER/PCA Test/AST_05_07XT_20060807_7016_stack.tif'
-    extscene = None
-
-    ifile = r'C:/Workdata/Remote Sensing/Landsat/LC09_L1TP_173080_20211110_20220119_02_T1.tar'
-    # ifile2 = r'C:/Workdata/Remote Sensing/ASTER/PCA Test/AST_05_07XT_20060807_7016_pca.tif'
-
-    dat = get_data(ifile, extscene=extscene)
-    # dat2 = get_data(ifile2, extscene=extscene)
-
-    # pmnf, ev = mnf_calc(dat, ncmps=ncmps, noisetxt='', piter=pbar.iter)
+    ifile = r"D:\Workdata\PyGMI Test Data\Remote Sensing\Import\Sentinel-2\S2A_MSIL2A_20210305T075811_N0214_R035_T35JML_20210305T103519.zip"
 
     app = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
 
-    # tmp = PCA()
-    tmp = MNF()
-    tmp.indata['Raster'] = dat
+    os.chdir(os.path.dirname(ifile))
+
+    tmp = ImportData()
     tmp.settings()
 
+    dat = tmp.outdata['Raster']
+
+    tmp = PCA()
+    # tmp = MNF()
+    tmp.indata['Raster'] = dat
+    try:
+        tmp.settings()
+    except MemoryError:
+        print("error")
+        return
+
     outdat = tmp.outdata['Raster']
 
     for i, dat in enumerate(outdat):
@@ -934,36 +1063,29 @@ def _testfn2():
         vmin = dat.data.mean()-dat.data.std()*2
         vmax = dat.data.mean()+dat.data.std()*2
         plt.imshow(dat.data, vmin=vmin, vmax=vmax)
-        # plt.subplot(122)
-        # plt.title(dat2[i].dataid)
-        # vmin = dat2[i].data.mean()-dat2[i].data.std()*2
-        # vmax = dat2[i].data.mean()+dat2[i].data.std()*2
-        # plt.imshow(dat2[i].data, vmin=vmin, vmax=vmax)
         plt.show()
 
 
 def _testfn3():
     import sys
-    from matplotlib import rcParams
     from pygmi.rsense.iodefs import ImportBatch
 
-    rcParams['figure.dpi'] = 150
-
-    idir = r'e:\WorkProjects\ST-2022-1355 Onshore Mapping\Niger\sentinel_2\full'
+    idir = r'd:\aster'
+    os.chdir(r'D:\\')
 
     app = QtWidgets.QApplication(sys.argv)
 
     tmp1 = ImportBatch()
     tmp1.idir = idir
-    tmp1.settings(True)
+    tmp1.settings()
 
     dat = tmp1.outdata
 
-    tmp2 = PCA()
-    # tmp2 = MNF()
+    # tmp2 = PCA()
+    tmp2 = MNF()
     tmp2.indata = dat
     tmp2.settings()
 
 
 if __name__ == "__main__":
-    _testfn()
+    _testfn2()
