@@ -33,12 +33,13 @@ import os
 import numpy as np
 import numexpr as ne
 from PyQt5 import QtWidgets
+import geopandas as gpd
+from shapely import Polygon, make_valid
 from matplotlib import colormaps
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib import patches
-from osgeo import ogr, osr
 import scipy.spatial.distance as sdist
 
 from pygmi.misc import BasicModule
@@ -51,9 +52,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
         fig = Figure()
         super().__init__(fig)
         if parent is None:
-            self.showprocesslog = print
+            self.showlog = print
         else:
-            self.showprocesslog = parent.showprocesslog
+            self.showlog = parent.showlog
 
         # figure stuff
         self.htype = 'Linear'
@@ -110,6 +111,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
             pxy = idat[:2]
             np1 = idat[3:-1]
             pwidth = self.pwidth*idat[-1]
+
+            # patch = beach(np1, xy=pxy)
+
+            # self.axes.add_collection(patch)
+
             xxx, yyy, xxx2, yyy2 = beachball(np1, pxy[0], pxy[1], pwidth,
                                              self.isgeog)
 
@@ -136,10 +142,10 @@ class BeachBall(BasicModule):
 
         self.mmc = MyMplCanvas(self)
         self.btn_saveshp = QtWidgets.QPushButton('Save Shapefile')
-        self.cbox_alg = QtWidgets.QComboBox()
+        self.cmb_alg = QtWidgets.QComboBox()
         self.dsb_dist = QtWidgets.QDoubleSpinBox()
-        self.radio_geog = QtWidgets.QRadioButton('Geographic Units')
-        self.radio_proj = QtWidgets.QRadioButton('Projected Units')
+        self.rb_geog = QtWidgets.QRadioButton('Geographic Units')
+        self.rb_proj = QtWidgets.QRadioButton('Projected Units')
 
         self.setupui()
 
@@ -168,21 +174,21 @@ class BeachBall(BasicModule):
         alist = sorted(set(alist))
 
         if not alist:
-            self.showprocesslog('Error: no Fault Plane Solutions')
+            self.showlog('Error: no Fault Plane Solutions')
             self.nofps = True
             return False
         self.nofps = False
 
         try:
-            self.cbox_alg.currentIndexChanged.disconnect()
+            self.cmb_alg.currentIndexChanged.disconnect()
         except TypeError:
             pass
 
-        self.cbox_alg.clear()
-        self.cbox_alg.addItems(alist)
+        self.cmb_alg.clear()
+        self.cmb_alg.addItems(alist)
         self.algorithm = alist[0]
 
-        self.cbox_alg.currentIndexChanged.connect(self.change_alg)
+        self.cmb_alg.currentIndexChanged.connect(self.change_alg)
 
         pwidth = 1.
 
@@ -219,27 +225,27 @@ class BeachBall(BasicModule):
         hbl_all = QtWidgets.QHBoxLayout(self)
         mpl_toolbar = NavigationToolbar2QT(self.mmc, self)
         vbl_raster = QtWidgets.QVBoxLayout()
-        label2 = QtWidgets.QLabel('FPS Algorithm:')
-        label3 = QtWidgets.QLabel('Width Scale Factor:')
+        lbl_2 = QtWidgets.QLabel('FPS Algorithm:')
+        lbl_3 = QtWidgets.QLabel('Width Scale Factor:')
 
         self.dsb_dist.setDecimals(4)
         self.dsb_dist.setMinimum(0.0001)
         self.dsb_dist.setSingleStep(0.0001)
         self.dsb_dist.setProperty('value', 0.001)
 
-        self.radio_geog.setChecked(True)
+        self.rb_geog.setChecked(True)
 
         spacer = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum,
                                        QtWidgets.QSizePolicy.Expanding)
 
         self.setWindowTitle('Fault Plane Solution (FPS)')
 
-        vbl_raster.addWidget(label2)
-        vbl_raster.addWidget(self.cbox_alg)
-        vbl_raster.addWidget(label3)
+        vbl_raster.addWidget(lbl_2)
+        vbl_raster.addWidget(self.cmb_alg)
+        vbl_raster.addWidget(lbl_3)
         vbl_raster.addWidget(self.dsb_dist)
-        vbl_raster.addWidget(self.radio_geog)
-        vbl_raster.addWidget(self.radio_proj)
+        vbl_raster.addWidget(self.rb_geog)
+        vbl_raster.addWidget(self.rb_proj)
         vbl_raster.addItem(spacer)
         vbl_raster.addWidget(self.btn_saveshp)
         vbl_right = QtWidgets.QVBoxLayout()
@@ -250,7 +256,7 @@ class BeachBall(BasicModule):
 
         self.btn_saveshp.clicked.connect(self.save_shp)
         self.dsb_dist.valueChanged.connect(self.change_alg)
-        self.radio_geog.toggled.connect(self.change_alg)
+        self.rb_geog.toggled.connect(self.change_alg)
 
     def save_shp(self):
         """
@@ -274,104 +280,59 @@ class BeachBall(BasicModule):
 
         indata = self.mmc.data
 
-        ifile_bnd = self.ifile[:-4]+'_bnd.shp'
         if os.path.isfile(self.ifile):
             tmp = self.ifile[:-4]
             os.remove(tmp+'.shp')
             os.remove(tmp+'.shx')
             os.remove(tmp+'.prj')
             os.remove(tmp+'.dbf')
-        if os.path.isfile(ifile_bnd):
-            tmp = ifile_bnd[:-4]
-            os.remove(tmp+'.shp')
-            os.remove(tmp+'.shx')
-            os.remove(tmp+'.prj')
-            os.remove(tmp+'.dbf')
 
-        driver = ogr.GetDriverByName('ESRI Shapefile')
-        data_source = driver.CreateDataSource(self.ifile)
-        data_source2 = driver.CreateDataSource(ifile_bnd)
-
-        # create the spatial reference, WGS84
-        srs = osr.SpatialReference()
-        srs.ImportFromEPSG(4326)
-        srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-
-        # create the layer
-        layer = data_source.CreateLayer('Fault Plane Solution', srs,
-                                        ogr.wkbPolygon)
-        layer.CreateField(ogr.FieldDefn('Strike', ogr.OFTReal))
-        layer.CreateField(ogr.FieldDefn('Dip', ogr.OFTReal))
-        layer.CreateField(ogr.FieldDefn('Rake', ogr.OFTReal))
-        layer.CreateField(ogr.FieldDefn('Magnitude', ogr.OFTReal))
-        layer.CreateField(ogr.FieldDefn('Quadrant', ogr.OFTString))
-        layer.CreateField(ogr.FieldDefn('Depth', ogr.OFTReal))
-
-        layer2 = data_source2.CreateLayer('Fault Plane Solution Boundaries',
-                                          srs, ogr.wkbPolygon)
-
-        layer2.CreateField(ogr.FieldDefn('Strike', ogr.OFTReal))
-        layer2.CreateField(ogr.FieldDefn('Dip', ogr.OFTReal))
-        layer2.CreateField(ogr.FieldDefn('Rake', ogr.OFTReal))
-        layer2.CreateField(ogr.FieldDefn('Magnitude', ogr.OFTReal))
-        layer2.CreateField(ogr.FieldDefn('Quadrant', ogr.OFTString))
-        layer2.CreateField(ogr.FieldDefn('Depth', ogr.OFTReal))
+        layer = {'Strike': [],
+                 'Dip': [],
+                 'Rake': [],
+                 'Magnitude': [],
+                 'Quadrant': [],
+                 'Depth': [],
+                 'geometry': []}
 
         # Calculate BeachBall
-        for idat in indata:
+        for i, idat in enumerate(indata):
             pxy = idat[:2]
             np1 = idat[3:-1]
             depth = idat[2]
             pwidth = self.mmc.pwidth*idat[-1]
             xxx, yyy, xxx2, yyy2 = beachball(np1, pxy[0], pxy[1], pwidth,
                                              self.mmc.isgeog,
-                                             self.showprocesslog)
+                                             self.showlog)
 
             pvert1 = np.transpose([yyy, xxx])
             pvert0 = np.transpose([xxx2, yyy2])
 
-            # Create Geometry
-            outring = ogr.Geometry(ogr.wkbLinearRing)
-            for i in pvert1:
-                outring.AddPoint(i[0], i[1])
+            poly1 = Polygon(pvert1)
+            poly0 = Polygon(pvert0)
 
-            innerring = ogr.Geometry(ogr.wkbLinearRing)
-            for i in pvert0:
-                innerring.AddPoint(i[0], i[1])
+            poly1 = make_valid(poly1)
+            poly0 = make_valid(poly0)
 
-            poly = ogr.Geometry(ogr.wkbPolygon)
-            poly.AddGeometry(outring)
+            layer['geometry'].append(poly0)
+            layer['Strike'].append(0)
+            layer['Dip'].append(0)
+            layer['Rake'].append(0)
+            layer['Magnitude'].append(0)
+            layer['Depth'].append(depth)
+            layer['Quadrant'].append('Tensional (White)')
 
-            poly1 = ogr.Geometry(ogr.wkbPolygon)
-            poly1.AddGeometry(innerring)
+            layer['geometry'].append(poly1)
+            layer['Strike'].append(np1[0])
+            layer['Dip'].append(np1[1])
+            layer['Rake'].append(np1[2])
+            layer['Magnitude'].append(idat[-1])
+            layer['Depth'].append(depth)
+            layer['Quadrant'].append('Compressional (Colour)')
 
-            feature = ogr.Feature(layer.GetLayerDefn())
-
-            feature.SetField('Strike', np1[0])
-            feature.SetField('Dip', np1[1])
-            feature.SetField('Rake', np1[2])
-            feature.SetField('Magnitude', idat[-1])
-            feature.SetField('Quadrant', 'Compressional')
-            feature.SetField('Depth', depth)
-
-            feature.SetGeometry(poly)
-            # Create the feature in the layer (shapefile)
-            layer.CreateFeature(feature)
-            # Destroy the feature to free resources
-
-            feature2 = ogr.Feature(layer2.GetLayerDefn())
-            feature2.SetField('Quadrant', 'Tensional and Compressional')
-            feature2.SetField('Depth', depth)
-            feature2.SetGeometry(poly1)
-            # Create the feature in the layer (shapefile)
-            layer2.CreateFeature(feature2)
-            layer2.CreateFeature(feature)
-            # Destroy the feature to free resources
-            feature.Destroy()
-            feature2.Destroy()
-
-        data_source.Destroy()
-        data_source2.Destroy()
+        gdf = gpd.GeoDataFrame(layer)
+        gdf = gdf.set_crs(4326)
+        gdf.to_file(self.ifile)
 
         return True
 
@@ -384,7 +345,7 @@ class BeachBall(BasicModule):
         None.
 
         """
-        txt = str(self.cbox_alg.currentText())
+        txt = str(self.cmb_alg.currentText())
         self.algorithm = txt
         data = self.indata[self.stype]
 
@@ -398,7 +359,7 @@ class BeachBall(BasicModule):
                        i['1'].magnitude_1]
                 indata.append(tmp)
 
-        self.mmc.isgeog = self.radio_geog.isChecked()
+        self.mmc.isgeog = self.rb_geog.isChecked()
         self.mmc.data = np.array(indata)
         self.mmc.pwidth = self.dsb_dist.value()
         self.mmc.init_graph()
@@ -419,48 +380,39 @@ class BeachBall(BasicModule):
 
         """
         if self.nofps:
-            self.showprocesslog('Error: no Fault Plane Solutions')
+            self.showlog('Error: no Fault Plane Solutions')
             return False
 
-        self.show()
         QtWidgets.QApplication.processEvents()
-
         self.mmc.init_graph()
+
+        if not nodialog:
+            temp = self.exec()
+
+            if temp == 0:
+                return False
+
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.algorithm)
+        self.saveobj(self.nofps)
+        self.saveobj(self.stype)
+        self.saveobj(self.cmb_alg)
+        self.saveobj(self.dsb_dist)
+        self.saveobj(self.rb_geog)
+        self.saveobj(self.rb_proj)
 
 
-def beachball(fm, centerx, centery, diam, isgeog, showprocesslog=print):
+def beachball(fm, centerx, centery, diam, isgeog, showlog=print):
     """
     Beachball.
 
@@ -493,7 +445,7 @@ def beachball(fm, centerx, centery, diam, isgeog, showprocesslog=print):
         draw beachball with this diameter.
     isgeog : bool
         True if in geographic coordinates, False otherwise.
-    showprocesslog : function, optional
+    showlog : function, optional
         Routine to show text messages. The default is print.
 
     Returns
@@ -584,7 +536,7 @@ def beachball(fm, centerx, centery, diam, isgeog, showprocesslog=print):
     l2 = np.sqrt(d**2/(np.sin(phi)**2 + np.cos(phi)**2 * d**2/m**2))
 
     if D == 0:
-        showprocesslog('Enter a diameter for the beachballs!')
+        showlog('Enter a diameter for the beachballs!')
         return None
 
     inc = 1
@@ -900,3 +852,56 @@ def TDL(AN, BN):
             FL = -FL
 
     return FT, FD, FL
+
+
+def _testfn():
+    """Test routine."""
+    import sys
+    from pygmi.seis.iodefs import ImportSeisan
+
+    app = QtWidgets.QApplication(sys.argv)
+    tmp = ImportSeisan()
+    tmp.ifile = r"D:\workdata\PyGMI Test Data\Seismology\collect2.out"
+    tmp.settings(True)
+
+    outdata = tmp.outdata
+
+    tmp = BeachBall()
+    tmp.indata = outdata
+    tmp.data_init()
+    tmp.settings()
+
+
+def _testfn2():
+    """Test routine."""
+    import matplotlib.pyplot as plt
+
+    np1 = [20.77, 25, 0]
+    # np1 = [150, 87, 1]
+    xxx, yyy, xxx2, yyy2 = beachball(np1, 30, -30, 1, True)
+
+    pvert1 = np.transpose([yyy, xxx])
+    pvert0 = np.transpose([xxx2, yyy2])
+
+    fig = plt.figure()
+    ax = plt.gca()
+    ax.set_aspect('equal')
+
+    xmin = 29
+    xmax = 31
+    ymin = -31
+    ymax = -29
+
+    ax.set_xlim((xmin, xmax))
+    ax.set_ylim((ymin, ymax))
+
+    patch = patches.Polygon(pvert1, edgecolor=(0.0, 0.0, 0.0))
+    ax.add_patch(patch)
+
+    plt.show()
+
+    breakpoint()
+
+
+if __name__ == "__main__":
+    _testfn()
