@@ -31,18 +31,22 @@ menu.
 
 import os
 import numpy as np
-from osgeo import ogr, osr
 from PyQt5 import QtWidgets, QtCore
+import geopandas as gpd
+from shapely.geometry import Polygon
 from scipy.spatial.distance import cdist
 from scipy.stats import linregress
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.patches import Ellipse
-import contextily as ctx
-import pyproj
+from shapelysmooth import catmull_rom_smooth
+from scipy.spatial.distance import pdist
+from scipy.spatial import ConvexHull
 
+from pygmi.vector.dataprep import gridxyz
 from pygmi.misc import ContextModule
+from pygmi.seis.iodefs import importmacro
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
@@ -59,10 +63,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def __init__(self, parent=None):
 
-        fig = Figure()
+        fig = Figure(layout='constrained')
         self.axes = fig.add_subplot(111)
 
         self.ellipses = []
+        self.isolines = None
 
         super().__init__(fig)
 
@@ -156,15 +161,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
             self.ellipses.append(ell.get_verts())
             self.axes.add_artist(ell)
 
-
-        try:
-            ctx.add_basemap(self.axes, crs=pyproj.CRS.from_epsg(4326),
-                            source=ctx.providers.OpenStreetMap.Mapnik)
-        except:
-            print('No internet')
-
-
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_hexbin(self, data1, data2, xlbl='Time', ylbl='ML',
@@ -202,6 +198,10 @@ class MyMplCanvas(FigureCanvasQTAgg):
         x = np.ma.masked_invalid(data1)
         y = np.ma.masked_invalid(data2)
 
+        if y.mask.min() == True or x.mask.min() == True:
+            self.figure.canvas.draw()
+            return
+
         xmin = x.min()
         xmax = x.max()
         ymin = y.min()
@@ -236,7 +236,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         cbar = self.figure.colorbar(hbin[3])
         cbar.set_label('Number of Events')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_hist(self, data1, xlbl='Data Value',
@@ -271,6 +270,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         dattmp = np.array(data1)
         dattmp = dattmp[~np.isnan(dattmp)]
+        if dattmp.size == 0:
+            self.figure.canvas.draw()
+            return
 
         if np.unique(dattmp).size == 1:
             bins = 5
@@ -287,7 +289,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         for tick in self.axes.get_xticklabels():
             tick.set_rotation(90)
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_bvalue(self, data1a, bins='doane'):
@@ -328,6 +329,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
         bins2 = np.round(bins2, 1)  # gets rid of round off error.
 
         num2 = np.cumsum(num[::-1])[::-1]
+
+        if num2[-1] == 0:
+            num2 = num2[:-1]
+            bins2 = bins2[:-1]
+
         num3 = np.log10(num2)
 
         xtmp = bins2[bins2 >= cmax]
@@ -361,7 +367,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         self.axes.legend()
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_pres(self, data1, phase='P'):
@@ -395,10 +400,12 @@ class MyMplCanvas(FigureCanvasQTAgg):
         pid = pid[~np.isnan(tres)]
         tres = tres[~np.isnan(tres)].astype(float)
 
+        pid = np.char.strip(pid)
+
         if phase == 'P':
-            ptres = tres[pid == 'P   ']
+            ptres = tres[pid == 'P']
         else:
-            ptres = tres[pid == 'S   ']
+            ptres = tres[pid == 'S']
 
         txt = 'mean: '+str(np.around(ptres.mean(), 3))
         txt += '\nstd: '+str(np.around(ptres.std(), 3))
@@ -409,7 +416,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.set_xlabel('Time Residual (seconds)')
         self.axes.set_ylabel('Frequency (%)')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_residual(self, dat, res='ML'):
@@ -440,17 +446,22 @@ class MyMplCanvas(FigureCanvasQTAgg):
             A1 = {}
             T1 = {}
             for rec in event['4']:
-                if (rec.quality+rec.phase_id).strip() in ['IAML', 'AML',
-                                                          'ES', 'E']:
+                i = rec.station_name
+                if rec.magnitude is not None:
+                    if i not in A:
+                        A[i] = []
+                    A[i].append(rec.magnitude_residual)
+                elif (rec.quality+rec.phase_id).strip() in ['IAML', 'AML',
+                                                            'ES', 'E']:
                     if (rec.amplitude is None or
                             rec.epicentral_distance is None):
                         continue
                     ML = (np.log10(rec.amplitude) +
                           1.149*np.log10(rec.epicentral_distance) +
                           0.00063*rec.epicentral_distance-2.04)
-                    A1[rec.station_name] = ML
+                    A1[i] = ML
                 if rec.travel_time_residual is not None:
-                    T1[rec.station_name] = rec.travel_time_residual
+                    T1[i] = rec.travel_time_residual
             if A1:
                 if np.nonzero(~np.isnan(list(A1.values())))[0].size == 0:
                     A1mean = 0
@@ -469,11 +480,12 @@ class MyMplCanvas(FigureCanvasQTAgg):
         dmean = {}
         dstd = {}
 
-        sname_list = list(A.keys())
-
         if res != 'ML':
             A = T
 
+        sname_list = list(A.keys())
+        sname_list.sort()
+
         for j, i in enumerate(sname_list):
             if np.nonzero(~np.isnan(A[i]))[0].size == 0:
                 continue
@@ -490,7 +502,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         else:
             self.axes.set_ylabel('ML-mean(ML)')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
     def update_wadati(self, dat, min_wad=5, min_vps=1.53,
@@ -528,9 +539,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
                 if rec.weighting_indicator == 9:
                     continue
                 time = rec.hour*3600+rec.minutes*60+rec.seconds
-                if rec.phase_id == 'P   ':
+                if rec.phase_id.strip() == 'P':
                     P[rec.station_name] = time
-                if rec.phase_id == 'S   ':
+                if rec.phase_id.strip() == 'S':
                     S[rec.station_name] = time
 
             # Make sure P and S times are from same stations
@@ -575,9 +586,115 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.set_xlabel('P Time (seconds)')
         self.axes.set_ylabel('S-P Time (seconds)')
 
-        self.figure.tight_layout()
         self.figure.canvas.draw()
 
+    def update_isohull(self, datd):
+        """
+        Update isoseismic plot using convex hull method.
+
+        Parameters
+        ----------
+        datd : GeoDatFrame
+            Macroseismic data.
+
+        Returns
+        -------
+        None.
+
+        """
+        df1 = datd
+
+        x = df1.lon.to_numpy()
+        y = df1.lat.to_numpy()
+        z = df1.intensity.to_numpy()
+
+        plist = []
+        uvals = np.sort(df1.intensity.unique())
+
+        for i in uvals:
+            df2 = df1[df1.intensity >= i]
+            hull = df2.unary_union.convex_hull
+            hull = catmull_rom_smooth(hull)
+
+            plist.append(hull)
+            if len(plist) > 1:
+                plist[-2] = plist[-2].difference(hull)
+
+        gdf = gpd.GeoDataFrame({"Intensity": uvals}, geometry=plist)
+
+        self.figure.clear()
+        self.axes = self.figure.add_subplot(111)
+        self.axes.plot(x, y, 'k.')
+
+        gdf.plot(ax=self.axes, column='Intensity', legend=True, edgecolor='k',
+                 legend_kwds={'label': 'Intensity'})
+
+        self.figure.canvas.draw()
+
+        self.isolines = gdf
+
+    def update_isocontour(self, datd):
+        """
+        Update isoseismic plot using contours.
+
+        Parameters
+        ----------
+        datd : GeoDatFrame
+            Macroseismic data.
+
+        Returns
+        -------
+        None.
+
+        """
+        df1 = datd
+
+        x = df1.lon.to_numpy()
+        y = df1.lat.to_numpy()
+        z = df1.intensity.to_numpy()
+        uvals = np.sort(df1.intensity.unique())
+
+        X = np.transpose([x, y])
+        X = np.unique(X, axis=0)
+        r = pdist(X)
+        dxy = np.percentile(r, 10) / 10
+
+        dat = gridxyz(x, y, z, dxy, method='Linear', bdist=None)
+
+        xmin, xmax, ymin, ymax = dat.extent
+        rows, cols = dat.data.shape
+
+        xi = np.linspace(xmin, xmax, cols, endpoint=False) + dxy/2
+        yi = np.linspace(ymin, ymax, rows, endpoint=False) + dxy/2
+
+        xi, yi = np.meshgrid(xi, yi)
+        zi = dat.data
+
+        self.figure.clear()
+        self.axes = self.figure.add_subplot(111)
+
+        self.axes.plot(x, y, 'k.')
+
+        zi = zi[::-1]+0.0001
+        cntr1 = self.axes.contour(xi, yi, zi, levels=uvals, colors='k')
+        cntr = self.axes.contourf(xi, yi, zi, levels=uvals, extend='max')
+
+        self.figure.colorbar(cntr)
+        self.figure.canvas.draw()
+
+        pnts = np.transpose([x, y])
+        hull0 = ConvexHull(pnts)
+        gdict = {'Intensity': [0], 'geometry': [Polygon(pnts[hull0.vertices])]}
+
+        plist, pvals = contourtopoly(cntr1)
+
+        gdict['Intensity'] += pvals
+        gdict['geometry'] += plist
+
+        gdf = gpd.GeoDataFrame(gdict)
+
+        self.isolines = gdf
+
 
 class GraphWindow(ContextModule):
     """Graph Window - The QDialog window which will contain our image."""
@@ -595,14 +712,14 @@ class GraphWindow(ContextModule):
 
         self.btn_saveshp = QtWidgets.QPushButton('Save Shapefile')
 
-        self.combobox1 = QtWidgets.QComboBox()
-        self.combobox2 = QtWidgets.QComboBox()
-        self.label1 = QtWidgets.QLabel('Bands:')
-        self.label2 = QtWidgets.QLabel('Bands:')
-        self.hbl.addWidget(self.label1)
-        self.hbl.addWidget(self.combobox1)
-        self.hbl.addWidget(self.label2)
-        self.hbl.addWidget(self.combobox2)
+        self.cmb_1 = QtWidgets.QComboBox()
+        self.cmb_2 = QtWidgets.QComboBox()
+        self.lbl_1 = QtWidgets.QLabel('Bands:')
+        self.lbl_2 = QtWidgets.QLabel('Bands:')
+        self.hbl.addWidget(self.lbl_1)
+        self.hbl.addWidget(self.cmb_1)
+        self.hbl.addWidget(self.lbl_2)
+        self.hbl.addWidget(self.cmb_2)
 
         vbl.addWidget(self.mmc)
         vbl.addWidget(mpl_toolbar)
@@ -611,8 +728,8 @@ class GraphWindow(ContextModule):
 
         self.setFocus()
 
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
+        self.cmb_1.currentIndexChanged.connect(self.change_band)
+        self.cmb_2.currentIndexChanged.connect(self.change_band)
         self.btn_saveshp.clicked.connect(self.save_shp)
 
     def change_band(self):
@@ -642,17 +759,17 @@ class PlotQC(GraphWindow):
 
     Attributes
     ----------
-    label2 : QLabel
-        reference to GraphWindow's label2
-    combobox2 : QComboBox
-        reference to GraphWindow's combobox2
+    lbl_2 : QLabel
+        reference to GraphWindow's lbl_2
+    cmb_2 : QComboBox
+        reference to GraphWindow's cmb_2
     """
 
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.label2.hide()
-        self.combobox2.hide()
+        self.lbl_2.hide()
+        self.cmb_2.hide()
         self.datd = None
 
     def change_band(self):
@@ -666,7 +783,7 @@ class PlotQC(GraphWindow):
         """
         self.btn_saveshp.hide()
 
-        i = self.combobox1.currentText()
+        i = self.cmb_1.currentText()
         if i == 'Hour Histogram':
             self.mmc.update_hist(self.datd['1_hour'], 'Hour', bins=24,
                                  rng=(-0.5, 23.5))
@@ -674,21 +791,26 @@ class PlotQC(GraphWindow):
             self.mmc.update_hist(self.datd['1_month'], 'Month', bins=12,
                                  rng=(0.5, 12.5))
         elif i == 'Year Histogram':
-            bins = np.unique(self.datd['1_year']).size
+            bins = max(self.datd['1_year']) - min(self.datd['1_year']) + 1
             bmin = np.nanmin(self.datd['1_year'])-0.5
             bmax = np.nanmax(self.datd['1_year'])+0.5
             self.mmc.update_hist(self.datd['1_year'], 'Year', bins=bins,
                                  rng=(bmin, bmax))
         elif i == 'Number of Stations':
+            if np.isnan(self.datd['1_number_of_stations_used']).all():
+                bmin = 0.5
+                bmax = 1.5
+            else:
+                bmin = np.nanmin(self.datd['1_number_of_stations_used']) + 0.5
+                bmax = np.nanmax(self.datd['1_number_of_stations_used']) + 1.5
+
             bins = np.unique(self.datd['1_number_of_stations_used']).size
-            bmin = np.nanmin(self.datd['1_number_of_stations_used'])+0.5
-            bmax = np.nanmax(self.datd['1_number_of_stations_used'])+1.5
+
             self.mmc.update_hist(self.datd['1_number_of_stations_used'],
                                  i, bins=bins, rng=(bmin, bmax))
-
         elif i == 'RMS of time residuals':
             rts = np.array(self.datd['1_rms_of_time_residuals'])
-            self.mmc.update_hist(rts, i)
+            self.mmc.update_hist(rts, i+' (sec)')
         elif i == 'ML vs Time':
             self.mmc.update_hexbin(self.datd['1_ML_time'], self.datd['1_ML'],
                                    'Time (Hours)', 'ML',
@@ -703,11 +825,11 @@ class PlotQC(GraphWindow):
             self.btn_saveshp.show()
             self.mmc.update_ellipse(self.datd, self.indata['Seis'], True)
         elif i == 'GAP':
-            self.mmc.update_hist(self.datd['E_gap'], i)
+            self.mmc.update_hist(self.datd['E_gap'], i+' (°)')
         elif i == 'Longitude Error':
-            self.mmc.update_hist(self.datd['E_longitude_error'], i)
+            self.mmc.update_hist(self.datd['E_longitude_error'], i+' (km)')
         elif i == 'Latitude Error':
-            self.mmc.update_hist(self.datd['E_latitude_error'], i)
+            self.mmc.update_hist(self.datd['E_latitude_error'], i+' (km)')
         elif i == 'b-Value':
             self.mmc.update_bvalue(self.datd['1_ML'])
         elif i == 'P-Phase Residuals':
@@ -735,7 +857,7 @@ class PlotQC(GraphWindow):
         self.datd = import_for_plots(data)
 
         if not self.datd:
-            self.showprocesslog('There is no compatible data in the file')
+            self.showlog('There is no compatible data in the file')
             return
 
         products = ['Hour Histogram',
@@ -760,10 +882,10 @@ class PlotQC(GraphWindow):
                          'Wadati']
 
         for i in products:
-            self.combobox1.addItem(i)
+            self.cmb_1.addItem(i)
 
-        self.label1.setText('Product:')
-        self.combobox1.setCurrentIndex(0)
+        self.lbl_1.setText('Product:')
+        self.cmb_1.setCurrentIndex(0)
         self.change_band()
 
     def save_shp(self):
@@ -793,43 +915,147 @@ class PlotQC(GraphWindow):
             os.remove(tmp+'.prj')
             os.remove(tmp+'.dbf')
 
-        driver = ogr.GetDriverByName('ESRI Shapefile')
-        data_source = driver.CreateDataSource(ifile)
-
-        # create the spatial reference, WGS84
-        srs = osr.SpatialReference()
-        srs.ImportFromEPSG(4326)
-        srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-
-        # create the layer
-        layer = data_source.CreateLayer('Fault Plane Solution', srs,
-                                        ogr.wkbPolygon)
-
-        # Calculate BeachBall
         indata = self.mmc.ellipses
-        for pvert in indata:
-            # Create Geometry
-            outring = ogr.Geometry(ogr.wkbLinearRing)
-            for i in pvert:
-                outring.AddPoint(i[0], i[1])
+        geom = [Polygon(i) for i in indata]
 
-            poly = ogr.Geometry(ogr.wkbPolygon)
-            poly.AddGeometry(outring)
+        gdict = {'geometry': geom}
 
-            feature = ogr.Feature(layer.GetLayerDefn())
+        gdf = gpd.GeoDataFrame(gdict)
+        gdf = gdf.set_crs(4326)
 
-            feature.SetGeometry(poly)
-            # Create the feature in the layer (shapefile)
-            layer.CreateFeature(feature)
-            # Destroy the feature to free resources
-
-            feature.Destroy()
-
-        data_source.Destroy()
+        gdf.to_file(filename)
 
         return True
 
 
+class PlotIso(GraphWindow):
+    """
+    Plot Hist Class.
+
+    Attributes
+    ----------
+    lbl_2 : QLabel
+        reference to GraphWindow's lbl_2
+    cmb_2 : QComboBox
+        reference to GraphWindow's cmb_2
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+
+        self.lbl_2.hide()
+        self.cmb_2.hide()
+        self.datd = None
+
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        i = self.cmb_1.currentText()
+        if i == 'Convex Hull Method':
+            self.mmc.update_isohull(self.datd)
+        elif i == 'Standard Contours':
+            self.mmc.update_isocontour(self.datd)
+
+    def run(self):
+        """
+        Entry point to run routine.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.show()
+        self.datd = self.indata['MacroSeis']
+
+        products = ['Convex Hull Method',
+                    'Standard Contours']
+
+        for i in products:
+            self.cmb_1.addItem(i)
+
+        self.lbl_1.setText('Product:')
+        self.cmb_1.setCurrentIndex(0)
+        self.change_band()
+
+    def save_shp(self):
+        """
+        Save shapefile.
+
+        Returns
+        -------
+        bool
+            True if successful, False otherwise.
+
+        """
+        ext = 'Shape file (*.shp)'
+
+        filename, _ = QtWidgets.QFileDialog.getSaveFileName(
+            self.parent, 'Save Shape File', '.', ext)
+        if filename == '':
+            return False
+        os.chdir(os.path.dirname(filename))
+
+        ifile = str(filename)
+
+        if os.path.isfile(ifile):
+            tmp = ifile[:-4]
+            os.remove(tmp+'.shp')
+            os.remove(tmp+'.shx')
+            os.remove(tmp+'.prj')
+            os.remove(tmp+'.dbf')
+
+        gdf = self.mmc.isolines
+        gdf = gdf.set_crs(4326)
+
+        gdf.to_file(filename)
+
+        return True
+
+
+def contourtopoly(cntr):
+    """
+    Convert Matplotlib contours to Polygons.
+
+    Parameters
+    ----------
+    cntr : Matplotlib countour
+        Contour collection.
+
+    Returns
+    -------
+    plist : list
+        List of Polygon objects.
+
+    """
+    plist = []
+    pvals = []
+    vals = cntr.levels
+    for i, path in enumerate(cntr.get_paths()):
+        val = vals[i]
+        if path.to_polygons():
+            poly = None
+            for polypoints in path.to_polygons():
+                x = polypoints[:, 0]
+                y = polypoints[:, 1]
+
+                poly = Polygon([coords for coords in zip(x, y)])
+
+                if not poly.is_valid:
+                    poly = poly.buffer(0.)
+
+                plist.append(poly)
+                pvals.append(val)
+
+    return plist, pvals
+
+
 def import_for_plots(dat):
     """
     Import data to plot.
@@ -917,6 +1143,124 @@ def eigsorted(cov):
     return vals[order], vecs[:, order]
 
 
+def _testiso():
+    """Test creation of isoseismal maps."""
+    import matplotlib.pyplot as plt
+    import matplotlib.tri as tri
+    from scipy.spatial.distance import pdist
+    from pygmi.vector.dataprep import gridxyz
+    from shapelysmooth import catmull_rom_smooth
+    import rasterio as rio
+    from contourpy import contour_generator
+    from scipy.spatial import ConvexHull
+
+    ifile = r"D:\Workdata\seismology\macro\2015-12-02-0714-54.macro"
+
+    df1 = importmacro(ifile)
+
+    x = df1.lon.to_numpy()
+    y = df1.lat.to_numpy()
+    z = df1.intensity.to_numpy()
+
+    uvals = np.sort(df1.intensity.unique())
+
+    # Tricontour plot
+    # plt.figure(dpi=150)
+    # ax = plt.gca()
+    # plt.plot(x, y, '.')
+
+    # cntr1t = ax.tricontour(x, y, z, levels=uvals, colors='k')
+    # cntr = ax.tricontourf(x, y, z, levels=uvals)
+    # # ax.clabel(cntr1t, inline=True)
+    # plt.colorbar(cntr)
+
+    # plt.show()
+
+    # Using linear interpolation
+    X = np.transpose([x, y])
+    r = pdist(X)
+    dxy = r.min() / 10
+
+    dat = gridxyz(x, y, z, dxy, method='Linear', bdist=None)
+
+    xmin, xmax, ymin, ymax = dat.extent
+    rows, cols = dat.data.shape
+
+    xi = np.linspace(xmin, xmax, cols, endpoint=False) + dxy/2
+    yi = np.linspace(ymin, ymax, rows, endpoint=False) + dxy/2
+
+    xi, yi = np.meshgrid(xi, yi)
+    zi = dat.data
+
+    plt.figure(dpi=150)
+    ax = plt.gca()
+
+    plt.plot(x, y, '.')
+
+    zi = zi[::-1]+0.0001
+    cntr1 = ax.contour(xi, yi, zi, levels=uvals, colors='k',
+                       algorithm='serial')
+    cntr = ax.contourf(xi, yi, zi, levels=uvals, algorithm='serial')
+    # ax.clabel(cntr1, inline=True)
+
+    plt.colorbar(cntr)
+    plt.show()
+
+    # New method using rasterio
+    # plist = []
+
+    # for i in uvals:
+    #     df2 = df1[df1.intensity >= i]
+    #     hull = df2.unary_union.convex_hull
+    #     hull = catmull_rom_smooth(hull)
+
+    #     plist.append(hull)
+    #     if len(plist) > 1:
+    #         plist[-2] = plist[-2].difference(hull)
+
+    # gdf = gpd.GeoDataFrame({"Intensity": uvals}, geometry=plist)
+
+    # plt.figure(dpi=250)
+    # ax = plt.gca()
+    # plt.plot(x, y, '.')
+    # gdf.plot(ax=ax, column='Intensity', legend=True,
+    #          legend_kwds={'label': 'Intensity'})
+    # plt.show()
+
+    # contour tests
+
+    # plist = contourtopoly(cntr)
+    # gdf = gpd.GeoDataFrame({"Intensity": cntr.levels[:-1]}, geometry=plist)
+
+    # ax = plt.gca()
+    # plt.plot(x, y, '.')
+
+    # gdf.plot(ax=ax, column='Intensity', legend=True, edgecolor='k',
+    #          legend_kwds={'label': 'Intensity'})
+
+    # plt.show()
+
+    pnts = np.transpose([x, y])
+    hull0 = ConvexHull(pnts)
+    gdict = {'Intensity': [0], 'geometry': [Polygon(pnts[hull0.vertices])]}
+
+    plist, pvals = contourtopoly(cntr1)
+
+    gdict['Intensity'] += pvals
+    gdict['geometry'] += plist
+
+    gdf = gpd.GeoDataFrame(gdict)
+
+    plt.figure(dpi=250)
+    ax = plt.gca()
+    plt.plot(x, y, '.')
+    gdf.plot(ax=ax, column='Intensity', legend=True, edgecolor='k',
+             facecolor='none', legend_kwds={'label': 'Intensity'})
+    plt.show()
+
+    breakpoint()
+
+
 def _testfn():
     """Test routine."""
     import sys
@@ -924,66 +1268,23 @@ def _testfn():
 
     app = QtWidgets.QApplication(sys.argv)
     tmp = ImportSeisan()
-    tmp.ifile = r"D:\Workdata\PyGMI Test Data\Sesimology\collect2.out"
+    # tmp.ifile = r"D:\Workdata\PyGMI Test Data\Seismology\collect 7.out"
+    tmp.ifile = r"E:\Workdata\seismology\seiscomp\events.txt"
+
     tmp.settings(True)
 
-    data = tmp.outdata['Seis']
+    data = tmp.outdata
 
-    dat = import_for_plots(data)
+    # dat = import_for_plots(data)
 
+    # tmp = PlotIso()
     tmp = PlotQC()
-    tmp.indata['Seis'] = data
+    tmp.indata = data
     tmp.run()
-    tmp.exec_()
 
-
-def _testfn2():
-    """Test for wave files."""
-    import sys
-    import matplotlib.pyplot as plt
-    from pygmi.seis.iodefs import ImportSeisan
-
-    ifile = r'D:\Workdata\seismology\april2021\collect.out'
-
-    app = QtWidgets.QApplication(sys.argv)
-    tmp = ImportSeisan()
-    tmp.ifile = ifile
-    tmp.settings(True)
-
-    data = tmp.outdata['Seis']
-
-    ifile = r'D:\Workdata\seismology\april2021\mulplt.wav'
-
-    with open(ifile, encoding='utf-8') as pntfile:
-        ltmp = pntfile.read()
-
-    ltmp = ltmp.split('\n')
-
-    l1 = ltmp.pop(0)
-    l2 = ltmp.pop(0)
-
-    while len(ltmp) > 2:
-        h1 = ltmp.pop(0)
-        h2 = ltmp.pop(0).split()
-
-        samples = int(h2[0])
-        rate = float(h2[1])
-        comp = h2[5]
-        year = h2[6]
-        month = h2[7]
-        day = h2[8]
-
-        lines = samples // 7 + 1
-        y = ''.join(ltmp[:lines]).split()
-        y = np.array(y, dtype=float)
-        x = np.arange(0, samples*rate, rate)
-
-        ltmp = ltmp[lines:]
-
-        plt.title(comp)
-        plt.plot(x, y)
-        plt.show()
+    app.exec()
 
 
 if __name__ == "__main__":
     _testfn()
+    # _testiso()
