@@ -50,12 +50,13 @@ class MenuWidget():
 
         self.parent = parent
         self.parent.add_to_context('Seis')
+        self.parent.add_to_context('MacroSeis')
         context_menu = self.parent.context_menu
 
         self.menu = QtWidgets.QMenu('Seismology')
         parent.menubar.addAction(self.menu.menuAction())
 
-        self.action_import_seisan = QtWidgets.QAction('Import SEISAN Data')
+        self.action_import_seisan = QtWidgets.QAction('Import Seismic Data')
         self.menu.addAction(self.action_import_seisan)
         self.action_import_seisan.triggered.connect(self.import_seisan)
 
@@ -86,6 +87,12 @@ class MenuWidget():
 
         # Context menus
 
+        context_menu['MacroSeis'].addSeparator()
+
+        self.action_show_iso_plots = QtWidgets.QAction('Show Isoseismic Plots')
+        context_menu['MacroSeis'].addAction(self.action_show_iso_plots)
+        self.action_show_iso_plots.triggered.connect(self.show_iso_plots)
+
         context_menu['Seis'].addSeparator()
 
         self.action_show_QC_plots = QtWidgets.QAction('Show QC Plots')
@@ -123,8 +130,8 @@ class MenuWidget():
                                 beachball.BeachBall)
 
     def import_seisan(self):
-        """Import Seisan."""
-        self.parent.item_insert('Io', 'Import SEISAN Data',
+        """Import Seismic data."""
+        self.parent.item_insert('Io', 'Import Seismic Data',
                                 iodefs.ImportSeisan)
 
     def correct_desc(self):
@@ -153,3 +160,7 @@ class MenuWidget():
     def show_QC_plots(self):
         """Show QC plots."""
         self.parent.launch_context_item(graphs.PlotQC)
+
+    def show_iso_plots(self):
+        """Show QC plots."""
+        self.parent.launch_context_item(graphs.PlotIso)
