@@ -45,7 +45,7 @@ class CorrectDescriptions(BasicModule):
         idir = os.path.dirname(os.path.realpath(__file__))
         tfile = os.path.join(idir, r'descriptions.txt')
 
-        self.textfile = QtWidgets.QLineEdit(tfile)
+        self.le_textfile = QtWidgets.QLineEdit(tfile)
 
         self.setupui()
 
@@ -58,9 +58,8 @@ class CorrectDescriptions(BasicModule):
         None.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
+        gl_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
-        # helpdocs = menu_default.HelpButton('pygmi.seis.utils.cordesc')
         pb_textfile = QtWidgets.QPushButton('Load Description List')
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
@@ -69,11 +68,10 @@ class CorrectDescriptions(BasicModule):
 
         self.setWindowTitle(r'Correct Descriptions')
 
-        gridlayout_main.addWidget(self.textfile, 0, 0, 1, 1)
-        gridlayout_main.addWidget(pb_textfile, 0, 1, 1, 1)
+        gl_main.addWidget(self.le_textfile, 0, 0, 1, 1)
+        gl_main.addWidget(pb_textfile, 0, 1, 1, 1)
 
-        # gridlayout_main.addWidget(helpdocs, 5, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 5, 1, 1, 3)
+        gl_main.addWidget(buttonbox, 5, 1, 1, 3)
 
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -93,7 +91,7 @@ class CorrectDescriptions(BasicModule):
         None.
 
         """
-        ext = ('Description list (*.txt)')
+        ext = 'Description list (*.txt)'
 
         if filename == '':
             filename, _ = QtWidgets.QFileDialog.getOpenFileName(
@@ -101,7 +99,7 @@ class CorrectDescriptions(BasicModule):
             if filename == '':
                 return
 
-        self.textfile.setText(filename)
+        self.le_textfile.setText(filename)
 
     def settings(self, nodialog=False):
         """
@@ -121,7 +119,7 @@ class CorrectDescriptions(BasicModule):
         if 'Seis' not in self.indata:
             return False
 
-        tmp = self.exec_()
+        tmp = self.exec()
 
         if tmp != 1:
             return False
@@ -130,36 +128,16 @@ class CorrectDescriptions(BasicModule):
 
         return True
 
-    def loadproj(self, projdata):
-        """
-        Load project data into class.
-
-        Parameters
-        ----------
-        projdata : dictionary
-            Project data loaded from JSON project file.
-
-        Returns
-        -------
-        chk : bool
-            A check to see if settings was successfully run.
-
-        """
-        return False
-
     def saveproj(self):
         """
         Save project data from class.
 
         Returns
         -------
-        projdata : dictionary
-            Project data to be saved to JSON project file.
+        None.
 
         """
-        projdata = {}
-
-        return projdata
+        self.saveobj(self.le_textfile)
 
     def acceptall(self):
         """
@@ -172,7 +150,7 @@ class CorrectDescriptions(BasicModule):
         None.
 
         """
-        filename = self.textfile.text()
+        filename = self.le_textfile.text()
         with open(filename, encoding='utf-8') as fno:
             tmp = fno.read()
 
@@ -192,12 +170,10 @@ class CorrectDescriptions(BasicModule):
             if cmatch:
                 cmatch = cmatch[0]
             else:
-                # self.showprocesslog('No match found for '+text)
                 nomatch.append(text)
                 continue
 
             if cmatch != text:
-                # self.showprocesslog('Correcting '+text+' to '+cmatch)
                 correction.append(text+' to '+cmatch)
                 i['3'].region = cmatch
 
