@@ -33,12 +33,13 @@ import sys
 import tempfile
 from PyQt5 import QtWidgets
 import numpy as np
-from rasterio.crs import CRS
+from pyproj.crs import CRS
 import pytest
 
 from pygmi.raster.datatypes import Data
 from pygmi.raster import cooper, dataprep, equation_editor, ginterp, graphs
 from pygmi.raster import iodefs, normalisation, smooth
+from pygmi.raster.misc import aspect2
 
 APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
 
@@ -86,6 +87,7 @@ def test_viz():
              [2.613125929752753, 2.613125929752753]]
     vtot, vstd, vsum = cooper.visibility2d(datin, 1, 0)
 
+    # breakpoint()
     np.testing.assert_array_equal(vtot, vtot2)
     np.testing.assert_array_equal(vstd, vstd2)
     np.testing.assert_array_equal(vsum, vsum2)
@@ -159,7 +161,7 @@ def test_aspect():
              [0., 0., 0., 0.],
              [0., 0., 0., 0.]]]
 
-    dat = ginterp.aspect2(data)
+    dat = aspect2(data)
 
     np.testing.assert_array_equal(dat, dat2)
 
@@ -305,6 +307,7 @@ def test_corr2d():
 def smalldata():
     """Small test dataset."""
     dat = Data()
+    dat.dataid = 'test'
     dat.data = np.ma.array([[29000., 29000.], [29000., 29000.]],
                            mask=[[0, 0], [0, 0]])
     dat.set_transform(1, 25, 1, -27)
@@ -373,25 +376,25 @@ def test_normalisation():
 
     tmp = normalisation.Normalisation(None)
     tmp.indata = {'Raster': [datin, datin]}
-    tmp.radiobutton_interval.setChecked(True)
+    tmp.rb_interval.setChecked(True)
     tmp.settings(True)
     datout = np.ma.array([[0., 1.], [0., 1.]])
 
     np.testing.assert_array_equal(tmp.outdata['Raster'][0].data, datout)
 
-    tmp.radiobutton_mean.setChecked(True)
+    tmp.rb_mean.setChecked(True)
     tmp.settings(True)
     datout = np.ma.array([[-1., 1.], [-1., 1.]])
 
     np.testing.assert_array_equal(tmp.outdata['Raster'][0].data, datout)
 
-    tmp.radiobutton_median.setChecked(True)
+    tmp.rb_median.setChecked(True)
     tmp.settings(True)
     datout = np.ma.array([[-1., 1.], [-1., 1.]])
 
     np.testing.assert_array_equal(tmp.outdata['Raster'][0].data, datout)
 
-    tmp.radiobutton_8bit.setChecked(True)
+    tmp.rb_8bit.setChecked(True)
     tmp.settings(True)
 
     datout = np.ma.array([[0., 255.], [0., 255.]])
@@ -408,8 +411,8 @@ def test_smooth():
     tmp = smooth.Smooth(None)
     tmp.indata = {'Raster': [datin]}
 
-    tmp.radiobutton_2dmean.setChecked(True)
-    tmp.radiobutton_box.setChecked(True)
+    tmp.rb_2dmean.setChecked(True)
+    tmp.rb_box.setChecked(True)
     tmp.choosefilter()
     tmp.settings(True)
     datout2 = tmp.outdata['Raster'][0].data.data
@@ -424,7 +427,7 @@ def test_smooth():
 
     np.testing.assert_array_almost_equal(datout2, datout)
 
-    tmp.radiobutton_disk.setChecked(True)
+    tmp.rb_disk.setChecked(True)
     tmp.choosefilter()
     tmp.settings(True)
     datout2 = tmp.outdata['Raster'][0].data.data
@@ -446,7 +449,7 @@ def test_smooth():
 
     np.testing.assert_array_almost_equal(datout2, datout)
 
-    tmp.radiobutton_gaussian.setChecked(True)
+    tmp.rb_gaussian.setChecked(True)
     tmp.choosefilter()
     tmp.settings(True)
 
@@ -466,8 +469,8 @@ def test_smooth():
 
     np.testing.assert_array_almost_equal(datout2, datout)
 
-    tmp.radiobutton_2dmedian.setChecked(True)
-    tmp.radiobutton_box.setChecked(True)
+    tmp.rb_2dmedian.setChecked(True)
+    tmp.rb_box.setChecked(True)
     tmp.choosefilter()
     tmp.settings(True)
     datout2 = tmp.outdata['Raster'][0].data.data
@@ -482,7 +485,7 @@ def test_smooth():
 
     np.testing.assert_array_almost_equal(datout2, datout)
 
-    tmp.radiobutton_disk.setChecked(True)
+    tmp.rb_disk.setChecked(True)
     tmp.choosefilter()
     tmp.settings(True)
     datout2 = tmp.outdata['Raster'][0].data.data
@@ -545,4 +548,11 @@ def test_agc():
 
 
 if __name__ == "__main__":
-    test_vertical()
+    # dat = Data()
+    # dat.data = np.ma.array([[29000., 29000.], [29000., 29000.]],
+    #                        mask=[[0, 0], [0, 0]])
+    # dat.dataid = 'test'
+    # dat.set_transform(1, 25, 1, -27)
+    # dat.crs = CRS.from_epsg(4326)
+    # test_io_ascii(dat)
+    test_viz()
