@@ -38,7 +38,7 @@ from scipy.interpolate import griddata
 from scipy.ndimage import distance_transform_edt
 
 
-def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
+def minc(x, y, z, dxy, showlog=print, extent=None, bdist=None,
          maxiters=100):
     """
     Minimum Curvature Gridding.
@@ -53,7 +53,7 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
         1D array with z coordinates.
     dxy : float
         Cell x and y dimension.
-    showprocesslog : function, optional
+    showlog : function, optional
         Routine to show text messages. The default is print.
     extent : list, optional
         Extent defined as (left, right, bottom, top). The default is None.
@@ -85,7 +85,7 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
 
     extent = np.array(extent)
 
-    showprocesslog('Setting up grid...')
+    showlog('Setting up grid...')
 
     # Add buffer
     extent[0] -= dxy*3
@@ -93,23 +93,19 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
     extent[2] -= dxy*3
     extent[3] += dxy*3
 
-    rows = int((extent[3] - extent[2])/dxy+1)
-    cols = int((extent[1] - extent[0])/dxy+1)
-
-    dxy1 = dxy
-    for mult in [4, 2, 1]:
-        dxy = dxy1*mult
-
     # Make new start grid
 
-    xxx = np.linspace(extent[0], extent[1], cols)
-    yyy = np.linspace(extent[2], extent[3], rows)
+    xxx = np.arange(extent[0], extent[1]+dxy/2, dxy)
+    yyy = np.arange(extent[2], extent[3]+dxy/2, dxy)
+
     xxx, yyy = np.meshgrid(xxx, yyy)
+    rows, cols = xxx.shape
 
     points = np.transpose([x.flatten(), y.flatten()])
 
-    showprocesslog('Creating nearest neighbour starting value...')
+    showlog('Creating nearest neighbour starting value...')
 
+    # u = griddata(points, z, (xxx, yyy), method='linear')
     u = griddata(points, z, (xxx, yyy), method='nearest')
     u = u[::-1]
 
@@ -120,7 +116,7 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
     y2 = y.flatten()
     z2 = z.flatten()
 
-    showprocesslog('Organizing input data...')
+    showlog('Organizing input data...')
 
     crds, blist = morg(x2, y2, z2, extent, dxy, rows, cols)
 
@@ -145,7 +141,7 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
         coords[iint, jint].append([bmax, r, zval, b])
 
     if excludedpnts > 0:
-        showprocesslog(str(excludedpnts)+' point(s) excluded.')
+        showlog(str(excludedpnts)+' point(s) excluded.')
     # Choose only the closest coordinate per cell
     ijxyz = []
     for key in coords:
@@ -161,7 +157,7 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
             _, _, zval, b = coords[key][0]
             ijxyz.append([iint, jint, zval, b])
 
-    showprocesslog('Creating minimum curvature grid...')
+    showlog('Creating minimum curvature grid...')
     uold = np.zeros((rows, cols))
 
     # mean error per cell
@@ -192,13 +188,13 @@ def minc(x, y, z, dxy, showprocesslog=print, extent=None, bdist=None,
         errdiff1 = np.abs(u-uold)
         errstd = errdiff1.std()*2.5
         errdiff = np.sum(errdiff1)/(rows*cols)
-        showprocesslog(f'Solution Error: {errdiff:.5f}')
+        showlog(f'Solution Error: {errdiff:.5f}')
 
         if errdiff > errold:
             u = uold
-            showprocesslog('Solution diverging. Stopping...')
+            showlog('Solution diverging. Stopping...')
             break
-    showprocesslog('Finished!')
+    showlog('Finished!')
 
     u = np.ma.array(u)
 
@@ -390,7 +386,7 @@ def off_grid(u, i, j, wn, b):
         2D grid of z values.
     i : int
         Current row.
-    j : TYPE
+    j : int
         Current Column.
     wn : float
         Data value.
@@ -399,8 +395,8 @@ def off_grid(u, i, j, wn, b):
 
     Returns
     -------
-    uij : TYPE
-        DESCRIPTION.
+    uij : float
+        Output value.
 
     """
     ba, bb, bc, bd, be = b
@@ -637,22 +633,22 @@ def _testfn():
     import sys
     from PyQt5 import QtWidgets
     import matplotlib.pyplot as plt
-    from pygmi.vector.iodefs import ImportLineData
+    from pygmi.vector.iodefs import ImportXYZ
 
     app = QtWidgets.QApplication(sys.argv)
 
     ifile = r'c:\Workdata\vector\Line Data\MAGARCHIVE.XYZ'
 
-    IO = ImportLineData()
+    IO = ImportXYZ()
     IO.ifile = ifile
     IO.filt = 'Geosoft XYZ (*.xyz)'
     IO.settings(True)
 
-    dat = IO.outdata['Line']
+    dat = IO.outdata['Vector']
 
-    x = dat[ifile]['pygmiX'].to_numpy()
-    y = dat[ifile]['pygmiY'].to_numpy()
-    z = dat[ifile]['Column 8'].to_numpy()
+    x = dat.geometry.x.to_numpy()
+    y = dat.geometry.y.to_numpy()
+    z = dat['Column 8'].to_numpy()
 
     dxy = 125
 
@@ -669,6 +665,5 @@ def _testfn():
     plt.show()
 
 
-
 if __name__ == "__main__":
     _testfn()
